
#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 2015
 * transforms:
 *    ('imul', 'a', '#b(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b'))
 *    ('imul', 'a@8', 128) => ('ishl', 'a', 7)
 *    ('imul', 'a@16', 32768) => ('ishl', 'a', 15)
 *    ('imul', 'a@32', 2147483648) => ('ishl', 'a', 31)
 *    ('imul', 'a@64', 9223372036854775808) => ('ishl', 'a', 63)
 *    ('imul', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b'))))
 *    ('ishl', 'a', '#b') => ('imul', 'a', ('ishl', 1, 'b'))
 *    ('imul@64', 'a', '#b(is_bitcount2)') => ('iadd', ('ishl', 'a', ('ufind_msb', 'b')), ('ishl', 'a', ('find_lsb', 'b')))
 *    ('unpack_64_2x32_split_x', ('imul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b')
 *    ('unpack_64_2x32_split_x', ('umul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b')
 *    ('imul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('imul_high', 'a', 'b'))
 *    ('umul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('umul_high', 'a', 'b'))
 *    ('udiv', 'a', 1) => a
 *    ('idiv', 'a', 1) => a
 *    ('umod', 'a', 1) => 0
 *    ('imod', 'a', 1) => 0
 *    ('imod', 'a', -1) => 0
 *    ('irem', 'a', 1) => 0
 *    ('irem', 'a', -1) => 0
 *    ('udiv', 'a', '#b(is_pos_power_of_two)') => ('ushr', 'a', ('find_lsb', 'b'))
 *    ('idiv', 'a', '#b(is_pos_power_of_two)') => ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', 'b')))
 *    ('idiv', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', ('iabs', 'b')))))
 *    ('umod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1))
 *    ('imod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1))
 *    ('imod', 'a', '#b(is_neg_power_of_two)') => ('bcsel', ('ieq', ('ior', 'a', 'b'), 'b'), 0, ('ior', 'a', 'b'))
 *    ('irem', 'a', '#b(is_pos_power_of_two)') => ('isub', 'a', ('iand', ('bcsel', ('ilt', 'a', 0), ('iadd', 'a', ('isub', 'b', 1)), 'a'), ('ineg', 'b')))
 *    ('irem', 'a', '#b(is_neg_power_of_two)') => ('irem', 'a', ('iabs', 'b'))
 *    ('~fneg', ('fneg', 'a')) => a
 *    ('ineg', ('ineg', 'a')) => a
 *    ('fabs', ('fneg', 'a')) => ('fabs', 'a')
 *    ('fabs', ('u2f', 'a')) => ('u2f', 'a')
 *    ('iabs', ('iabs', 'a')) => ('iabs', 'a')
 *    ('iabs', ('ineg', 'a')) => ('iabs', 'a')
 *    ('f2b', ('fneg', 'a')) => ('f2b', 'a')
 *    ('i2b', ('ineg', 'a')) => ('i2b', 'a')
 *    ('~fadd', 'a', 0.0) => a
 *    ('fadd(is_only_used_as_float)', 'a@16', 0.0) => a
 *    ('fadd(is_only_used_as_float)', 'a@32', 0.0) => a
 *    ('iadd', 'a', 0) => a
 *    ('iadd_sat', 'a', 0) => a
 *    ('isub_sat', 'a', 0) => a
 *    ('uadd_sat', 'a', 0) => a
 *    ('usub_sat', 'a', 0) => a
 *    ('usadd_4x8_vc4', 'a', 0) => a
 *    ('usadd_4x8_vc4', 'a', -1) => -1
 *    ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmulz', 'a', 'b'), ('fmulz', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c'))
 *    ('~ffma', 'a', 'b', ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffma', 'a', 'b', ('fmul(is_used_once)', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmul(is_used_once)', 'a', 'b'), ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffma', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('ffma', 'a', 'c', 'd'))
 *    ('~ffmaz', 'a', 'b', ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffmaz', 'a', 'b', ('fmulz(is_used_once)', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmulz(is_used_once)', 'a', 'b'), ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffmaz', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('ffmaz', 'a', 'c', 'd'))
 *    ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c'))
 *    ('iadd', ('ishl', 'b', 'a'), ('ishl', 'c', 'a')) => ('ishl', ('iadd', 'b', 'c'), 'a')
 *    ('iand', ('ior', 'a', 'b'), ('ior', 'a', 'c')) => ('ior', 'a', ('iand', 'b', 'c'))
 *    ('ior', ('iand', 'a', 'b'), ('iand', 'a', 'c')) => ('iand', 'a', ('ior', 'b', 'c'))
 *    ('ieq', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('ine', ('iand', 'a', 'b'), 0)
 *    ('ine', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('ieq', ('iand', 'a', 'b'), 0)
 *    ('~fadd', ('fneg', 'a'), 'a') => 0.0
 *    ('iadd', ('ineg', 'a'), 'a') => 0
 *    ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b
 *    ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b
 *    ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b
 *    ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b
 *    ('fadd', ('fsat', 'a'), ('fsat', ('fneg', 'a'))) => ('fsat', ('fabs', 'a'))
 *    ('~fmul', 'a', 0.0) => 0.0
 *    ('fmul', 'a@16', 0.0) => 0.0
 *    ('fmul', 'a@32', 0.0) => 0.0
 *    ('fmulz', 'a', 0.0) => 0.0
 *    ('fmulz', 'a', 'b(is_finite_not_zero)') => ('fmul', 'a', 'b')
 *    ('fmulz', 'a(is_finite)', 'b(is_finite)') => ('fmul', 'a', 'b')
 *    ('fmulz', 'a', 'a') => ('fmul', 'a', 'a')
 *    ('ffmaz', 'a', 'b(is_finite_not_zero)', 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', 'a(is_finite)', 'b(is_finite)', 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', 'a', 'a', 'b') => ('ffma', 'a', 'a', 'b')
 *    ('imul', 'a', 0) => 0
 *    ('umul_unorm_4x8_vc4', 'a', 0) => 0
 *    ('umul_unorm_4x8_vc4', 'a', -1) => a
 *    ('~fmul', 'a', 1.0) => a
 *    ('~fmulz', 'a', 1.0) => a
 *    ('fmul(is_only_used_as_float)', 'a', 1.0) => a
 *    ('imul', 'a', 1) => a
 *    ('fmul', 'a', -1.0) => ('fneg', 'a')
 *    ('imul', 'a', -1) => ('ineg', 'a')
 *    ('fmul', ('fsign', 'a'), ('fmul', 'a', 'a')) => ('fmul', ('fabs', 'a'), 'a')
 *    ('fmul', ('fmul', ('fsign', 'a'), 'a'), 'a') => ('fmul', ('fabs', 'a'), 'a')
 *    ('~ffma', 0.0, 'a', 'b') => b
 *    ('ffma@16(is_only_used_as_float)', 0.0, 'a', 'b') => b
 *    ('ffma@32(is_only_used_as_float)', 0.0, 'a', 'b') => b
 *    ('ffmaz', 0.0, 'a', 'b') => ('fadd', 0.0, 'b')
 *    ('~ffma', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffma@16', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffma@32', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffmaz', 'a', 'b', 0.0) => ('fmulz', 'a', 'b')
 *    ('ffma', 1.0, 'a', 'b') => ('fadd', 'a', 'b')
 *    ('ffmaz', 1.0, 'a', 'b') => ('fadd', 'a', 'b')
 *    ('ffma', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b')
 *    ('ffmaz', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b')
 *    ('~ffma', '#a', '#b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffmaz', '#a', '#b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~flrp', 'a', 'b', 0.0) => a
 *    ('~flrp', 'a', 'b', 1.0) => b
 *    ('~flrp', 'a', 'a', 'b') => a
 *    ('~flrp', 0.0, 'a', 'b') => ('fmul', 'a', 'b')
 *    ('~flrp', 'a', ('fadd(is_used_once)', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('sdot_4x8_iadd', 'a', 0, 'b') => b
 *    ('udot_4x8_uadd', 'a', 0, 'b') => b
 *    ('sdot_4x8_iadd_sat', 'a', 0, 'b') => b
 *    ('udot_4x8_uadd_sat', 'a', 0, 'b') => b
 *    ('sdot_2x16_iadd', 'a', 0, 'b') => b
 *    ('udot_2x16_uadd', 'a', 0, 'b') => b
 *    ('sdot_2x16_iadd_sat', 'a', 0, 'b') => b
 *    ('udot_2x16_uadd_sat', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd', 0, 'a', 'b') => b
 *    ('sudot_4x8_iadd_sat', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd_sat', 0, 'a', 'b') => b
 *    ('iadd', ('sdot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('udot_4x8_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_4x8_uadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sudot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sudot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sdot_2x16_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_2x16_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('udot_2x16_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_2x16_uadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sdot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('udot_4x8_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_4x8_uadd', 'a', 'b', 'c')
 *    ('iadd', ('sudot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('sudot_4x8_iadd', 'a', 'b(is_not_const)', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('sdot_2x16_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_2x16_iadd', 'a', 'b', 'c')
 *    ('iadd', ('udot_2x16_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_2x16_uadd', 'a', 'b', 'c')
 *    ('sdot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('udot_4x8_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_4x8_uadd', 'a', 'b', 0), 'c')
 *    ('sudot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sudot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('sdot_2x16_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_2x16_iadd', 'a', 'b', 0), 'c')
 *    ('udot_2x16_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_2x16_uadd', 'a', 'b', 0), 'c')
 *    ('sdot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('udot_4x8_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_4x8_uadd', 'a', 'b', 0), 'c')
 *    ('sudot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sudot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('sdot_2x16_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_2x16_iadd', 'a', 'b', 0), 'c')
 *    ('udot_2x16_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_2x16_uadd', 'a', 'b', 0), 'c')
 *    ('fmul@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', 'a', 'b')
 *    ('fmul@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', 'a', 'b')
 *    ('ffma@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('ffma@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 1.0, ('fexp2', ('fmul@32', 'a', 'b'))) => ('fexp2', ('fmulz', 'a', 'b'))
 *    ('sdot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c')
 *    ('udot_4x8_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sudot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sdot_2x16_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c')
 *    ('udot_2x16_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c')
 *    ('udot_4x8_uadd_sat', 'a', 'b', '#c(is_ult_0xfffc07fc)') => ('udot_4x8_uadd', 'a', 'b', 'c')
 *    ('udot_4x8_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sdot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c')
 *    ('sudot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('udot_2x16_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c')
 *    ('sdot_2x16_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c')
 *    ('~flrp@16', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@16', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@16', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@16', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@16', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@16', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@16', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@16', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp@32', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@32', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@32', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@32', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@32', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@32', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@32', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp@64', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@64', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@64', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@64', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@64', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@64', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@64', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp', ('fmul(is_used_once)', 'a', 'b'), ('fmul(is_used_once)', 'a', 'c'), 'd') => ('fmul', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp', 'a', 0.0, 'c') => ('fadd', ('fmul', ('fneg', 'a'), 'c'), 'a')
 *    ('ftrunc@16', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a')))
 *    ('ftrunc@32', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a')))
 *    ('ftrunc@64', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a')))
 *    ('ffloor@16', 'a') => ('fsub', 'a', ('ffract', 'a'))
 *    ('ffloor@32', 'a') => ('fsub', 'a', ('ffract', 'a'))
 *    ('ffloor@64', 'a') => ('fsub', 'a', ('ffract', 'a'))
 *    ('fadd@16', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a')
 *    ('fadd@32', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a')
 *    ('fadd@64', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a')
 *    ('ffract@16', 'a') => ('fsub', 'a', ('ffloor', 'a'))
 *    ('ffract@32', 'a') => ('fsub', 'a', ('ffloor', 'a'))
 *    ('ffract@64', 'a') => ('fsub', 'a', ('ffloor', 'a'))
 *    ('fceil', 'a') => ('fneg', ('ffloor', ('fneg', 'a')))
 *    ('ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~fmul', ('fadd', ('iand', ('ineg', ('b2i', 'a@bool')), ('fmul', 'b', 'c')), '#d'), '#e') => ('bcsel', 'a', ('fmul', ('fadd', ('fmul', 'b', 'c'), 'd'), 'e'), ('fmul', 'd', 'e'))
 *    ('fdph', 'a', 'b') => ('fdot4', ('vec4', 'a.x', 'a.y', 'a.z', 1.0), 'b')
 *    ('fdot4', ('vec4', 'a', 'b', 'c', 1.0), 'd') => ('fdph', ('vec3', 'a', 'b', 'c'), 'd')
 *    ('fdot4', ('vec4', 'a', 0.0, 0.0, 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot4', ('vec4', 'a', 'b', 0.0, 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c')
 *    ('fdot4', ('vec4', 'a', 'b', 'c', 0.0), 'd') => ('fdot3', ('vec3', 'a', 'b', 'c'), 'd')
 *    ('fdot3', ('vec3', 'a', 0.0, 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot3', ('vec3', 'a', 'b', 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c')
 *    ('fdot2', ('vec2', 'a', 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot2', 'a', 1.0) => ('fadd', 'a.x', 'a.y')
 *    ('fdot2', 'a', 'b') => ('fsum2', ('fmul', 'a', 'b'))
 *    ('fdot3', 'a', 'b') => ('fsum3', ('fmul', 'a', 'b'))
 *    ('fdot4', 'a', 'b') => ('fsum4', ('fmul', 'a', 'b'))
 *    ('fsum2', 'a') => ('fadd', 'a.x', 'a.y')
 *    ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a')))
 *    ('ishl', ('iadd', ('imul', 'a', '#b'), '#c'), '#d') => ('iadd', ('imul', 'a', ('ishl', 'b', 'd')), ('ishl', 'c', 'd'))
 *    ('ishl', ('imul', 'a', '#b'), '#c') => ('imul', 'a', ('ishl', 'b', 'c'))
 *    ('ishl@8', ('ishl@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ishl@8', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@8', ('ushr@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ushr@8', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@8', ('ishr@8', 'a', '#b'), '#c') => ('ishr@8', 'a', ('imin', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 7))
 *    ('ishl@16', ('ishl@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ishl@16', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@16', ('ushr@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ushr@16', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@16', ('ishr@16', 'a', '#b'), '#c') => ('ishr@16', 'a', ('imin', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 15))
 *    ('ishl@32', ('ishl@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ishl@32', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@32', ('ushr@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ushr@32', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@32', ('ishr@32', 'a', '#b'), '#c') => ('ishr@32', 'a', ('imin', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 31))
 *    ('ishl@64', ('ishl@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ishl@64', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@64', ('ushr@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ushr@64', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@64', ('ishr@64', 'a', '#b'), '#c') => ('ishr@64', 'a', ('imin', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 63))
 *    ('ishl', ('ushr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b'))
 *    ('ishl', ('ishr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b'))
 *    ('ushr', ('ishl', 'a@8', '#b'), 'b') => ('iand', 'a', ('ushr', 255, 'b'))
 *    ('ishl', ('ushr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b'))
 *    ('ishl', ('ishr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b'))
 *    ('ushr', ('ishl', 'a@16', '#b'), 'b') => ('iand', 'a', ('ushr', 65535, 'b'))
 *    ('ishl', ('ushr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b'))
 *    ('ishl', ('ishr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b'))
 *    ('ushr', ('ishl', 'a@32', '#b'), 'b') => ('iand', 'a', ('ushr', 4294967295, 'b'))
 *    ('ishl', ('ushr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b'))
 *    ('ishl', ('ishr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b'))
 *    ('ushr', ('ishl', 'a@64', '#b'), 'b') => ('iand', 'a', ('ushr', 18446744073709551615, 'b'))
 *    ('iand', ('ishl', 'a@32', '#b(is_first_5_bits_uge_2)'), -4) => ('ishl', 'a', 'b')
 *    ('iand', ('imul', 'a', '#b(is_unsigned_multiple_of_4)'), -4) => ('imul', 'a', 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_2)'), 4294967294) => ('iadd', ('iand', 'a', 4294967294), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_4)'), 4294967292) => ('iadd', ('iand', 'a', 4294967292), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_8)'), 4294967288) => ('iadd', ('iand', 'a', 4294967288), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_16)'), 4294967280) => ('iadd', ('iand', 'a', 4294967280), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_32)'), 4294967264) => ('iadd', ('iand', 'a', 4294967264), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_64)'), 4294967232) => ('iadd', ('iand', 'a', 4294967232), 'b')
 *    ('ishl@32', ('iand', 'a@32', 2147483647), 1) => ('ishl', 'a', 1)
 *    ('iand', ('ishl', 'a@32', 1), 4294967294) => ('ishl', 'a', 1)
 *    ('iand', ('ushr', 'a@32', 1), 2147483647) => ('ushr', 'a', 1)
 *    ('ishl@32', ('iand', 'a@32', 1073741823), 2) => ('ishl', 'a', 2)
 *    ('iand', ('ishl', 'a@32', 2), 4294967292) => ('ishl', 'a', 2)
 *    ('iand', ('ushr', 'a@32', 2), 1073741823) => ('ushr', 'a', 2)
 *    ('ishl@32', ('iand', 'a@32', 65535), 16) => ('ishl', 'a', 16)
 *    ('iand', ('ishl', 'a@32', 16), 4294901760) => ('ishl', 'a', 16)
 *    ('iand', ('ushr', 'a@32', 16), 65535) => ('ushr', 'a', 16)
 *    ('ishl@32', ('iand', 'a@32', 255), 24) => ('ishl', 'a', 24)
 *    ('iand', ('ishl', 'a@32', 24), 4278190080) => ('ishl', 'a', 24)
 *    ('iand', ('ushr', 'a@32', 24), 255) => ('ushr', 'a', 24)
 *    ('ishl', ('iadd', 'a', '#b'), '#c') => ('iadd', ('ishl', 'a', 'c'), ('ishl', 'b', 'c'))
 *    ('imul', ('iadd(is_used_once)', 'a', '#b'), '#c') => ('iadd', ('imul', 'a', 'c'), ('imul', 'b', 'c'))
 *    ('imul', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('imul', ('iadd', 'a', 'c'), 'd'), ('imul', 'b', 'd'))
 *    ('ishl', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('ishl', ('iadd', 'a', 'c'), 'd'), ('ishl', 'b', 'd'))
 *    ('inot', ('flt(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('fge', 'a', 'b')
 *    ('inot', ('fge(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('flt', 'a', 'b')
 *    ('inot', ('feq(is_used_once)', 'a', 'b')) => ('fneu', 'a', 'b')
 *    ('inot', ('fneu(is_used_once)', 'a', 'b')) => ('feq', 'a', 'b')
 *    ('inot', ('ilt(is_used_once)', 'a', 'b')) => ('ige', 'a', 'b')
 *    ('inot', ('ult(is_used_once)', 'a', 'b')) => ('uge', 'a', 'b')
 *    ('inot', ('ige(is_used_once)', 'a', 'b')) => ('ilt', 'a', 'b')
 *    ('inot', ('uge(is_used_once)', 'a', 'b')) => ('ult', 'a', 'b')
 *    ('inot', ('ieq(is_used_once)', 'a', 'b')) => ('ine', 'a', 'b')
 *    ('inot', ('ine(is_used_once)', 'a', 'b')) => ('ieq', 'a', 'b')
 *    ('iand', ('feq', 'a', 'b'), ('fneu', 'a', 'b')) => False
 *    ('iand', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => False
 *    ('iand', ('ieq', 'a', 'b'), ('ine', 'a', 'b')) => False
 *    ('iand', ('ilt', 'a', 'b'), ('ilt', 'b', 'a')) => False
 *    ('iand', ('ult', 'a', 'b'), ('ult', 'b', 'a')) => False
 *    ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a')
 *    ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a')
 *    ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a')
 *    ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a')
 *    ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a')
 *    ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0)
 *    ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a')
 *    ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0)
 *    ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a')
 *    ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0)
 *    ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a')
 *    ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b')
 *    ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b')
 *    ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b')
 *    ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0)
 *    ('flt', 0.0, ('fsat(is_used_once)', 'a')) => ('flt', 0.0, 'a')
 *    ('fge', 0.0, ('b2f', 'a@1')) => ('inot', 'a')
 *    ('fge', ('fneg', ('b2f', 'a@1')), 0.0) => ('inot', 'a')
 *    ('fneu', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fneu', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fneu', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('ior', 'a', 'b')
 *    ('fneu', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('iand', 'a', 'b')
 *    ('fneu', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('iand', 'a', 'b')
 *    ('fneu', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ixor', 'a', 'b')
 *    ('fneu', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ixor', 'a', 'b')
 *    ('fneu', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ixor', 'a', 'b')
 *    ('feq', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ieq', 'a', 'b')
 *    ('feq', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ieq', 'a', 'b')
 *    ('feq', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ieq', 'a', 'b')
 *    ('flt', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('ior', 'a', 'b')
 *    ('flt', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('ior', 'a', 'b')
 *    ('fge', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('fge', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b'))
 *    ('flt', 'a', ('fneg', 'a')) => ('flt', 'a', 0.0)
 *    ('fge', 'a', ('fneg', 'a')) => ('fge', 'a', 0.0)
 *    ('flt', ('fmin', 'c', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')))), 0.0) => ('ior', ('flt', 'c', 0.0), ('ior', 'a', 'b'))
 *    ('~flt', ('fadd', 'a', 'b'), 'a') => ('flt', 'b', 0.0)
 *    ('~fge', ('fadd', 'a', 'b'), 'a') => ('fge', 'b', 0.0)
 *    ('~feq', ('fadd', 'a', 'b'), 'a') => ('feq', 'b', 0.0)
 *    ('~fneu', ('fadd', 'a', 'b'), 'a') => ('fneu', 'b', 0.0)
 *    ('~flt', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('flt', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('flt', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~fge', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fge', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fge', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~feq', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('feq', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~feq', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('feq', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~fneu', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fneu', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~fneu', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fneu', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('ieq', ('iadd', 'a', 'b'), 'a') => ('ieq', 'b', 0)
 *    ('ine', ('iadd', 'a', 'b'), 'a') => ('ine', 'b', 0)
 *    ('feq', ('b2f', 'a@1'), 0.0) => ('inot', 'a')
 *    ('fneu', ('b2f', 'a@1'), 0.0) => a
 *    ('ieq', ('b2i', 'a@1'), 0) => ('inot', 'a')
 *    ('ine', ('b2i', 'a@1'), 0) => a
 *    ('fneu', ('u2f', 'a'), 0.0) => ('ine', 'a', 0)
 *    ('feq', ('u2f', 'a'), 0.0) => ('ieq', 'a', 0)
 *    ('fge', ('u2f', 'a'), 0.0) => True
 *    ('fge', 0.0, ('u2f', 'a')) => ('uge', 0, 'a')
 *    ('flt', ('u2f', 'a'), 0.0) => False
 *    ('flt', 0.0, ('u2f', 'a')) => ('ult', 0, 'a')
 *    ('fneu', ('i2f', 'a'), 0.0) => ('ine', 'a', 0)
 *    ('feq', ('i2f', 'a'), 0.0) => ('ieq', 'a', 0)
 *    ('fge', ('i2f', 'a'), 0.0) => ('ige', 'a', 0)
 *    ('fge', 0.0, ('i2f', 'a')) => ('ige', 0, 'a')
 *    ('flt', ('i2f', 'a'), 0.0) => ('ilt', 'a', 0)
 *    ('flt', 0.0, ('i2f', 'a')) => ('ilt', 0, 'a')
 *    ('~flt', 0.0, ('fabs', 'a')) => ('fneu', 'a', 0.0)
 *    ('~flt', ('fneg', ('fabs', 'a')), 0.0) => ('fneu', 'a', 0.0)
 *    ('fge', 0.0, ('fabs', 'a')) => ('feq', 'a', 0.0)
 *    ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0)
 *    ('iand', ('fge', 'a', 0.0), ('fge', 1.0, 'a')) => ('feq', 'a', ('fsat', 'a'))
 *    ('fmax', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('ior', 'a', 'b'))
 *    ('fmax', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('iand', 'a', 'b')))
 *    ('fmin', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b'))
 *    ('fmin', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('ior', 'a', 'b')))
 *    ('fmin', ('b2f', 'a@1'), '#b') => ('bcsel', 'a', ('fmin', 'b', 1.0), ('fmin', 'b', 0.0))
 *    ('flt', ('fadd(is_used_once)', 'a', ('fneg', 'b')), 0.0) => ('flt', 'a', 'b')
 *    ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0)
 *    ('~bcsel', ('flt', 'b', 'a'), 'b', 'a') => ('fmin', 'a', 'b')
 *    ('~bcsel', ('flt', 'a', 'b'), 'b', 'a') => ('fmax', 'a', 'b')
 *    ('~bcsel', ('fge', 'a', 'b'), 'b', 'a') => ('fmin', 'a', 'b')
 *    ('~bcsel', ('fge', 'b', 'a'), 'b', 'a') => ('fmax', 'a', 'b')
 *    ('bcsel', ('ult', 'b', 'a'), 'b', 'a') => ('umin', 'a', 'b')
 *    ('bcsel', ('ult', 'a', 'b'), 'b', 'a') => ('umax', 'a', 'b')
 *    ('bcsel', ('uge', 'a', 'b'), 'b', 'a') => ('umin', 'a', 'b')
 *    ('bcsel', ('uge', 'b', 'a'), 'b', 'a') => ('umax', 'a', 'b')
 *    ('bcsel', ('ilt', 'b', 'a'), 'b', 'a') => ('imin', 'a', 'b')
 *    ('bcsel', ('ilt', 'a', 'b'), 'b', 'a') => ('imax', 'a', 'b')
 *    ('bcsel', ('ige', 'a', 'b'), 'b', 'a') => ('imin', 'a', 'b')
 *    ('bcsel', ('ige', 'b', 'a'), 'b', 'a') => ('imax', 'a', 'b')
 *    ('bcsel', ('i2b', 'a'), 'b', 'c') => ('bcsel', ('ine', 'a', 0), 'b', 'c')
 *    ('bcsel', ('inot', 'a'), 'b', 'c') => ('bcsel', 'a', 'c', 'b')
 *    ('bcsel', 'a', ('bcsel', 'a', 'b', 'c'), 'd') => ('bcsel', 'a', 'b', 'd')
 *    ('bcsel', 'a', 'b', ('bcsel', 'a', 'c', 'd')) => ('bcsel', 'a', 'b', 'd')
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', True, 'b') => ('ior', 'a', 'b')
 *    ('bcsel', 'a', 'a', 'b') => ('ior', 'a', 'b')
 *    ('bcsel', 'a', 'b', False) => ('iand', 'a', 'b')
 *    ('bcsel', 'a', 'b', 'a') => ('iand', 'a', 'b')
 *    ('~fmin', 'a', 'a') => a
 *    ('~fmax', 'a', 'a') => a
 *    ('imin', 'a', 'a') => a
 *    ('imax', 'a', 'a') => a
 *    ('umin', 'a', 'a') => a
 *    ('umin', 'a', 0) => 0
 *    ('umin', 'a', -1) => a
 *    ('umax', 'a', 'a') => a
 *    ('umax', 'a', 0) => a
 *    ('umax', 'a', -1) => -1
 *    ('fmax', ('fmax', 'a', 'b'), 'b') => ('fmax', 'a', 'b')
 *    ('umax', ('umax', 'a', 'b'), 'b') => ('umax', 'a', 'b')
 *    ('imax', ('imax', 'a', 'b'), 'b') => ('imax', 'a', 'b')
 *    ('fmin', ('fmin', 'a', 'b'), 'b') => ('fmin', 'a', 'b')
 *    ('umin', ('umin', 'a', 'b'), 'b') => ('umin', 'a', 'b')
 *    ('imin', ('imin', 'a', 'b'), 'b') => ('imin', 'a', 'b')
 *    ('fmax', ('fmax', ('fmax', 'a', 'b'), 'c'), 'a') => ('fmax', ('fmax', 'a', 'b'), 'c')
 *    ('umax', ('umax', ('umax', 'a', 'b'), 'c'), 'a') => ('umax', ('umax', 'a', 'b'), 'c')
 *    ('imax', ('imax', ('imax', 'a', 'b'), 'c'), 'a') => ('imax', ('imax', 'a', 'b'), 'c')
 *    ('fmin', ('fmin', ('fmin', 'a', 'b'), 'c'), 'a') => ('fmin', ('fmin', 'a', 'b'), 'c')
 *    ('umin', ('umin', ('umin', 'a', 'b'), 'c'), 'a') => ('umin', ('umin', 'a', 'b'), 'c')
 *    ('imin', ('imin', ('imin', 'a', 'b'), 'c'), 'a') => ('imin', ('imin', 'a', 'b'), 'c')
 *    ('ieq', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ine', 'a', 'b')
 *    ('iand@8', 'a', ('inot', ('ishr', 'a', 7))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@8', 128), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@8', 128), 128) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@8', 128), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@8', 128), 128) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@8', 7), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@8', 7), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@8', 7), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@8', 7), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@8', 7), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@8', 7), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@8', 7), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@8', 7), -1) => ('ige', 'a', 0)
 *    ('iand@16', 'a', ('inot', ('ishr', 'a', 15))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@16', 32768), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@16', 32768), 32768) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@16', 32768), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@16', 32768), 32768) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@16', 15), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@16', 15), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@16', 15), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@16', 15), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@16', 15), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@16', 15), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@16', 15), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@16', 15), -1) => ('ige', 'a', 0)
 *    ('iand@32', 'a', ('inot', ('ishr', 'a', 31))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@32', 2147483648), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@32', 2147483648), 2147483648) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@32', 2147483648), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@32', 2147483648), 2147483648) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@32', 31), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@32', 31), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@32', 31), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@32', 31), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@32', 31), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@32', 31), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@32', 31), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@32', 31), -1) => ('ige', 'a', 0)
 *    ('iand@64', 'a', ('inot', ('ishr', 'a', 63))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@64', 9223372036854775808), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@64', 9223372036854775808), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@64', 63), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@64', 63), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@64', 63), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@64', 63), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@64', 63), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@64', 63), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@64', 63), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@64', 63), -1) => ('ige', 'a', 0)
 *    ('fmin', 'a', ('fneg', 'a')) => ('fneg', ('fabs', 'a'))
 *    ('imin', 'a', ('ineg', 'a')) => ('ineg', ('iabs', 'a'))
 *    ('fmin', 'a', ('fneg', ('fabs', 'a'))) => ('fneg', ('fabs', 'a'))
 *    ('imin', 'a', ('ineg', ('iabs', 'a'))) => ('ineg', ('iabs', 'a'))
 *    ('~fmin', 'a', ('fabs', 'a')) => a
 *    ('imin', 'a', ('iabs', 'a')) => a
 *    ('~fmax', 'a', ('fneg', ('fabs', 'a'))) => a
 *    ('imax', 'a', ('ineg', ('iabs', 'a'))) => a
 *    ('fmax', 'a', ('fabs', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('iabs', 'a')) => ('iabs', 'a')
 *    ('fmax', 'a', ('fneg', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('ineg', 'a')) => ('iabs', 'a')
 *    ('~fmax', ('fabs', 'a'), 0.0) => ('fabs', 'a')
 *    ('fmin', ('fmax', 'a', 0.0), 1.0) => ('fsat', 'a')
 *    ('~fmax', ('fmin', 'a', 1.0), 0.0) => ('fsat', 'a')
 *    ('~fmin', ('fmax', 'a', -1.0), 0.0) => ('fneg', ('fsat', ('fneg', 'a')))
 *    ('~fmax', ('fmin', 'a', 0.0), -1.0) => ('fneg', ('fsat', ('fneg', 'a')))
 *    ('fsat', ('fsign', 'a')) => ('b2f', ('!flt', 0.0, 'a'))
 *    ('fsat', ('b2f', 'a')) => ('b2f', 'a')
 *    ('fsat', 'a') => ('fmin', ('fmax', 'a', 0.0), 1.0)
 *    ('fsat', ('fsat', 'a')) => ('fsat', 'a')
 *    ('fsat', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fsat', ('fadd', ('fneg', 'a'), ('fneg', 'b')))
 *    ('fsat', ('fneg(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fneg', 'a'), 'b'))
 *    ('fsat', ('fneg(is_used_once)', ('fmulz(is_used_once)', 'a', 'b'))) => ('fsat', ('fmulz', ('fneg', 'a'), 'b'))
 *    ('fsat', ('fabs(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fabs', 'a'), ('fabs', 'b')))
 *    ('fmin', ('fmax', ('fmin', ('fmax', 'a', 'b'), 'c'), 'b'), 'c') => ('fmin', ('fmax', 'a', 'b'), 'c')
 *    ('imin', ('imax', ('imin', ('imax', 'a', 'b'), 'c'), 'b'), 'c') => ('imin', ('imax', 'a', 'b'), 'c')
 *    ('umin', ('umax', ('umin', ('umax', 'a', 'b'), 'c'), 'b'), 'c') => ('umin', ('umax', 'a', 'b'), 'c')
 *    ('fmax', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmax', 'a', 'b'))
 *    ('~fmin', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmin', 'a', 'b'))
 *    ('fmax', ('fneg', ('fmin', 'b', 'a')), 'b') => ('fmax', ('fabs', 'b'), ('fneg', 'a'))
 *    ('fmin', ('fneg', ('fmax', 'b', 'a')), 'b') => ('fmin', ('fneg', ('fabs', 'b')), ('fneg', 'a'))
 *    ('fmax', ('fadd(is_used_once)', ('fneg', 'a(is_not_negative)'), '#b(is_zero_to_one)'), 0.0) => ('fsat', ('fadd', ('fneg', 'a'), 'b'))
 *    ('extract_u8', ('imin', ('imax', 'a', 0), 255), 0) => ('imin', ('imax', 'a', 0), 255)
 *    ('ior', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('!fmax', 'b', 'c'))
 *    ('ior', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c')
 *    ('ior', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('!fmin', 'b', 'c'))
 *    ('ior', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c')
 *    ('ior', ('flt', 'a', '#b'), ('flt', 'a', '#c')) => ('flt', 'a', ('!fmax', 'b', 'c'))
 *    ('ior', ('flt', '#a', 'c'), ('flt', '#b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c')
 *    ('ior', ('fge', 'a', '#b'), ('fge', 'a', '#c')) => ('fge', 'a', ('!fmin', 'b', 'c'))
 *    ('ior', ('fge', '#a', 'c'), ('fge', '#b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c')
 *    ('~iand', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('fmin', 'b', 'c'))
 *    ('~iand', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c')
 *    ('~iand', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('fmax', 'b', 'c'))
 *    ('~iand', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c')
 *    ('iand', ('flt', 'a', '#b(is_a_number)'), ('flt', 'a', '#c(is_a_number)')) => ('flt', 'a', ('fmin', 'b', 'c'))
 *    ('iand', ('flt', '#a(is_a_number)', 'c'), ('flt', '#b(is_a_number)', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c')
 *    ('iand', ('fge', 'a', '#b(is_a_number)'), ('fge', 'a', '#c(is_a_number)')) => ('fge', 'a', ('fmax', 'b', 'c'))
 *    ('iand', ('fge', '#a(is_a_number)', 'c'), ('fge', '#b(is_a_number)', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c')
 *    ('ior', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imax', 'b', 'c'))
 *    ('ior', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imin', 'a', 'b'), 'c')
 *    ('ior', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imin', 'b', 'c'))
 *    ('ior', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imax', 'a', 'b'), 'c')
 *    ('ior', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umax', 'b', 'c'))
 *    ('ior', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umin', 'a', 'b'), 'c')
 *    ('ior', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umin', 'b', 'c'))
 *    ('ior', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umax', 'a', 'b'), 'c')
 *    ('iand', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imin', 'b', 'c'))
 *    ('iand', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imax', 'a', 'b'), 'c')
 *    ('iand', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imax', 'b', 'c'))
 *    ('iand', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imin', 'a', 'b'), 'c')
 *    ('iand', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umin', 'b', 'c'))
 *    ('iand', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umax', 'a', 'b'), 'c')
 *    ('iand', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umax', 'b', 'c'))
 *    ('iand', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umin', 'a', 'b'), 'c')
 *    ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'c'), 'd'), ('flt', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt', 'a', 'c'), 'd'), ('flt(is_used_once)', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'b'), 'd'), ('flt', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt', 'a', 'b'), 'd'), ('flt(is_used_once)', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd')
 *    ('ior', ('flt', 'a(is_a_number)', 'b(is_a_number)'), ('flt', 'b', 'a')) => ('fneu', 'a', 'b')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@16', ('feq', 'a', 0.0), 1.0, ('i2f16', ('iadd', ('b2i16', ('flt', 0.0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0.0)))))) => ('i2f16', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@16'), ('b2f', 'c@16')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f16', ('f2i', 'a@16')) => ('ftrunc', 'a')
 *    ('~f2i16', ('i2f', 'a@16')) => a
 *    ('~f2i16', ('u2f', 'a@16')) => a
 *    ('~f2u16', ('i2f', 'a@16')) => a
 *    ('~f2u16', ('u2f', 'a@16')) => a
 *    ('fadd', ('b2f16', ('flt', 0.0, 'a@16')), ('fneg', ('b2f16', ('flt', 'a@16', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i16', ('flt', 0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0)))) => ('f2i16', ('fsign', 'a'))
 *    ('f2f16', ('f2f32', 'a@16')) => a
 *    ('i2i16', ('i2i32', 'a@16')) => a
 *    ('u2u16', ('u2u32', 'a@16')) => a
 *    ('f2f16', ('b2f32', 'a@1')) => ('b2f16', 'a')
 *    ('i2i16', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('u2u16', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('f2u32', ('f2f32', 'a@16')) => ('f2u32', 'a')
 *    ('f2i32', ('f2f32', 'a@16')) => ('f2i32', 'a')
 *    ('f2f16', ('u2f32', 'a')) => ('u2f16', 'a')
 *    ('f2f16', ('i2f32', 'a')) => ('i2f16', 'a')
 *    ('u2f32', ('u2u32', 'a@16')) => ('u2f32', 'a')
 *    ('i2f32', ('i2i32', 'a@16')) => ('i2f32', 'a')
 *    ('f2f16', ('f2f64', 'a@16')) => a
 *    ('i2i16', ('i2i64', 'a@16')) => a
 *    ('u2u16', ('u2u64', 'a@16')) => a
 *    ('f2f16', ('b2f64', 'a@1')) => ('b2f16', 'a')
 *    ('i2i16', ('b2i64', 'a@1')) => ('b2i16', 'a')
 *    ('u2u16', ('b2i64', 'a@1')) => ('b2i16', 'a')
 *    ('f2u64', ('f2f64', 'a@16')) => ('f2u64', 'a')
 *    ('f2i64', ('f2f64', 'a@16')) => ('f2i64', 'a')
 *    ('f2f16', ('u2f64', 'a')) => ('u2f16', 'a')
 *    ('f2f16', ('i2f64', 'a')) => ('i2f16', 'a')
 *    ('u2f64', ('u2u64', 'a@16')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i64', 'a@16')) => ('i2f64', 'a')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@32', ('feq', 'a', 0.0), 1.0, ('i2f32', ('iadd', ('b2i32', ('flt', 0.0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0.0)))))) => ('i2f32', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@32'), ('b2f', 'c@32')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f32', ('f2i', 'a@32')) => ('ftrunc', 'a')
 *    ('~f2i32', ('i2f', 'a@32')) => a
 *    ('~f2i32', ('u2f', 'a@32')) => a
 *    ('~f2u32', ('i2f', 'a@32')) => a
 *    ('~f2u32', ('u2f', 'a@32')) => a
 *    ('fadd', ('b2f32', ('flt', 0.0, 'a@32')), ('fneg', ('b2f32', ('flt', 'a@32', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i32', ('flt', 0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0)))) => ('f2i32', ('fsign', 'a'))
 *    ('f2f32', ('f2f64', 'a@32')) => a
 *    ('i2i32', ('i2i64', 'a@32')) => a
 *    ('u2u32', ('u2u64', 'a@32')) => a
 *    ('f2f32', ('b2f64', 'a@1')) => ('b2f32', 'a')
 *    ('i2i32', ('b2i64', 'a@1')) => ('b2i32', 'a')
 *    ('u2u32', ('b2i64', 'a@1')) => ('b2i32', 'a')
 *    ('f2u64', ('f2f64', 'a@32')) => ('f2u64', 'a')
 *    ('f2i64', ('f2f64', 'a@32')) => ('f2i64', 'a')
 *    ('f2f32', ('u2f64', 'a')) => ('u2f32', 'a')
 *    ('f2f32', ('i2f64', 'a')) => ('i2f32', 'a')
 *    ('u2f64', ('u2u64', 'a@32')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i64', 'a@32')) => ('i2f64', 'a')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@64', ('feq', 'a', 0.0), 1.0, ('i2f64', ('iadd', ('b2i64', ('flt', 0.0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0.0)))))) => ('i2f64', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@64'), ('b2f', 'c@64')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f64', ('f2i', 'a@64')) => ('ftrunc', 'a')
 *    ('~f2i64', ('i2f', 'a@64')) => a
 *    ('~f2i64', ('u2f', 'a@64')) => a
 *    ('~f2u64', ('i2f', 'a@64')) => a
 *    ('~f2u64', ('u2f', 'a@64')) => a
 *    ('fadd', ('b2f64', ('flt', 0.0, 'a@64')), ('fneg', ('b2f64', ('flt', 'a@64', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i64', ('flt', 0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0)))) => ('f2i64', ('fsign', 'a'))
 *    ('f2fmp', ('u2f32', 'a@32')) => ('u2fmp', 'a')
 *    ('f2fmp', ('i2f32', 'a@32')) => ('i2fmp', 'a')
 *    ('f2u16', ('f2fmp', 'a@32')) => ('f2u16', 'a')
 *    ('f2i16', ('f2fmp', 'a@32')) => ('f2i16', 'a')
 *    ('i2imp', ('f2u32', 'a@32')) => ('f2ump', 'a')
 *    ('i2imp', ('f2i32', 'a@32')) => ('f2imp', 'a')
 *    ('u2f16', ('i2imp', 'a@32')) => ('u2f16', 'a')
 *    ('i2f16', ('i2imp', 'a@32')) => ('i2f16', 'a')
 *    ('iand', ('u2u16', ('u2u8', 'a@16')), '#b') => ('iand', 'a', ('iand', 'b', 255))
 *    ('u2u16', ('u2u8(is_used_once)', ('iand', 'a@16', '#b'))) => ('iand', 'a', ('iand', 'b', 255))
 *    ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('iand', 'a', 'b'))
 *    ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('iand', 'a', 'b'))
 *    ('iand', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('iand', 'a', 'c'), 'b')
 *    ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ior', 'a', 'b'))
 *    ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ior', 'a', 'b'))
 *    ('ior', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ior', 'a', 'c'), 'b')
 *    ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ixor', 'a', 'b'))
 *    ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ixor', 'a', 'b'))
 *    ('ixor', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ixor', 'a', 'c'), 'b')
 *    ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i8', 'a@8')) => a
 *    ('ishl', 'a@8', ('iand', 7, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@8', ('iand', 7, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@8', ('iand', 7, 'b')) => ('ushr', 'a', 'b')
 *    ('ushr', 'a@8', ('ishl(is_used_once)', ('iand', 'b', 1), 2)) => ('ushr', 'a', ('ishl', 'b', 2))
 *    ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i16', 'a@16')) => a
 *    ('ishl', 'a@16', ('iand', 15, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@16', ('iand', 15, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@16', ('iand', 15, 'b')) => ('ushr', 'a', 'b')
 *    ('ushr', 'a@16', ('ishl(is_used_once)', ('iand', 'b', 1), 3)) => ('ushr', 'a', ('ishl', 'b', 3))
 *    ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i32', 'a@32')) => a
 *    ('ishl', 'a@32', ('iand', 31, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@32', ('iand', 31, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@32', ('iand', 31, 'b')) => ('ushr', 'a', 'b')
 *    ('ushr', 'a@32', ('ishl(is_used_once)', ('iand', 'b', 1), 4)) => ('ushr', 'a', ('ishl', 'b', 4))
 *    ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i64', 'a@64')) => a
 *    ('ishl', 'a@64', ('iand', 63, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@64', ('iand', 63, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@64', ('iand', 63, 'b')) => ('ushr', 'a', 'b')
 *    ('ushr', 'a@64', ('ishl(is_used_once)', ('iand', 'b', 1), 5)) => ('ushr', 'a', ('ishl', 'b', 5))
 *    ('ior', ('ieq', 'a', 0), ('ieq', 'a', 1)) => ('uge', 1, 'a')
 *    ('ior', ('uge', 1, 'a'), ('ieq', 'a', 2)) => ('uge', 2, 'a')
 *    ('ior', ('uge', 2, 'a'), ('ieq', 'a', 3)) => ('uge', 3, 'a')
 *    ('ior', 'a', ('ieq', 'a', False)) => True
 *    ('ine', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ine', 'a', 'b')
 *    ('b2i', ('ine', 'a@1', 'b@1')) => ('b2i', ('ixor', 'a', 'b'))
 *    ('iand', ('inot', ('iand', ('ior', ('ieq', 'a', 0), 'b'), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', 'b', 'c')), ('ilt', 'a', 0))
 *    ('iand', ('inot', ('iand', ('ieq', ('umin', 'a', 'b'), 0), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', ('ieq', 'b', 0), 'c')), ('ilt', 'a', 0))
 *    ('flt', 'a', ('fmax', 'b', 'a')) => ('flt', 'a', 'b')
 *    ('flt', ('fmin', 'a', 'b'), 'a') => ('flt', 'b', 'a')
 *    ('~fge', 'a', ('fmin', 'b', 'a')) => True
 *    ('~fge', ('fmax', 'a', 'b'), 'a') => True
 *    ('flt', 'a', ('fmin', 'b', 'a')) => False
 *    ('flt', ('fmax', 'a', 'b'), 'a') => False
 *    ('~fge', 'a', ('fmax', 'b', 'a')) => ('fge', 'a', 'b')
 *    ('~fge', ('fmin', 'a', 'b'), 'a') => ('fge', 'b', 'a')
 *    ('ilt', 'a', ('imax', 'b', 'a')) => ('ilt', 'a', 'b')
 *    ('ilt', ('imin', 'a', 'b'), 'a') => ('ilt', 'b', 'a')
 *    ('ige', 'a', ('imin', 'b', 'a')) => True
 *    ('ige', ('imax', 'a', 'b'), 'a') => True
 *    ('ult', 'a', ('umax', 'b', 'a')) => ('ult', 'a', 'b')
 *    ('ult', ('umin', 'a', 'b'), 'a') => ('ult', 'b', 'a')
 *    ('uge', 'a', ('umin', 'b', 'a')) => True
 *    ('uge', ('umax', 'a', 'b'), 'a') => True
 *    ('ilt', 'a', ('imin', 'b', 'a')) => False
 *    ('ilt', ('imax', 'a', 'b'), 'a') => False
 *    ('ige', 'a', ('imax', 'b', 'a')) => ('ige', 'a', 'b')
 *    ('ige', ('imin', 'a', 'b'), 'a') => ('ige', 'b', 'a')
 *    ('ult', 'a', ('umin', 'b', 'a')) => False
 *    ('ult', ('umax', 'a', 'b'), 'a') => False
 *    ('uge', 'a', ('umax', 'b', 'a')) => ('uge', 'a', 'b')
 *    ('uge', ('umin', 'a', 'b'), 'a') => ('uge', 'b', 'a')
 *    ('ult', 'a', ('iand', 'b', 'a')) => False
 *    ('ult', ('ior', 'a', 'b'), 'a') => False
 *    ('uge', 'a', ('iand', 'b', 'a')) => True
 *    ('uge', ('ior', 'a', 'b'), 'a') => True
 *    ('ilt', '#a', ('imax', '#b', 'c')) => ('ior', ('ilt', 'a', 'b'), ('ilt', 'a', 'c'))
 *    ('ilt', ('imin', '#a', 'b'), '#c') => ('ior', ('ilt', 'a', 'c'), ('ilt', 'b', 'c'))
 *    ('ige', '#a', ('imin', '#b', 'c')) => ('ior', ('ige', 'a', 'b'), ('ige', 'a', 'c'))
 *    ('ige', ('imax', '#a', 'b'), '#c') => ('ior', ('ige', 'a', 'c'), ('ige', 'b', 'c'))
 *    ('ult', '#a', ('umax', '#b', 'c')) => ('ior', ('ult', 'a', 'b'), ('ult', 'a', 'c'))
 *    ('ult', ('umin', '#a', 'b'), '#c') => ('ior', ('ult', 'a', 'c'), ('ult', 'b', 'c'))
 *    ('uge', '#a', ('umin', '#b', 'c')) => ('ior', ('uge', 'a', 'b'), ('uge', 'a', 'c'))
 *    ('uge', ('umax', '#a', 'b'), '#c') => ('ior', ('uge', 'a', 'c'), ('uge', 'b', 'c'))
 *    ('ilt', '#a', ('imin', '#b', 'c')) => ('iand', ('ilt', 'a', 'b'), ('ilt', 'a', 'c'))
 *    ('ilt', ('imax', '#a', 'b'), '#c') => ('iand', ('ilt', 'a', 'c'), ('ilt', 'b', 'c'))
 *    ('ige', '#a', ('imax', '#b', 'c')) => ('iand', ('ige', 'a', 'b'), ('ige', 'a', 'c'))
 *    ('ige', ('imin', '#a', 'b'), '#c') => ('iand', ('ige', 'a', 'c'), ('ige', 'b', 'c'))
 *    ('ult', '#a', ('umin', '#b', 'c')) => ('iand', ('ult', 'a', 'b'), ('ult', 'a', 'c'))
 *    ('ult', ('umax', '#a', 'b'), '#c') => ('iand', ('ult', 'a', 'c'), ('ult', 'b', 'c'))
 *    ('uge', '#a', ('umax', '#b', 'c')) => ('iand', ('uge', 'a', 'b'), ('uge', 'a', 'c'))
 *    ('uge', ('umin', '#a', 'b'), '#c') => ('iand', ('uge', 'a', 'c'), ('uge', 'b', 'c'))
 *    ('bcsel', ('ilt', 'a', 0), ('ineg', ('ishr', 'a', 'b')), ('ishr', 'a', 'b')) => ('iabs', ('ishr', 'a', 'b'))
 *    ('iabs', ('ishr', ('iabs', 'a'), 'b')) => ('ishr', ('iabs', 'a'), 'b')
 *    ('fabs', ('slt', 'a', 'b')) => ('slt', 'a', 'b')
 *    ('fabs', ('sge', 'a', 'b')) => ('sge', 'a', 'b')
 *    ('fabs', ('seq', 'a', 'b')) => ('seq', 'a', 'b')
 *    ('fabs', ('sne', 'a', 'b')) => ('sne', 'a', 'b')
 *    ('slt', 'a', 'b') => ('b2f', ('flt', 'a', 'b'))
 *    ('sge', 'a', 'b') => ('b2f', ('fge', 'a', 'b'))
 *    ('seq', 'a', 'b') => ('b2f', ('feq', 'a', 'b'))
 *    ('sne', 'a', 'b') => ('b2f', ('fneu', 'a', 'b'))
 *    ('seq', ('seq', 'a', 'b'), 1.0) => ('seq', 'a', 'b')
 *    ('seq', ('sne', 'a', 'b'), 1.0) => ('sne', 'a', 'b')
 *    ('seq', ('slt', 'a', 'b'), 1.0) => ('slt', 'a', 'b')
 *    ('seq', ('sge', 'a', 'b'), 1.0) => ('sge', 'a', 'b')
 *    ('sne', ('seq', 'a', 'b'), 0.0) => ('seq', 'a', 'b')
 *    ('sne', ('sne', 'a', 'b'), 0.0) => ('sne', 'a', 'b')
 *    ('sne', ('slt', 'a', 'b'), 0.0) => ('slt', 'a', 'b')
 *    ('sne', ('sge', 'a', 'b'), 0.0) => ('sge', 'a', 'b')
 *    ('seq', ('seq', 'a', 'b'), 0.0) => ('sne', 'a', 'b')
 *    ('seq', ('sne', 'a', 'b'), 0.0) => ('seq', 'a', 'b')
 *    ('seq', ('slt', 'a', 'b'), 0.0) => ('sge', 'a', 'b')
 *    ('seq', ('sge', 'a', 'b'), 0.0) => ('slt', 'a', 'b')
 *    ('sne', ('seq', 'a', 'b'), 1.0) => ('sne', 'a', 'b')
 *    ('sne', ('sne', 'a', 'b'), 1.0) => ('seq', 'a', 'b')
 *    ('sne', ('slt', 'a', 'b'), 1.0) => ('sge', 'a', 'b')
 *    ('sne', ('sge', 'a', 'b'), 1.0) => ('slt', 'a', 'b')
 *    ('fall_equal2', 'a', 'b') => ('fmin', ('seq', 'a.x', 'b.x'), ('seq', 'a.y', 'b.y'))
 *    ('fall_equal3', 'a', 'b') => ('seq', ('fany_nequal3', 'a', 'b'), 0.0)
 *    ('fall_equal4', 'a', 'b') => ('seq', ('fany_nequal4', 'a', 'b'), 0.0)
 *    ('fall_equal8', 'a', 'b') => ('seq', ('fany_nequal8', 'a', 'b'), 0.0)
 *    ('fall_equal16', 'a', 'b') => ('seq', ('fany_nequal16', 'a', 'b'), 0.0)
 *    ('fany_nequal2', 'a', 'b') => ('fmax', ('sne', 'a.x', 'b.x'), ('sne', 'a.y', 'b.y'))
 *    ('fany_nequal3', 'a', 'b') => ('fsat', ('fdot3', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('fany_nequal4', 'a', 'b') => ('fsat', ('fdot4', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('fany_nequal8', 'a', 'b') => ('fsat', ('fdot8', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('fany_nequal16', 'a', 'b') => ('fsat', ('fdot16', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('ball_iequal2', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y'))
 *    ('ball_iequal3', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('iand', ('ieq', 'a.y', 'b.y'), ('ieq', 'a.z', 'b.z')))
 *    ('ball_iequal4', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('iand', ('ieq', 'a.z', 'b.z'), ('ieq', 'a.w', 'b.w')))
 *    ('ball_iequal8', 'a', 'b') => ('iand', ('iand', ('iand', ('ieq', 'a.a', 'b.a'), ('ieq', 'a.b', 'b.b')), ('iand', ('ieq', 'a.c', 'b.c'), ('ieq', 'a.d', 'b.d'))), ('iand', ('iand', ('ieq', 'a.e', 'b.e'), ('ieq', 'a.f', 'b.f')), ('iand', ('ieq', 'a.g', 'b.g'), ('ieq', 'a.h', 'b.h'))))
 *    ('ball_iequal16', 'a', 'b') => ('iand', ('iand', ('iand', ('iand', ('ieq', 'a.a', 'b.a'), ('ieq', 'a.b', 'b.b')), ('iand', ('ieq', 'a.c', 'b.c'), ('ieq', 'a.d', 'b.d'))), ('iand', ('iand', ('ieq', 'a.e', 'b.e'), ('ieq', 'a.f', 'b.f')), ('iand', ('ieq', 'a.g', 'b.g'), ('ieq', 'a.h', 'b.h')))), ('iand', ('iand', ('iand', ('ieq', 'a.i', 'b.i'), ('ieq', 'a.j', 'b.j')), ('iand', ('ieq', 'a.k', 'b.k'), ('ieq', 'a.l', 'b.l'))), ('iand', ('iand', ('ieq', 'a.m', 'b.m'), ('ieq', 'a.n', 'b.n')), ('iand', ('ieq', 'a.o', 'b.o'), ('ieq', 'a.p', 'b.p')))))
 *    ('ball_fequal2', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y'))
 *    ('ball_fequal3', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('iand', ('feq', 'a.y', 'b.y'), ('feq', 'a.z', 'b.z')))
 *    ('ball_fequal4', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('iand', ('feq', 'a.z', 'b.z'), ('feq', 'a.w', 'b.w')))
 *    ('ball_fequal8', 'a', 'b') => ('iand', ('iand', ('iand', ('feq', 'a.a', 'b.a'), ('feq', 'a.b', 'b.b')), ('iand', ('feq', 'a.c', 'b.c'), ('feq', 'a.d', 'b.d'))), ('iand', ('iand', ('feq', 'a.e', 'b.e'), ('feq', 'a.f', 'b.f')), ('iand', ('feq', 'a.g', 'b.g'), ('feq', 'a.h', 'b.h'))))
 *    ('ball_fequal16', 'a', 'b') => ('iand', ('iand', ('iand', ('iand', ('feq', 'a.a', 'b.a'), ('feq', 'a.b', 'b.b')), ('iand', ('feq', 'a.c', 'b.c'), ('feq', 'a.d', 'b.d'))), ('iand', ('iand', ('feq', 'a.e', 'b.e'), ('feq', 'a.f', 'b.f')), ('iand', ('feq', 'a.g', 'b.g'), ('feq', 'a.h', 'b.h')))), ('iand', ('iand', ('iand', ('feq', 'a.i', 'b.i'), ('feq', 'a.j', 'b.j')), ('iand', ('feq', 'a.k', 'b.k'), ('feq', 'a.l', 'b.l'))), ('iand', ('iand', ('feq', 'a.m', 'b.m'), ('feq', 'a.n', 'b.n')), ('iand', ('feq', 'a.o', 'b.o'), ('feq', 'a.p', 'b.p')))))
 *    ('bany_inequal2', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y'))
 *    ('bany_inequal3', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ior', ('ine', 'a.y', 'b.y'), ('ine', 'a.z', 'b.z')))
 *    ('bany_inequal4', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ior', ('ine', 'a.z', 'b.z'), ('ine', 'a.w', 'b.w')))
 *    ('bany_inequal8', 'a', 'b') => ('ior', ('ior', ('ior', ('ine', 'a.a', 'b.a'), ('ine', 'a.b', 'b.b')), ('ior', ('ine', 'a.c', 'b.c'), ('ine', 'a.d', 'b.d'))), ('ior', ('ior', ('ine', 'a.e', 'b.e'), ('ine', 'a.f', 'b.f')), ('ior', ('ine', 'a.g', 'b.g'), ('ine', 'a.h', 'b.h'))))
 *    ('bany_inequal16', 'a', 'b') => ('ior', ('ior', ('ior', ('ior', ('ine', 'a.a', 'b.a'), ('ine', 'a.b', 'b.b')), ('ior', ('ine', 'a.c', 'b.c'), ('ine', 'a.d', 'b.d'))), ('ior', ('ior', ('ine', 'a.e', 'b.e'), ('ine', 'a.f', 'b.f')), ('ior', ('ine', 'a.g', 'b.g'), ('ine', 'a.h', 'b.h')))), ('ior', ('ior', ('ior', ('ine', 'a.i', 'b.i'), ('ine', 'a.j', 'b.j')), ('ior', ('ine', 'a.k', 'b.k'), ('ine', 'a.l', 'b.l'))), ('ior', ('ior', ('ine', 'a.m', 'b.m'), ('ine', 'a.n', 'b.n')), ('ior', ('ine', 'a.o', 'b.o'), ('ine', 'a.p', 'b.p')))))
 *    ('bany_fnequal2', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y'))
 *    ('bany_fnequal3', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('ior', ('fneu', 'a.y', 'b.y'), ('fneu', 'a.z', 'b.z')))
 *    ('bany_fnequal4', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('ior', ('fneu', 'a.z', 'b.z'), ('fneu', 'a.w', 'b.w')))
 *    ('bany_fnequal8', 'a', 'b') => ('ior', ('ior', ('ior', ('fneu', 'a.a', 'b.a'), ('fneu', 'a.b', 'b.b')), ('ior', ('fneu', 'a.c', 'b.c'), ('fneu', 'a.d', 'b.d'))), ('ior', ('ior', ('fneu', 'a.e', 'b.e'), ('fneu', 'a.f', 'b.f')), ('ior', ('fneu', 'a.g', 'b.g'), ('fneu', 'a.h', 'b.h'))))
 *    ('bany_fnequal16', 'a', 'b') => ('ior', ('ior', ('ior', ('ior', ('fneu', 'a.a', 'b.a'), ('fneu', 'a.b', 'b.b')), ('ior', ('fneu', 'a.c', 'b.c'), ('fneu', 'a.d', 'b.d'))), ('ior', ('ior', ('fneu', 'a.e', 'b.e'), ('fneu', 'a.f', 'b.f')), ('ior', ('fneu', 'a.g', 'b.g'), ('fneu', 'a.h', 'b.h')))), ('ior', ('ior', ('ior', ('fneu', 'a.i', 'b.i'), ('fneu', 'a.j', 'b.j')), ('ior', ('fneu', 'a.k', 'b.k'), ('fneu', 'a.l', 'b.l'))), ('ior', ('ior', ('fneu', 'a.m', 'b.m'), ('fneu', 'a.n', 'b.n')), ('ior', ('fneu', 'a.o', 'b.o'), ('fneu', 'a.p', 'b.p')))))
 *    ('feq', ('seq', 'a', 'b'), 1.0) => ('feq', 'a', 'b')
 *    ('feq', ('sne', 'a', 'b'), 1.0) => ('fneu', 'a', 'b')
 *    ('feq', ('slt', 'a', 'b'), 1.0) => ('flt', 'a', 'b')
 *    ('feq', ('sge', 'a', 'b'), 1.0) => ('fge', 'a', 'b')
 *    ('fneu', ('seq', 'a', 'b'), 0.0) => ('feq', 'a', 'b')
 *    ('fneu', ('sne', 'a', 'b'), 0.0) => ('fneu', 'a', 'b')
 *    ('fneu', ('slt', 'a', 'b'), 0.0) => ('flt', 'a', 'b')
 *    ('fneu', ('sge', 'a', 'b'), 0.0) => ('fge', 'a', 'b')
 *    ('feq', ('seq', 'a', 'b'), 0.0) => ('fneu', 'a', 'b')
 *    ('feq', ('sne', 'a', 'b'), 0.0) => ('feq', 'a', 'b')
 *    ('feq', ('slt', 'a', 'b'), 0.0) => ('fge', 'a', 'b')
 *    ('feq', ('sge', 'a', 'b'), 0.0) => ('flt', 'a', 'b')
 *    ('fneu', ('seq', 'a', 'b'), 1.0) => ('fneu', 'a', 'b')
 *    ('fneu', ('sne', 'a', 'b'), 1.0) => ('feq', 'a', 'b')
 *    ('fneu', ('slt', 'a', 'b'), 1.0) => ('fge', 'a', 'b')
 *    ('fneu', ('sge', 'a', 'b'), 1.0) => ('flt', 'a', 'b')
 *    ('fneu', ('fneg', 'a'), 'a') => ('fneu', 'a', 0.0)
 *    ('feq', ('fneg', 'a'), 'a') => ('feq', 'a', 0.0)
 *    ('imul', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('iand', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('ior', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b'))
 *    ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b'))
 *    ('fsat', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('b2f', ('ior', 'a', 'b'))
 *    ('iand', 'a@bool16', 1.0) => ('b2f', 'a')
 *    ('iand', 'a@bool32', 1.0) => ('b2f', 'a')
 *    ('flt', ('fneg', ('b2f', 'a@1')), 0) => a
 *    ('ilt', 'a', 'a') => False
 *    ('ige', 'a', 'a') => True
 *    ('ieq', 'a', 'a') => True
 *    ('ine', 'a', 'a') => False
 *    ('ult', 'a', 'a') => False
 *    ('uge', 'a', 'a') => True
 *    ('flt', 'a', 'a') => False
 *    ('fge', 'a(is_a_number)', 'a') => True
 *    ('feq', 'a(is_a_number)', 'a') => True
 *    ('fneu', 'a(is_a_number)', 'a') => False
 *    ('iand', 'a', 'a') => a
 *    ('iand', 'a', 0) => 0
 *    ('iand', 'a', -1) => a
 *    ('iand', 'a', ('inot', 'a')) => 0
 *    ('ior', 'a', 'a') => a
 *    ('ior', 'a', 0) => a
 *    ('ior', 'a', -1) => -1
 *    ('ior', 'a', ('inot', 'a')) => -1
 *    ('ixor', 'a', 'a') => 0
 *    ('ixor', 'a', 0) => a
 *    ('ixor', 'a', ('ixor', 'a', 'b')) => b
 *    ('ixor', 'a', -1) => ('inot', 'a')
 *    ('inot', ('inot', 'a')) => a
 *    ('ior', ('iand', 'a', 'b'), 'b') => b
 *    ('ior', ('ior', 'a', 'b'), 'b') => ('ior', 'a', 'b')
 *    ('iand', ('ior', 'a', 'b'), 'b') => b
 *    ('iand', ('iand', 'a', 'b'), 'b') => ('iand', 'a', 'b')
 *    ('iand', ('inot', 'a'), ('inot', 'b')) => ('inot', ('ior', 'a', 'b'))
 *    ('ior', ('inot', 'a'), ('inot', 'b')) => ('inot', ('iand', 'a', 'b'))
 *    ('ishl', 0, 'a') => 0
 *    ('ishl', 'a', 0) => a
 *    ('ishr', 0, 'a') => 0
 *    ('ishr', -1, 'a') => -1
 *    ('ishr', 'a', 0) => a
 *    ('ushr', 0, 'a') => 0
 *    ('ushr', 'a', 0) => a
 *    ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('isub', 16, 'b'))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('isub', 32, 'b'))) => ('urol', 'a', 'b')
 *    ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('isub', 16, 'b'))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('isub', 32, 'b'))) => ('uror', 'a', 'b')
 *    ('urol@8', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 8, 'b')))
 *    ('urol@16', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 16, 'b')))
 *    ('urol@32', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 32, 'b')))
 *    ('urol@64', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 64, 'b')))
 *    ('uror@8', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 8, 'b')))
 *    ('uror@16', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 16, 'b')))
 *    ('uror@32', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 32, 'b')))
 *    ('uror@64', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 64, 'b')))
 *    ('~fexp2', ('flog2', 'a')) => a
 *    ('~flog2', ('fexp2', 'a')) => a
 *    ('fpow', 'a', 'b') => ('fexp2', ('fmul', ('flog2', 'a'), 'b'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 'b')) => ('fpow', 'a', 'b')
 *    ('~fexp2', ('fadd', ('fmul', ('flog2', 'a'), 'b'), ('fmul', ('flog2', 'c'), 'd'))) => ('~fmul', ('fpow', 'a', 'b'), ('fpow', 'c', 'd'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 0.5)) => ('fsqrt', 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 2.0)) => ('fmul', 'a', 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 4.0)) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))
 *    ('~fpow', 'a', 1.0) => a
 *    ('~fpow', 'a', 2.0) => ('fmul', 'a', 'a')
 *    ('~fpow', 'a', 4.0) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))
 *    ('~fpow', 2.0, 'a') => ('fexp2', 'a')
 *    ('~fpow', ('fpow', 'a', 2.2), 0.454545) => a
 *    ('~fpow', ('fabs', ('fpow', 'a', 2.2)), 0.454545) => ('fabs', 'a')
 *    ('~fsqrt', ('fexp2', 'a')) => ('fexp2', ('fmul', 0.5, 'a'))
 *    ('~frcp', ('fexp2', 'a')) => ('fexp2', ('fneg', 'a'))
 *    ('~frsq', ('fexp2', 'a')) => ('fexp2', ('fmul', -0.5, 'a'))
 *    ('~flog2', ('fsqrt', 'a')) => ('fmul', 0.5, ('flog2', 'a'))
 *    ('~flog2', ('frcp', 'a')) => ('fneg', ('flog2', 'a'))
 *    ('~flog2', ('frsq', 'a')) => ('fmul', -0.5, ('flog2', 'a'))
 *    ('~flog2', ('fpow', 'a', 'b')) => ('fmul', 'b', ('flog2', 'a'))
 *    ('~fmul', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('fadd', 'a', 'b'))
 *    ('bcsel', ('flt', 'a', 0.0), 0.0, ('fsqrt', 'a')) => ('fsqrt', ('fmax', 'a', 0.0))
 *    ('~fmul', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a')
 *    ('~fmulz', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a')
 *    ('~fdiv', 1.0, 'a') => ('frcp', 'a')
 *    ('fdiv', 'a', 'b') => ('fmul', 'a', ('frcp', 'b'))
 *    ('~frcp', ('frcp', 'a')) => a
 *    ('~frcp', ('fsqrt', 'a')) => ('frsq', 'a')
 *    ('fsqrt', 'a') => ('frcp', ('frsq', 'a'))
 *    ('~frcp', ('frsq', 'a')) => ('fsqrt', 'a')
 *    ('fsin', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))
 *    ('fcos', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))
 *    ('i2b16(is_used_by_if)', 'a') => ('ine16', 'a', 0)
 *    ('i2b32(is_used_by_if)', 'a') => ('ine32', 'a', 0)
 *    ('i2b1(is_used_by_if)', 'a') => ('ine', 'a', 0)
 *    ('ieq', 'a', True) => a
 *    ('ine(is_not_used_by_if)', 'a', True) => ('inot', 'a')
 *    ('ine', 'a', False) => a
 *    ('ieq(is_not_used_by_if)', 'a', False) => ('inot', 'a')
 *    ('bcsel', 'a', True, False) => a
 *    ('bcsel', 'a', False, True) => ('inot', 'a')
 *    ('bcsel', True, 'b', 'c') => b
 *    ('bcsel', False, 'b', 'c') => c
 *    ('bcsel@16', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@16', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@16', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@16', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel@32', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@32', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@32', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@32', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel@64', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@64', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@64', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@64', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel', 'a', 'b', 'b') => b
 *    ('~fcsel', 'a', 'b', 'b') => b
 *    ('bcsel', 'a', -1, 0) => ('ineg', ('b2i', 'a@1'))
 *    ('bcsel', 'a', 0, -1) => ('ineg', ('b2i', ('inot', 'a')))
 *    ('bcsel', 'a', 1, 0) => ('b2i', 'a@1')
 *    ('bcsel', 'a', 0, 1) => ('b2i', ('inot', 'a'))
 *    ('iand', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('ior', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('ieq', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a')
 *    ('ieq', ('ineg', ('b2i', 'a@1')), -1) => a
 *    ('ine', ('ineg', ('b2i', 'a@1')), 0) => a
 *    ('ine', ('ineg', ('b2i', 'a@1')), -1) => ('inot', 'a')
 *    ('ige', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a')
 *    ('ilt', ('ineg', ('b2i', 'a@1')), 0) => a
 *    ('ult', 0, ('ineg', ('b2i', 'a@1'))) => a
 *    ('iand', ('ineg', ('b2i', 'a')), 1.0) => ('b2f', 'a')
 *    ('iand', ('ineg', ('b2i', 'a')), 1) => ('b2i', 'a')
 *    ('imax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('imin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('umax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('umin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('i2b16', ('b2i', 'a@16')) => a
 *    ('i2b32', ('b2i', 'a@32')) => a
 *    ('f2i', ('ftrunc', 'a')) => ('f2i', 'a')
 *    ('f2u', ('ftrunc', 'a')) => ('f2u', 'a')
 *    ('i2b', ('ineg', 'a')) => ('i2b', 'a')
 *    ('i2b', ('iabs', 'a')) => ('i2b', 'a')
 *    ('inot', ('f2b1', 'a')) => ('feq', 'a', 0.0)
 *    ('f2fmp', ('f2f32', 'a@16')) => a
 *    ('i2imp', ('i2i32', 'a@16')) => a
 *    ('i2imp', ('u2u32', 'a@16')) => a
 *    ('f2imp', ('f2f32', 'a@16')) => ('f2i16', 'a')
 *    ('f2ump', ('f2f32', 'a@16')) => ('f2u16', 'a')
 *    ('i2fmp', ('i2i32', 'a@16')) => ('i2f16', 'a')
 *    ('u2fmp', ('u2u32', 'a@16')) => ('u2f16', 'a')
 *    ('f2fmp', ('b2f32', 'a@1')) => ('b2f16', 'a')
 *    ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('f2imp', ('b2f32', 'a@1')) => ('b2i16', 'a')
 *    ('f2ump', ('b2f32', 'a@1')) => ('b2i16', 'a')
 *    ('i2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a')
 *    ('u2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a')
 *    ('f2f32', ('f2fmp', 'a@32')) => a
 *    ('i2i32', ('i2imp', 'a@32')) => a
 *    ('u2u32', ('i2imp', 'a@32')) => a
 *    ('i2i32', ('f2imp', 'a@32')) => ('f2i32', 'a')
 *    ('u2u32', ('f2ump', 'a@32')) => ('f2u32', 'a')
 *    ('f2f32', ('i2fmp', 'a@32')) => ('i2f32', 'a')
 *    ('f2f32', ('u2fmp', 'a@32')) => ('u2f32', 'a')
 *    ('~f2f32', ('f2f64', 'a@32')) => a
 *    ('ffloor', 'a(is_integral)') => a
 *    ('fceil', 'a(is_integral)') => a
 *    ('ftrunc', 'a(is_integral)') => a
 *    ('fround_even', 'a(is_integral)') => a
 *    ('~ffract', 'a(is_integral)') => 0.0
 *    ('fabs', 'a(is_not_negative)') => a
 *    ('iabs', 'a(is_not_negative)') => a
 *    ('fsat', 'a(is_not_positive)') => 0.0
 *    ('~fmin', 'a(is_not_negative)', 1.0) => ('fsat', 'a')
 *    ('flt', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => False
 *    ('flt', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => False
 *    ('fmax', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0)
 *    ('fmax', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0)
 *    ('fneu', 'a(is_not_zero)', 0.0) => True
 *    ('feq', 'a(is_not_zero)', 0.0) => False
 *    ('fge', 'a(is_a_number_not_negative)', 'b(is_a_number_not_positive)') => True
 *    ('fge', 'a(is_not_positive)', 'b(is_gt_zero)') => False
 *    ('fge', 'a(is_lt_zero)', 'b(is_not_negative)') => False
 *    ('flt', 'a(is_not_negative)', 'b(is_not_positive)') => False
 *    ('flt', 'a(is_a_number_not_positive)', 'b(is_a_number_gt_zero)') => True
 *    ('flt', 'a(is_a_number_lt_zero)', 'b(is_a_number_not_negative)') => True
 *    ('ine', 'a(is_not_zero)', 0) => True
 *    ('ieq', 'a(is_not_zero)', 0) => False
 *    ('ige', 'a(is_not_negative)', 'b(is_not_positive)') => True
 *    ('ige', 'a(is_not_positive)', 'b(is_gt_zero)') => False
 *    ('ige', 'a(is_lt_zero)', 'b(is_not_negative)') => False
 *    ('ilt', 'a(is_not_negative)', 'b(is_not_positive)') => False
 *    ('ilt', 'a(is_not_positive)', 'b(is_gt_zero)') => True
 *    ('ilt', 'a(is_lt_zero)', 'b(is_not_negative)') => True
 *    ('ult', 0, 'a(is_gt_zero)') => True
 *    ('ult', 'a', 0) => False
 *    ('unpack_64_2x32_split_x', ('pack_64_2x32_split', 'a', 'b')) => a
 *    ('unpack_64_2x32_split_y', ('pack_64_2x32_split', 'a', 'b')) => b
 *    ('unpack_64_2x32_split_x', ('pack_64_2x32', 'a')) => a.x
 *    ('unpack_64_2x32_split_y', ('pack_64_2x32', 'a')) => a.y
 *    ('unpack_64_2x32_split_x', ('u2u64', 'a@32')) => a
 *    ('unpack_64_2x32_split_y', ('u2u64', 'a')) => 0
 *    ('unpack_64_2x32_split_x', ('i2i64', 'a@32')) => a
 *    ('unpack_64_2x32_split_y', ('i2i64(is_used_once)', 'a@32')) => ('ishr', 'a', 31)
 *    ('unpack_64_2x32', ('pack_64_2x32_split', 'a', 'b')) => ('vec2', 'a', 'b')
 *    ('unpack_64_2x32', ('pack_64_2x32', 'a')) => a
 *    ('unpack_double_2x32_dxil', ('pack_double_2x32_dxil', 'a')) => a
 *    ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')) => a
 *    ('pack_64_2x32', ('vec2', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a'))) => a
 *    ('pack_64_2x32', ('unpack_64_2x32', 'a')) => a
 *    ('pack_double_2x32_dxil', ('unpack_double_2x32_dxil', 'a')) => a
 *    ('iand', ('ieq', ('unpack_32_2x16_split_x', 'a'), '#b'), ('ieq', ('unpack_32_2x16_split_y', 'a'), '#c')) => ('ieq', 'a', ('pack_32_2x16_split', 'b', 'c'))
 *    ('ushr', 'a@16', 8) => ('extract_u8', 'a', 1)
 *    ('ushr', 'a@32', 24) => ('extract_u8', 'a', 3)
 *    ('ushr', 'a@64', 56) => ('extract_u8', 'a', 7)
 *    ('ishr', 'a@16', 8) => ('extract_i8', 'a', 1)
 *    ('ishr', 'a@32', 24) => ('extract_i8', 'a', 3)
 *    ('ishr', 'a@64', 56) => ('extract_i8', 'a', 7)
 *    ('iand', 255, 'a') => ('extract_u8', 'a', 0)
 *    ('u2u8', ('extract_u16', 'a', 1)) => ('u2u8', ('extract_u8', 'a', 2))
 *    ('u2u8', ('ushr', 'a', 8)) => ('u2u8', ('extract_u8', 'a', 1))
 *    ('i2i16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('i2i16', ('extract_i8', 'a', 'b'))
 *    ('u2u16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('u2u16', ('extract_u8', 'a', 'b'))
 *    ('ubfe', 'a', 0, 8) => ('extract_u8', 'a', 0)
 *    ('ubfe', 'a', 8, 8) => ('extract_u8', 'a', 1)
 *    ('ubfe', 'a', 16, 8) => ('extract_u8', 'a', 2)
 *    ('ubfe', 'a', 24, 8) => ('extract_u8', 'a', 3)
 *    ('ibfe', 'a', 0, 8) => ('extract_i8', 'a', 0)
 *    ('ibfe', 'a', 8, 8) => ('extract_i8', 'a', 1)
 *    ('ibfe', 'a', 16, 8) => ('extract_i8', 'a', 2)
 *    ('ibfe', 'a', 24, 8) => ('extract_i8', 'a', 3)
 *    ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('ushr', ('ishl', 'a@32', 16), 16) => ('extract_u16', 'a', 0)
 *    ('ushr', 'a@32', 16) => ('extract_u16', 'a', 1)
 *    ('ishr', ('ishl', 'a@32', 16), 16) => ('extract_i16', 'a', 0)
 *    ('ishr', 'a@32', 16) => ('extract_i16', 'a', 1)
 *    ('iand', 65535, 'a') => ('extract_u16', 'a', 0)
 *    ('ubfe', 'a', 0, 16) => ('extract_u16', 'a', 0)
 *    ('ubfe', 'a', 16, 16) => ('extract_u16', 'a', 1)
 *    ('ibfe', 'a', 0, 16) => ('extract_i16', 'a', 0)
 *    ('ibfe', 'a', 16, 16) => ('extract_i16', 'a', 1)
 *    ('ior', ('ishl', ('u2u32', 'a@8'), 24), ('ior', ('ishl', ('u2u32', 'b@8'), 16), ('ior', ('ishl', ('u2u32', 'c@8'), 8), ('u2u32', 'd@8')))) => ('pack_32_4x8', ('vec4', 'd', 'c', 'b', 'a'))
 *    ('extract_u16', ('extract_i16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b')
 *    ('extract_u16', ('extract_u16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b')
 *    ('pack_64_2x32_split', 'a', 'b') => ('ior', ('u2u64', 'a'), ('ishl', ('u2u64', 'b'), 32))
 *    ('pack_32_2x16_split', 'a', 'b') => ('ior', ('u2u32', 'a'), ('ishl', ('u2u32', 'b'), 16))
 *    ('unpack_64_2x32_split_x', 'a') => ('u2u32', 'a')
 *    ('unpack_64_2x32_split_y', 'a') => ('u2u32', ('ushr', 'a', 32))
 *    ('unpack_32_2x16_split_x', 'a') => ('u2u16', 'a')
 *    ('unpack_32_2x16_split_y', 'a') => ('u2u16', ('ushr', 'a', 16))
 *    ('unpack_half_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_half_2x16_split_x', 'a')
 *    ('unpack_32_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_32_2x16_split_x', 'a')
 *    ('unpack_64_2x32_split_x', ('iand', 'a', 4294967295)) => ('unpack_64_2x32_split_x', 'a')
 *    ('unpack_half_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_32_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_32_2x16_split_y', 'a')
 *    ('unpack_64_2x32_split_y', ('iand', 'a', 18446744069414584320)) => ('unpack_64_2x32_split_y', 'a')
 *    ('unpack_half_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_half_2x16_split_x', 'a')
 *    ('unpack_half_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_half_2x16_split_x', ('ushr', 'a', 16)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_32_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_32_2x16_split_x', 'a')
 *    ('unpack_32_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_32_2x16_split_y', 'a')
 *    ('ishl', ('pack_half_2x16', ('vec2', 'a', 0)), 16) => ('pack_half_2x16', ('vec2', 0, 'a'))
 *    ('ushr', ('pack_half_2x16', ('vec2', 0, 'a')), 16) => ('pack_half_2x16', ('vec2', 'a', 0))
 *    ('iadd', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b'))
 *    ('ior', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b'))
 *    ('ishl', ('pack_half_2x16_split', 'a', 0), 16) => ('pack_half_2x16_split', 0, 'a')
 *    ('ushr', ('pack_half_2x16_split', 0, 'a'), 16) => ('pack_half_2x16_split', 'a', 0)
 *    ('extract_u16', ('pack_half_2x16_split', 0, 'a'), 1) => ('pack_half_2x16_split', 'a', 0)
 *    ('iadd', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b')
 *    ('ior', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('i2i', 'a')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('i2i', 'b')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('i2i', 'c')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('i2i', 'd')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('u2u', 'a')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('u2u', 'b')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('u2u', 'c')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('u2u', 'd')
 *    ('extract_u8', ('ushr', 'a@16', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@32', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@32', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ushr', 'a@32', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ushr', 'a@64', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@64', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ushr', 'a@64', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ushr', 'a@64', 32), 0) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ushr', 'a@64', 40), 0) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ushr', 'a@64', 48), 0) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ushr', 'a@64', 56), 0) => ('extract_u8', 'a', 7)
 *    ('extract_u8', ('ishr', 'a@16', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@32', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@32', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishr', 'a@32', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishr', 'a@64', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@64', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishr', 'a@64', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishr', 'a@64', 32), 0) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ishr', 'a@64', 40), 0) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ishr', 'a@64', 48), 0) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ishr', 'a@64', 56), 0) => ('extract_u8', 'a', 7)
 *    ('extract_u8', ('extract_u16', 'a', 1), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@16', 8), 1) => ('extract_u8', 'a', 0)
 *    ('extract_u8', ('ishl', 'a@32', 8), 3) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@32', 16), 3) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishl', 'a@32', 24), 3) => ('extract_u8', 'a', 0)
 *    ('extract_u8', ('ishl', 'a@64', 8), 7) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ishl', 'a@64', 16), 7) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ishl', 'a@64', 24), 7) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ishl', 'a@64', 32), 7) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishl', 'a@64', 40), 7) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@64', 48), 7) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishl', 'a@64', 56), 7) => ('extract_u8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@16', 8), 1) => ('extract_i8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@32', 8), 3) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('ishl', 'a@32', 16), 3) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('ishl', 'a@32', 24), 3) => ('extract_i8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@64', 8), 7) => ('extract_i8', 'a', 6)
 *    ('extract_i8', ('ishl', 'a@64', 16), 7) => ('extract_i8', 'a', 5)
 *    ('extract_i8', ('ishl', 'a@64', 24), 7) => ('extract_i8', 'a', 4)
 *    ('extract_i8', ('ishl', 'a@64', 32), 7) => ('extract_i8', 'a', 3)
 *    ('extract_i8', ('ishl', 'a@64', 40), 7) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('ishl', 'a@64', 48), 7) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('ishl', 'a@64', 56), 7) => ('extract_i8', 'a', 0)
 *    ('ussub_4x8_vc4', 'a', 0) => a
 *    ('ussub_4x8_vc4', 'a', -1) => 0
 *    ('fsub', 'a', 'b') => ('fadd', 'a', ('fneg', 'b'))
 *    ('isub', 'a', 'b') => ('iadd', 'a', ('ineg', 'b'))
 *    ('uabs_usub', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b'))
 *    ('uabs_isub', 'a', 'b') => ('bcsel', ('ilt', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b'))
 *    ('fmul(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmul', 'a', 'b'))
 *    ('fmulz(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmulz', 'a', 'b'))
 *    ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('imul', ('ineg', 'a'), 'b') => ('ineg', ('imul', 'a', 'b'))
 *    ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('~fmulz(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmulz', ('fmulz', 'a', 'c'), 'b')
 *    ('~fmul(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)') => ('fmulz', ('fmul', 'a', 'c'), 'b')
 *    ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~ffma', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd')
 *    ('~ffma', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)', 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_fmul)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('ffma(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffma', 'a', 'b', 'd'), 'c')
 *    ('~fadd(is_used_once)', ('ffmaz(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffmaz', 'a', 'b', 'd'), 'c')
 *    ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('~fmul', '#a', ('fmul', 'b(is_not_const)', '#c')) => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('~fmulz', '#a', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmulz', 'a', 'c'), 'b')
 *    ('~fmul', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmul', 'a', 'c'), 'b')
 *    ('~ffma', '#a', ('fmul', 'b(is_not_const)', '#c'), 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', '#a', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('imul', '#a', ('imul', 'b(is_not_const)', '#c')) => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd', '#a', ('fadd', 'b(is_not_const)', '#c')) => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd', '#a', ('fneg', ('fadd', 'b(is_not_const)', '#c'))) => ('fadd', ('fadd', 'a', ('fneg', 'c')), ('fneg', 'b'))
 *    ('~fadd', '#a', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffma', 'b', 'c', ('fadd', 'a', 'd'))
 *    ('~fadd', '#a', ('fneg', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffma', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd')))
 *    ('~fadd', '#a', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffmaz', 'b', 'c', ('fadd', 'a', 'd'))
 *    ('~fadd', '#a', ('fneg', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffmaz', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd')))
 *    ('iadd', '#a', ('iadd', 'b(is_not_const)', '#c')) => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('iand', '#a', ('iand', 'b(is_not_const)', '#c')) => ('iand', ('iand', 'a', 'c'), 'b')
 *    ('ior', '#a', ('ior', 'b(is_not_const)', '#c')) => ('ior', ('ior', 'a', 'c'), 'b')
 *    ('ixor', '#a', ('ixor', 'b(is_not_const)', '#c')) => ('ixor', ('ixor', 'a', 'c'), 'b')
 *    ('~fadd', ('fadd(is_used_once)', 'a(is_fmul)', 'b(is_fmul)'), 'c(is_not_fmul)') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('idiv', ('imul(no_signed_wrap)', 'a', 'b'), 'b') => a
 *    ('bcsel', ('ige', ('find_lsb', 'a'), 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a')
 *    ('bcsel', ('ige', ('ifind_msb', 'a'), 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ige', ('ufind_msb', 'a'), 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ige', ('ifind_msb_rev', 'a'), 0), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ige', ('ufind_msb_rev', 'a'), 0), ('ufind_msb_rev', 'a'), -1) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ufind_msb_rev', 'a'), -1) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a', -1), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', 'a', -1), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ifind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb', 'a'))), -1) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ufind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), -1) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ieq', ('ifind_msb', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ifind_msb', 'a')))) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ieq', ('ufind_msb', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ifind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb', 'a'))), ('ifind_msb', 'a')) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ufind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), ('ufind_msb', 'a')) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ieq', ('ifind_msb', 'a@32'), -1), ('ifind_msb', 'a'), ('iadd', 31, ('ineg', ('ifind_msb', 'a')))) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ieq', ('ufind_msb', 'a@32'), -1), ('ufind_msb', 'a'), ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), -1) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ieq', 'a@32', 0), -1, ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), ('ufind_msb', 'a')) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ieq', 'a@32', 0), ('ufind_msb', 'a'), ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ifind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a'))), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', ('ufind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ieq', ('ifind_msb_rev', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a')))) => ('ifind_msb', 'a')
 *    ('bcsel', ('ieq', ('ufind_msb_rev', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', ('ifind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a'))), ('ifind_msb_rev', 'a')) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', ('ufind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), ('ufind_msb_rev', 'a')) => ('ufind_msb', 'a')
 *    ('bcsel', ('ieq', ('ifind_msb_rev', 'a@32'), -1), ('ifind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a')))) => ('ifind_msb', 'a')
 *    ('bcsel', ('ieq', ('ufind_msb_rev', 'a@32'), -1), ('ufind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ieq', 'a@32', 0), -1, ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), ('ufind_msb_rev', 'a')) => ('ufind_msb', 'a')
 *    ('bcsel', ('ieq', 'a@32', 0), ('ufind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a')
 *    ('find_lsb', ('bitfield_reverse', 'a')) => ('ufind_msb_rev', 'a')
 *    ('ufind_msb_rev', ('bitfield_reverse', 'a')) => ('find_lsb', 'a')
 *    ('~fmul', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b')
 *    ('~fmul', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b'))
 *    ('~fmulz', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b')
 *    ('~fmulz', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b'))
 *    ('fabs', ('bcsel(is_used_once)', 'b', ('fneg', 'a'), 'a')) => ('fabs', 'a')
 *    ('fabs', ('bcsel(is_used_once)', 'b', 'a', ('fneg', 'a'))) => ('fabs', 'a')
 *    ('~bcsel', ('flt', 'a', 0.0), ('fneg', 'a'), 'a') => ('fabs', 'a')
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), 'd') => ('bcsel', ('iand', 'a', 'b'), 'c', 'd')
 *    ('bcsel', 'a', 'b', ('bcsel', 'c', 'b', 'd')) => ('bcsel', ('ior', 'a', 'c'), 'b', 'd')
 *    ('fmod', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ffloor', ('fdiv', 'a', 'b'))))
 *    ('frem', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ftrunc', ('fdiv', 'a', 'b'))))
 *    ('uadd_carry', 'a', 'b') => ('b2i', ('ult', ('iadd', 'a', 'b'), 'a'))
 *    ('usub_borrow', 'a', 'b') => ('b2i', ('ult', 'a', 'b'))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bfi', ('bfm', 'bits', 'offset'), 'insert', 'base'))
 *    ('ihadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('uhadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('irhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('urhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('ihadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('uhadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('irhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('urhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('imul_32x16', 'a', 'b') => ('imul', 'a', ('extract_i16', 'b', 0))
 *    ('umul_32x16', 'a', 'b') => ('imul', 'a', ('extract_u16', 'b', 0))
 *    ('uadd_sat@64', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b'))
 *    ('uadd_sat', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b'))
 *    ('usub_sat', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b'))
 *    ('usub_sat@64', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b'))
 *    ('iadd_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), ('iadd', 'a', 'b'), 9223372036854775807))
 *    ('isub_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), ('isub', 'a', 'b'), 9223372036854775807))
 *    ('ilt', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ilt', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ige', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ige', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ilt', 'a@64', 0) => ('ilt', ('unpack_64_2x32_split_y', 'a'), 0)
 *    ('ige', 'a@64', 0) => ('ige', ('unpack_64_2x32_split_y', 'a'), 0)
 *    ('ine', 'a@64', 0) => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('ieq', 'a@64', 0) => ('ieq', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('ult', 0, 'a@64') => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('ior', ('iand', 'base', ('inot', ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))), ('iand', ('ishl', 'insert', 'offset'), ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bitfield_select', ('bfm', 'bits', 'offset'), ('ishl', 'insert', 'offset'), 'base'))
 *    ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ibfe', 'value', 'offset', 'bits'))
 *    ('ubitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ubfe', 'value', 'offset', 'bits'))
 *    ('bitfield_select', 'a', 'b', 0) => ('iand', 'a', 'b')
 *    ('bitfield_select', 'a', ('iand', 'a', 'b'), 'c') => ('bitfield_select', 'a', 'b', 'c')
 *    ('ubfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ubfe', 'value', 'offset', 'bits')
 *    ('ubfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ubfe', 'value', 'offset', 'bits')
 *    ('ibfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ibfe', 'value', 'offset', 'bits')
 *    ('ibfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ibfe', 'value', 'offset', 'bits')
 *    ('bfm', 'bits', ('iand', 31, 'offset')) => ('bfm', 'bits', 'offset')
 *    ('bfm', ('iand', 31, 'bits'), 'offset') => ('bfm', 'bits', 'offset')
 *    ('ult', 'a', ('umin', ('iand', 'a', 'b'), 'c')) => False
 *    ('ult', 31, ('umin', '#bits(is_ult_32)', 'a')) => False
 *    ('ubfe', 'value', 'offset', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset'))))) => ('ubfe', 'value', 'offset', 'width')
 *    ('ibfe', 'value', 'offset', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset'))))) => ('ibfe', 'value', 'offset', 'width')
 *    ('bfm', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset')))), 'offset') => ('bfm', 'width', 'offset')
 *    ('ubfe', 'a', 'b', 0) => 0
 *    ('ibfe', 'a', 'b', 0) => 0
 *    ('ubfe', 'a', 0, '#b') => ('iand', 'a', ('ushr', 4294967295, ('ineg', 'b')))
 *    ('b2i32', ('i2b', ('ubfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1)
 *    ('b2i32', ('i2b', ('ibfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1)
 *    ('ine', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ieq', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ine', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ieq', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ieq', 0, 'bits'), 0, ('ishr', ('ishl', 'value', ('isub', ('isub', 32, 'bits'), 'offset')), ('isub', 32, 'bits')))
 *    ('ubitfield_extract', 'value', 'offset', 'bits') => ('iand', ('ushr', 'value', 'offset'), ('bcsel', ('ieq', 'bits', 32), 4294967295, ('isub', ('ishl', 1, 'bits'), 1)))
 *    ('ifind_msb', 'value') => ('ufind_msb', ('bcsel', ('ilt', 'value', 0), ('inot', 'value'), 'value'))
 *    ('ifind_msb', 'value') => ('bcsel', ('ige', ('ifind_msb_rev', 'value'), 0), ('isub', 31, ('ifind_msb_rev', 'value')), ('ifind_msb_rev', 'value'))
 *    ('ufind_msb', 'value') => ('bcsel', ('ige', ('ufind_msb_rev', 'value'), 0), ('isub', 31, ('ufind_msb_rev', 'value')), ('ufind_msb_rev', 'value'))
 *    ('uclz', 'a') => ('umin', 32, ('ufind_msb_rev', 'a'))
 *    ('find_lsb', 'value') => ('ufind_msb', ('iand', 'value', ('ineg', 'value')))
 *    ('extract_i8', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 3, 'b'), 8)), 24)
 *    ('extract_u8', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 8)), 255)
 *    ('extract_i16', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 1, 'b'), 16)), 16)
 *    ('extract_u16', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 16)), 65535)
 *    ('pack_unorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 65535.0))))
 *    ('pack_unorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 255.0))))
 *    ('pack_snorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 32767.0))))
 *    ('pack_snorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0))))
 *    ('unpack_unorm_2x16', 'v') => ('fdiv', ('u2f32', ('vec2', ('extract_u16', 'v', 0), ('extract_u16', 'v', 1))), 65535.0)
 *    ('unpack_unorm_4x8', 'v') => ('fdiv', ('u2f32', ('vec4', ('extract_u8', 'v', 0), ('extract_u8', 'v', 1), ('extract_u8', 'v', 2), ('extract_u8', 'v', 3))), 255.0)
 *    ('unpack_snorm_2x16', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec2', ('extract_i16', 'v', 0), ('extract_i16', 'v', 1))), 32767.0)))
 *    ('unpack_snorm_4x8', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec4', ('extract_i8', 'v', 0), ('extract_i8', 'v', 1), ('extract_i8', 'v', 2), ('extract_i8', 'v', 3))), 127.0)))
 *    ('pack_half_2x16_split', 'a@32', 'b@32') => ('ior', ('ishl', ('u2u32', ('f2f16', 'b')), 16), ('u2u32', ('f2f16', 'a')))
 *    ('unpack_half_2x16_split_x', 'a@32') => ('f2f32', ('u2u16', 'a'))
 *    ('unpack_half_2x16_split_y', 'a@32') => ('f2f32', ('u2u16', ('ushr', 'a', 16)))
 *    ('pack_32_2x16_split', 'a@16', 'b@16') => ('ior', ('ishl', ('u2u32', 'b'), 16), ('u2u32', 'a'))
 *    ('unpack_32_2x16_split_x', 'a@32') => ('u2u16', 'a')
 *    ('unpack_32_2x16_split_y', 'a@32') => ('u2u16', ('ushr', 'a', 16))
 *    ('isign', 'a') => ('imin', ('imax', 'a', -1), 1)
 *    ('imin', ('imax', 'a', -1), 1) => ('isign', 'a')
 *    ('imax', ('imin', 'a', 1), -1) => ('isign', 'a')
 *    ('fsign', 'a') => ('fsub', ('b2f', ('!flt', 0.0, 'a')), ('b2f', ('!flt', 'a', 0.0)))
 *    ('amul', 'a', 'b') => ('imul', 'a', 'b')
 *    ('umul24', 'a', 'b') => ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215))
 *    ('umad24', 'a', 'b', 'c') => ('iadd', ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)), 'c')
 *    ('imul24_relaxed', 'a', 'b') => ('imul24', 'a', 'b')
 *    ('imul24_relaxed', 'a', 'b') => ('imul', 'a', 'b')
 *    ('umad24_relaxed', 'a', 'b', 'c') => ('umad24', 'a', 'b', 'c')
 *    ('umad24_relaxed', 'a', 'b', 'c') => ('iadd', ('umul24_relaxed', 'a', 'b'), 'c')
 *    ('umul24_relaxed', 'a', 'b') => ('umul24', 'a', 'b')
 *    ('umul24_relaxed', 'a', 'b') => ('imul', 'a', 'b')
 *    ('imad24_ir3', 'a', 'b', 0) => ('imul24', 'a', 'b')
 *    ('imad24_ir3', 'a', 0, 'c') => c
 *    ('imad24_ir3', 'a', 1, 'c') => ('iadd', 'a', 'c')
 *    ('imad24_ir3', '#a', '#b', 'c') => ('iadd', ('imul', 'a', 'b'), 'c')
 *    ('imul24', 'a', '#b@32(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b'))
 *    ('imul24', 'a', '#b@32(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b'))))
 *    ('imul24', 'a', 0) => 0
 *    ('iadd_sat@8', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 127, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 128, ('iadd', 'a', 'b')))
 *    ('isub_sat@8', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 127, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 128, ('isub', 'a', 'b')))
 *    ('iadd_sat@16', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 32767, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 32768, ('iadd', 'a', 'b')))
 *    ('isub_sat@16', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 32767, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 32768, ('isub', 'a', 'b')))
 *    ('iadd_sat@32', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 2147483647, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 2147483648, ('iadd', 'a', 'b')))
 *    ('isub_sat@32', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 2147483647, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 2147483648, ('isub', 'a', 'b')))
 *    ('iadd_sat@64', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 9223372036854775807, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 9223372036854775808, ('iadd', 'a', 'b')))
 *    ('isub_sat@64', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 9223372036854775807, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 9223372036854775808, ('isub', 'a', 'b')))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('f2b1', ('b2f', 'a@1')) => a
 *    ('i2b1', ('b2i', 'a@1')) => a
 *    ('f2b8', ('b2f', 'a@8')) => a
 *    ('i2b8', ('b2i', 'a@8')) => a
 *    ('f2b16', ('b2f', 'a@16')) => a
 *    ('i2b16', ('b2i', 'a@16')) => a
 *    ('f2b32', ('b2f', 'a@32')) => a
 *    ('i2b32', ('b2i', 'a@32')) => a
 *    ('f2f', ('b2f', 'a')) => ('b2f', 'a')
 *    ('f2u', ('b2f', 'a')) => ('b2i', 'a')
 *    ('f2i', ('b2f', 'a')) => ('b2i', 'a')
 *    ('u2f', ('b2i', 'a')) => ('b2f', 'a')
 *    ('u2u', ('b2i', 'a')) => ('b2i', 'a')
 *    ('i2f', ('b2i', 'a')) => ('b2f', 'a')
 *    ('i2i', ('b2i', 'a')) => ('b2i', 'a')
 *    ('i2i1', 'a@1') => a
 *    ('i2i8', 'a@8') => a
 *    ('i2i16', 'a@16') => a
 *    ('i2i32', 'a@32') => a
 *    ('i2i64', 'a@64') => a
 *    ('u2u1', 'a@1') => a
 *    ('u2u8', 'a@8') => a
 *    ('u2u16', 'a@16') => a
 *    ('u2u32', 'a@32') => a
 *    ('u2u64', 'a@64') => a
 *    ('f2f16', 'a@16') => a
 *    ('f2f32', 'a@32') => a
 *    ('f2f64', 'a@64') => a
 *    ('b2b1', 'a@1') => a
 *    ('b2b8', 'a@8') => a
 *    ('b2b16', 'a@16') => a
 *    ('b2b32', 'a@32') => a
 *    ('i2i1', ('i2i8', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u8', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i8', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u8', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i16', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u16', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i16', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u16', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i32', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u32', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i32', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u32', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i64', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u64', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i64', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u64', 'a')) => ('u2u1', 'a')
 *    ('i2i8', ('i2i1', 'a@1')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u1', 'a@1')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i16', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u16', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i16', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u16', 'a')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i32', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u32', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i32', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u32', 'a')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i64', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u64', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i64', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u64', 'a')) => ('u2u8', 'a')
 *    ('i2i16', ('i2i1', 'a@1')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u1', 'a@1')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i8', 'a@1')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u8', 'a@1')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i8', 'a@8')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u8', 'a@8')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i32', 'a')) => ('i2i16', 'a')
 *    ('i2i16', ('u2u32', 'a')) => ('u2u16', 'a')
 *    ('u2u16', ('i2i32', 'a')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u32', 'a')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i64', 'a')) => ('i2i16', 'a')
 *    ('i2i16', ('u2u64', 'a')) => ('u2u16', 'a')
 *    ('u2u16', ('i2i64', 'a')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u64', 'a')) => ('u2u16', 'a')
 *    ('i2i32', ('i2i1', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u1', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i8', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u8', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i8', 'a@8')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u8', 'a@8')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@8')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@8')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@16')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@16')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i64', 'a')) => ('i2i32', 'a')
 *    ('i2i32', ('u2u64', 'a')) => ('u2u32', 'a')
 *    ('u2u32', ('i2i64', 'a')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u64', 'a')) => ('u2u32', 'a')
 *    ('i2i64', ('i2i1', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u1', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i8', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u8', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i8', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u8', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@16')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@16')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@16')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@16')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@32')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@32')) => ('u2u64', 'a')
 *    ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a')
 *    ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a')
 *    ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a')
 *    ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a')
 *    ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a')
 *    ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a')
 *    ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a')
 *    ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a')
 *    ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a')
 *    ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a')
 *    ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a')
 *    ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a')
 *    ('ieq', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i16', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i16', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i16', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i16', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i16', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i16', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i32', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i32', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i32', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i32', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i32', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i32', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i64', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i64', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i32', ('i2i16', 'b')), 'b'))
 *    ('ine', ('i2i32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i32', ('i2i16', 'b')), 'b'))
 *    ('ilt', ('i2i32', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b'))))
 *    ('ilt', '#a', ('i2i32', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b')))
 *    ('ige', ('i2i32', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b'))))
 *    ('ige', '#a', ('i2i32', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i64', ('i2i16', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i64', ('i2i16', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('i2i32', 'b')), ('ieq', ('i2i64', ('i2i32', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('i2i32', 'b')), ('ine', ('i2i64', ('i2i32', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@32'), '#b') => ('iand', ('ilt', -2147483648, 'b'), ('ior', ('ilt', 2147483647, 'b'), ('ilt', 'a', ('i2i32', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@32')) => ('iand', ('ilt', 'a', 2147483647), ('ior', ('ilt', 'a', -2147483648), ('ilt', ('i2i32', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@32'), '#b') => ('iand', ('ige', 2147483647, 'b'), ('ior', ('ige', -2147483648, 'b'), ('ige', 'a', ('i2i32', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@32')) => ('iand', ('ige', 'a', -2147483648), ('ior', ('ige', 'a', 2147483647), ('ige', ('i2i32', 'a'), 'b')))
 *    ('ieq', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u16', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u16', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u16', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u16', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u16', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u16', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u32', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u32', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u32', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u32', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u32', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u32', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u64', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u64', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u32', ('u2u16', 'b')), 'b'))
 *    ('ine', ('u2u32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u32', ('u2u16', 'b')), 'b'))
 *    ('ult', ('u2u32', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b'))))
 *    ('ult', '#a', ('u2u32', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b')))
 *    ('uge', ('u2u32', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b'))))
 *    ('uge', '#a', ('u2u32', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u64', ('u2u16', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u64', ('u2u16', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('u2u32', 'b')), ('ieq', ('u2u64', ('u2u32', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('u2u32', 'b')), ('ine', ('u2u64', ('u2u32', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@32'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 4294967295, 'b'), ('ult', 'a', ('u2u32', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@32')) => ('iand', ('ult', 'a', 4294967295), ('ior', ('ult', 'a', 0), ('ult', ('u2u32', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@32'), '#b') => ('iand', ('uge', 4294967295, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u32', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@32')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 4294967295), ('uge', ('u2u32', 'a'), 'b')))
 *    ('feq', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('feq', 'a', ('f2f16', 'b'))
 *    ('fneu', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fneu', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fge', 'a', ('f2f16', 'b'))
 *    ('flt', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('flt', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('fge', ('f2f16', 'b'), 'a')
 *    ('flt', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('flt', ('f2f16', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f16', 'b'))
 *    ('fneu', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f16', 'b'))
 *    ('flt', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('fge', ('f2f16', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('flt', ('f2f16', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f32', 'b'))
 *    ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f32', 'b'))
 *    ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('feq', 'a', ('f2f32', 'b'))
 *    ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fneu', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fge', 'a', ('f2f32', 'b'))
 *    ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('flt', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a')
 *    ('i2i32', ('iand', 'a@64', 4294967295)) => ('u2u32', 'a')
 *    ('i2i16', ('iand', 'a@32', 65535)) => ('u2u16', 'a')
 *    ('i2i16', ('iand', 'a@64', 65535)) => ('u2u16', 'a')
 *    ('i2i8', ('iand', 'a@16', 255)) => ('u2u8', 'a')
 *    ('i2i8', ('iand', 'a@32', 255)) => ('u2u8', 'a')
 *    ('i2i8', ('iand', 'a@64', 255)) => ('u2u8', 'a')
 *    ('u2u16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a
 *    ('extract_u8(only_lower_8_bits_used)', 'a@16', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a
 *    ('extract_i8(only_lower_8_bits_used)', 'a@16', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ixor', 'a', 'b')
 *    ('u2u32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a
 *    ('extract_u8(only_lower_8_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a
 *    ('extract_i8(only_lower_8_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('u2u32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a
 *    ('extract_u16(only_lower_16_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('extract_u16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a
 *    ('extract_i16(only_lower_16_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('extract_i16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('ldexp@16', 'x', 'exp') => ('fmul', ('fmul', 'x', ('i2i16', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -30), 30), 1), 15), 10))), ('i2i16', ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -30), 30), ('ishr', ('imin', ('imax', 'exp', -30), 30), 1)), 15), 10)))
 *    ('ldexp@32', 'x', 'exp') => ('fmul', ('fmul', 'x', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -254), 254), 1), 127), 23)), ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -254), 254), ('ishr', ('imin', ('imax', 'exp', -254), 254), 1)), 127), 23))
 *    ('ldexp@64', 'x', 'exp') => ('fmul', ('fmul', 'x', ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1), 1023), 20))), ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -2046), 2046), ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1)), 1023), 20)))
 *    ('ior(many-comm-expr)', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 1431655765), 1), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 2863311530), 1)) => ('bitfield_reverse', 'x')
 *    ('ior(many-comm-expr)', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 4278255360), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 16711935)) => ('bitfield_reverse', 'x')
 *    ('ball_iequal2', ('ieq', 'a', 'b'), -1) => ('ball_iequal2', 'a', 'b')
 *    ('ball_iequal2', ('feq', 'a', 'b'), -1) => ('ball_fequal2', 'a', 'b')
 *    ('bany_inequal2', ('ine', 'a', 'b'), 0) => ('bany_inequal2', 'a', 'b')
 *    ('bany_inequal2', ('fneu', 'a', 'b'), 0) => ('bany_fnequal2', 'a', 'b')
 *    ('ball_iequal3', ('ieq', 'a', 'b'), -1) => ('ball_iequal3', 'a', 'b')
 *    ('ball_iequal3', ('feq', 'a', 'b'), -1) => ('ball_fequal3', 'a', 'b')
 *    ('bany_inequal3', ('ine', 'a', 'b'), 0) => ('bany_inequal3', 'a', 'b')
 *    ('bany_inequal3', ('fneu', 'a', 'b'), 0) => ('bany_fnequal3', 'a', 'b')
 *    ('ball_iequal4', ('ieq', 'a', 'b'), -1) => ('ball_iequal4', 'a', 'b')
 *    ('ball_iequal4', ('feq', 'a', 'b'), -1) => ('ball_fequal4', 'a', 'b')
 *    ('bany_inequal4', ('ine', 'a', 'b'), 0) => ('bany_inequal4', 'a', 'b')
 *    ('bany_inequal4', ('fneu', 'a', 'b'), 0) => ('bany_fnequal4', 'a', 'b')
 *    ('ball_iequal8', ('ieq', 'a', 'b'), -1) => ('ball_iequal8', 'a', 'b')
 *    ('ball_iequal8', ('feq', 'a', 'b'), -1) => ('ball_fequal8', 'a', 'b')
 *    ('bany_inequal8', ('ine', 'a', 'b'), 0) => ('bany_inequal8', 'a', 'b')
 *    ('bany_inequal8', ('fneu', 'a', 'b'), 0) => ('bany_fnequal8', 'a', 'b')
 *    ('ball_iequal16', ('ieq', 'a', 'b'), -1) => ('ball_iequal16', 'a', 'b')
 *    ('ball_iequal16', ('feq', 'a', 'b'), -1) => ('ball_fequal16', 'a', 'b')
 *    ('bany_inequal16', ('ine', 'a', 'b'), 0) => ('bany_inequal16', 'a', 'b')
 *    ('bany_inequal16', ('fneu', 'a', 'b'), 0) => ('bany_fnequal16', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('flt', 'a', 'b')) => ('!flt', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('flt', 'b', 'a')) => ('!flt', 'b', 'a')
 *    ('iand', ('feq', 'a', 'a'), ('fge', 'a', 'b')) => ('!fge', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('fge', 'b', 'a')) => ('!fge', 'b', 'a')
 *    ('iand', ('feq', 'a', 'a'), ('feq', 'a', 'b')) => ('!feq', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'a')) => ('!feq', 'b', 'a')
 *    ('feq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('feq', 'b', 'd'), ('feq', 'c', 'd'))
 *    ('fneu', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fneu', 'b', 'd'), ('fneu', 'c', 'd'))
 *    ('ieq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ieq', 'b', 'd'), ('ieq', 'c', 'd'))
 *    ('ine', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ine', 'b', 'd'), ('ine', 'c', 'd'))
 *    ('flt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('flt', 'b', 'd'), ('flt', 'c', 'd'))
 *    ('flt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('flt', 'd', 'b'), ('flt', 'd', 'c'))
 *    ('fge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fge', 'b', 'd'), ('fge', 'c', 'd'))
 *    ('fge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('fge', 'd', 'b'), ('fge', 'd', 'c'))
 *    ('ilt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ilt', 'b', 'd'), ('ilt', 'c', 'd'))
 *    ('ilt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ilt', 'd', 'b'), ('ilt', 'd', 'c'))
 *    ('ige', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ige', 'b', 'd'), ('ige', 'c', 'd'))
 *    ('ige', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ige', 'd', 'b'), ('ige', 'd', 'c'))
 *    ('ult', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ult', 'b', 'd'), ('ult', 'c', 'd'))
 *    ('ult', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ult', 'd', 'b'), ('ult', 'd', 'c'))
 *    ('uge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('uge', 'b', 'd'), ('uge', 'c', 'd'))
 *    ('uge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('uge', 'd', 'b'), ('uge', 'd', 'c'))
 *    ('fadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fadd', 'b', 'd'), ('fadd', 'c', 'd'))
 *    ('fmul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmul', 'b', 'd'), ('fmul', 'c', 'd'))
 *    ('fmulz', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmulz', 'b', 'd'), ('fmulz', 'c', 'd'))
 *    ('iadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('iadd', 'b', 'd'), ('iadd', 'c', 'd'))
 *    ('imul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('imul', 'b', 'd'), ('imul', 'c', 'd'))
 *    ('fddx', 'a') => 0.0
 *    ('fddx_fine', 'a') => 0.0
 *    ('fddx_coarse', 'a') => 0.0
 *    ('fddy', 'a') => 0.0
 *    ('fddy_fine', 'a') => 0.0
 *    ('fddy_coarse', 'a') => 0.0
 *    ('umul_low', '#a(is_lower_half_zero)', 'b') => 0
 *    ('imadsh_mix16', '#a@32(is_lower_half_zero)', 'b@32', 'c@32') => c
 *    ('imadsh_mix16', 'a@32', '#b@32(is_upper_half_zero)', 'c@32') => c
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd')
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd')
 *    ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c(is_not_const)'), ('fmulz', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz', 'b', 'c(is_not_const)'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c(is_not_const)'), ('fmul', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul', 'b', 'c(is_not_const)'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c'), ('iadd', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c(is_not_const)'), ('iadd', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd', 'b', 'c(is_not_const)'), ('iadd(is_used_once)', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd', 'b', 'c'), ('iadd(is_used_once)', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c'), ('imul', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c(is_not_const)'), ('imul', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul', 'b', 'c(is_not_const)'), ('imul(is_used_once)', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul', 'b', 'c'), ('imul(is_used_once)', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c'), ('iand', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c(is_not_const)'), ('iand', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand', 'b', 'c(is_not_const)'), ('iand(is_used_once)', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand', 'b', 'c'), ('iand(is_used_once)', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c'), ('ior', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c(is_not_const)'), ('ior', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior', 'b', 'c(is_not_const)'), ('ior(is_used_once)', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior', 'b', 'c'), ('ior(is_used_once)', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c'), ('ixor', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c(is_not_const)'), ('ixor', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor', 'b', 'c(is_not_const)'), ('ixor(is_used_once)', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor', 'b', 'c'), ('ixor(is_used_once)', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c'), ('fmin', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c(is_not_const)'), ('fmin', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin', 'b', 'c(is_not_const)'), ('fmin(is_used_once)', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin', 'b', 'c'), ('fmin(is_used_once)', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c'), ('fmax', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c(is_not_const)'), ('fmax', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax', 'b', 'c(is_not_const)'), ('fmax(is_used_once)', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax', 'b', 'c'), ('fmax(is_used_once)', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c'), ('imin', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c(is_not_const)'), ('imin', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin', 'b', 'c(is_not_const)'), ('imin(is_used_once)', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin', 'b', 'c'), ('imin(is_used_once)', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c'), ('imax', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c(is_not_const)'), ('imax', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax', 'b', 'c(is_not_const)'), ('imax(is_used_once)', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax', 'b', 'c'), ('imax(is_used_once)', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c'), ('umin', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c(is_not_const)'), ('umin', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin', 'b', 'c(is_not_const)'), ('umin(is_used_once)', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin', 'b', 'c'), ('umin(is_used_once)', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c'), ('umax', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c(is_not_const)'), ('umax', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax', 'b', 'c(is_not_const)'), ('umax(is_used_once)', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax', 'b', 'c'), ('umax(is_used_once)', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c')
 *    ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c')
 *    ('bcsel', 'c', ('frcp(is_used_once)', 'a'), ('frcp(is_used_once)', 'b')) => ('frcp', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('frsq(is_used_once)', 'a'), ('frsq(is_used_once)', 'b')) => ('frsq', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsqrt(is_used_once)', 'a'), ('fsqrt(is_used_once)', 'b')) => ('fsqrt', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('flog2(is_used_once)', 'a'), ('flog2(is_used_once)', 'b')) => ('flog2', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsin(is_used_once)', 'a'), ('fsin(is_used_once)', 'b')) => ('fsin', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fcos(is_used_once)', 'a'), ('fcos(is_used_once)', 'b')) => ('fcos', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsin_amd(is_used_once)', 'a'), ('fsin_amd(is_used_once)', 'b')) => ('fsin_amd', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fcos_amd(is_used_once)', 'a'), ('fcos_amd(is_used_once)', 'b')) => ('fcos_amd', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fneg(is_used_once)', 'a'), ('fneg(is_used_once)', 'b')) => ('fneg', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fabs(is_used_once)', 'a'), ('fabs(is_used_once)', 'b')) => ('fabs', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b'))
 *    ('ineg', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('ineg', 'a'), ('ineg', 'b'))
 *    ('iabs', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('iabs', 'a'), ('iabs', 'b'))
 *    ('inot', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('inot', 'a'), ('inot', 'b'))
 *    ('isign', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('isign', 'a'), ('isign', 'b'))
 *    ('fisnormal', 'a@16') => ('ult', 4095, ('iadd', ('ishl', 'a', 1), 2048))
 *    ('fisnormal', 'a@32') => ('ult', 33554431, ('iadd', ('ishl', 'a', 1), 16777216))
 *    ('fisnormal', 'a@64') => ('ult', 18014398509481983, ('iadd', ('ishl', 'a', 1), 9007199254740992))
 *    ('f2f16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2f16', 'a'), ('f2f16', 'b'))
 *    ('f2fmp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2fmp', 'a'), ('f2fmp', 'b'))
 *    ('u2u16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('u2u16', 'a'), ('u2u16', 'b'))
 *    ('i2i16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2i16', 'a'), ('i2i16', 'b'))
 *    ('i2imp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2imp', 'a'), ('i2imp', 'b'))
 *    ('f2f16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'))
 *    ('f2fmp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))
 *    ('u2u16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'))
 *    ('i2i16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'))
 *    ('i2imp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'))
 *    ('f2f16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'), ('f2f16', 'd'))
 *    ('f2fmp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'), ('f2fmp', 'd'))
 *    ('u2u16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'), ('u2u16', 'd'))
 *    ('i2i16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'), ('i2i16', 'd'))
 *    ('i2imp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'), ('i2imp', 'd'))
 */


static const nir_search_value_union nir_opt_algebraic_values[] = {
   /* ('imul', 'a', '#b(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 4 },
      -1,
   } },

   /* ('imul', 'a@8', 128) => ('ishl', 'a', 7) */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x80 /* 128 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 6, 7 },
      -1,
   } },

   /* replace1_0 -> 6 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7 /* 7 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 9 },
      -1,
   } },

   /* ('imul', 'a@16', 32768) => ('ishl', 'a', 15) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x8000 /* 32768 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 11, 12 },
      -1,
   } },

   /* replace2_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf /* 15 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 14 },
      -1,
   } },

   /* ('imul', 'a@32', 2147483648) => ('ishl', 'a', 31) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x80000000 /* 2147483648 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 16, 17 },
      -1,
   } },

   /* replace3_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1f /* 31 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 19 },
      -1,
   } },

   /* ('imul', 'a@64', 9223372036854775808) => ('ishl', 'a', 63) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x8000000000000000 /* 9223372036854775808 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 21, 22 },
      -1,
   } },

   /* replace4_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3f /* 63 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 24 },
      -1,
   } },

   /* ('imul', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b')))) */
   /* search5_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 26 },
      -1,
   } },

   /* replace5_0_0 -> 0 in the cache */
   /* replace5_0_1_0_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 28 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 30 },
      -1,
   } },

   /* ('ishl', 'a', '#b') => ('imul', 'a', ('ishl', 1, 'b')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 32, 33 },
      -1,
   } },

   /* replace6_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 35, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 37 },
      -1,
   } },

   /* ('imul@64', 'a', '#b(is_bitcount2)') => ('iadd', ('ishl', 'a', ('ufind_msb', 'b')), ('ishl', 'a', ('find_lsb', 'b'))) */
   /* search7_0 -> 21 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 21, 39 },
      -1,
   } },

   /* replace7_0_0 -> 21 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 42 },
      -1,
   } },
   /* replace7_1_0 -> 21 in the cache */
   /* replace7_1_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 44 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 43, 45 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', ('imul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b') */
   /* search8_0_0 -> 16 in the cache */
   /* search8_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul_2x32_64,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 47 },
      -1,
   } },

   /* replace8_0 -> 16 in the cache */
   /* replace8_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', ('umul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b') */
   /* search9_0_0 -> 16 in the cache */
   /* search9_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umul_2x32_64,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 50 },
      -1,
   } },

   /* replace9_0 -> 16 in the cache */
   /* replace9_1 -> 36 in the cache */
   /* replace9 -> 49 in the cache */

   /* ('imul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('imul_high', 'a', 'b')) */
   /* search10_0 -> 16 in the cache */
   /* search10_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul_2x32_64,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace10_0_0 -> 16 in the cache */
   /* replace10_0_1 -> 36 in the cache */
   /* replace10_0 -> 49 in the cache */
   /* replace10_1_0 -> 16 in the cache */
   /* replace10_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul_high,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 2,
      { 49, 53 },
      -1,
   } },

   /* ('umul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('umul_high', 'a', 'b')) */
   /* search11_0 -> 16 in the cache */
   /* search11_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umul_2x32_64,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace11_0_0 -> 16 in the cache */
   /* replace11_0_1 -> 36 in the cache */
   /* replace11_0 -> 49 in the cache */
   /* replace11_1_0 -> 16 in the cache */
   /* replace11_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_high,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 2,
      { 49, 56 },
      -1,
   } },

   /* ('udiv', 'a', 1) => a */
   /* search12_0 -> 32 in the cache */
   /* search12_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_udiv,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace12 -> 32 in the cache */

   /* ('idiv', 'a', 1) => a */
   /* search13_0 -> 32 in the cache */
   /* search13_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace13 -> 32 in the cache */

   /* ('umod', 'a', 1) => 0 */
   /* search14_0 -> 32 in the cache */
   /* search14_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umod,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },

   /* ('imod', 'a', 1) => 0 */
   /* search15_0 -> 32 in the cache */
   /* search15_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace15 -> 61 in the cache */

   /* ('imod', 'a', -1) => 0 */
   /* search16_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 32, 63 },
      -1,
   } },

   /* replace16 -> 61 in the cache */

   /* ('irem', 'a', 1) => 0 */
   /* search17_0 -> 32 in the cache */
   /* search17_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace17 -> 61 in the cache */

   /* ('irem', 'a', -1) => 0 */
   /* search18_0 -> 32 in the cache */
   /* search18_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 32, 63 },
      -1,
   } },

   /* replace18 -> 61 in the cache */

   /* ('udiv', 'a', '#b(is_pos_power_of_two)') => ('ushr', 'a', ('find_lsb', 'b')) */
   /* search19_0 -> 0 in the cache */
   /* search19_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_udiv,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace19_0 -> 0 in the cache */
   /* replace19_1_0 -> 3 in the cache */
   /* replace19_1 -> 4 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 0, 4 },
      -1,
   } },

   /* ('idiv', 'a', '#b(is_pos_power_of_two)') => ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', 'b'))) */
   /* search20_0 -> 0 in the cache */
   /* search20_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace20_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace20_1_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace20_1_1_0 -> 3 in the cache */
   /* replace20_1_1 -> 4 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 71, 4 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 70, 72 },
      -1,
   } },

   /* ('idiv', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', ('iabs', 'b'))))) */
   /* search21_0 -> 0 in the cache */
   /* search21_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace21_0_0_0 -> 0 in the cache */
   /* replace21_0_0 -> 70 in the cache */
   /* replace21_0_1_0_0 -> 0 in the cache */
   /* replace21_0_1_0 -> 71 in the cache */
   /* replace21_0_1_1_0_0 -> 3 in the cache */
   /* replace21_0_1_1_0 -> 28 in the cache */
   /* replace21_0_1_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 71, 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 70, 75 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 76 },
      -1,
   } },

   /* ('umod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1)) */
   /* search22_0 -> 0 in the cache */
   /* search22_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umod,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace22_0 -> 0 in the cache */
   /* replace22_1_0 -> 3 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3, 79 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 80 },
      -1,
   } },

   /* ('imod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1)) */
   /* search23_0 -> 0 in the cache */
   /* search23_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace23_0 -> 0 in the cache */
   /* replace23_1_0 -> 3 in the cache */
   /* replace23_1_1 -> 79 in the cache */
   /* replace23_1 -> 80 in the cache */
   /* replace23 -> 81 in the cache */

   /* ('imod', 'a', '#b(is_neg_power_of_two)') => ('bcsel', ('ieq', ('ior', 'a', 'b'), 'b'), 0, ('ior', 'a', 'b')) */
   /* search24_0 -> 0 in the cache */
   /* search24_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace24_0_0_0 -> 0 in the cache */
   /* replace24_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace24_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 84, 3 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   /* replace24_2_0 -> 0 in the cache */
   /* replace24_2_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 85, 86, 87 },
      -1,
   } },

   /* ('irem', 'a', '#b(is_pos_power_of_two)') => ('isub', 'a', ('iand', ('bcsel', ('ilt', 'a', 0), ('iadd', 'a', ('isub', 'b', 1)), 'a'), ('ineg', 'b'))) */
   /* search25_0 -> 0 in the cache */
   /* search25_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace25_0 -> 0 in the cache */
   /* replace25_1_0_0_0 -> 0 in the cache */
   /* replace25_1_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 86 },
      -1,
   } },
   /* replace25_1_0_1_0 -> 0 in the cache */
   /* replace25_1_0_1_1_0 -> 3 in the cache */
   /* replace25_1_0_1_1_1 -> 79 in the cache */
   /* replace25_1_0_1_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 80 },
      -1,
   } },
   /* replace25_1_0_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 90, 91, 0 },
      -1,
   } },
   /* replace25_1_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 92, 93 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 0, 94 },
      -1,
   } },

   /* ('irem', 'a', '#b(is_neg_power_of_two)') => ('irem', 'a', ('iabs', 'b')) */
   /* search26_0 -> 0 in the cache */
   /* search26_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace26_0 -> 0 in the cache */
   /* replace26_1_0 -> 3 in the cache */
   /* replace26_1 -> 28 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 28 },
      -1,
   } },

   /* ('~fneg', ('fneg', 'a')) => a */
   /* search27_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace27 -> 32 in the cache */

   /* ('ineg', ('ineg', 'a')) => a */
   /* search28_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace28 -> 32 in the cache */

   /* ('fabs', ('fneg', 'a')) => ('fabs', 'a') */
   /* search29_0_0 -> 32 in the cache */
   /* search29_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace29_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('fabs', ('u2f', 'a')) => ('u2f', 'a') */
   /* search30_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 104 },
      -1,
   } },

   /* replace30_0 -> 32 in the cache */
   /* replace30 -> 104 in the cache */

   /* ('iabs', ('iabs', 'a')) => ('iabs', 'a') */
   /* search31_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 106 },
      -1,
   } },

   /* replace31_0 -> 32 in the cache */
   /* replace31 -> 106 in the cache */

   /* ('iabs', ('ineg', 'a')) => ('iabs', 'a') */
   /* search32_0_0 -> 32 in the cache */
   /* search32_0 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace32_0 -> 32 in the cache */
   /* replace32 -> 106 in the cache */

   /* ('f2b', ('fneg', 'a')) => ('f2b', 'a') */
   /* search33_0_0 -> 32 in the cache */
   /* search33_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2b,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace33_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2b,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2b', ('ineg', 'a')) => ('i2b', 'a') */
   /* search34_0_0 -> 32 in the cache */
   /* search34_0 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace34_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~fadd', 'a', 0.0) => a */
   /* search35_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* replace35 -> 32 in the cache */

   /* ('fadd(is_only_used_as_float)', 'a@16', 0.0) => a */
   /* search36_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 115 },
      1,
   } },

   /* replace36 -> 11 in the cache */

   /* ('fadd(is_only_used_as_float)', 'a@32', 0.0) => a */
   /* search37_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 117 },
      1,
   } },

   /* replace37 -> 16 in the cache */

   /* ('iadd', 'a', 0) => a */
   /* search38_0 -> 32 in the cache */
   /* search38_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace38 -> 32 in the cache */

   /* ('iadd_sat', 'a', 0) => a */
   /* search39_0 -> 32 in the cache */
   /* search39_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace39 -> 32 in the cache */

   /* ('isub_sat', 'a', 0) => a */
   /* search40_0 -> 32 in the cache */
   /* search40_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* replace40 -> 32 in the cache */

   /* ('uadd_sat', 'a', 0) => a */
   /* search41_0 -> 32 in the cache */
   /* search41_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace41 -> 32 in the cache */

   /* ('usub_sat', 'a', 0) => a */
   /* search42_0 -> 32 in the cache */
   /* search42_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* replace42 -> 32 in the cache */

   /* ('usadd_4x8_vc4', 'a', 0) => a */
   /* search43_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_usadd_4x8_vc4,
      0, 1,
      { 16, 124 },
      -1,
   } },

   /* replace43 -> 16 in the cache */

   /* ('usadd_4x8_vc4', 'a', -1) => -1 */
   /* search44_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_usadd_4x8_vc4,
      0, 1,
      { 16, 126 },
      -1,
   } },

   /* replace44 -> 126 in the cache */

   /* ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* search45_1_0 -> 128 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 130, 132 },
      -1,
   } },

   /* replace45_0 -> 128 in the cache */
   /* replace45_1_0 -> 129 in the cache */
   /* replace45_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 128, 134 },
      -1,
   } },

   /* ('~fadd', ('fmulz', 'a', 'b'), ('fmulz', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c')) */
   /* search46_0_0 -> 16 in the cache */
   /* search46_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* search46_1_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 16, 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 136, 138 },
      -1,
   } },

   /* replace46_0 -> 16 in the cache */
   /* replace46_1_0 -> 36 in the cache */
   /* replace46_1_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 36, 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 16, 140 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search47_0 -> 0 in the cache */
   /* search47_1 -> 3 in the cache */
   /* search47_2_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 0, 142, 143 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 3, 144 },
      -1,
   } },

   /* replace47_0 -> 0 in the cache */
   /* replace47_1_0 -> 3 in the cache */
   /* replace47_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3, 142 },
      -1,
   } },
   /* replace47_2 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 146, 143 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', ('fmul(is_used_once)', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   /* search48_0 -> 0 in the cache */
   /* search48_1 -> 3 in the cache */
   /* search48_2_0 -> 0 in the cache */
   /* search48_2_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 0, 142 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 3, 148 },
      -1,
   } },

   /* replace48_0 -> 0 in the cache */
   /* replace48_1_0 -> 3 in the cache */
   /* replace48_1_1 -> 142 in the cache */
   /* replace48_1 -> 146 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 0, 146 },
      -1,
   } },

   /* ('~fadd', ('fmul(is_used_once)', 'a', 'b'), ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 151, 152 },
      0,
   } },
   /* search49_1_0 -> 151 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 151, 154, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 153, 156 },
      -1,
   } },

   /* replace49_0 -> 151 in the cache */
   /* replace49_1_0 -> 152 in the cache */
   /* replace49_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 152, 154 },
      -1,
   } },
   /* replace49_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 151, 158, 155 },
      -1,
   } },

   /* ('~ffma', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('ffma', 'a', 'c', 'd')) */
   /* search50_0 -> 151 in the cache */
   /* search50_1_0 -> 152 in the cache */
   /* search50_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 152, 154 },
      0,
   } },
   /* search50_2_0 -> 152 in the cache */
   /* search50_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 151, 160, 161 },
      -1,
   } },

   /* replace50_0 -> 152 in the cache */
   /* replace50_1_0 -> 151 in the cache */
   /* replace50_1_1 -> 154 in the cache */
   /* replace50_1_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 151, 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 152, 163 },
      -1,
   } },

   /* ('~ffmaz', 'a', 'b', ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search51_0 -> 16 in the cache */
   /* search51_1 -> 36 in the cache */
   /* search51_2_0 -> 16 in the cache */
   /* search51_2_1 -> 137 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 16, 137, 165 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 16, 36, 166 },
      -1,
   } },

   /* replace51_0 -> 16 in the cache */
   /* replace51_1_0 -> 36 in the cache */
   /* replace51_1_1 -> 137 in the cache */
   /* replace51_1 -> 140 in the cache */
   /* replace51_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 16, 140, 165 },
      -1,
   } },

   /* ('~ffmaz', 'a', 'b', ('fmulz(is_used_once)', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c')) */
   /* search52_0 -> 16 in the cache */
   /* search52_1 -> 36 in the cache */
   /* search52_2_0 -> 16 in the cache */
   /* search52_2_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 137 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 16, 36, 169 },
      -1,
   } },

   /* replace52_0 -> 16 in the cache */
   /* replace52_1_0 -> 36 in the cache */
   /* replace52_1_1 -> 137 in the cache */
   /* replace52_1 -> 140 in the cache */
   /* replace52 -> 141 in the cache */

   /* ('~fadd', ('fmulz(is_used_once)', 'a', 'b'), ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search53_0_0 -> 16 in the cache */
   /* search53_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 36 },
      0,
   } },
   /* search53_1_0 -> 16 in the cache */
   /* search53_1_1 -> 137 in the cache */
   /* search53_1_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 16, 137, 165 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 171, 172 },
      -1,
   } },

   /* replace53_0 -> 16 in the cache */
   /* replace53_1_0 -> 36 in the cache */
   /* replace53_1_1 -> 137 in the cache */
   /* replace53_1 -> 140 in the cache */
   /* replace53_2 -> 165 in the cache */
   /* replace53 -> 168 in the cache */

   /* ('~ffmaz', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('ffmaz', 'a', 'c', 'd')) */
   /* search54_0 -> 16 in the cache */
   /* search54_1_0 -> 36 in the cache */
   /* search54_1_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 137 },
      0,
   } },
   /* search54_2_0 -> 36 in the cache */
   /* search54_2_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 36, 165 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 16, 174, 175 },
      -1,
   } },

   /* replace54_0 -> 36 in the cache */
   /* replace54_1_0 -> 16 in the cache */
   /* replace54_1_1 -> 137 in the cache */
   /* replace54_1_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 16, 137, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 36, 177 },
      -1,
   } },

   /* ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c')) */
   /* search55_0_0 -> 128 in the cache */
   /* search55_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* search55_1_0 -> 128 in the cache */
   /* search55_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 179, 180 },
      -1,
   } },

   /* replace55_0 -> 128 in the cache */
   /* replace55_1_0 -> 129 in the cache */
   /* replace55_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 128, 182 },
      -1,
   } },

   /* ('iadd', ('ishl', 'b', 'a'), ('ishl', 'c', 'a')) => ('ishl', ('iadd', 'b', 'c'), 'a') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 184, 185 },
      -1,
   } },
   /* search56_1_0 -> 131 in the cache */
   /* search56_1_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 131, 185 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 186, 187 },
      -1,
   } },

   /* replace56_0_0 -> 184 in the cache */
   /* replace56_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 184, 131 },
      -1,
   } },
   /* replace56_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 189, 185 },
      -1,
   } },

   /* ('iand', ('ior', 'a', 'b'), ('ior', 'a', 'c')) => ('ior', 'a', ('iand', 'b', 'c')) */
   /* search57_0_0 -> 128 in the cache */
   /* search57_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* search57_1_0 -> 128 in the cache */
   /* search57_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 191, 192 },
      -1,
   } },

   /* replace57_0 -> 128 in the cache */
   /* replace57_1_0 -> 129 in the cache */
   /* replace57_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 128, 194 },
      -1,
   } },

   /* ('ior', ('iand', 'a', 'b'), ('iand', 'a', 'c')) => ('iand', 'a', ('ior', 'b', 'c')) */
   /* search58_0_0 -> 128 in the cache */
   /* search58_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* search58_1_0 -> 128 in the cache */
   /* search58_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 196, 197 },
      -1,
   } },

   /* replace58_0 -> 128 in the cache */
   /* replace58_1_0 -> 129 in the cache */
   /* replace58_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 128, 199 },
      -1,
   } },

   /* ('ieq', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('ine', ('iand', 'a', 'b'), 0) */
   /* search59_0_0 -> 0 in the cache */
   /* search59_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search59_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 201, 3 },
      -1,
   } },

   /* replace59_0_0 -> 0 in the cache */
   /* replace59_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace59_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 203, 86 },
      -1,
   } },

   /* ('ine', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('ieq', ('iand', 'a', 'b'), 0) */
   /* search60_0_0 -> 0 in the cache */
   /* search60_0_1 -> 1 in the cache */
   /* search60_0 -> 201 in the cache */
   /* search60_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 201, 3 },
      -1,
   } },

   /* replace60_0_0 -> 0 in the cache */
   /* replace60_0_1 -> 3 in the cache */
   /* replace60_0 -> 203 in the cache */
   /* replace60_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 203, 86 },
      -1,
   } },

   /* ('~fadd', ('fneg', 'a'), 'a') => 0.0 */
   /* search61_0_0 -> 32 in the cache */
   /* search61_0 -> 98 in the cache */
   /* search61_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace61 -> 113 in the cache */

   /* ('iadd', ('ineg', 'a'), 'a') => 0 */
   /* search62_0_0 -> 32 in the cache */
   /* search62_0 -> 100 in the cache */
   /* search62_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 100, 32 },
      -1,
   } },

   /* replace62 -> 61 in the cache */

   /* ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b */
   /* search63_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search63_1_0 -> 0 in the cache */
   /* search63_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 209, 210 },
      -1,
   } },

   /* replace63 -> 3 in the cache */

   /* ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b */
   /* search64_0 -> 0 in the cache */
   /* search64_1_0_0 -> 0 in the cache */
   /* search64_1_0 -> 209 in the cache */
   /* search64_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 209, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 0, 212 },
      -1,
   } },

   /* replace64 -> 3 in the cache */

   /* ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b */
   /* search65_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search65_1_0 -> 0 in the cache */
   /* search65_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 214, 215 },
      -1,
   } },

   /* replace65 -> 3 in the cache */

   /* ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b */
   /* search66_0 -> 0 in the cache */
   /* search66_1_0_0 -> 0 in the cache */
   /* search66_1_0 -> 214 in the cache */
   /* search66_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 214, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 0, 217 },
      -1,
   } },

   /* replace66 -> 3 in the cache */

   /* ('fadd', ('fsat', 'a'), ('fsat', ('fneg', 'a'))) => ('fsat', ('fabs', 'a')) */
   /* search67_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search67_1_0_0 -> 32 in the cache */
   /* search67_1_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 219, 220 },
      -1,
   } },

   /* replace67_0_0 -> 32 in the cache */
   /* replace67_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 103 },
      -1,
   } },

   /* ('~fmul', 'a', 0.0) => 0.0 */
   /* search68_0 -> 32 in the cache */
   /* search68_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* replace68 -> 113 in the cache */

   /* ('fmul', 'a@16', 0.0) => 0.0 */
   /* search69_0 -> 11 in the cache */
   /* search69_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 115 },
      -1,
   } },

   /* replace69 -> 115 in the cache */

   /* ('fmul', 'a@32', 0.0) => 0.0 */
   /* search70_0 -> 16 in the cache */
   /* search70_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 16, 117 },
      -1,
   } },

   /* replace70 -> 117 in the cache */

   /* ('fmulz', 'a', 0.0) => 0.0 */
   /* search71_0 -> 16 in the cache */
   /* search71_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 117 },
      -1,
   } },

   /* replace71 -> 117 in the cache */

   /* ('fmulz', 'a', 'b(is_finite_not_zero)') => ('fmul', 'a', 'b') */
   /* search72_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 227 },
      -1,
   } },

   /* replace72_0 -> 16 in the cache */
   /* replace72_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('fmulz', 'a(is_finite)', 'b(is_finite)') => ('fmul', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 230, 231 },
      -1,
   } },

   /* replace73_0 -> 16 in the cache */
   /* replace73_1 -> 36 in the cache */
   /* replace73 -> 229 in the cache */

   /* ('fmulz', 'a', 'a') => ('fmul', 'a', 'a') */
   /* search74_0 -> 16 in the cache */
   /* search74_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      -1, 0,
      { 16, 16 },
      -1,
   } },

   /* replace74_0 -> 16 in the cache */
   /* replace74_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 16, 16 },
      -1,
   } },

   /* ('ffmaz', 'a', 'b(is_finite_not_zero)', 'c') => ('ffma', 'a', 'b', 'c') */
   /* search75_0 -> 16 in the cache */
   /* search75_1 -> 227 in the cache */
   /* search75_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 227, 137 },
      -1,
   } },

   /* replace75_0 -> 16 in the cache */
   /* replace75_1 -> 36 in the cache */
   /* replace75_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* ('ffmaz', 'a(is_finite)', 'b(is_finite)', 'c') => ('ffma', 'a', 'b', 'c') */
   /* search76_0 -> 230 in the cache */
   /* search76_1 -> 231 in the cache */
   /* search76_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 230, 231, 137 },
      -1,
   } },

   /* replace76_0 -> 16 in the cache */
   /* replace76_1 -> 36 in the cache */
   /* replace76_2 -> 137 in the cache */
   /* replace76 -> 236 in the cache */

   /* ('ffmaz', 'a', 'a', 'b') => ('ffma', 'a', 'a', 'b') */
   /* search77_0 -> 16 in the cache */
   /* search77_1 -> 16 in the cache */
   /* search77_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      -1, 0,
      { 16, 16, 36 },
      -1,
   } },

   /* replace77_0 -> 16 in the cache */
   /* replace77_1 -> 16 in the cache */
   /* replace77_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      -1, 0,
      { 16, 16, 36 },
      -1,
   } },

   /* ('imul', 'a', 0) => 0 */
   /* search78_0 -> 32 in the cache */
   /* search78_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace78 -> 61 in the cache */

   /* ('umul_unorm_4x8_vc4', 'a', 0) => 0 */
   /* search79_0 -> 16 in the cache */
   /* search79_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_unorm_4x8_vc4,
      0, 1,
      { 16, 124 },
      -1,
   } },

   /* replace79 -> 124 in the cache */

   /* ('umul_unorm_4x8_vc4', 'a', -1) => a */
   /* search80_0 -> 16 in the cache */
   /* search80_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_unorm_4x8_vc4,
      0, 1,
      { 16, 126 },
      -1,
   } },

   /* replace80 -> 16 in the cache */

   /* ('~fmul', 'a', 1.0) => a */
   /* search81_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 243 },
      -1,
   } },

   /* replace81 -> 32 in the cache */

   /* ('~fmulz', 'a', 1.0) => a */
   /* search82_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 245 },
      -1,
   } },

   /* replace82 -> 16 in the cache */

   /* ('fmul(is_only_used_as_float)', 'a', 1.0) => a */
   /* search83_0 -> 32 in the cache */
   /* search83_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 243 },
      1,
   } },

   /* replace83 -> 32 in the cache */

   /* ('imul', 'a', 1) => a */
   /* search84_0 -> 32 in the cache */
   /* search84_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 35 },
      -1,
   } },

   /* replace84 -> 32 in the cache */

   /* ('fmul', 'a', -1.0) => ('fneg', 'a') */
   /* search85_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 249 },
      -1,
   } },

   /* replace85_0 -> 32 in the cache */
   /* replace85 -> 98 in the cache */

   /* ('imul', 'a', -1) => ('ineg', 'a') */
   /* search86_0 -> 32 in the cache */
   /* search86_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace86_0 -> 32 in the cache */
   /* replace86 -> 100 in the cache */

   /* ('fmul', ('fsign', 'a'), ('fmul', 'a', 'a')) => ('fmul', ('fabs', 'a'), 'a') */
   /* search87_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search87_1_0 -> 32 in the cache */
   /* search87_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 32, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 252, 253 },
      -1,
   } },

   /* replace87_0_0 -> 32 in the cache */
   /* replace87_0 -> 103 in the cache */
   /* replace87_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 103, 32 },
      -1,
   } },

   /* ('fmul', ('fmul', ('fsign', 'a'), 'a'), 'a') => ('fmul', ('fabs', 'a'), 'a') */
   /* search88_0_0_0 -> 32 in the cache */
   /* search88_0_0 -> 252 in the cache */
   /* search88_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 252, 32 },
      -1,
   } },
   /* search88_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 256, 32 },
      -1,
   } },

   /* replace88_0_0 -> 32 in the cache */
   /* replace88_0 -> 103 in the cache */
   /* replace88_1 -> 32 in the cache */
   /* replace88 -> 255 in the cache */

   /* ('~ffma', 0.0, 'a', 'b') => b */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search89_1 -> 0 in the cache */
   /* search89_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 258, 0, 3 },
      -1,
   } },

   /* replace89 -> 3 in the cache */

   /* ('ffma@16(is_only_used_as_float)', 0.0, 'a', 'b') => b */
   /* search90_0 -> 115 in the cache */
   /* search90_1 -> 11 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 115, 11, 260 },
      1,
   } },

   /* replace90 -> 260 in the cache */

   /* ('ffma@32(is_only_used_as_float)', 0.0, 'a', 'b') => b */
   /* search91_0 -> 117 in the cache */
   /* search91_1 -> 16 in the cache */
   /* search91_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 117, 16, 36 },
      1,
   } },

   /* replace91 -> 36 in the cache */

   /* ('ffmaz', 0.0, 'a', 'b') => ('fadd', 0.0, 'b') */
   /* search92_0 -> 117 in the cache */
   /* search92_1 -> 16 in the cache */
   /* search92_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 117, 16, 36 },
      -1,
   } },

   /* replace92_0 -> 117 in the cache */
   /* replace92_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 117, 36 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search93_0 -> 0 in the cache */
   /* search93_1 -> 3 in the cache */
   /* search93_2 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 0, 3, 258 },
      -1,
   } },

   /* replace93_0 -> 0 in the cache */
   /* replace93_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ffma@16', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search94_0 -> 11 in the cache */
   /* search94_1 -> 260 in the cache */
   /* search94_2 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 11, 260, 115 },
      -1,
   } },

   /* replace94_0 -> 11 in the cache */
   /* replace94_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 260 },
      -1,
   } },

   /* ('ffma@32', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search95_0 -> 16 in the cache */
   /* search95_1 -> 36 in the cache */
   /* search95_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 117 },
      -1,
   } },

   /* replace95_0 -> 16 in the cache */
   /* replace95_1 -> 36 in the cache */
   /* replace95 -> 229 in the cache */

   /* ('ffmaz', 'a', 'b', 0.0) => ('fmulz', 'a', 'b') */
   /* search96_0 -> 16 in the cache */
   /* search96_1 -> 36 in the cache */
   /* search96_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 36, 117 },
      -1,
   } },

   /* replace96_0 -> 16 in the cache */
   /* replace96_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('ffma', 1.0, 'a', 'b') => ('fadd', 'a', 'b') */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* search97_1 -> 0 in the cache */
   /* search97_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 272, 0, 3 },
      -1,
   } },

   /* replace97_0 -> 0 in the cache */
   /* replace97_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ffmaz', 1.0, 'a', 'b') => ('fadd', 'a', 'b') */
   /* search98_0 -> 245 in the cache */
   /* search98_1 -> 16 in the cache */
   /* search98_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 245, 16, 36 },
      -1,
   } },

   /* replace98_0 -> 16 in the cache */
   /* replace98_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('ffma', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b') */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   /* search99_1 -> 0 in the cache */
   /* search99_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 277, 0, 3 },
      -1,
   } },

   /* replace99_0_0 -> 0 in the cache */
   /* replace99_0 -> 214 in the cache */
   /* replace99_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 214, 3 },
      -1,
   } },

   /* ('ffmaz', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b') */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   /* search100_1 -> 16 in the cache */
   /* search100_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 280, 16, 36 },
      -1,
   } },

   /* replace100_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 16 },
      -1,
   } },
   /* replace100_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 282, 36 },
      -1,
   } },

   /* ('~ffma', '#a', '#b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search101_2 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 284, 285, 131 },
      -1,
   } },

   /* replace101_0_0 -> 128 in the cache */
   /* replace101_0_1 -> 129 in the cache */
   /* replace101_0 -> 130 in the cache */
   /* replace101_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 130, 131 },
      -1,
   } },

   /* ('~ffmaz', '#a', '#b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search102_1 -> 33 in the cache */
   /* search102_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 288, 33, 137 },
      -1,
   } },

   /* replace102_0_0 -> 16 in the cache */
   /* replace102_0_1 -> 36 in the cache */
   /* replace102_0 -> 136 in the cache */
   /* replace102_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 136, 137 },
      -1,
   } },

   /* ('~flrp', 'a', 'b', 0.0) => a */
   /* search103_0 -> 0 in the cache */
   /* search103_1 -> 3 in the cache */
   /* search103_2 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 3, 258 },
      -1,
   } },

   /* replace103 -> 0 in the cache */

   /* ('~flrp', 'a', 'b', 1.0) => b */
   /* search104_0 -> 0 in the cache */
   /* search104_1 -> 3 in the cache */
   /* search104_2 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 3, 272 },
      -1,
   } },

   /* replace104 -> 3 in the cache */

   /* ('~flrp', 'a', 'a', 'b') => a */
   /* search105_0 -> 0 in the cache */
   /* search105_1 -> 0 in the cache */
   /* search105_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 0, 3 },
      -1,
   } },

   /* replace105 -> 0 in the cache */

   /* ('~flrp', 0.0, 'a', 'b') => ('fmul', 'a', 'b') */
   /* search106_0 -> 258 in the cache */
   /* search106_1 -> 0 in the cache */
   /* search106_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 258, 0, 3 },
      -1,
   } },

   /* replace106_0 -> 0 in the cache */
   /* replace106_1 -> 3 in the cache */
   /* replace106 -> 266 in the cache */

   /* ('~flrp', 'a', ('fadd(is_used_once)', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search107_0 -> 128 in the cache */
   /* search107_1_0 -> 128 in the cache */
   /* search107_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 128, 129 },
      0,
   } },
   /* search107_2 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 128, 295, 131 },
      -1,
   } },

   /* replace107_0_0 -> 129 in the cache */
   /* replace107_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 129, 131 },
      -1,
   } },
   /* replace107_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 297, 128 },
      -1,
   } },

   /* ('sdot_4x8_iadd', 'a', 0, 'b') => b */
   /* search108_0 -> 16 in the cache */
   /* search108_1 -> 124 in the cache */
   /* search108_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 16, 124, 36 },
      -1,
   } },

   /* replace108 -> 36 in the cache */

   /* ('udot_4x8_uadd', 'a', 0, 'b') => b */
   /* search109_0 -> 16 in the cache */
   /* search109_1 -> 124 in the cache */
   /* search109_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 16, 124, 36 },
      -1,
   } },

   /* replace109 -> 36 in the cache */

   /* ('sdot_4x8_iadd_sat', 'a', 0, 'b') => b */
   /* search110_0 -> 16 in the cache */
   /* search110_1 -> 124 in the cache */
   /* search110_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 16, 124, 36 },
      -1,
   } },

   /* replace110 -> 36 in the cache */

   /* ('udot_4x8_uadd_sat', 'a', 0, 'b') => b */
   /* search111_0 -> 16 in the cache */
   /* search111_1 -> 124 in the cache */
   /* search111_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 124, 36 },
      -1,
   } },

   /* replace111 -> 36 in the cache */

   /* ('sdot_2x16_iadd', 'a', 0, 'b') => b */
   /* search112_0 -> 16 in the cache */
   /* search112_1 -> 124 in the cache */
   /* search112_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 16, 124, 36 },
      -1,
   } },

   /* replace112 -> 36 in the cache */

   /* ('udot_2x16_uadd', 'a', 0, 'b') => b */
   /* search113_0 -> 16 in the cache */
   /* search113_1 -> 124 in the cache */
   /* search113_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 16, 124, 36 },
      -1,
   } },

   /* replace113 -> 36 in the cache */

   /* ('sdot_2x16_iadd_sat', 'a', 0, 'b') => b */
   /* search114_0 -> 16 in the cache */
   /* search114_1 -> 124 in the cache */
   /* search114_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 16, 124, 36 },
      -1,
   } },

   /* replace114 -> 36 in the cache */

   /* ('udot_2x16_uadd_sat', 'a', 0, 'b') => b */
   /* search115_0 -> 16 in the cache */
   /* search115_1 -> 124 in the cache */
   /* search115_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 16, 124, 36 },
      -1,
   } },

   /* replace115 -> 36 in the cache */

   /* ('sudot_4x8_iadd', 'a', 0, 'b') => b */
   /* search116_0 -> 16 in the cache */
   /* search116_1 -> 124 in the cache */
   /* search116_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 124, 36 },
      -1,
   } },

   /* replace116 -> 36 in the cache */

   /* ('sudot_4x8_iadd', 0, 'a', 'b') => b */
   /* search117_0 -> 124 in the cache */
   /* search117_1 -> 16 in the cache */
   /* search117_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 124, 16, 36 },
      -1,
   } },

   /* replace117 -> 36 in the cache */

   /* ('sudot_4x8_iadd_sat', 'a', 0, 'b') => b */
   /* search118_0 -> 16 in the cache */
   /* search118_1 -> 124 in the cache */
   /* search118_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 16, 124, 36 },
      -1,
   } },

   /* replace118 -> 36 in the cache */

   /* ('sudot_4x8_iadd_sat', 0, 'a', 'b') => b */
   /* search119_0 -> 124 in the cache */
   /* search119_1 -> 16 in the cache */
   /* search119_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 124, 16, 36 },
      -1,
   } },

   /* replace119 -> 36 in the cache */

   /* ('iadd', ('sdot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search120_0_0 -> 16 in the cache */
   /* search120_0_1 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 16, 36, 311 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 312, 313 },
      -1,
   } },

   /* replace120_0 -> 16 in the cache */
   /* replace120_1 -> 36 in the cache */
   /* replace120_2_0 -> 137 in the cache */
   /* replace120_2_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 137, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 2,
      { 16, 36, 315 },
      -1,
   } },

   /* ('iadd', ('udot_4x8_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_4x8_uadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search121_0_0 -> 16 in the cache */
   /* search121_0_1 -> 36 in the cache */
   /* search121_0_2 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 16, 36, 311 },
      0,
   } },
   /* search121_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 317, 313 },
      -1,
   } },

   /* replace121_0 -> 16 in the cache */
   /* replace121_1 -> 36 in the cache */
   /* replace121_2_0 -> 137 in the cache */
   /* replace121_2_1 -> 165 in the cache */
   /* replace121_2 -> 315 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 2,
      { 16, 36, 315 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sudot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search122_0_0 -> 16 in the cache */
   /* search122_0_1 -> 36 in the cache */
   /* search122_0_2 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 311 },
      0,
   } },
   /* search122_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 320, 313 },
      -1,
   } },

   /* replace122_0 -> 16 in the cache */
   /* replace122_1 -> 36 in the cache */
   /* replace122_2_0 -> 137 in the cache */
   /* replace122_2_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 137, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 1,
      { 16, 36, 322 },
      -1,
   } },

   /* ('iadd', ('sdot_2x16_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_2x16_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search123_0_0 -> 16 in the cache */
   /* search123_0_1 -> 36 in the cache */
   /* search123_0_2 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 16, 36, 311 },
      0,
   } },
   /* search123_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 324, 313 },
      -1,
   } },

   /* replace123_0 -> 16 in the cache */
   /* replace123_1 -> 36 in the cache */
   /* replace123_2_0 -> 137 in the cache */
   /* replace123_2_1 -> 165 in the cache */
   /* replace123_2 -> 315 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 2,
      { 16, 36, 315 },
      -1,
   } },

   /* ('iadd', ('udot_2x16_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_2x16_uadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search124_0_0 -> 16 in the cache */
   /* search124_0_1 -> 36 in the cache */
   /* search124_0_2 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 16, 36, 311 },
      0,
   } },
   /* search124_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 327, 313 },
      -1,
   } },

   /* replace124_0 -> 16 in the cache */
   /* replace124_1 -> 36 in the cache */
   /* replace124_2_0 -> 137 in the cache */
   /* replace124_2_1 -> 165 in the cache */
   /* replace124_2 -> 315 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 2,
      { 16, 36, 315 },
      -1,
   } },

   /* ('iadd', ('sdot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_4x8_iadd', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search125_0_1 -> 36 in the cache */
   /* search125_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 330, 36, 124 },
      -1,
   } },
   /* search125_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 331, 137 },
      -1,
   } },

   /* replace125_0 -> 16 in the cache */
   /* replace125_1 -> 36 in the cache */
   /* replace125_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* ('iadd', ('udot_4x8_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_4x8_uadd', 'a', 'b', 'c') */
   /* search126_0_0 -> 330 in the cache */
   /* search126_0_1 -> 36 in the cache */
   /* search126_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 330, 36, 124 },
      -1,
   } },
   /* search126_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 334, 137 },
      -1,
   } },

   /* replace126_0 -> 16 in the cache */
   /* replace126_1 -> 36 in the cache */
   /* replace126_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c') */
   /* search127_0_0 -> 330 in the cache */
   /* search127_0_1 -> 36 in the cache */
   /* search127_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 330, 36, 124 },
      -1,
   } },
   /* search127_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 337, 137 },
      -1,
   } },

   /* replace127_0 -> 16 in the cache */
   /* replace127_1 -> 36 in the cache */
   /* replace127_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 137 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd', 'a', 'b(is_not_const)', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c') */
   /* search128_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search128_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 340, 124 },
      -1,
   } },
   /* search128_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 341, 137 },
      -1,
   } },

   /* replace128_0 -> 16 in the cache */
   /* replace128_1 -> 36 in the cache */
   /* replace128_2 -> 137 in the cache */
   /* replace128 -> 339 in the cache */

   /* ('iadd', ('sdot_2x16_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_2x16_iadd', 'a', 'b', 'c') */
   /* search129_0_0 -> 330 in the cache */
   /* search129_0_1 -> 36 in the cache */
   /* search129_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 330, 36, 124 },
      -1,
   } },
   /* search129_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 343, 137 },
      -1,
   } },

   /* replace129_0 -> 16 in the cache */
   /* replace129_1 -> 36 in the cache */
   /* replace129_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* ('iadd', ('udot_2x16_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_2x16_uadd', 'a', 'b', 'c') */
   /* search130_0_0 -> 330 in the cache */
   /* search130_0_1 -> 36 in the cache */
   /* search130_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 330, 36, 124 },
      -1,
   } },
   /* search130_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 346, 137 },
      -1,
   } },

   /* replace130_0 -> 16 in the cache */
   /* replace130_1 -> 36 in the cache */
   /* replace130_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* ('sdot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search131_0 -> 288 in the cache */
   /* search131_1 -> 33 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 288, 33, 349 },
      -1,
   } },

   /* replace131_0_0 -> 16 in the cache */
   /* replace131_0_1 -> 36 in the cache */
   /* replace131_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 16, 36, 124 },
      -1,
   } },
   /* replace131_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 351, 137 },
      -1,
   } },

   /* ('udot_4x8_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_4x8_uadd', 'a', 'b', 0), 'c') */
   /* search132_0 -> 288 in the cache */
   /* search132_1 -> 33 in the cache */
   /* search132_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 288, 33, 349 },
      -1,
   } },

   /* replace132_0_0 -> 16 in the cache */
   /* replace132_0_1 -> 36 in the cache */
   /* replace132_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 16, 36, 124 },
      -1,
   } },
   /* replace132_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 354, 137 },
      -1,
   } },

   /* ('sudot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sudot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search133_0 -> 288 in the cache */
   /* search133_1 -> 33 in the cache */
   /* search133_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 288, 33, 349 },
      -1,
   } },

   /* replace133_0_0 -> 16 in the cache */
   /* replace133_0_1 -> 36 in the cache */
   /* replace133_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 124 },
      -1,
   } },
   /* replace133_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 357, 137 },
      -1,
   } },

   /* ('sdot_2x16_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_2x16_iadd', 'a', 'b', 0), 'c') */
   /* search134_0 -> 288 in the cache */
   /* search134_1 -> 33 in the cache */
   /* search134_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 288, 33, 349 },
      -1,
   } },

   /* replace134_0_0 -> 16 in the cache */
   /* replace134_0_1 -> 36 in the cache */
   /* replace134_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 16, 36, 124 },
      -1,
   } },
   /* replace134_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 360, 137 },
      -1,
   } },

   /* ('udot_2x16_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_2x16_uadd', 'a', 'b', 0), 'c') */
   /* search135_0 -> 288 in the cache */
   /* search135_1 -> 33 in the cache */
   /* search135_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 288, 33, 349 },
      -1,
   } },

   /* replace135_0_0 -> 16 in the cache */
   /* replace135_0_1 -> 36 in the cache */
   /* replace135_0_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 16, 36, 124 },
      -1,
   } },
   /* replace135_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 363, 137 },
      -1,
   } },

   /* ('sdot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search136_0 -> 288 in the cache */
   /* search136_1 -> 33 in the cache */
   /* search136_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 288, 33, 349 },
      -1,
   } },

   /* replace136_0_0 -> 16 in the cache */
   /* replace136_0_1 -> 36 in the cache */
   /* replace136_0_2 -> 124 in the cache */
   /* replace136_0 -> 351 in the cache */
   /* replace136_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 2,
      { 351, 137 },
      -1,
   } },

   /* ('udot_4x8_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_4x8_uadd', 'a', 'b', 0), 'c') */
   /* search137_0 -> 288 in the cache */
   /* search137_1 -> 33 in the cache */
   /* search137_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 288, 33, 349 },
      -1,
   } },

   /* replace137_0_0 -> 16 in the cache */
   /* replace137_0_1 -> 36 in the cache */
   /* replace137_0_2 -> 124 in the cache */
   /* replace137_0 -> 354 in the cache */
   /* replace137_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 2,
      { 354, 137 },
      -1,
   } },

   /* ('sudot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sudot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search138_0 -> 288 in the cache */
   /* search138_1 -> 33 in the cache */
   /* search138_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 288, 33, 349 },
      -1,
   } },

   /* replace138_0_0 -> 16 in the cache */
   /* replace138_0_1 -> 36 in the cache */
   /* replace138_0_2 -> 124 in the cache */
   /* replace138_0 -> 357 in the cache */
   /* replace138_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 357, 137 },
      -1,
   } },

   /* ('sdot_2x16_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_2x16_iadd', 'a', 'b', 0), 'c') */
   /* search139_0 -> 288 in the cache */
   /* search139_1 -> 33 in the cache */
   /* search139_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 288, 33, 349 },
      -1,
   } },

   /* replace139_0_0 -> 16 in the cache */
   /* replace139_0_1 -> 36 in the cache */
   /* replace139_0_2 -> 124 in the cache */
   /* replace139_0 -> 360 in the cache */
   /* replace139_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 2,
      { 360, 137 },
      -1,
   } },

   /* ('udot_2x16_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_2x16_uadd', 'a', 'b', 0), 'c') */
   /* search140_0 -> 288 in the cache */
   /* search140_1 -> 33 in the cache */
   /* search140_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 288, 33, 349 },
      -1,
   } },

   /* replace140_0_0 -> 16 in the cache */
   /* replace140_0_1 -> 36 in the cache */
   /* replace140_0_2 -> 124 in the cache */
   /* replace140_0 -> 363 in the cache */
   /* replace140_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 2,
      { 363, 137 },
      -1,
   } },

   /* ('fmul@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search141_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      1, 1,
      { 375, 117 },
      -1,
   } },
   /* search141_0_1 -> 117 in the cache */
   /* search141_0_2 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 376, 117, 185 },
      -1,
   } },
   /* search141_1_0_0 -> 185 in the cache */
   /* search141_1_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      2, 1,
      { 185, 117 },
      -1,
   } },
   /* search141_1_1 -> 117 in the cache */
   /* search141_1_2 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 378, 117, 375 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 377, 379 },
      -1,
   } },

   /* replace141_0 -> 185 in the cache */
   /* replace141_1 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 185, 375 },
      -1,
   } },

   /* ('fmul@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', 'a', 'b') */
   /* search142_0 -> 16 in the cache */
   /* search142_1_0_0 -> 16 in the cache */
   /* search142_1_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      1, 1,
      { 16, 117 },
      -1,
   } },
   /* search142_1_1 -> 117 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      6,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 382, 117, 383 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 16, 384 },
      -1,
   } },

   /* replace142_0 -> 16 in the cache */
   /* replace142_1 -> 36 in the cache */
   /* replace142 -> 271 in the cache */

   /* ('ffma@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search143_0_0_0 -> 375 in the cache */
   /* search143_0_0_1 -> 117 in the cache */
   /* search143_0_0 -> 376 in the cache */
   /* search143_0_1 -> 117 in the cache */
   /* search143_0_2 -> 185 in the cache */
   /* search143_0 -> 377 in the cache */
   /* search143_1_0_0 -> 185 in the cache */
   /* search143_1_0_1 -> 117 in the cache */
   /* search143_1_0 -> 378 in the cache */
   /* search143_1_1 -> 117 in the cache */
   /* search143_1_2 -> 375 in the cache */
   /* search143_1 -> 379 in the cache */
   /* search143_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 377, 379, 137 },
      -1,
   } },

   /* replace143_0 -> 185 in the cache */
   /* replace143_1 -> 375 in the cache */
   /* replace143_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 185, 375, 137 },
      -1,
   } },

   /* ('ffma@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search144_0 -> 16 in the cache */
   /* search144_1_0_0 -> 16 in the cache */
   /* search144_1_0_1 -> 117 in the cache */
   /* search144_1_0 -> 382 in the cache */
   /* search144_1_1 -> 117 in the cache */
   /* search144_1_2 -> 383 in the cache */
   /* search144_1 -> 384 in the cache */
   /* search144_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 16, 384, 137 },
      -1,
   } },

   /* replace144_0 -> 16 in the cache */
   /* replace144_1 -> 36 in the cache */
   /* replace144_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 1.0, ('fexp2', ('fmul@32', 'a', 'b'))) => ('fexp2', ('fmulz', 'a', 'b')) */
   /* search145_0_0 -> 375 in the cache */
   /* search145_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      0, 1,
      { 375, 117 },
      -1,
   } },
   /* search145_1 -> 245 in the cache */
   /* search145_2_0_0 -> 185 in the cache */
   /* search145_2_0_1 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 185, 375 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 391 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 390, 245, 392 },
      -1,
   } },

   /* replace145_0_0 -> 185 in the cache */
   /* replace145_0_1 -> 375 in the cache */
   /* replace145_0 -> 381 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 381 },
      -1,
   } },

   /* ('sdot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c') */
   /* search146_0 -> 16 in the cache */
   /* search146_1 -> 36 in the cache */
   /* search146_2 -> 137 in the cache */
   /* search146 -> 333 in the cache */

   /* replace146_0_0_0_0_0 -> 16 in the cache */
   /* replace146_0_0_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 124 },
      -1,
   } },
   /* replace146_0_0_0_1_0 -> 36 in the cache */
   /* replace146_0_0_0_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 124 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 395, 396 },
      -1,
   } },
   /* replace146_0_0_1_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 398 },
      -1,
   } },
   /* replace146_0_0_1_1_0 -> 36 in the cache */
   /* replace146_0_0_1_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 399, 400 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 397, 401 },
      -1,
   } },
   /* replace146_0_1_0_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 403 },
      -1,
   } },
   /* replace146_0_1_0_1_0 -> 36 in the cache */
   /* replace146_0_1_0_1_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 403 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 404, 405 },
      -1,
   } },
   /* replace146_0_1_1_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 407 },
      -1,
   } },
   /* replace146_0_1_1_1_0 -> 36 in the cache */
   /* replace146_0_1_1_1_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 408, 409 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 406, 410 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 402, 411 },
      -1,
   } },
   /* replace146_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 412, 137 },
      -1,
   } },

   /* ('udot_4x8_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search147_0 -> 16 in the cache */
   /* search147_1 -> 36 in the cache */
   /* search147_2 -> 137 in the cache */
   /* search147 -> 336 in the cache */

   /* replace147_0_0_0_0_0 -> 16 in the cache */
   /* replace147_0_0_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 124 },
      -1,
   } },
   /* replace147_0_0_0_1_0 -> 36 in the cache */
   /* replace147_0_0_0_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 124 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 414, 415 },
      -1,
   } },
   /* replace147_0_0_1_0_0 -> 16 in the cache */
   /* replace147_0_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 398 },
      -1,
   } },
   /* replace147_0_0_1_1_0 -> 36 in the cache */
   /* replace147_0_0_1_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 417, 418 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 416, 419 },
      -1,
   } },
   /* replace147_0_1_0_0_0 -> 16 in the cache */
   /* replace147_0_1_0_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 403 },
      -1,
   } },
   /* replace147_0_1_0_1_0 -> 36 in the cache */
   /* replace147_0_1_0_1_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 403 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 421, 422 },
      -1,
   } },
   /* replace147_0_1_1_0_0 -> 16 in the cache */
   /* replace147_0_1_1_0_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 407 },
      -1,
   } },
   /* replace147_0_1_1_1_0 -> 36 in the cache */
   /* replace147_0_1_1_1_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 424, 425 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 423, 426 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 420, 427 },
      -1,
   } },
   /* replace147_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 428, 137 },
      -1,
   } },

   /* ('sudot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search148_0 -> 16 in the cache */
   /* search148_1 -> 36 in the cache */
   /* search148_2 -> 137 in the cache */
   /* search148 -> 339 in the cache */

   /* replace148_0_0_0_0_0 -> 16 in the cache */
   /* replace148_0_0_0_0_1 -> 124 in the cache */
   /* replace148_0_0_0_0 -> 395 in the cache */
   /* replace148_0_0_0_1_0 -> 36 in the cache */
   /* replace148_0_0_0_1_1 -> 124 in the cache */
   /* replace148_0_0_0_1 -> 415 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 395, 415 },
      -1,
   } },
   /* replace148_0_0_1_0_0 -> 16 in the cache */
   /* replace148_0_0_1_0_1 -> 398 in the cache */
   /* replace148_0_0_1_0 -> 399 in the cache */
   /* replace148_0_0_1_1_0 -> 36 in the cache */
   /* replace148_0_0_1_1_1 -> 398 in the cache */
   /* replace148_0_0_1_1 -> 418 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 399, 418 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 430, 431 },
      -1,
   } },
   /* replace148_0_1_0_0_0 -> 16 in the cache */
   /* replace148_0_1_0_0_1 -> 403 in the cache */
   /* replace148_0_1_0_0 -> 404 in the cache */
   /* replace148_0_1_0_1_0 -> 36 in the cache */
   /* replace148_0_1_0_1_1 -> 403 in the cache */
   /* replace148_0_1_0_1 -> 422 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 404, 422 },
      -1,
   } },
   /* replace148_0_1_1_0_0 -> 16 in the cache */
   /* replace148_0_1_1_0_1 -> 407 in the cache */
   /* replace148_0_1_1_0 -> 408 in the cache */
   /* replace148_0_1_1_1_0 -> 36 in the cache */
   /* replace148_0_1_1_1_1 -> 407 in the cache */
   /* replace148_0_1_1_1 -> 425 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 408, 425 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 433, 434 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 432, 435 },
      -1,
   } },
   /* replace148_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 436, 137 },
      -1,
   } },

   /* ('sdot_2x16_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c') */
   /* search149_0 -> 16 in the cache */
   /* search149_1 -> 36 in the cache */
   /* search149_2 -> 137 in the cache */
   /* search149 -> 345 in the cache */

   /* replace149_0_0_0_0 -> 16 in the cache */
   /* replace149_0_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 124 },
      -1,
   } },
   /* replace149_0_0_1_0 -> 36 in the cache */
   /* replace149_0_0_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 36, 124 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 438, 439 },
      -1,
   } },
   /* replace149_0_1_0_0 -> 16 in the cache */
   /* replace149_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 398 },
      -1,
   } },
   /* replace149_0_1_1_0 -> 36 in the cache */
   /* replace149_0_1_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 36, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 441, 442 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 440, 443 },
      -1,
   } },
   /* replace149_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 444, 137 },
      -1,
   } },

   /* ('udot_2x16_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c') */
   /* search150_0 -> 16 in the cache */
   /* search150_1 -> 36 in the cache */
   /* search150_2 -> 137 in the cache */
   /* search150 -> 348 in the cache */

   /* replace150_0_0_0_0 -> 16 in the cache */
   /* replace150_0_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 124 },
      -1,
   } },
   /* replace150_0_0_1_0 -> 36 in the cache */
   /* replace150_0_0_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 36, 124 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 446, 447 },
      -1,
   } },
   /* replace150_0_1_0_0 -> 16 in the cache */
   /* replace150_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 398 },
      -1,
   } },
   /* replace150_0_1_1_0 -> 36 in the cache */
   /* replace150_0_1_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 36, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 449, 450 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 448, 451 },
      -1,
   } },
   /* replace150_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 452, 137 },
      -1,
   } },

   /* ('udot_4x8_uadd_sat', 'a', 'b', '#c(is_ult_0xfffc07fc)') => ('udot_4x8_uadd', 'a', 'b', 'c') */
   /* search151_0 -> 16 in the cache */
   /* search151_1 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      7,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 36, 454 },
      -1,
   } },

   /* replace151_0 -> 16 in the cache */
   /* replace151_1 -> 36 in the cache */
   /* replace151_2 -> 137 in the cache */
   /* replace151 -> 336 in the cache */

   /* ('udot_4x8_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search152_0 -> 16 in the cache */
   /* search152_1 -> 36 in the cache */
   /* search152_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* replace152_0_0_0_0_0 -> 16 in the cache */
   /* replace152_0_0_0_0_1 -> 124 in the cache */
   /* replace152_0_0_0_0 -> 414 in the cache */
   /* replace152_0_0_0_1_0 -> 36 in the cache */
   /* replace152_0_0_0_1_1 -> 124 in the cache */
   /* replace152_0_0_0_1 -> 415 in the cache */
   /* replace152_0_0_0 -> 416 in the cache */
   /* replace152_0_0_1_0_0 -> 16 in the cache */
   /* replace152_0_0_1_0_1 -> 398 in the cache */
   /* replace152_0_0_1_0 -> 417 in the cache */
   /* replace152_0_0_1_1_0 -> 36 in the cache */
   /* replace152_0_0_1_1_1 -> 398 in the cache */
   /* replace152_0_0_1_1 -> 418 in the cache */
   /* replace152_0_0_1 -> 419 in the cache */
   /* replace152_0_0 -> 420 in the cache */
   /* replace152_0_1_0_0_0 -> 16 in the cache */
   /* replace152_0_1_0_0_1 -> 403 in the cache */
   /* replace152_0_1_0_0 -> 421 in the cache */
   /* replace152_0_1_0_1_0 -> 36 in the cache */
   /* replace152_0_1_0_1_1 -> 403 in the cache */
   /* replace152_0_1_0_1 -> 422 in the cache */
   /* replace152_0_1_0 -> 423 in the cache */
   /* replace152_0_1_1_0_0 -> 16 in the cache */
   /* replace152_0_1_1_0_1 -> 407 in the cache */
   /* replace152_0_1_1_0 -> 424 in the cache */
   /* replace152_0_1_1_1_0 -> 36 in the cache */
   /* replace152_0_1_1_1_1 -> 407 in the cache */
   /* replace152_0_1_1_1 -> 425 in the cache */
   /* replace152_0_1_1 -> 426 in the cache */
   /* replace152_0_1 -> 427 in the cache */
   /* replace152_0 -> 428 in the cache */
   /* replace152_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 8,
      { 428, 137 },
      -1,
   } },

   /* ('sdot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c') */
   /* search153_0 -> 16 in the cache */
   /* search153_1 -> 36 in the cache */
   /* search153_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* replace153_0_0_0_0_0 -> 16 in the cache */
   /* replace153_0_0_0_0_1 -> 124 in the cache */
   /* replace153_0_0_0_0 -> 395 in the cache */
   /* replace153_0_0_0_1_0 -> 36 in the cache */
   /* replace153_0_0_0_1_1 -> 124 in the cache */
   /* replace153_0_0_0_1 -> 396 in the cache */
   /* replace153_0_0_0 -> 397 in the cache */
   /* replace153_0_0_1_0_0 -> 16 in the cache */
   /* replace153_0_0_1_0_1 -> 398 in the cache */
   /* replace153_0_0_1_0 -> 399 in the cache */
   /* replace153_0_0_1_1_0 -> 36 in the cache */
   /* replace153_0_0_1_1_1 -> 398 in the cache */
   /* replace153_0_0_1_1 -> 400 in the cache */
   /* replace153_0_0_1 -> 401 in the cache */
   /* replace153_0_0 -> 402 in the cache */
   /* replace153_0_1_0_0_0 -> 16 in the cache */
   /* replace153_0_1_0_0_1 -> 403 in the cache */
   /* replace153_0_1_0_0 -> 404 in the cache */
   /* replace153_0_1_0_1_0 -> 36 in the cache */
   /* replace153_0_1_0_1_1 -> 403 in the cache */
   /* replace153_0_1_0_1 -> 405 in the cache */
   /* replace153_0_1_0 -> 406 in the cache */
   /* replace153_0_1_1_0_0 -> 16 in the cache */
   /* replace153_0_1_1_0_1 -> 407 in the cache */
   /* replace153_0_1_1_0 -> 408 in the cache */
   /* replace153_0_1_1_1_0 -> 36 in the cache */
   /* replace153_0_1_1_1_1 -> 407 in the cache */
   /* replace153_0_1_1_1 -> 409 in the cache */
   /* replace153_0_1_1 -> 410 in the cache */
   /* replace153_0_1 -> 411 in the cache */
   /* replace153_0 -> 412 in the cache */
   /* replace153_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 8,
      { 412, 137 },
      -1,
   } },

   /* ('sudot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search154_0 -> 16 in the cache */
   /* search154_1 -> 36 in the cache */
   /* search154_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 16, 36, 137 },
      -1,
   } },

   /* replace154_0_0_0_0_0 -> 16 in the cache */
   /* replace154_0_0_0_0_1 -> 124 in the cache */
   /* replace154_0_0_0_0 -> 395 in the cache */
   /* replace154_0_0_0_1_0 -> 36 in the cache */
   /* replace154_0_0_0_1_1 -> 124 in the cache */
   /* replace154_0_0_0_1 -> 415 in the cache */
   /* replace154_0_0_0 -> 430 in the cache */
   /* replace154_0_0_1_0_0 -> 16 in the cache */
   /* replace154_0_0_1_0_1 -> 398 in the cache */
   /* replace154_0_0_1_0 -> 399 in the cache */
   /* replace154_0_0_1_1_0 -> 36 in the cache */
   /* replace154_0_0_1_1_1 -> 398 in the cache */
   /* replace154_0_0_1_1 -> 418 in the cache */
   /* replace154_0_0_1 -> 431 in the cache */
   /* replace154_0_0 -> 432 in the cache */
   /* replace154_0_1_0_0_0 -> 16 in the cache */
   /* replace154_0_1_0_0_1 -> 403 in the cache */
   /* replace154_0_1_0_0 -> 404 in the cache */
   /* replace154_0_1_0_1_0 -> 36 in the cache */
   /* replace154_0_1_0_1_1 -> 403 in the cache */
   /* replace154_0_1_0_1 -> 422 in the cache */
   /* replace154_0_1_0 -> 433 in the cache */
   /* replace154_0_1_1_0_0 -> 16 in the cache */
   /* replace154_0_1_1_0_1 -> 407 in the cache */
   /* replace154_0_1_1_0 -> 408 in the cache */
   /* replace154_0_1_1_1_0 -> 36 in the cache */
   /* replace154_0_1_1_1_1 -> 407 in the cache */
   /* replace154_0_1_1_1 -> 425 in the cache */
   /* replace154_0_1_1 -> 434 in the cache */
   /* replace154_0_1 -> 435 in the cache */
   /* replace154_0 -> 436 in the cache */
   /* replace154_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 8,
      { 436, 137 },
      -1,
   } },

   /* ('udot_2x16_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c') */
   /* search155_0 -> 16 in the cache */
   /* search155_1 -> 36 in the cache */
   /* search155_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* replace155_0_0_0_0 -> 16 in the cache */
   /* replace155_0_0_0_1 -> 124 in the cache */
   /* replace155_0_0_0 -> 446 in the cache */
   /* replace155_0_0_1_0 -> 36 in the cache */
   /* replace155_0_0_1_1 -> 124 in the cache */
   /* replace155_0_0_1 -> 447 in the cache */
   /* replace155_0_0 -> 448 in the cache */
   /* replace155_0_1_0_0 -> 16 in the cache */
   /* replace155_0_1_0_1 -> 398 in the cache */
   /* replace155_0_1_0 -> 449 in the cache */
   /* replace155_0_1_1_0 -> 36 in the cache */
   /* replace155_0_1_1_1 -> 398 in the cache */
   /* replace155_0_1_1 -> 450 in the cache */
   /* replace155_0_1 -> 451 in the cache */
   /* replace155_0 -> 452 in the cache */
   /* replace155_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 4,
      { 452, 137 },
      -1,
   } },

   /* ('sdot_2x16_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c') */
   /* search156_0 -> 16 in the cache */
   /* search156_1 -> 36 in the cache */
   /* search156_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* replace156_0_0_0_0 -> 16 in the cache */
   /* replace156_0_0_0_1 -> 124 in the cache */
   /* replace156_0_0_0 -> 438 in the cache */
   /* replace156_0_0_1_0 -> 36 in the cache */
   /* replace156_0_0_1_1 -> 124 in the cache */
   /* replace156_0_0_1 -> 439 in the cache */
   /* replace156_0_0 -> 440 in the cache */
   /* replace156_0_1_0_0 -> 16 in the cache */
   /* replace156_0_1_0_1 -> 398 in the cache */
   /* replace156_0_1_0 -> 441 in the cache */
   /* replace156_0_1_1_0 -> 36 in the cache */
   /* replace156_0_1_1_1 -> 398 in the cache */
   /* replace156_0_1_1 -> 442 in the cache */
   /* replace156_0_1 -> 443 in the cache */
   /* replace156_0 -> 444 in the cache */
   /* replace156_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 4,
      { 444, 137 },
      -1,
   } },

   /* ('~flrp@16', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search157_0 -> 11 in the cache */
   /* search157_1 -> 260 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 11, 260, 467 },
      -1,
   } },

   /* replace157_0 -> 466 in the cache */
   /* replace157_1 -> 260 in the cache */
   /* replace157_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 466, 260, 11 },
      -1,
   } },

   /* ('~flrp@16', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search158_0 -> 11 in the cache */
   /* search158_1_0 -> 11 in the cache */
   /* search158_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 260 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 11, 470, 471 },
      -1,
   } },

   /* replace158_0_0 -> 260 in the cache */
   /* replace158_0_1 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 260, 471 },
      -1,
   } },
   /* replace158_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 473, 11 },
      -1,
   } },

   /* ('~flrp@16', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search159_0_0 -> 11 in the cache */
   /* search159_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 260 },
      0,
   } },
   /* search159_1_0 -> 11 in the cache */
   /* search159_1_1 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 11, 471 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 475, 476, 477 },
      -1,
   } },

   /* replace159_0_0 -> 260 in the cache */
   /* replace159_0_1 -> 471 in the cache */
   /* replace159_0_2 -> 477 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 260, 471, 477 },
      -1,
   } },
   /* replace159_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 479, 11 },
      -1,
   } },

   /* ('~flrp@16', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search160_0 -> 11 in the cache */
   /* search160_1_0 -> 11 in the cache */
   /* search160_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 260 },
      0,
   } },
   /* search160_2 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 11, 481, 471 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace160_0_1 -> 260 in the cache */
   /* replace160_0_2 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 483, 260, 471 },
      -1,
   } },
   /* replace160_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 484, 11 },
      -1,
   } },

   /* ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search161_0_0 -> 11 in the cache */
   /* search161_0_1_0 -> 483 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 483, 487 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 11, 488 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search161_1_1 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 490, 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 489, 491 },
      -1,
   } },

   /* replace161_0 -> 11 in the cache */
   /* replace161_1 -> 490 in the cache */
   /* replace161_2 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 11, 490, 486 },
      -1,
   } },

   /* ('~fadd@16', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search162_0_0 -> 11 in the cache */
   /* search162_0_1_0_0 -> 483 in the cache */
   /* search162_0_1_0_1_0 -> 486 in the cache */
   /* search162_0_1_0_1 -> 487 in the cache */
   /* search162_0_1_0 -> 488 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 488 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 11, 494 },
      -1,
   } },
   /* search162_1_0 -> 490 in the cache */
   /* search162_1_1_0 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 490, 496 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 495, 497 },
      -1,
   } },

   /* replace162_0 -> 11 in the cache */
   /* replace162_1 -> 490 in the cache */
   /* replace162_2_0 -> 486 in the cache */
   /* replace162_2 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 11, 490, 496 },
      -1,
   } },

   /* ('~fadd@16', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search163_0 -> 11 in the cache */
   /* search163_1_0 -> 486 in the cache */
   /* search163_1_1_0 -> 490 in the cache */
   /* search163_1_1_1_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 490, 500 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 486, 501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 11, 502 },
      -1,
   } },

   /* replace163_0 -> 11 in the cache */
   /* replace163_1 -> 490 in the cache */
   /* replace163_2 -> 486 in the cache */
   /* replace163 -> 493 in the cache */

   /* ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search164_0_0 -> 11 in the cache */
   /* search164_0_1_0 -> 483 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 505 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 483, 506 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 11, 507 },
      -1,
   } },
   /* search164_1_0 -> 490 in the cache */
   /* search164_1_1_0 -> 504 in the cache */
   /* search164_1_1 -> 505 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 490, 505 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 508, 509 },
      -1,
   } },

   /* replace164_0 -> 504 in the cache */
   /* replace164_1 -> 490 in the cache */
   /* replace164_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 504, 490, 11 },
      -1,
   } },

   /* ('~fadd@16', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search165_0 -> 11 in the cache */
   /* search165_1_0_0 -> 504 in the cache */
   /* search165_1_0 -> 505 in the cache */
   /* search165_1_1_0 -> 490 in the cache */
   /* search165_1_1_1_0 -> 11 in the cache */
   /* search165_1_1_1 -> 500 in the cache */
   /* search165_1_1 -> 501 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 505, 501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 11, 512 },
      -1,
   } },

   /* replace165_0 -> 504 in the cache */
   /* replace165_1 -> 490 in the cache */
   /* replace165_2 -> 11 in the cache */
   /* replace165 -> 511 in the cache */

   /* ('~ffma@16', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search166_0 -> 11 in the cache */
   /* search166_1_0 -> 483 in the cache */
   /* search166_1_1_0_0 -> 504 in the cache */
   /* search166_1_1_0 -> 505 in the cache */
   /* search166_1_1 -> 506 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 483, 506 },
      -1,
   } },
   /* search166_2_0 -> 490 in the cache */
   /* search166_2_1_0 -> 504 in the cache */
   /* search166_2_1 -> 505 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 490, 505 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 11, 514, 515 },
      -1,
   } },

   /* replace166_0 -> 504 in the cache */
   /* replace166_1 -> 490 in the cache */
   /* replace166_2 -> 11 in the cache */
   /* replace166 -> 511 in the cache */

   /* ('~ffma@16', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search167_1_0 -> 504 in the cache */
   /* search167_1 -> 505 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 518 },
      -1,
   } },
   /* search167_2_1_0 -> 504 in the cache */
   /* search167_2_1 -> 505 in the cache */
   /* search167_2_2 -> 518 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 519, 505, 518 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 517, 505, 520 },
      -1,
   } },

   /* replace167_0 -> 504 in the cache */
   /* replace167_1 -> 517 in the cache */
   /* replace167_2 -> 518 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 504, 517, 518 },
      -1,
   } },

   /* ('~ffma@16', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 523 },
      -1,
   } },
   /* search168_1_0 -> 260 in the cache */
   /* search168_1_1_0 -> 518 in the cache */
   /* search168_1_1 -> 519 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 260, 519 },
      -1,
   } },
   /* search168_2 -> 518 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 524, 525, 518 },
      -1,
   } },

   /* replace168_0 -> 523 in the cache */
   /* replace168_1 -> 260 in the cache */
   /* replace168_2 -> 518 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 260, 518 },
      -1,
   } },

   /* ('~ffma@16', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search169_0_0 -> 523 in the cache */
   /* search169_0 -> 524 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 528 },
      -1,
   } },
   /* search169_1_1 -> 490 in the cache */
   /* search169_1_2 -> 477 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 529, 490, 477 },
      -1,
   } },
   /* search169_2_0 -> 528 in the cache */
   /* search169_2_1 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 528, 490 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 524, 530, 531 },
      -1,
   } },

   /* replace169_0 -> 523 in the cache */
   /* replace169_1 -> 477 in the cache */
   /* replace169_2_0 -> 528 in the cache */
   /* replace169_2_1 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 528, 490 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 523, 477, 533 },
      -1,
   } },

   /* ('~fadd@16', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search170_0 -> 483 in the cache */
   /* search170_1_0_0_0 -> 483 in the cache */
   /* search170_1_0_0_1_0 -> 11 in the cache */
   /* search170_1_0_0_1 -> 500 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 483, 500 },
      -1,
   } },
   /* search170_1_0_1_0 -> 483 in the cache */
   /* search170_1_0_1_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 483, 536 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 535, 537 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 538 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 483, 539 },
      -1,
   } },

   /* replace170_0 -> 260 in the cache */
   /* replace170_1 -> 483 in the cache */
   /* replace170_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 260, 483, 11 },
      -1,
   } },

   /* ('~flrp@32', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search171_0 -> 16 in the cache */
   /* search171_1 -> 36 in the cache */
   /* search171_2_0 -> 466 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 16, 36, 542 },
      -1,
   } },

   /* replace171_0 -> 466 in the cache */
   /* replace171_1 -> 36 in the cache */
   /* replace171_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 466, 36, 16 },
      -1,
   } },

   /* ('~flrp@32', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search172_0 -> 16 in the cache */
   /* search172_1_0 -> 16 in the cache */
   /* search172_1_1 -> 36 in the cache */
   /* search172_1 -> 276 in the cache */
   /* search172_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 16, 276, 137 },
      -1,
   } },

   /* replace172_0_0 -> 36 in the cache */
   /* replace172_0_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 36, 137 },
      -1,
   } },
   /* replace172_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 546, 16 },
      -1,
   } },

   /* ('~flrp@32', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search173_0_0 -> 16 in the cache */
   /* search173_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 36 },
      0,
   } },
   /* search173_1_0 -> 16 in the cache */
   /* search173_1_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 16, 137 },
      0,
   } },
   /* search173_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 548, 549, 165 },
      -1,
   } },

   /* replace173_0_0 -> 36 in the cache */
   /* replace173_0_1 -> 137 in the cache */
   /* replace173_0_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 36, 137, 165 },
      -1,
   } },
   /* replace173_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 551, 16 },
      -1,
   } },

   /* ('~flrp@32', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search174_0 -> 16 in the cache */
   /* search174_1_0 -> 16 in the cache */
   /* search174_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 16, 36 },
      0,
   } },
   /* search174_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 16, 553, 137 },
      -1,
   } },

   /* replace174_0_0 -> 245 in the cache */
   /* replace174_0_1 -> 36 in the cache */
   /* replace174_0_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 245, 36, 137 },
      -1,
   } },
   /* replace174_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 555, 16 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search175_0_0 -> 16 in the cache */
   /* search175_0_1_0 -> 245 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 557 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 245, 558 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 16, 559 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search175_1_1 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 561, 557 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 560, 562 },
      -1,
   } },

   /* replace175_0 -> 16 in the cache */
   /* replace175_1 -> 561 in the cache */
   /* replace175_2 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 16, 561, 557 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search176_0_0 -> 16 in the cache */
   /* search176_0_1_0_0 -> 245 in the cache */
   /* search176_0_1_0_1_0 -> 557 in the cache */
   /* search176_0_1_0_1 -> 558 in the cache */
   /* search176_0_1_0 -> 559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 559 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 16, 565 },
      -1,
   } },
   /* search176_1_0 -> 561 in the cache */
   /* search176_1_1_0 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 557 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 561, 567 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 566, 568 },
      -1,
   } },

   /* replace176_0 -> 16 in the cache */
   /* replace176_1 -> 561 in the cache */
   /* replace176_2_0 -> 557 in the cache */
   /* replace176_2 -> 567 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 16, 561, 567 },
      -1,
   } },

   /* ('~fadd@32', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search177_0 -> 16 in the cache */
   /* search177_1_0 -> 557 in the cache */
   /* search177_1_1_0 -> 561 in the cache */
   /* search177_1_1_1_0 -> 16 in the cache */
   /* search177_1_1_1 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 561, 282 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 557, 571 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 16, 572 },
      -1,
   } },

   /* replace177_0 -> 16 in the cache */
   /* replace177_1 -> 561 in the cache */
   /* replace177_2 -> 557 in the cache */
   /* replace177 -> 564 in the cache */

   /* ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search178_0_0 -> 16 in the cache */
   /* search178_0_1_0 -> 245 in the cache */
   /* search178_0_1_1_0_0 -> 504 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 574 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 245, 575 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 16, 576 },
      -1,
   } },
   /* search178_1_0 -> 561 in the cache */
   /* search178_1_1_0 -> 504 in the cache */
   /* search178_1_1 -> 574 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 561, 574 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 577, 578 },
      -1,
   } },

   /* replace178_0 -> 504 in the cache */
   /* replace178_1 -> 561 in the cache */
   /* replace178_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 504, 561, 16 },
      -1,
   } },

   /* ('~fadd@32', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search179_0 -> 16 in the cache */
   /* search179_1_0_0 -> 504 in the cache */
   /* search179_1_0 -> 574 in the cache */
   /* search179_1_1_0 -> 561 in the cache */
   /* search179_1_1_1_0 -> 16 in the cache */
   /* search179_1_1_1 -> 282 in the cache */
   /* search179_1_1 -> 571 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 574, 571 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 16, 581 },
      -1,
   } },

   /* replace179_0 -> 504 in the cache */
   /* replace179_1 -> 561 in the cache */
   /* replace179_2 -> 16 in the cache */
   /* replace179 -> 580 in the cache */

   /* ('~ffma@32', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search180_0 -> 16 in the cache */
   /* search180_1_0 -> 245 in the cache */
   /* search180_1_1_0_0 -> 504 in the cache */
   /* search180_1_1_0 -> 574 in the cache */
   /* search180_1_1 -> 575 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 245, 575 },
      -1,
   } },
   /* search180_2_0 -> 561 in the cache */
   /* search180_2_1_0 -> 504 in the cache */
   /* search180_2_1 -> 574 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 561, 574 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 16, 583, 584 },
      -1,
   } },

   /* replace180_0 -> 504 in the cache */
   /* replace180_1 -> 561 in the cache */
   /* replace180_2 -> 16 in the cache */
   /* replace180 -> 580 in the cache */

   /* ('~ffma@32', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   /* search181_0 -> 375 in the cache */
   /* search181_1_0 -> 504 in the cache */
   /* search181_1 -> 574 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 586 },
      -1,
   } },
   /* search181_2_1_0 -> 504 in the cache */
   /* search181_2_1 -> 574 in the cache */
   /* search181_2_2 -> 586 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 587, 574, 586 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 375, 574, 588 },
      -1,
   } },

   /* replace181_0 -> 504 in the cache */
   /* replace181_1 -> 375 in the cache */
   /* replace181_2 -> 586 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 504, 375, 586 },
      -1,
   } },

   /* ('~ffma@32', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   /* search182_0_0 -> 523 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 523 },
      -1,
   } },
   /* search182_1_0 -> 36 in the cache */
   /* search182_1_1_0 -> 586 in the cache */
   /* search182_1_1 -> 587 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 36, 587 },
      -1,
   } },
   /* search182_2 -> 586 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 591, 592, 586 },
      -1,
   } },

   /* replace182_0 -> 523 in the cache */
   /* replace182_1 -> 36 in the cache */
   /* replace182_2 -> 586 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 36, 586 },
      -1,
   } },

   /* ('~ffma@32', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search183_0_0 -> 523 in the cache */
   /* search183_0 -> 591 in the cache */
   /* search183_1_0_0 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 185 },
      -1,
   } },
   /* search183_1_1 -> 561 in the cache */
   /* search183_1_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 595, 561, 165 },
      -1,
   } },
   /* search183_2_0 -> 185 in the cache */
   /* search183_2_1 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 185, 561 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 591, 596, 597 },
      -1,
   } },

   /* replace183_0 -> 523 in the cache */
   /* replace183_1 -> 165 in the cache */
   /* replace183_2_0 -> 185 in the cache */
   /* replace183_2_1 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 185, 561 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 523, 165, 599 },
      -1,
   } },

   /* ('~fadd@32', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search184_0 -> 245 in the cache */
   /* search184_1_0_0_0 -> 245 in the cache */
   /* search184_1_0_0_1_0 -> 16 in the cache */
   /* search184_1_0_0_1 -> 282 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 245, 282 },
      -1,
   } },
   /* search184_1_0_1_0 -> 245 in the cache */
   /* search184_1_0_1_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 245, 602 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 601, 603 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 604 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 245, 605 },
      -1,
   } },

   /* replace184_0 -> 36 in the cache */
   /* replace184_1 -> 245 in the cache */
   /* replace184_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 36, 245, 16 },
      -1,
   } },

   /* ('~flrp@64', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search185_0 -> 21 in the cache */
   /* search185_1 -> 41 in the cache */
   /* search185_2_0 -> 466 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 21, 41, 608 },
      -1,
   } },

   /* replace185_0 -> 466 in the cache */
   /* replace185_1 -> 41 in the cache */
   /* replace185_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 466, 41, 21 },
      -1,
   } },

   /* ('~flrp@64', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search186_0 -> 21 in the cache */
   /* search186_1_0 -> 21 in the cache */
   /* search186_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 21, 41 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 21, 611, 612 },
      -1,
   } },

   /* replace186_0_0 -> 41 in the cache */
   /* replace186_0_1 -> 612 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 41, 612 },
      -1,
   } },
   /* replace186_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 614, 21 },
      -1,
   } },

   /* ('~flrp@64', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search187_0_0 -> 21 in the cache */
   /* search187_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search187_1_0 -> 21 in the cache */
   /* search187_1_1 -> 612 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 21, 612 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 616, 617, 618 },
      -1,
   } },

   /* replace187_0_0 -> 41 in the cache */
   /* replace187_0_1 -> 612 in the cache */
   /* replace187_0_2 -> 618 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 41, 612, 618 },
      -1,
   } },
   /* replace187_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 620, 21 },
      -1,
   } },

   /* ('~flrp@64', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search188_0 -> 21 in the cache */
   /* search188_1_0 -> 21 in the cache */
   /* search188_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search188_2 -> 612 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 21, 622, 612 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace188_0_1 -> 41 in the cache */
   /* replace188_0_2 -> 612 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 624, 41, 612 },
      -1,
   } },
   /* replace188_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 625, 21 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search189_0_0 -> 21 in the cache */
   /* search189_0_1_0 -> 624 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 627 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 624, 628 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 21, 629 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search189_1_1 -> 627 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 631, 627 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 630, 632 },
      -1,
   } },

   /* replace189_0 -> 21 in the cache */
   /* replace189_1 -> 631 in the cache */
   /* replace189_2 -> 627 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 21, 631, 627 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search190_0_0 -> 21 in the cache */
   /* search190_0_1_0_0 -> 624 in the cache */
   /* search190_0_1_0_1_0 -> 627 in the cache */
   /* search190_0_1_0_1 -> 628 in the cache */
   /* search190_0_1_0 -> 629 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 629 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 21, 635 },
      -1,
   } },
   /* search190_1_0 -> 631 in the cache */
   /* search190_1_1_0 -> 627 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 627 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 631, 637 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 636, 638 },
      -1,
   } },

   /* replace190_0 -> 21 in the cache */
   /* replace190_1 -> 631 in the cache */
   /* replace190_2_0 -> 627 in the cache */
   /* replace190_2 -> 637 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 21, 631, 637 },
      -1,
   } },

   /* ('~fadd@64', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search191_0 -> 21 in the cache */
   /* search191_1_0 -> 627 in the cache */
   /* search191_1_1_0 -> 631 in the cache */
   /* search191_1_1_1_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 631, 641 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 627, 642 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 21, 643 },
      -1,
   } },

   /* replace191_0 -> 21 in the cache */
   /* replace191_1 -> 631 in the cache */
   /* replace191_2 -> 627 in the cache */
   /* replace191 -> 634 in the cache */

   /* ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search192_0_0 -> 21 in the cache */
   /* search192_0_1_0 -> 624 in the cache */
   /* search192_0_1_1_0_0 -> 504 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 645 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 624, 646 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 21, 647 },
      -1,
   } },
   /* search192_1_0 -> 631 in the cache */
   /* search192_1_1_0 -> 504 in the cache */
   /* search192_1_1 -> 645 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 631, 645 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 648, 649 },
      -1,
   } },

   /* replace192_0 -> 504 in the cache */
   /* replace192_1 -> 631 in the cache */
   /* replace192_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 504, 631, 21 },
      -1,
   } },

   /* ('~fadd@64', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search193_0 -> 21 in the cache */
   /* search193_1_0_0 -> 504 in the cache */
   /* search193_1_0 -> 645 in the cache */
   /* search193_1_1_0 -> 631 in the cache */
   /* search193_1_1_1_0 -> 21 in the cache */
   /* search193_1_1_1 -> 641 in the cache */
   /* search193_1_1 -> 642 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 645, 642 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 21, 652 },
      -1,
   } },

   /* replace193_0 -> 504 in the cache */
   /* replace193_1 -> 631 in the cache */
   /* replace193_2 -> 21 in the cache */
   /* replace193 -> 651 in the cache */

   /* ('~ffma@64', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search194_0 -> 21 in the cache */
   /* search194_1_0 -> 624 in the cache */
   /* search194_1_1_0_0 -> 504 in the cache */
   /* search194_1_1_0 -> 645 in the cache */
   /* search194_1_1 -> 646 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 624, 646 },
      -1,
   } },
   /* search194_2_0 -> 631 in the cache */
   /* search194_2_1_0 -> 504 in the cache */
   /* search194_2_1 -> 645 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 631, 645 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 21, 654, 655 },
      -1,
   } },

   /* replace194_0 -> 504 in the cache */
   /* replace194_1 -> 631 in the cache */
   /* replace194_2 -> 21 in the cache */
   /* replace194 -> 651 in the cache */

   /* ('~ffma@64', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search195_1_0 -> 504 in the cache */
   /* search195_1 -> 645 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 658 },
      -1,
   } },
   /* search195_2_1_0 -> 504 in the cache */
   /* search195_2_1 -> 645 in the cache */
   /* search195_2_2 -> 658 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 659, 645, 658 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 657, 645, 660 },
      -1,
   } },

   /* replace195_0 -> 504 in the cache */
   /* replace195_1 -> 657 in the cache */
   /* replace195_2 -> 658 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 504, 657, 658 },
      -1,
   } },

   /* ('~ffma@64', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   /* search196_0_0 -> 523 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 523 },
      -1,
   } },
   /* search196_1_0 -> 41 in the cache */
   /* search196_1_1_0 -> 658 in the cache */
   /* search196_1_1 -> 659 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 41, 659 },
      -1,
   } },
   /* search196_2 -> 658 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 663, 664, 658 },
      -1,
   } },

   /* replace196_0 -> 523 in the cache */
   /* replace196_1 -> 41 in the cache */
   /* replace196_2 -> 658 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 41, 658 },
      -1,
   } },

   /* ('~ffma@64', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search197_0_0 -> 523 in the cache */
   /* search197_0 -> 663 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 667 },
      -1,
   } },
   /* search197_1_1 -> 631 in the cache */
   /* search197_1_2 -> 618 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 668, 631, 618 },
      -1,
   } },
   /* search197_2_0 -> 667 in the cache */
   /* search197_2_1 -> 631 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 667, 631 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 663, 669, 670 },
      -1,
   } },

   /* replace197_0 -> 523 in the cache */
   /* replace197_1 -> 618 in the cache */
   /* replace197_2_0 -> 667 in the cache */
   /* replace197_2_1 -> 631 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 667, 631 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 523, 618, 672 },
      -1,
   } },

   /* ('~fadd@64', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search198_0 -> 624 in the cache */
   /* search198_1_0_0_0 -> 624 in the cache */
   /* search198_1_0_0_1_0 -> 21 in the cache */
   /* search198_1_0_0_1 -> 641 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 624, 641 },
      -1,
   } },
   /* search198_1_0_1_0 -> 624 in the cache */
   /* search198_1_0_1_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 624, 675 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 674, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 677 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 624, 678 },
      -1,
   } },

   /* replace198_0 -> 41 in the cache */
   /* replace198_1 -> 624 in the cache */
   /* replace198_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 41, 624, 21 },
      -1,
   } },

   /* ('~flrp', ('fmul(is_used_once)', 'a', 'b'), ('fmul(is_used_once)', 'a', 'c'), 'd') => ('fmul', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search199_0_0 -> 151 in the cache */
   /* search199_0_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 151, 152 },
      0,
   } },
   /* search199_1_0 -> 151 in the cache */
   /* search199_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 151, 154 },
      0,
   } },
   /* search199_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 681, 682, 155 },
      -1,
   } },

   /* replace199_0_0 -> 152 in the cache */
   /* replace199_0_1 -> 154 in the cache */
   /* replace199_0_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 152, 154, 155 },
      -1,
   } },
   /* replace199_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 684, 151 },
      -1,
   } },

   /* ('~flrp', 'a', 0.0, 'c') => ('fadd', ('fmul', ('fneg', 'a'), 'c'), 'a') */
   /* search200_0 -> 0 in the cache */
   /* search200_1 -> 258 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 258, 686 },
      -1,
   } },

   /* replace200_0_0_0 -> 0 in the cache */
   /* replace200_0_0 -> 214 in the cache */
   /* replace200_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 214, 686 },
      -1,
   } },
   /* replace200_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 688, 0 },
      -1,
   } },

   /* ('ftrunc@16', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a'))) */
   /* search201_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace201_0_0 -> 11 in the cache */
   /* replace201_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 115 },
      -1,
   } },
   /* replace201_1_0_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 692 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 693 },
      -1,
   } },
   /* replace201_2_0_0 -> 11 in the cache */
   /* replace201_2_0 -> 692 in the cache */
   /* replace201_2 -> 693 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 691, 694, 693 },
      -1,
   } },

   /* ('ftrunc@32', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a'))) */
   /* search202_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace202_0_0 -> 16 in the cache */
   /* replace202_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 117 },
      -1,
   } },
   /* replace202_1_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 698 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 699 },
      -1,
   } },
   /* replace202_2_0_0 -> 16 in the cache */
   /* replace202_2_0 -> 698 in the cache */
   /* replace202_2 -> 699 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 697, 700, 699 },
      -1,
   } },

   /* ('ftrunc@64', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a'))) */
   /* search203_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace203_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 21, 703 },
      -1,
   } },
   /* replace203_1_0_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 705 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 706 },
      -1,
   } },
   /* replace203_2_0_0 -> 21 in the cache */
   /* replace203_2_0 -> 705 in the cache */
   /* replace203_2 -> 706 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 704, 707, 706 },
      -1,
   } },

   /* ('ffloor@16', 'a') => ('fsub', 'a', ('ffract', 'a')) */
   /* search204_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace204_0 -> 11 in the cache */
   /* replace204_1_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 11, 710 },
      -1,
   } },

   /* ('ffloor@32', 'a') => ('fsub', 'a', ('ffract', 'a')) */
   /* search205_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace205_0 -> 16 in the cache */
   /* replace205_1_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 16, 713 },
      -1,
   } },

   /* ('ffloor@64', 'a') => ('fsub', 'a', ('ffract', 'a')) */
   /* search206_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace206_0 -> 21 in the cache */
   /* replace206_1_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 21, 716 },
      -1,
   } },

   /* ('fadd@16', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a') */
   /* search207_0 -> 11 in the cache */
   /* search207_1_0_0 -> 11 in the cache */
   /* search207_1_0 -> 710 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 710 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 718 },
      -1,
   } },

   /* replace207_0 -> 11 in the cache */
   /* replace207 -> 709 in the cache */

   /* ('fadd@32', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a') */
   /* search208_0 -> 16 in the cache */
   /* search208_1_0_0 -> 16 in the cache */
   /* search208_1_0 -> 713 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 713 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 720 },
      -1,
   } },

   /* replace208_0 -> 16 in the cache */
   /* replace208 -> 712 in the cache */

   /* ('fadd@64', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a') */
   /* search209_0 -> 21 in the cache */
   /* search209_1_0_0 -> 21 in the cache */
   /* search209_1_0 -> 716 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 716 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 21, 722 },
      -1,
   } },

   /* replace209_0 -> 21 in the cache */
   /* replace209 -> 715 in the cache */

   /* ('ffract@16', 'a') => ('fsub', 'a', ('ffloor', 'a')) */
   /* search210_0 -> 11 in the cache */
   /* search210 -> 710 in the cache */

   /* replace210_0 -> 11 in the cache */
   /* replace210_1_0 -> 11 in the cache */
   /* replace210_1 -> 709 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 11, 709 },
      -1,
   } },

   /* ('ffract@32', 'a') => ('fsub', 'a', ('ffloor', 'a')) */
   /* search211_0 -> 16 in the cache */
   /* search211 -> 713 in the cache */

   /* replace211_0 -> 16 in the cache */
   /* replace211_1_0 -> 16 in the cache */
   /* replace211_1 -> 712 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 16, 712 },
      -1,
   } },

   /* ('ffract@64', 'a') => ('fsub', 'a', ('ffloor', 'a')) */
   /* search212_0 -> 21 in the cache */
   /* search212 -> 716 in the cache */

   /* replace212_0 -> 21 in the cache */
   /* replace212_1_0 -> 21 in the cache */
   /* replace212_1 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 21, 715 },
      -1,
   } },

   /* ('fceil', 'a') => ('fneg', ('ffloor', ('fneg', 'a'))) */
   /* search213_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace213_0_0_0 -> 32 in the cache */
   /* replace213_0_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 728 },
      -1,
   } },

   /* ('ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search214_0 -> 11 in the cache */
   /* search214_1 -> 260 in the cache */
   /* search214_2 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 11, 260, 471 },
      -1,
   } },

   /* replace214_0_0 -> 11 in the cache */
   /* replace214_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 11, 260 },
      -1,
   } },
   /* replace214_1 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 731, 471 },
      -1,
   } },

   /* ('ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search215_0 -> 16 in the cache */
   /* search215_1 -> 36 in the cache */
   /* search215_2 -> 137 in the cache */
   /* search215 -> 236 in the cache */

   /* replace215_0_0 -> 16 in the cache */
   /* replace215_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace215_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 733, 137 },
      -1,
   } },

   /* ('ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search216_0 -> 21 in the cache */
   /* search216_1 -> 41 in the cache */
   /* search216_2 -> 612 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 21, 41, 612 },
      -1,
   } },

   /* replace216_0_0 -> 21 in the cache */
   /* replace216_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace216_1 -> 612 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 736, 612 },
      -1,
   } },

   /* ('ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   /* search217_0 -> 16 in the cache */
   /* search217_1 -> 36 in the cache */
   /* search217_2 -> 137 in the cache */
   /* search217 -> 389 in the cache */

   /* replace217_0_0 -> 16 in the cache */
   /* replace217_0_1 -> 36 in the cache */
   /* replace217_0 -> 136 in the cache */
   /* replace217_1 -> 137 in the cache */
   /* replace217 -> 290 in the cache */

   /* ('~ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search218_0 -> 11 in the cache */
   /* search218_1 -> 260 in the cache */
   /* search218_2 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 11, 260, 471 },
      -1,
   } },

   /* replace218_0_0 -> 11 in the cache */
   /* replace218_0_1 -> 260 in the cache */
   /* replace218_0 -> 731 in the cache */
   /* replace218_1 -> 471 in the cache */
   /* replace218 -> 732 in the cache */

   /* ('~ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search219_0 -> 16 in the cache */
   /* search219_1 -> 36 in the cache */
   /* search219_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* replace219_0_0 -> 16 in the cache */
   /* replace219_0_1 -> 36 in the cache */
   /* replace219_0 -> 733 in the cache */
   /* replace219_1 -> 137 in the cache */
   /* replace219 -> 734 in the cache */

   /* ('~ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search220_0 -> 21 in the cache */
   /* search220_1 -> 41 in the cache */
   /* search220_2 -> 612 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 21, 41, 612 },
      -1,
   } },

   /* replace220_0_0 -> 21 in the cache */
   /* replace220_0_1 -> 41 in the cache */
   /* replace220_0 -> 736 in the cache */
   /* replace220_1 -> 612 in the cache */
   /* replace220 -> 737 in the cache */

   /* ('~ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   /* search221_0 -> 16 in the cache */
   /* search221_1 -> 36 in the cache */
   /* search221_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* replace221_0_0 -> 16 in the cache */
   /* replace221_0_1 -> 36 in the cache */
   /* replace221_0 -> 136 in the cache */
   /* replace221_1 -> 137 in the cache */
   /* replace221 -> 290 in the cache */

   /* ('~fmul', ('fadd', ('iand', ('ineg', ('b2i', 'a@bool')), ('fmul', 'b', 'c')), '#d'), '#e') => ('bcsel', 'a', ('fmul', ('fadd', ('fmul', 'b', 'c'), 'd'), 'e'), ('fmul', 'd', 'e')) */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 742 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 743 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 745, 746 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_iand,
      2, 2,
      { 744, 747 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 3,
      { 748, 749 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 4,
      { 750, 751 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace222_1_0_0_0 -> 745 in the cache */
   /* replace222_1_0_0_1 -> 746 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 745, 746 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 754, 755 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 756, 757 },
      -1,
   } },
   /* replace222_2_0 -> 755 in the cache */
   /* replace222_2_1 -> 757 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 755, 757 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 753, 758, 759 },
      -1,
   } },

   /* ('fdph', 'a', 'b') => ('fdot4', ('vec4', 'a.x', 'a.y', 'a.z', 1.0), 'b') */
   /* search223_0 -> 0 in the cache */
   /* search223_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {2},
   } },
   /* replace223_0_3 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 762, 763, 764, 272 },
      -1,
   } },
   /* replace223_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 765, 3 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 'b', 'c', 1.0), 'd') => ('fdph', ('vec3', 'a', 'b', 'c'), 'd') */
   /* search224_0_0 -> 151 in the cache */
   /* search224_0_1 -> 152 in the cache */
   /* search224_0_2 -> 154 in the cache */
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 151, 152, 154, 767 },
      -1,
   } },
   /* search224_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 768, 155 },
      -1,
   } },

   /* replace224_0_0 -> 151 in the cache */
   /* replace224_0_1 -> 152 in the cache */
   /* replace224_0_2 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 151, 152, 154 },
      -1,
   } },
   /* replace224_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 770, 155 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 0.0, 0.0, 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search225_0_0 -> 0 in the cache */
   /* search225_0_1 -> 258 in the cache */
   /* search225_0_2 -> 258 in the cache */
   /* search225_0_3 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 0, 258, 258, 258 },
      -1,
   } },
   /* search225_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 772, 3 },
      -1,
   } },

   /* replace225_0 -> 0 in the cache */
   /* replace225_1 -> 3 in the cache */
   /* replace225 -> 266 in the cache */

   /* ('fdot4', ('vec4', 'a', 'b', 0.0, 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c') */
   /* search226_0_0 -> 128 in the cache */
   /* search226_0_1 -> 129 in the cache */
   { .constant = {
      { nir_search_value_constant, -3 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search226_0_3 -> 774 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 128, 129, 774, 774 },
      -1,
   } },
   /* search226_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 775, 131 },
      -1,
   } },

   /* replace226_0_0 -> 128 in the cache */
   /* replace226_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 128, 129 },
      -1,
   } },
   /* replace226_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 777, 131 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 'b', 'c', 0.0), 'd') => ('fdot3', ('vec3', 'a', 'b', 'c'), 'd') */
   /* search227_0_0 -> 151 in the cache */
   /* search227_0_1 -> 152 in the cache */
   /* search227_0_2 -> 154 in the cache */
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 151, 152, 154, 779 },
      -1,
   } },
   /* search227_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 780, 155 },
      -1,
   } },

   /* replace227_0_0 -> 151 in the cache */
   /* replace227_0_1 -> 152 in the cache */
   /* replace227_0_2 -> 154 in the cache */
   /* replace227_0 -> 770 in the cache */
   /* replace227_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 770, 155 },
      -1,
   } },

   /* ('fdot3', ('vec3', 'a', 0.0, 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search228_0_0 -> 0 in the cache */
   /* search228_0_1 -> 258 in the cache */
   /* search228_0_2 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 0, 258, 258 },
      -1,
   } },
   /* search228_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 783, 3 },
      -1,
   } },

   /* replace228_0 -> 0 in the cache */
   /* replace228_1 -> 3 in the cache */
   /* replace228 -> 266 in the cache */

   /* ('fdot3', ('vec3', 'a', 'b', 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c') */
   /* search229_0_0 -> 128 in the cache */
   /* search229_0_1 -> 129 in the cache */
   /* search229_0_2 -> 774 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 128, 129, 774 },
      -1,
   } },
   /* search229_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 785, 131 },
      -1,
   } },

   /* replace229_0_0 -> 128 in the cache */
   /* replace229_0_1 -> 129 in the cache */
   /* replace229_0 -> 777 in the cache */
   /* replace229_1 -> 131 in the cache */
   /* replace229 -> 778 in the cache */

   /* ('fdot2', ('vec2', 'a', 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search230_0_0 -> 0 in the cache */
   /* search230_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 0, 258 },
      -1,
   } },
   /* search230_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 787, 3 },
      -1,
   } },

   /* replace230_0 -> 0 in the cache */
   /* replace230_1 -> 3 in the cache */
   /* replace230 -> 266 in the cache */

   /* ('fdot2', 'a', 1.0) => ('fadd', 'a.x', 'a.y') */
   /* search231_0 -> 32 in the cache */
   /* search231_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 32, 243 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      -1, 0,
      { 790, 791 },
      -1,
   } },

   /* ('fdot2', 'a', 'b') => ('fsum2', ('fmul', 'a', 'b')) */
   /* search232_0 -> 0 in the cache */
   /* search232_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace232_0_0 -> 0 in the cache */
   /* replace232_0_1 -> 3 in the cache */
   /* replace232_0 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsum2,
      -1, 1,
      { 266 },
      -1,
   } },

   /* ('fdot3', 'a', 'b') => ('fsum3', ('fmul', 'a', 'b')) */
   /* search233_0 -> 0 in the cache */
   /* search233_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace233_0_0 -> 0 in the cache */
   /* replace233_0_1 -> 3 in the cache */
   /* replace233_0 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsum3,
      -1, 1,
      { 266 },
      -1,
   } },

   /* ('fdot4', 'a', 'b') => ('fsum4', ('fmul', 'a', 'b')) */
   /* search234_0 -> 0 in the cache */
   /* search234_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace234_0_0 -> 0 in the cache */
   /* replace234_0_1 -> 3 in the cache */
   /* replace234_0 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsum4,
      -1, 1,
      { 266 },
      -1,
   } },

   /* ('fsum2', 'a') => ('fadd', 'a.x', 'a.y') */
   /* search235_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsum2,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace235_0 -> 790 in the cache */
   /* replace235_1 -> 791 in the cache */
   /* replace235 -> 792 in the cache */

   /* ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a'))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      8,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 800 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 801 },
      0,
   } },
   /* search236_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 802, 243 },
      -1,
   } },

   /* replace236_0_0 -> 243 in the cache */
   /* replace236_0_1_0 -> 32 in the cache */
   /* replace236_0_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 243, 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 804 },
      -1,
   } },

   /* ('ishl', ('iadd', ('imul', 'a', '#b'), '#c'), '#d') => ('iadd', ('imul', 'a', ('ishl', 'b', 'd')), ('ishl', 'c', 'd')) */
   /* search237_0_0_0 -> 128 in the cache */
   /* search237_0_0_1 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 128, 285 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 806, 807 },
      -1,
   } },
   /* search237_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 808, 313 },
      -1,
   } },

   /* replace237_0_0 -> 128 in the cache */
   /* replace237_0_1_0 -> 129 in the cache */
   /* replace237_0_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 129, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 128, 810 },
      -1,
   } },
   /* replace237_1_0 -> 131 in the cache */
   /* replace237_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 131, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 811, 812 },
      -1,
   } },

   /* ('ishl', ('imul', 'a', '#b'), '#c') => ('imul', 'a', ('ishl', 'b', 'c')) */
   /* search238_0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 814 },
      -1,
   } },
   /* search238_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 815, 311 },
      -1,
   } },

   /* replace238_0 -> 0 in the cache */
   /* replace238_1_0 -> 3 in the cache */
   /* replace238_1_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3, 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 817 },
      -1,
   } },

   /* ('ishl@8', ('ishl@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ishl@8', 'a', ('iadd', 'b', 'c')), 0) */
   /* search239_0_0 -> 6 in the cache */
   /* search239_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search239_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 819, 311 },
      -1,
   } },

   /* replace239_0_0_0_0 -> 36 in the cache */
   /* replace239_0_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 9 },
      -1,
   } },
   /* replace239_0_0_1_0 -> 137 in the cache */
   /* replace239_0_0_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 137, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 821, 822 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x8 /* 8 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 823, 824 },
      -1,
   } },
   /* replace239_1_0 -> 6 in the cache */
   /* replace239_1_1_0 -> 36 in the cache */
   /* replace239_1_1_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 36, 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 6, 826 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 825, 827, 828 },
      -1,
   } },

   /* ('ushr@8', ('ushr@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ushr@8', 'a', ('iadd', 'b', 'c')), 0) */
   /* search240_0_0 -> 6 in the cache */
   /* search240_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search240_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 830, 311 },
      -1,
   } },

   /* replace240_0_0_0_0 -> 36 in the cache */
   /* replace240_0_0_0_1 -> 9 in the cache */
   /* replace240_0_0_0 -> 821 in the cache */
   /* replace240_0_0_1_0 -> 137 in the cache */
   /* replace240_0_0_1_1 -> 9 in the cache */
   /* replace240_0_0_1 -> 822 in the cache */
   /* replace240_0_0 -> 823 in the cache */
   /* replace240_0_1 -> 824 in the cache */
   /* replace240_0 -> 825 in the cache */
   /* replace240_1_0 -> 6 in the cache */
   /* replace240_1_1_0 -> 36 in the cache */
   /* replace240_1_1_1 -> 137 in the cache */
   /* replace240_1_1 -> 826 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 6, 826 },
      -1,
   } },
   /* replace240_2 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 825, 832, 828 },
      -1,
   } },

   /* ('ishr@8', ('ishr@8', 'a', '#b'), '#c') => ('ishr@8', 'a', ('imin', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 7)) */
   /* search241_0_0 -> 6 in the cache */
   /* search241_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search241_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 834, 311 },
      -1,
   } },

   /* replace241_0 -> 6 in the cache */
   /* replace241_1_0_0_0 -> 36 in the cache */
   /* replace241_1_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 9 },
      -1,
   } },
   /* replace241_1_0_1_0 -> 137 in the cache */
   /* replace241_1_0_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 137, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 836, 837 },
      -1,
   } },
   /* replace241_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 838, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 6, 839 },
      -1,
   } },

   /* ('ishl@16', ('ishl@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ishl@16', 'a', ('iadd', 'b', 'c')), 0) */
   /* search242_0_0 -> 11 in the cache */
   /* search242_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search242_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 841, 311 },
      -1,
   } },

   /* replace242_0_0_0_0 -> 36 in the cache */
   /* replace242_0_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 14 },
      -1,
   } },
   /* replace242_0_0_1_0 -> 137 in the cache */
   /* replace242_0_0_1_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 137, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 843, 844 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x10 /* 16 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 845, 846 },
      -1,
   } },
   /* replace242_1_0 -> 11 in the cache */
   /* replace242_1_1_0 -> 36 in the cache */
   /* replace242_1_1_1 -> 137 in the cache */
   /* replace242_1_1 -> 826 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 826 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 847, 848, 849 },
      -1,
   } },

   /* ('ushr@16', ('ushr@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ushr@16', 'a', ('iadd', 'b', 'c')), 0) */
   /* search243_0_0 -> 11 in the cache */
   /* search243_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search243_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 851, 311 },
      -1,
   } },

   /* replace243_0_0_0_0 -> 36 in the cache */
   /* replace243_0_0_0_1 -> 14 in the cache */
   /* replace243_0_0_0 -> 843 in the cache */
   /* replace243_0_0_1_0 -> 137 in the cache */
   /* replace243_0_0_1_1 -> 14 in the cache */
   /* replace243_0_0_1 -> 844 in the cache */
   /* replace243_0_0 -> 845 in the cache */
   /* replace243_0_1 -> 846 in the cache */
   /* replace243_0 -> 847 in the cache */
   /* replace243_1_0 -> 11 in the cache */
   /* replace243_1_1_0 -> 36 in the cache */
   /* replace243_1_1_1 -> 137 in the cache */
   /* replace243_1_1 -> 826 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 826 },
      -1,
   } },
   /* replace243_2 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 847, 853, 849 },
      -1,
   } },

   /* ('ishr@16', ('ishr@16', 'a', '#b'), '#c') => ('ishr@16', 'a', ('imin', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 15)) */
   /* search244_0_0 -> 11 in the cache */
   /* search244_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search244_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 855, 311 },
      -1,
   } },

   /* replace244_0 -> 11 in the cache */
   /* replace244_1_0_0_0 -> 36 in the cache */
   /* replace244_1_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 14 },
      -1,
   } },
   /* replace244_1_0_1_0 -> 137 in the cache */
   /* replace244_1_0_1_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 137, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 857, 858 },
      -1,
   } },
   /* replace244_1_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 859, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 11, 860 },
      -1,
   } },

   /* ('ishl@32', ('ishl@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ishl@32', 'a', ('iadd', 'b', 'c')), 0) */
   /* search245_0_0 -> 16 in the cache */
   /* search245_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search245_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 862, 311 },
      -1,
   } },

   /* replace245_0_0_0_0 -> 36 in the cache */
   /* replace245_0_0_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 19 },
      -1,
   } },
   /* replace245_0_0_1_0 -> 137 in the cache */
   /* replace245_0_0_1_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 137, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 864, 865 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x20 /* 32 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 866, 867 },
      -1,
   } },
   /* replace245_1_0 -> 16 in the cache */
   /* replace245_1_1_0 -> 36 in the cache */
   /* replace245_1_1_1 -> 137 in the cache */
   /* replace245_1_1 -> 826 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 826 },
      -1,
   } },
   /* replace245_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 868, 869, 124 },
      -1,
   } },

   /* ('ushr@32', ('ushr@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ushr@32', 'a', ('iadd', 'b', 'c')), 0) */
   /* search246_0_0 -> 16 in the cache */
   /* search246_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search246_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 871, 311 },
      -1,
   } },

   /* replace246_0_0_0_0 -> 36 in the cache */
   /* replace246_0_0_0_1 -> 19 in the cache */
   /* replace246_0_0_0 -> 864 in the cache */
   /* replace246_0_0_1_0 -> 137 in the cache */
   /* replace246_0_0_1_1 -> 19 in the cache */
   /* replace246_0_0_1 -> 865 in the cache */
   /* replace246_0_0 -> 866 in the cache */
   /* replace246_0_1 -> 867 in the cache */
   /* replace246_0 -> 868 in the cache */
   /* replace246_1_0 -> 16 in the cache */
   /* replace246_1_1_0 -> 36 in the cache */
   /* replace246_1_1_1 -> 137 in the cache */
   /* replace246_1_1 -> 826 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 826 },
      -1,
   } },
   /* replace246_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 868, 873, 124 },
      -1,
   } },

   /* ('ishr@32', ('ishr@32', 'a', '#b'), '#c') => ('ishr@32', 'a', ('imin', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 31)) */
   /* search247_0_0 -> 16 in the cache */
   /* search247_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search247_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 875, 311 },
      -1,
   } },

   /* replace247_0 -> 16 in the cache */
   /* replace247_1_0_0_0 -> 36 in the cache */
   /* replace247_1_0_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 19 },
      -1,
   } },
   /* replace247_1_0_1_0 -> 137 in the cache */
   /* replace247_1_0_1_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 137, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 877, 878 },
      -1,
   } },
   /* replace247_1_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 879, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 16, 880 },
      -1,
   } },

   /* ('ishl@64', ('ishl@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ishl@64', 'a', ('iadd', 'b', 'c')), 0) */
   /* search248_0_0 -> 21 in the cache */
   /* search248_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search248_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 882, 311 },
      -1,
   } },

   /* replace248_0_0_0_0 -> 36 in the cache */
   /* replace248_0_0_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 24 },
      -1,
   } },
   /* replace248_0_0_1_0 -> 137 in the cache */
   /* replace248_0_0_1_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 137, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 884, 885 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x40 /* 64 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 886, 887 },
      -1,
   } },
   /* replace248_1_0 -> 21 in the cache */
   /* replace248_1_1_0 -> 36 in the cache */
   /* replace248_1_1_1 -> 137 in the cache */
   /* replace248_1_1 -> 826 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 21, 826 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 888, 889, 890 },
      -1,
   } },

   /* ('ushr@64', ('ushr@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ushr@64', 'a', ('iadd', 'b', 'c')), 0) */
   /* search249_0_0 -> 21 in the cache */
   /* search249_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search249_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 892, 311 },
      -1,
   } },

   /* replace249_0_0_0_0 -> 36 in the cache */
   /* replace249_0_0_0_1 -> 24 in the cache */
   /* replace249_0_0_0 -> 884 in the cache */
   /* replace249_0_0_1_0 -> 137 in the cache */
   /* replace249_0_0_1_1 -> 24 in the cache */
   /* replace249_0_0_1 -> 885 in the cache */
   /* replace249_0_0 -> 886 in the cache */
   /* replace249_0_1 -> 887 in the cache */
   /* replace249_0 -> 888 in the cache */
   /* replace249_1_0 -> 21 in the cache */
   /* replace249_1_1_0 -> 36 in the cache */
   /* replace249_1_1_1 -> 137 in the cache */
   /* replace249_1_1 -> 826 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 21, 826 },
      -1,
   } },
   /* replace249_2 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 888, 894, 890 },
      -1,
   } },

   /* ('ishr@64', ('ishr@64', 'a', '#b'), '#c') => ('ishr@64', 'a', ('imin', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 63)) */
   /* search250_0_0 -> 21 in the cache */
   /* search250_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search250_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 896, 311 },
      -1,
   } },

   /* replace250_0 -> 21 in the cache */
   /* replace250_1_0_0_0 -> 36 in the cache */
   /* replace250_1_0_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 24 },
      -1,
   } },
   /* replace250_1_0_1_0 -> 137 in the cache */
   /* replace250_1_0_1_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 137, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 898, 899 },
      -1,
   } },
   /* replace250_1_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 900, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 21, 901 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b')) */
   /* search251_0_0 -> 6 in the cache */
   /* search251_0_1 -> 33 in the cache */
   /* search251_0 -> 830 in the cache */
   /* search251_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 830, 36 },
      -1,
   } },

   /* replace251_0 -> 6 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   /* replace251_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 904, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6, 905 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b')) */
   /* search252_0_0 -> 6 in the cache */
   /* search252_0_1 -> 33 in the cache */
   /* search252_0 -> 834 in the cache */
   /* search252_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 834, 36 },
      -1,
   } },

   /* replace252_0 -> 6 in the cache */
   /* replace252_1_0 -> 904 in the cache */
   /* replace252_1_1 -> 36 in the cache */
   /* replace252_1 -> 905 in the cache */
   /* replace252 -> 906 in the cache */

   /* ('ushr', ('ishl', 'a@8', '#b'), 'b') => ('iand', 'a', ('ushr', 255, 'b')) */
   /* search253_0_0 -> 6 in the cache */
   /* search253_0_1 -> 33 in the cache */
   /* search253_0 -> 819 in the cache */
   /* search253_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 819, 36 },
      -1,
   } },

   /* replace253_0 -> 6 in the cache */
   /* replace253_1_0 -> 904 in the cache */
   /* replace253_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 904, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6, 909 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b')) */
   /* search254_0_0 -> 11 in the cache */
   /* search254_0_1 -> 33 in the cache */
   /* search254_0 -> 851 in the cache */
   /* search254_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 851, 36 },
      -1,
   } },

   /* replace254_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* replace254_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 912, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 913 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b')) */
   /* search255_0_0 -> 11 in the cache */
   /* search255_0_1 -> 33 in the cache */
   /* search255_0 -> 855 in the cache */
   /* search255_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 855, 36 },
      -1,
   } },

   /* replace255_0 -> 11 in the cache */
   /* replace255_1_0 -> 912 in the cache */
   /* replace255_1_1 -> 36 in the cache */
   /* replace255_1 -> 913 in the cache */
   /* replace255 -> 914 in the cache */

   /* ('ushr', ('ishl', 'a@16', '#b'), 'b') => ('iand', 'a', ('ushr', 65535, 'b')) */
   /* search256_0_0 -> 11 in the cache */
   /* search256_0_1 -> 33 in the cache */
   /* search256_0 -> 841 in the cache */
   /* search256_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 841, 36 },
      -1,
   } },

   /* replace256_0 -> 11 in the cache */
   /* replace256_1_0 -> 912 in the cache */
   /* replace256_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 912, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 917 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b')) */
   /* search257_0_0 -> 16 in the cache */
   /* search257_0_1 -> 33 in the cache */
   /* search257_0 -> 871 in the cache */
   /* search257_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 871, 36 },
      -1,
   } },

   /* replace257_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   /* replace257_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 920, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 921 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b')) */
   /* search258_0_0 -> 16 in the cache */
   /* search258_0_1 -> 33 in the cache */
   /* search258_0 -> 875 in the cache */
   /* search258_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 875, 36 },
      -1,
   } },

   /* replace258_0 -> 16 in the cache */
   /* replace258_1_0 -> 920 in the cache */
   /* replace258_1_1 -> 36 in the cache */
   /* replace258_1 -> 921 in the cache */
   /* replace258 -> 922 in the cache */

   /* ('ushr', ('ishl', 'a@32', '#b'), 'b') => ('iand', 'a', ('ushr', 4294967295, 'b')) */
   /* search259_0_0 -> 16 in the cache */
   /* search259_0_1 -> 33 in the cache */
   /* search259_0 -> 862 in the cache */
   /* search259_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 862, 36 },
      -1,
   } },

   /* replace259_0 -> 16 in the cache */
   /* replace259_1_0 -> 920 in the cache */
   /* replace259_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 920, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 925 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b')) */
   /* search260_0_0 -> 21 in the cache */
   /* search260_0_1 -> 33 in the cache */
   /* search260_0 -> 892 in the cache */
   /* search260_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 892, 36 },
      -1,
   } },

   /* replace260_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffffffffffff /* 18446744073709551615 */ },
   } },
   /* replace260_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 928, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 929 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b')) */
   /* search261_0_0 -> 21 in the cache */
   /* search261_0_1 -> 33 in the cache */
   /* search261_0 -> 896 in the cache */
   /* search261_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 896, 36 },
      -1,
   } },

   /* replace261_0 -> 21 in the cache */
   /* replace261_1_0 -> 928 in the cache */
   /* replace261_1_1 -> 36 in the cache */
   /* replace261_1 -> 929 in the cache */
   /* replace261 -> 930 in the cache */

   /* ('ushr', ('ishl', 'a@64', '#b'), 'b') => ('iand', 'a', ('ushr', 18446744073709551615, 'b')) */
   /* search262_0_0 -> 21 in the cache */
   /* search262_0_1 -> 33 in the cache */
   /* search262_0 -> 882 in the cache */
   /* search262_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 882, 36 },
      -1,
   } },

   /* replace262_0 -> 21 in the cache */
   /* replace262_1_0 -> 928 in the cache */
   /* replace262_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 928, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 933 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', '#b(is_first_5_bits_uge_2)'), -4) => ('ishl', 'a', 'b') */
   /* search263_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      9,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 935 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x4 /* -4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 936, 937 },
      -1,
   } },

   /* replace263_0 -> 16 in the cache */
   /* replace263_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('iand', ('imul', 'a', '#b(is_unsigned_multiple_of_4)'), -4) => ('imul', 'a', 'b') */
   /* search264_0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      10,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 0, 940 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { -0x4 /* -4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 941, 942 },
      -1,
   } },

   /* replace264_0 -> 0 in the cache */
   /* replace264_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_2)'), 4294967294) => ('iadd', ('iand', 'a', 4294967294), 'b') */
   /* search265_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      11,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 945 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffe /* 4294967294 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 946, 947 },
      -1,
   } },

   /* replace265_0_0 -> 16 in the cache */
   /* replace265_0_1 -> 947 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 947 },
      -1,
   } },
   /* replace265_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 949, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_4)'), 4294967292) => ('iadd', ('iand', 'a', 4294967292), 'b') */
   /* search266_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      10,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 951 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffc /* 4294967292 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 952, 953 },
      -1,
   } },

   /* replace266_0_0 -> 16 in the cache */
   /* replace266_0_1 -> 953 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 953 },
      -1,
   } },
   /* replace266_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 955, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_8)'), 4294967288) => ('iadd', ('iand', 'a', 4294967288), 'b') */
   /* search267_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      12,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 957 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffff8 /* 4294967288 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 958, 959 },
      -1,
   } },

   /* replace267_0_0 -> 16 in the cache */
   /* replace267_0_1 -> 959 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 959 },
      -1,
   } },
   /* replace267_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 961, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_16)'), 4294967280) => ('iadd', ('iand', 'a', 4294967280), 'b') */
   /* search268_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      13,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 963 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffff0 /* 4294967280 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 964, 965 },
      -1,
   } },

   /* replace268_0_0 -> 16 in the cache */
   /* replace268_0_1 -> 965 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 965 },
      -1,
   } },
   /* replace268_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 967, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_32)'), 4294967264) => ('iadd', ('iand', 'a', 4294967264), 'b') */
   /* search269_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      14,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 969 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffe0 /* 4294967264 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 970, 971 },
      -1,
   } },

   /* replace269_0_0 -> 16 in the cache */
   /* replace269_0_1 -> 971 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 971 },
      -1,
   } },
   /* replace269_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 973, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_64)'), 4294967232) => ('iadd', ('iand', 'a', 4294967232), 'b') */
   /* search270_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      15,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 975 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffc0 /* 4294967232 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 976, 977 },
      -1,
   } },

   /* replace270_0_0 -> 16 in the cache */
   /* replace270_0_1 -> 977 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 977 },
      -1,
   } },
   /* replace270_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 979, 36 },
      -1,
   } },

   /* ('ishl@32', ('iand', 'a@32', 2147483647), 1) => ('ishl', 'a', 1) */
   /* search271_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fffffff /* 2147483647 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 981 },
      -1,
   } },
   /* search271_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 982, 398 },
      -1,
   } },

   /* replace271_0 -> 16 in the cache */
   /* replace271_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 398 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 1), 4294967294) => ('ishl', 'a', 1) */
   /* search272_0_0 -> 16 in the cache */
   /* search272_0_1 -> 398 in the cache */
   /* search272_0 -> 984 in the cache */
   /* search272_1 -> 947 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 984, 947 },
      -1,
   } },

   /* replace272_0 -> 16 in the cache */
   /* replace272_1 -> 398 in the cache */
   /* replace272 -> 984 in the cache */

   /* ('iand', ('ushr', 'a@32', 1), 2147483647) => ('ushr', 'a', 1) */
   /* search273_0_0 -> 16 in the cache */
   /* search273_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 398 },
      -1,
   } },
   /* search273_1 -> 981 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 986, 981 },
      -1,
   } },

   /* replace273_0 -> 16 in the cache */
   /* replace273_1 -> 398 in the cache */
   /* replace273 -> 986 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 1073741823), 2) => ('ishl', 'a', 2) */
   /* search274_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3fffffff /* 1073741823 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 988 },
      -1,
   } },
   /* search274_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 989, 403 },
      -1,
   } },

   /* replace274_0 -> 16 in the cache */
   /* replace274_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 403 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 2), 4294967292) => ('ishl', 'a', 2) */
   /* search275_0_0 -> 16 in the cache */
   /* search275_0_1 -> 403 in the cache */
   /* search275_0 -> 991 in the cache */
   /* search275_1 -> 953 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 991, 953 },
      -1,
   } },

   /* replace275_0 -> 16 in the cache */
   /* replace275_1 -> 403 in the cache */
   /* replace275 -> 991 in the cache */

   /* ('iand', ('ushr', 'a@32', 2), 1073741823) => ('ushr', 'a', 2) */
   /* search276_0_0 -> 16 in the cache */
   /* search276_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 403 },
      -1,
   } },
   /* search276_1 -> 988 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 993, 988 },
      -1,
   } },

   /* replace276_0 -> 16 in the cache */
   /* replace276_1 -> 403 in the cache */
   /* replace276 -> 993 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 65535), 16) => ('ishl', 'a', 16) */
   /* search277_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 995 },
      -1,
   } },
   /* search277_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 996, 846 },
      -1,
   } },

   /* replace277_0 -> 16 in the cache */
   /* replace277_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 846 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 16), 4294901760) => ('ishl', 'a', 16) */
   /* search278_0_0 -> 16 in the cache */
   /* search278_0_1 -> 846 in the cache */
   /* search278_0 -> 998 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffff0000 /* 4294901760 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 998, 999 },
      -1,
   } },

   /* replace278_0 -> 16 in the cache */
   /* replace278_1 -> 846 in the cache */
   /* replace278 -> 998 in the cache */

   /* ('iand', ('ushr', 'a@32', 16), 65535) => ('ushr', 'a', 16) */
   /* search279_0_0 -> 16 in the cache */
   /* search279_0_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 846 },
      -1,
   } },
   /* search279_1 -> 995 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1001, 995 },
      -1,
   } },

   /* replace279_0 -> 16 in the cache */
   /* replace279_1 -> 846 in the cache */
   /* replace279 -> 1001 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 255), 24) => ('ishl', 'a', 24) */
   /* search280_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 1003 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x18 /* 24 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 1004, 1005 },
      -1,
   } },

   /* replace280_0 -> 16 in the cache */
   /* replace280_1 -> 1005 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 1005 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 24), 4278190080) => ('ishl', 'a', 24) */
   /* search281_0_0 -> 16 in the cache */
   /* search281_0_1 -> 1005 in the cache */
   /* search281_0 -> 1007 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff000000 /* 4278190080 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1007, 1008 },
      -1,
   } },

   /* replace281_0 -> 16 in the cache */
   /* replace281_1 -> 1005 in the cache */
   /* replace281 -> 1007 in the cache */

   /* ('iand', ('ushr', 'a@32', 24), 255) => ('ushr', 'a', 24) */
   /* search282_0_0 -> 16 in the cache */
   /* search282_0_1 -> 1005 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 1005 },
      -1,
   } },
   /* search282_1 -> 1003 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1010, 1003 },
      -1,
   } },

   /* replace282_0 -> 16 in the cache */
   /* replace282_1 -> 1005 in the cache */
   /* replace282 -> 1010 in the cache */

   /* ('ishl', ('iadd', 'a', '#b'), '#c') => ('iadd', ('ishl', 'a', 'c'), ('ishl', 'b', 'c')) */
   /* search283_0_0 -> 0 in the cache */
   /* search283_0_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 814 },
      -1,
   } },
   /* search283_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 1012, 311 },
      -1,
   } },

   /* replace283_0_0 -> 0 in the cache */
   /* replace283_0_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 137 },
      -1,
   } },
   /* replace283_1_0 -> 3 in the cache */
   /* replace283_1_1 -> 137 in the cache */
   /* replace283_1 -> 817 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1014, 817 },
      -1,
   } },

   /* ('imul', ('iadd(is_used_once)', 'a', '#b'), '#c') => ('iadd', ('imul', 'a', 'c'), ('imul', 'b', 'c')) */
   /* search284_0_0 -> 128 in the cache */
   /* search284_0_1 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 128, 285 },
      0,
   } },
   /* search284_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 1016, 807 },
      -1,
   } },

   /* replace284_0_0 -> 128 in the cache */
   /* replace284_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 128, 131 },
      -1,
   } },
   /* replace284_1_0 -> 129 in the cache */
   /* replace284_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 1018, 1019 },
      -1,
   } },

   /* ('imul', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('imul', ('iadd', 'a', 'c'), 'd'), ('imul', 'b', 'd')) */
   /* search285_0_0_0 -> 151 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 151, 1021 },
      0,
   } },
   /* search285_0_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 2,
      { 1022, 154 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 3,
      { 1023, 1024 },
      -1,
   } },

   /* replace285_0_0_0 -> 151 in the cache */
   /* replace285_0_0_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 151, 154 },
      -1,
   } },
   /* replace285_0_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 2,
      { 1026, 155 },
      -1,
   } },
   /* replace285_1_0 -> 152 in the cache */
   /* replace285_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 1027, 1028 },
      -1,
   } },

   /* ('ishl', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('ishl', ('iadd', 'a', 'c'), 'd'), ('ishl', 'b', 'd')) */
   /* search286_0_0_0 -> 128 in the cache */
   /* search286_0_0_1 -> 285 in the cache */
   /* search286_0_0 -> 1016 in the cache */
   /* search286_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1016, 131 },
      0,
   } },
   /* search286_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 1030, 313 },
      -1,
   } },

   /* replace286_0_0_0 -> 128 in the cache */
   /* replace286_0_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 128, 131 },
      -1,
   } },
   /* replace286_0_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 1032, 165 },
      -1,
   } },
   /* replace286_1_0 -> 129 in the cache */
   /* replace286_1_1 -> 165 in the cache */
   /* replace286_1 -> 810 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1033, 810 },
      -1,
   } },

   /* ('inot', ('flt(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('fge', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1035, 1036 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1037 },
      -1,
   } },

   /* replace287_0 -> 0 in the cache */
   /* replace287_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('fge(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('flt', 'a', 'b') */
   /* search288_0_0 -> 1035 in the cache */
   /* search288_0_1 -> 1036 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1035, 1036 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1040 },
      -1,
   } },

   /* replace288_0 -> 0 in the cache */
   /* replace288_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('feq(is_used_once)', 'a', 'b')) => ('fneu', 'a', 'b') */
   /* search289_0_0 -> 0 in the cache */
   /* search289_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1043 },
      -1,
   } },

   /* replace289_0 -> 0 in the cache */
   /* replace289_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('fneu(is_used_once)', 'a', 'b')) => ('feq', 'a', 'b') */
   /* search290_0_0 -> 0 in the cache */
   /* search290_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1046 },
      -1,
   } },

   /* replace290_0 -> 0 in the cache */
   /* replace290_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ilt(is_used_once)', 'a', 'b')) => ('ige', 'a', 'b') */
   /* search291_0_0 -> 0 in the cache */
   /* search291_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1049 },
      -1,
   } },

   /* replace291_0 -> 0 in the cache */
   /* replace291_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ult(is_used_once)', 'a', 'b')) => ('uge', 'a', 'b') */
   /* search292_0_0 -> 0 in the cache */
   /* search292_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1052 },
      -1,
   } },

   /* replace292_0 -> 0 in the cache */
   /* replace292_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ige(is_used_once)', 'a', 'b')) => ('ilt', 'a', 'b') */
   /* search293_0_0 -> 0 in the cache */
   /* search293_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1055 },
      -1,
   } },

   /* replace293_0 -> 0 in the cache */
   /* replace293_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('uge(is_used_once)', 'a', 'b')) => ('ult', 'a', 'b') */
   /* search294_0_0 -> 0 in the cache */
   /* search294_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1058 },
      -1,
   } },

   /* replace294_0 -> 0 in the cache */
   /* replace294_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ieq(is_used_once)', 'a', 'b')) => ('ine', 'a', 'b') */
   /* search295_0_0 -> 0 in the cache */
   /* search295_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1061 },
      -1,
   } },

   /* replace295_0 -> 0 in the cache */
   /* replace295_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ine(is_used_once)', 'a', 'b')) => ('ieq', 'a', 'b') */
   /* search296_0_0 -> 0 in the cache */
   /* search296_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1064 },
      -1,
   } },

   /* replace296_0 -> 0 in the cache */
   /* replace296_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'b'), ('fneu', 'a', 'b')) => False */
   /* search297_0_0 -> 0 in the cache */
   /* search297_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search297_1_0 -> 0 in the cache */
   /* search297_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1067, 1068 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_bool, { NIR_FALSE /* False */ },
   } },

   /* ('iand', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => False */
   /* search298_0_0 -> 0 in the cache */
   /* search298_0_1 -> 3 in the cache */
   /* search298_0 -> 1042 in the cache */
   /* search298_1_0 -> 3 in the cache */
   /* search298_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1042, 1071 },
      -1,
   } },

   /* replace298 -> 1070 in the cache */

   /* ('iand', ('ieq', 'a', 'b'), ('ine', 'a', 'b')) => False */
   /* search299_0_0 -> 0 in the cache */
   /* search299_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search299_1_0 -> 0 in the cache */
   /* search299_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1073, 1074 },
      -1,
   } },

   /* replace299 -> 1070 in the cache */

   /* ('iand', ('ilt', 'a', 'b'), ('ilt', 'b', 'a')) => False */
   /* search300_0_0 -> 0 in the cache */
   /* search300_0_1 -> 3 in the cache */
   /* search300_0 -> 1057 in the cache */
   /* search300_1_0 -> 3 in the cache */
   /* search300_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1057, 1076 },
      -1,
   } },

   /* replace300 -> 1070 in the cache */

   /* ('iand', ('ult', 'a', 'b'), ('ult', 'b', 'a')) => False */
   /* search301_0_0 -> 0 in the cache */
   /* search301_0_1 -> 3 in the cache */
   /* search301_0 -> 1060 in the cache */
   /* search301_1_0 -> 3 in the cache */
   /* search301_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1060, 1078 },
      -1,
   } },

   /* replace301 -> 1070 in the cache */

   /* ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a') */
   /* search302_0_0 -> 0 in the cache */
   /* search302_0 -> 214 in the cache */
   /* search302_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 214, 1080 },
      -1,
   } },

   /* replace302_0 -> 3 in the cache */
   /* replace302_1 -> 0 in the cache */
   /* replace302 -> 1071 in the cache */

   /* ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a') */
   /* search303_0_0 -> 0 in the cache */
   /* search303_0 -> 214 in the cache */
   /* search303_1_0 -> 3 in the cache */
   /* search303_1 -> 1080 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 214, 1080 },
      -1,
   } },

   /* replace303_0 -> 3 in the cache */
   /* replace303_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a') */
   /* search304_0_0 -> 0 in the cache */
   /* search304_0 -> 214 in the cache */
   /* search304_1_0 -> 3 in the cache */
   /* search304_1 -> 1080 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 214, 1080 },
      -1,
   } },

   /* replace304_0 -> 3 in the cache */
   /* replace304_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 3, 0 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a') */
   /* search305_0_0 -> 0 in the cache */
   /* search305_0 -> 214 in the cache */
   /* search305_1_0 -> 3 in the cache */
   /* search305_1 -> 1080 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 214, 1080 },
      -1,
   } },

   /* replace305_0 -> 3 in the cache */
   /* replace305_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 3, 0 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a') */
   /* search306_0_0 -> 32 in the cache */
   /* search306_0 -> 98 in the cache */
   /* search306_1 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 98, 249 },
      -1,
   } },

   /* replace306_0 -> 243 in the cache */
   /* replace306_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 243, 32 },
      -1,
   } },

   /* ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0) */
   /* search307_0 -> 249 in the cache */
   /* search307_1_0 -> 32 in the cache */
   /* search307_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 249, 98 },
      -1,
   } },

   /* replace307_0 -> 32 in the cache */
   /* replace307_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 243 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a') */
   /* search308_0_0 -> 32 in the cache */
   /* search308_0 -> 98 in the cache */
   /* search308_1 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 98, 249 },
      -1,
   } },

   /* replace308_0 -> 243 in the cache */
   /* replace308_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 243, 32 },
      -1,
   } },

   /* ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0) */
   /* search309_0 -> 249 in the cache */
   /* search309_1_0 -> 32 in the cache */
   /* search309_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 249, 98 },
      -1,
   } },

   /* replace309_0 -> 32 in the cache */
   /* replace309_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 243 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a') */
   /* search310_0_0 -> 32 in the cache */
   /* search310_0 -> 98 in the cache */
   /* search310_1 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 98, 249 },
      -1,
   } },

   /* replace310_0 -> 243 in the cache */
   /* replace310_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 243, 32 },
      -1,
   } },

   /* ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0) */
   /* search311_0 -> 249 in the cache */
   /* search311_1_0 -> 32 in the cache */
   /* search311_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 249, 98 },
      -1,
   } },

   /* replace311_0 -> 32 in the cache */
   /* replace311_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 32, 243 },
      -1,
   } },

   /* ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      true,
      nir_type_invalid,
      17,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 1101 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1100, 1102 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace312_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1104, 1101 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b') */
   /* search313_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      17,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1106, 1107 },
      -1,
   } },

   /* replace313_0 -> 0 in the cache */
   /* replace313_1 -> 3 in the cache */
   /* replace313 -> 1039 in the cache */

   /* ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b') */
   /* search314_0_0 -> 0 in the cache */
   /* search314_0 -> 1106 in the cache */
   /* search314_1 -> 1107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1106, 1107 },
      -1,
   } },

   /* replace314_0 -> 0 in the cache */
   /* replace314_1 -> 3 in the cache */
   /* replace314 -> 1048 in the cache */

   /* ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b') */
   /* search315_0_0 -> 0 in the cache */
   /* search315_0 -> 1106 in the cache */
   /* search315_1 -> 1107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1106, 1107 },
      -1,
   } },

   /* replace315_0 -> 0 in the cache */
   /* replace315_1 -> 3 in the cache */
   /* replace315 -> 1045 in the cache */

   /* ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0) */
   /* search316_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 32 },
      0,
   } },
   /* search316_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1111, 243 },
      -1,
   } },

   /* replace316_0 -> 32 in the cache */
   /* replace316_1 -> 243 in the cache */
   /* replace316 -> 1095 in the cache */

   /* ('flt', 0.0, ('fsat(is_used_once)', 'a')) => ('flt', 0.0, 'a') */
   /* search317_0 -> 113 in the cache */
   /* search317_1_0 -> 32 in the cache */
   /* search317_1 -> 1111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 1111 },
      -1,
   } },

   /* replace317_0 -> 113 in the cache */
   /* replace317_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 32 },
      -1,
   } },

   /* ('fge', 0.0, ('b2f', 'a@1')) => ('inot', 'a') */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search318_1_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 753 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1115, 1116 },
      -1,
   } },

   /* replace318_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 753 },
      -1,
   } },

   /* ('fge', ('fneg', ('b2f', 'a@1')), 0.0) => ('inot', 'a') */
   /* search319_0_0_0 -> 753 in the cache */
   /* search319_0_0 -> 1116 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1116 },
      -1,
   } },
   /* search319_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1119, 1115 },
      -1,
   } },

   /* replace319_0 -> 753 in the cache */
   /* replace319 -> 1118 in the cache */

   /* ('fneu', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b') */
   /* search320_0_0_0 -> 753 in the cache */
   /* search320_0_0 -> 1116 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1121 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1116, 1122 },
      -1,
   } },
   /* search320_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1123, 1115 },
      -1,
   } },

   /* replace320_0 -> 753 in the cache */
   /* replace320_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 753, 1121 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b') */
   /* search321_0_0 -> 753 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* search321_0_2_0 -> 1121 in the cache */
   /* search321_0_2 -> 1122 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1126, 1122 },
      -1,
   } },
   /* search321_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1127, 1115 },
      -1,
   } },

   /* replace321_0 -> 753 in the cache */
   /* replace321_1 -> 1121 in the cache */
   /* replace321 -> 1125 in the cache */

   /* ('fneu', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('ior', 'a', 'b') */
   /* search322_0_0 -> 753 in the cache */
   /* search322_0 -> 1116 in the cache */
   /* search322_1_0_0 -> 1121 in the cache */
   /* search322_1_0 -> 1122 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1122 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1116, 1129 },
      -1,
   } },

   /* replace322_0 -> 753 in the cache */
   /* replace322_1 -> 1121 in the cache */
   /* replace322 -> 1125 in the cache */

   /* ('fneu', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('iand', 'a', 'b') */
   /* search323_0_0_0 -> 753 in the cache */
   /* search323_0_0 -> 1116 in the cache */
   /* search323_0_1_0 -> 1121 in the cache */
   /* search323_0_1 -> 1122 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 1116, 1122 },
      -1,
   } },
   /* search323_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1131, 1115 },
      -1,
   } },

   /* replace323_0 -> 753 in the cache */
   /* replace323_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 753, 1121 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('iand', 'a', 'b') */
   /* search324_0_0 -> 753 in the cache */
   /* search324_0_1_0 -> 1121 in the cache */
   /* search324_0_1 -> 1122 in the cache */
   /* search324_0_2 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1122, 1115 },
      -1,
   } },
   /* search324_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1134, 1115 },
      -1,
   } },

   /* replace324_0 -> 753 in the cache */
   /* replace324_1 -> 1121 in the cache */
   /* replace324 -> 1133 in the cache */

   /* ('fneu', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ixor', 'a', 'b') */
   /* search325_0_0_0 -> 753 in the cache */
   /* search325_0_0 -> 1116 in the cache */
   /* search325_0_1_0_0 -> 1121 in the cache */
   /* search325_0_1_0 -> 1122 in the cache */
   /* search325_0_1 -> 1129 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1116, 1129 },
      -1,
   } },
   /* search325_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1136, 1115 },
      -1,
   } },

   /* replace325_0 -> 753 in the cache */
   /* replace325_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 753, 1121 },
      -1,
   } },

   /* ('fneu', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ixor', 'a', 'b') */
   /* search326_0_0 -> 753 in the cache */
   /* search326_0 -> 1116 in the cache */
   /* search326_1_0 -> 1121 in the cache */
   /* search326_1 -> 1122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1116, 1122 },
      -1,
   } },

   /* replace326_0 -> 753 in the cache */
   /* replace326_1 -> 1121 in the cache */
   /* replace326 -> 1138 in the cache */

   /* ('fneu', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ixor', 'a', 'b') */
   /* search327_0_0_0 -> 753 in the cache */
   /* search327_0_0 -> 1116 in the cache */
   /* search327_0 -> 1119 in the cache */
   /* search327_1_0_0 -> 1121 in the cache */
   /* search327_1_0 -> 1122 in the cache */
   /* search327_1 -> 1129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1119, 1129 },
      -1,
   } },

   /* replace327_0 -> 753 in the cache */
   /* replace327_1 -> 1121 in the cache */
   /* replace327 -> 1138 in the cache */

   /* ('feq', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search328_0_0_0 -> 753 in the cache */
   /* search328_0_0 -> 1116 in the cache */
   /* search328_0_1_0 -> 1121 in the cache */
   /* search328_0_1 -> 1122 in the cache */
   /* search328_0 -> 1123 in the cache */
   /* search328_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1123, 1115 },
      -1,
   } },

   /* replace328_0_0 -> 753 in the cache */
   /* replace328_0_1 -> 1121 in the cache */
   /* replace328_0 -> 1125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1125 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search329_0_0 -> 753 in the cache */
   /* search329_0_1 -> 1126 in the cache */
   /* search329_0_2_0 -> 1121 in the cache */
   /* search329_0_2 -> 1122 in the cache */
   /* search329_0 -> 1127 in the cache */
   /* search329_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1127, 1115 },
      -1,
   } },

   /* replace329_0_0 -> 753 in the cache */
   /* replace329_0_1 -> 1121 in the cache */
   /* replace329_0 -> 1125 in the cache */
   /* replace329 -> 1142 in the cache */

   /* ('feq', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b')) */
   /* search330_0_0 -> 753 in the cache */
   /* search330_0 -> 1116 in the cache */
   /* search330_1_0_0 -> 1121 in the cache */
   /* search330_1_0 -> 1122 in the cache */
   /* search330_1 -> 1129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1116, 1129 },
      -1,
   } },

   /* replace330_0_0 -> 753 in the cache */
   /* replace330_0_1 -> 1121 in the cache */
   /* replace330_0 -> 1125 in the cache */
   /* replace330 -> 1142 in the cache */

   /* ('feq', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('iand', 'a', 'b')) */
   /* search331_0_0_0 -> 753 in the cache */
   /* search331_0_0 -> 1116 in the cache */
   /* search331_0_1_0 -> 1121 in the cache */
   /* search331_0_1 -> 1122 in the cache */
   /* search331_0 -> 1131 in the cache */
   /* search331_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1131, 1115 },
      -1,
   } },

   /* replace331_0_0 -> 753 in the cache */
   /* replace331_0_1 -> 1121 in the cache */
   /* replace331_0 -> 1133 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1133 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('inot', ('iand', 'a', 'b')) */
   /* search332_0_0 -> 753 in the cache */
   /* search332_0_1_0 -> 1121 in the cache */
   /* search332_0_1 -> 1122 in the cache */
   /* search332_0_2 -> 1115 in the cache */
   /* search332_0 -> 1134 in the cache */
   /* search332_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1134, 1115 },
      -1,
   } },

   /* replace332_0_0 -> 753 in the cache */
   /* replace332_0_1 -> 1121 in the cache */
   /* replace332_0 -> 1133 in the cache */
   /* replace332 -> 1146 in the cache */

   /* ('feq', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ieq', 'a', 'b') */
   /* search333_0_0_0 -> 753 in the cache */
   /* search333_0_0 -> 1116 in the cache */
   /* search333_0_1_0_0 -> 1121 in the cache */
   /* search333_0_1_0 -> 1122 in the cache */
   /* search333_0_1 -> 1129 in the cache */
   /* search333_0 -> 1136 in the cache */
   /* search333_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1136, 1115 },
      -1,
   } },

   /* replace333_0 -> 753 in the cache */
   /* replace333_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 753, 1121 },
      -1,
   } },

   /* ('feq', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ieq', 'a', 'b') */
   /* search334_0_0 -> 753 in the cache */
   /* search334_0 -> 1116 in the cache */
   /* search334_1_0 -> 1121 in the cache */
   /* search334_1 -> 1122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1116, 1122 },
      -1,
   } },

   /* replace334_0 -> 753 in the cache */
   /* replace334_1 -> 1121 in the cache */
   /* replace334 -> 1149 in the cache */

   /* ('feq', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ieq', 'a', 'b') */
   /* search335_0_0_0 -> 753 in the cache */
   /* search335_0_0 -> 1116 in the cache */
   /* search335_0 -> 1119 in the cache */
   /* search335_1_0_0 -> 1121 in the cache */
   /* search335_1_0 -> 1122 in the cache */
   /* search335_1 -> 1129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1119, 1129 },
      -1,
   } },

   /* replace335_0 -> 753 in the cache */
   /* replace335_1 -> 1121 in the cache */
   /* replace335 -> 1149 in the cache */

   /* ('flt', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('ior', 'a', 'b') */
   /* search336_0_0_0_0 -> 753 in the cache */
   /* search336_0_0_0 -> 1116 in the cache */
   /* search336_0_0_1_0 -> 1121 in the cache */
   /* search336_0_0_1 -> 1122 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1116, 1122 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1152 },
      -1,
   } },
   /* search336_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1153, 1115 },
      -1,
   } },

   /* replace336_0 -> 753 in the cache */
   /* replace336_1 -> 1121 in the cache */
   /* replace336 -> 1125 in the cache */

   /* ('flt', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('ior', 'a', 'b') */
   /* search337_0 -> 1115 in the cache */
   /* search337_1_0_0 -> 753 in the cache */
   /* search337_1_0 -> 1116 in the cache */
   /* search337_1_1_0 -> 1121 in the cache */
   /* search337_1_1 -> 1122 in the cache */
   /* search337_1 -> 1152 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1115, 1152 },
      -1,
   } },

   /* replace337_0 -> 753 in the cache */
   /* replace337_1 -> 1121 in the cache */
   /* replace337 -> 1125 in the cache */

   /* ('fge', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search338_0_0_0_0 -> 753 in the cache */
   /* search338_0_0_0 -> 1116 in the cache */
   /* search338_0_0_1_0 -> 1121 in the cache */
   /* search338_0_0_1 -> 1122 in the cache */
   /* search338_0_0 -> 1152 in the cache */
   /* search338_0 -> 1153 in the cache */
   /* search338_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1153, 1115 },
      -1,
   } },

   /* replace338_0_0 -> 753 in the cache */
   /* replace338_0_1 -> 1121 in the cache */
   /* replace338_0 -> 1125 in the cache */
   /* replace338 -> 1142 in the cache */

   /* ('fge', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b')) */
   /* search339_0 -> 1115 in the cache */
   /* search339_1_0_0 -> 753 in the cache */
   /* search339_1_0 -> 1116 in the cache */
   /* search339_1_1_0 -> 1121 in the cache */
   /* search339_1_1 -> 1122 in the cache */
   /* search339_1 -> 1152 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1115, 1152 },
      -1,
   } },

   /* replace339_0_0 -> 753 in the cache */
   /* replace339_0_1 -> 1121 in the cache */
   /* replace339_0 -> 1125 in the cache */
   /* replace339 -> 1142 in the cache */

   /* ('flt', 'a', ('fneg', 'a')) => ('flt', 'a', 0.0) */
   /* search340_0 -> 32 in the cache */
   /* search340_1_0 -> 32 in the cache */
   /* search340_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 98 },
      -1,
   } },

   /* replace340_0 -> 32 in the cache */
   /* replace340_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 113 },
      -1,
   } },

   /* ('fge', 'a', ('fneg', 'a')) => ('fge', 'a', 0.0) */
   /* search341_0 -> 32 in the cache */
   /* search341_1_0 -> 32 in the cache */
   /* search341_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 98 },
      -1,
   } },

   /* replace341_0 -> 32 in the cache */
   /* replace341_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 113 },
      -1,
   } },

   /* ('flt', ('fmin', 'c', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')))), 0.0) => ('ior', ('flt', 'c', 0.0), ('ior', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1163 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1164, 1166 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1167 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1162, 1168 },
      -1,
   } },
   /* search342_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 2,
      { 1169, 113 },
      -1,
   } },

   /* replace342_0_0 -> 1162 in the cache */
   /* replace342_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1162, 113 },
      -1,
   } },
   /* replace342_1_0 -> 1163 in the cache */
   /* replace342_1_1 -> 1165 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1163, 1165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1171, 1172 },
      -1,
   } },

   /* ('~flt', ('fadd', 'a', 'b'), 'a') => ('flt', 'b', 0.0) */
   /* search343_0_0 -> 0 in the cache */
   /* search343_0_1 -> 3 in the cache */
   /* search343_0 -> 274 in the cache */
   /* search343_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 274, 0 },
      -1,
   } },

   /* replace343_0 -> 3 in the cache */
   /* replace343_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3, 258 },
      -1,
   } },

   /* ('~fge', ('fadd', 'a', 'b'), 'a') => ('fge', 'b', 0.0) */
   /* search344_0_0 -> 0 in the cache */
   /* search344_0_1 -> 3 in the cache */
   /* search344_0 -> 274 in the cache */
   /* search344_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 274, 0 },
      -1,
   } },

   /* replace344_0 -> 3 in the cache */
   /* replace344_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3, 258 },
      -1,
   } },

   /* ('~feq', ('fadd', 'a', 'b'), 'a') => ('feq', 'b', 0.0) */
   /* search345_0_0 -> 0 in the cache */
   /* search345_0_1 -> 3 in the cache */
   /* search345_0 -> 215 in the cache */
   /* search345_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 215, 0 },
      -1,
   } },

   /* replace345_0 -> 3 in the cache */
   /* replace345_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 3, 258 },
      -1,
   } },

   /* ('~fneu', ('fadd', 'a', 'b'), 'a') => ('fneu', 'b', 0.0) */
   /* search346_0_0 -> 0 in the cache */
   /* search346_0_1 -> 3 in the cache */
   /* search346_0 -> 215 in the cache */
   /* search346_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 215, 0 },
      -1,
   } },

   /* replace346_0 -> 3 in the cache */
   /* replace346_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 3, 258 },
      -1,
   } },

   /* ('~flt', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('flt', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search347_0_0 -> 128 in the cache */
   /* search347_0_1 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 128, 285 },
      0,
   } },
   /* search347_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1182, 807 },
      -1,
   } },

   /* replace347_0 -> 128 in the cache */
   /* replace347_1_0 -> 131 in the cache */
   /* replace347_1_1_0 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 131, 1184 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 128, 1185 },
      -1,
   } },

   /* ('~flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('flt', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search348_0_0_0 -> 128 in the cache */
   /* search348_0_0_1 -> 285 in the cache */
   /* search348_0_0 -> 1182 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1182 },
      0,
   } },
   /* search348_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1187, 807 },
      -1,
   } },

   /* replace348_0_0_0 -> 131 in the cache */
   /* replace348_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 131, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1189 },
      -1,
   } },
   /* replace348_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1190, 128 },
      -1,
   } },

   /* ('~fge', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fge', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search349_0_0 -> 128 in the cache */
   /* search349_0_1 -> 285 in the cache */
   /* search349_0 -> 1182 in the cache */
   /* search349_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1182, 807 },
      -1,
   } },

   /* replace349_0 -> 128 in the cache */
   /* replace349_1_0 -> 131 in the cache */
   /* replace349_1_1_0 -> 129 in the cache */
   /* replace349_1_1 -> 1184 in the cache */
   /* replace349_1 -> 1185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 128, 1185 },
      -1,
   } },

   /* ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fge', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search350_0_0_0 -> 128 in the cache */
   /* search350_0_0_1 -> 285 in the cache */
   /* search350_0_0 -> 1182 in the cache */
   /* search350_0 -> 1187 in the cache */
   /* search350_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1187, 807 },
      -1,
   } },

   /* replace350_0_0_0 -> 131 in the cache */
   /* replace350_0_0_1 -> 129 in the cache */
   /* replace350_0_0 -> 1189 in the cache */
   /* replace350_0 -> 1190 in the cache */
   /* replace350_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1190, 128 },
      -1,
   } },

   /* ('~feq', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('feq', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search351_0_0 -> 128 in the cache */
   /* search351_0_1 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 128, 285 },
      0,
   } },
   /* search351_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1196, 807 },
      -1,
   } },

   /* replace351_0 -> 128 in the cache */
   /* replace351_1_0 -> 131 in the cache */
   /* replace351_1_1_0 -> 129 in the cache */
   /* replace351_1_1 -> 1184 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 131, 1184 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 128, 1198 },
      -1,
   } },

   /* ('~feq', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('feq', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search352_0_0_0 -> 128 in the cache */
   /* search352_0_0_1 -> 285 in the cache */
   /* search352_0_0 -> 1196 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1196 },
      0,
   } },
   /* search352_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1200, 807 },
      -1,
   } },

   /* replace352_0_0_0 -> 131 in the cache */
   /* replace352_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 131, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1202 },
      -1,
   } },
   /* replace352_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1203, 128 },
      -1,
   } },

   /* ('~fneu', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fneu', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search353_0_0 -> 128 in the cache */
   /* search353_0_1 -> 285 in the cache */
   /* search353_0 -> 1196 in the cache */
   /* search353_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1196, 807 },
      -1,
   } },

   /* replace353_0 -> 128 in the cache */
   /* replace353_1_0 -> 131 in the cache */
   /* replace353_1_1_0 -> 129 in the cache */
   /* replace353_1_1 -> 1184 in the cache */
   /* replace353_1 -> 1198 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 128, 1198 },
      -1,
   } },

   /* ('~fneu', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fneu', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search354_0_0_0 -> 128 in the cache */
   /* search354_0_0_1 -> 285 in the cache */
   /* search354_0_0 -> 1196 in the cache */
   /* search354_0 -> 1200 in the cache */
   /* search354_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1200, 807 },
      -1,
   } },

   /* replace354_0_0_0 -> 131 in the cache */
   /* replace354_0_0_1 -> 129 in the cache */
   /* replace354_0_0 -> 1202 in the cache */
   /* replace354_0 -> 1203 in the cache */
   /* replace354_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1203, 128 },
      -1,
   } },

   /* ('ieq', ('iadd', 'a', 'b'), 'a') => ('ieq', 'b', 0) */
   /* search355_0_0 -> 0 in the cache */
   /* search355_0_1 -> 3 in the cache */
   /* search355_0 -> 210 in the cache */
   /* search355_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 210, 0 },
      -1,
   } },

   /* replace355_0 -> 3 in the cache */
   /* replace355_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3, 86 },
      -1,
   } },

   /* ('ine', ('iadd', 'a', 'b'), 'a') => ('ine', 'b', 0) */
   /* search356_0_0 -> 0 in the cache */
   /* search356_0_1 -> 3 in the cache */
   /* search356_0 -> 210 in the cache */
   /* search356_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 210, 0 },
      -1,
   } },

   /* replace356_0 -> 3 in the cache */
   /* replace356_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3, 86 },
      -1,
   } },

   /* ('feq', ('b2f', 'a@1'), 0.0) => ('inot', 'a') */
   /* search357_0_0 -> 753 in the cache */
   /* search357_0 -> 1116 in the cache */
   /* search357_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1116, 1115 },
      -1,
   } },

   /* replace357_0 -> 753 in the cache */
   /* replace357 -> 1118 in the cache */

   /* ('fneu', ('b2f', 'a@1'), 0.0) => a */
   /* search358_0_0 -> 753 in the cache */
   /* search358_0 -> 1116 in the cache */
   /* search358_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1116, 1115 },
      -1,
   } },

   /* replace358 -> 753 in the cache */

   /* ('ieq', ('b2i', 'a@1'), 0) => ('inot', 'a') */
   /* search359_0_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 753 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1215, 1216 },
      -1,
   } },

   /* replace359_0 -> 753 in the cache */
   /* replace359 -> 1118 in the cache */

   /* ('ine', ('b2i', 'a@1'), 0) => a */
   /* search360_0_0 -> 753 in the cache */
   /* search360_0 -> 1215 in the cache */
   /* search360_1 -> 1216 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1215, 1216 },
      -1,
   } },

   /* replace360 -> 753 in the cache */

   /* ('fneu', ('u2f', 'a'), 0.0) => ('ine', 'a', 0) */
   /* search361_0_0 -> 32 in the cache */
   /* search361_0 -> 104 in the cache */
   /* search361_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 104, 1115 },
      -1,
   } },

   /* replace361_0 -> 32 in the cache */
   /* replace361_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('feq', ('u2f', 'a'), 0.0) => ('ieq', 'a', 0) */
   /* search362_0_0 -> 32 in the cache */
   /* search362_0 -> 104 in the cache */
   /* search362_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 104, 1115 },
      -1,
   } },

   /* replace362_0 -> 32 in the cache */
   /* replace362_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('fge', ('u2f', 'a'), 0.0) => True */
   /* search363_0_0 -> 32 in the cache */
   /* search363_0 -> 104 in the cache */
   /* search363_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 104, 1115 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_bool, { NIR_TRUE /* True */ },
   } },

   /* ('fge', 0.0, ('u2f', 'a')) => ('uge', 0, 'a') */
   /* search364_0 -> 1115 in the cache */
   /* search364_1_0 -> 32 in the cache */
   /* search364_1 -> 104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1115, 104 },
      -1,
   } },

   /* replace364_0 -> 61 in the cache */
   /* replace364_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('flt', ('u2f', 'a'), 0.0) => False */
   /* search365_0_0 -> 32 in the cache */
   /* search365_0 -> 104 in the cache */
   /* search365_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 104, 1115 },
      -1,
   } },

   /* replace365 -> 1070 in the cache */

   /* ('flt', 0.0, ('u2f', 'a')) => ('ult', 0, 'a') */
   /* search366_0 -> 1115 in the cache */
   /* search366_1_0 -> 32 in the cache */
   /* search366_1 -> 104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1115, 104 },
      -1,
   } },

   /* replace366_0 -> 61 in the cache */
   /* replace366_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('fneu', ('i2f', 'a'), 0.0) => ('ine', 'a', 0) */
   /* search367_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search367_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1230, 1115 },
      -1,
   } },

   /* replace367_0 -> 32 in the cache */
   /* replace367_1 -> 61 in the cache */
   /* replace367 -> 1220 in the cache */

   /* ('feq', ('i2f', 'a'), 0.0) => ('ieq', 'a', 0) */
   /* search368_0_0 -> 32 in the cache */
   /* search368_0 -> 1230 in the cache */
   /* search368_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1230, 1115 },
      -1,
   } },

   /* replace368_0 -> 32 in the cache */
   /* replace368_1 -> 61 in the cache */
   /* replace368 -> 1222 in the cache */

   /* ('fge', ('i2f', 'a'), 0.0) => ('ige', 'a', 0) */
   /* search369_0_0 -> 32 in the cache */
   /* search369_0 -> 1230 in the cache */
   /* search369_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1230, 1115 },
      -1,
   } },

   /* replace369_0 -> 32 in the cache */
   /* replace369_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('fge', 0.0, ('i2f', 'a')) => ('ige', 0, 'a') */
   /* search370_0 -> 1115 in the cache */
   /* search370_1_0 -> 32 in the cache */
   /* search370_1 -> 1230 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1115, 1230 },
      -1,
   } },

   /* replace370_0 -> 61 in the cache */
   /* replace370_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('flt', ('i2f', 'a'), 0.0) => ('ilt', 'a', 0) */
   /* search371_0_0 -> 32 in the cache */
   /* search371_0 -> 1230 in the cache */
   /* search371_1 -> 1115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1230, 1115 },
      -1,
   } },

   /* replace371_0 -> 32 in the cache */
   /* replace371_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('flt', 0.0, ('i2f', 'a')) => ('ilt', 0, 'a') */
   /* search372_0 -> 1115 in the cache */
   /* search372_1_0 -> 32 in the cache */
   /* search372_1 -> 1230 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1115, 1230 },
      -1,
   } },

   /* replace372_0 -> 61 in the cache */
   /* replace372_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('~flt', 0.0, ('fabs', 'a')) => ('fneu', 'a', 0.0) */
   /* search373_0 -> 113 in the cache */
   /* search373_1_0 -> 32 in the cache */
   /* search373_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 103 },
      -1,
   } },

   /* replace373_0 -> 32 in the cache */
   /* replace373_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* ('~flt', ('fneg', ('fabs', 'a')), 0.0) => ('fneu', 'a', 0.0) */
   /* search374_0_0_0 -> 32 in the cache */
   /* search374_0_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 103 },
      -1,
   } },
   /* search374_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1243, 113 },
      -1,
   } },

   /* replace374_0 -> 32 in the cache */
   /* replace374_1 -> 113 in the cache */
   /* replace374 -> 1242 in the cache */

   /* ('fge', 0.0, ('fabs', 'a')) => ('feq', 'a', 0.0) */
   /* search375_0 -> 113 in the cache */
   /* search375_1_0 -> 32 in the cache */
   /* search375_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 113, 103 },
      -1,
   } },

   /* replace375_0 -> 32 in the cache */
   /* replace375_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0) */
   /* search376_0_0_0 -> 32 in the cache */
   /* search376_0_0 -> 103 in the cache */
   /* search376_0 -> 1243 in the cache */
   /* search376_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1243, 113 },
      -1,
   } },

   /* replace376_0 -> 32 in the cache */
   /* replace376_1 -> 113 in the cache */
   /* replace376 -> 1246 in the cache */

   /* ('iand', ('fge', 'a', 0.0), ('fge', 1.0, 'a')) => ('feq', 'a', ('fsat', 'a')) */
   /* search377_0_0 -> 32 in the cache */
   /* search377_0_1 -> 113 in the cache */
   /* search377_0 -> 1161 in the cache */
   /* search377_1_0 -> 243 in the cache */
   /* search377_1_1 -> 32 in the cache */
   /* search377_1 -> 1093 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1161, 1093 },
      -1,
   } },

   /* replace377_0 -> 32 in the cache */
   /* replace377_1_0 -> 32 in the cache */
   /* replace377_1 -> 219 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 32, 219 },
      -1,
   } },

   /* ('fmax', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('ior', 'a', 'b')) */
   /* search378_0_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 753 },
      0,
   } },
   /* search378_1_0 -> 1121 in the cache */
   /* search378_1 -> 1122 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1250, 1122 },
      -1,
   } },

   /* replace378_0_0 -> 753 in the cache */
   /* replace378_0_1 -> 1121 in the cache */
   /* replace378_0 -> 1125 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1125 },
      -1,
   } },

   /* ('fmax', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('iand', 'a', 'b'))) */
   /* search379_0_0_0 -> 753 in the cache */
   /* search379_0_0 -> 1250 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1250 },
      0,
   } },
   /* search379_1_0_0 -> 1121 in the cache */
   /* search379_1_0 -> 1122 in the cache */
   /* search379_1 -> 1129 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1253, 1129 },
      -1,
   } },

   /* replace379_0_0_0 -> 753 in the cache */
   /* replace379_0_0_1 -> 1121 in the cache */
   /* replace379_0_0 -> 1133 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1255 },
      -1,
   } },

   /* ('fmin', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b')) */
   /* search380_0_0 -> 753 in the cache */
   /* search380_0 -> 1250 in the cache */
   /* search380_1_0 -> 1121 in the cache */
   /* search380_1 -> 1122 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1250, 1122 },
      -1,
   } },

   /* replace380_0_0 -> 753 in the cache */
   /* replace380_0_1 -> 1121 in the cache */
   /* replace380_0 -> 1133 in the cache */
   /* replace380 -> 1255 in the cache */

   /* ('fmin', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('ior', 'a', 'b'))) */
   /* search381_0_0_0 -> 753 in the cache */
   /* search381_0_0 -> 1250 in the cache */
   /* search381_0 -> 1253 in the cache */
   /* search381_1_0_0 -> 1121 in the cache */
   /* search381_1_0 -> 1122 in the cache */
   /* search381_1 -> 1129 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1253, 1129 },
      -1,
   } },

   /* replace381_0_0_0 -> 753 in the cache */
   /* replace381_0_0_1 -> 1121 in the cache */
   /* replace381_0_0 -> 1125 in the cache */
   /* replace381_0 -> 1252 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1252 },
      -1,
   } },

   /* ('fmin', ('b2f', 'a@1'), '#b') => ('bcsel', 'a', ('fmin', 'b', 1.0), ('fmin', 'b', 0.0)) */
   /* search382_0_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 753 },
      -1,
   } },
   /* search382_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1260, 814 },
      -1,
   } },

   /* replace382_0 -> 753 in the cache */
   /* replace382_1_0 -> 3 in the cache */
   /* replace382_1_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 3, 272 },
      -1,
   } },
   /* replace382_2_0 -> 3 in the cache */
   /* replace382_2_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 3, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 1262, 1263 },
      -1,
   } },

   /* ('flt', ('fadd(is_used_once)', 'a', ('fneg', 'b')), 0.0) => ('flt', 'a', 'b') */
   /* search383_0_0 -> 0 in the cache */
   /* search383_0_1_0 -> 3 in the cache */
   /* search383_0_1 -> 1080 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1080 },
      0,
   } },
   /* search383_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1265, 258 },
      -1,
   } },

   /* replace383_0 -> 0 in the cache */
   /* replace383_1 -> 3 in the cache */
   /* replace383 -> 1042 in the cache */

   /* ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0) */
   /* search384_0_0_0 -> 32 in the cache */
   /* search384_0_0 -> 103 in the cache */
   /* search384_0 -> 1243 in the cache */
   /* search384_1 -> 113 in the cache */
   /* search384 -> 1247 in the cache */

   /* replace384_0 -> 32 in the cache */
   /* replace384_1 -> 113 in the cache */
   /* replace384 -> 1246 in the cache */

   /* ('~bcsel', ('flt', 'b', 'a'), 'b', 'a') => ('fmin', 'a', 'b') */
   /* search385_0_0 -> 1104 in the cache */
   /* search385_0_1 -> 1101 in the cache */
   /* search385_0 -> 1105 in the cache */
   /* search385_1 -> 1104 in the cache */
   /* search385_2 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1105, 1104, 1101 },
      -1,
   } },

   /* replace385_0 -> 1101 in the cache */
   /* replace385_1 -> 1104 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1101, 1104 },
      -1,
   } },

   /* ('~bcsel', ('flt', 'a', 'b'), 'b', 'a') => ('fmax', 'a', 'b') */
   /* search386_0_0 -> 0 in the cache */
   /* search386_0_1 -> 3 in the cache */
   /* search386_0 -> 1042 in the cache */
   /* search386_1 -> 3 in the cache */
   /* search386_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1042, 3, 0 },
      -1,
   } },

   /* replace386_0 -> 0 in the cache */
   /* replace386_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('~bcsel', ('fge', 'a', 'b'), 'b', 'a') => ('fmin', 'a', 'b') */
   /* search387_0_0 -> 0 in the cache */
   /* search387_0_1 -> 3 in the cache */
   /* search387_0 -> 1039 in the cache */
   /* search387_1 -> 3 in the cache */
   /* search387_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1039, 3, 0 },
      -1,
   } },

   /* replace387_0 -> 0 in the cache */
   /* replace387_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('~bcsel', ('fge', 'b', 'a'), 'b', 'a') => ('fmax', 'a', 'b') */
   /* search388_0_0 -> 1104 in the cache */
   /* search388_0_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1104, 1101 },
      -1,
   } },
   /* search388_1 -> 1104 in the cache */
   /* search388_2 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1273, 1104, 1101 },
      -1,
   } },

   /* replace388_0 -> 1101 in the cache */
   /* replace388_1 -> 1104 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1101, 1104 },
      -1,
   } },

   /* ('bcsel', ('ult', 'b', 'a'), 'b', 'a') => ('umin', 'a', 'b') */
   /* search389_0_0 -> 1104 in the cache */
   /* search389_0_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1104, 1101 },
      -1,
   } },
   /* search389_1 -> 1104 in the cache */
   /* search389_2 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1276, 1104, 1101 },
      -1,
   } },

   /* replace389_0 -> 1101 in the cache */
   /* replace389_1 -> 1104 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 1101, 1104 },
      -1,
   } },

   /* ('bcsel', ('ult', 'a', 'b'), 'b', 'a') => ('umax', 'a', 'b') */
   /* search390_0_0 -> 0 in the cache */
   /* search390_0_1 -> 3 in the cache */
   /* search390_0 -> 1060 in the cache */
   /* search390_1 -> 3 in the cache */
   /* search390_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1060, 3, 0 },
      -1,
   } },

   /* replace390_0 -> 0 in the cache */
   /* replace390_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bcsel', ('uge', 'a', 'b'), 'b', 'a') => ('umin', 'a', 'b') */
   /* search391_0_0 -> 0 in the cache */
   /* search391_0_1 -> 3 in the cache */
   /* search391_0 -> 1054 in the cache */
   /* search391_1 -> 3 in the cache */
   /* search391_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1054, 3, 0 },
      -1,
   } },

   /* replace391_0 -> 0 in the cache */
   /* replace391_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bcsel', ('uge', 'b', 'a'), 'b', 'a') => ('umax', 'a', 'b') */
   /* search392_0_0 -> 1104 in the cache */
   /* search392_0_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1104, 1101 },
      -1,
   } },
   /* search392_1 -> 1104 in the cache */
   /* search392_2 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1283, 1104, 1101 },
      -1,
   } },

   /* replace392_0 -> 1101 in the cache */
   /* replace392_1 -> 1104 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 1101, 1104 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'b', 'a'), 'b', 'a') => ('imin', 'a', 'b') */
   /* search393_0_0 -> 1104 in the cache */
   /* search393_0_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1104, 1101 },
      -1,
   } },
   /* search393_1 -> 1104 in the cache */
   /* search393_2 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1286, 1104, 1101 },
      -1,
   } },

   /* replace393_0 -> 1101 in the cache */
   /* replace393_1 -> 1104 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 1101, 1104 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a', 'b'), 'b', 'a') => ('imax', 'a', 'b') */
   /* search394_0_0 -> 0 in the cache */
   /* search394_0_1 -> 3 in the cache */
   /* search394_0 -> 1057 in the cache */
   /* search394_1 -> 3 in the cache */
   /* search394_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1057, 3, 0 },
      -1,
   } },

   /* replace394_0 -> 0 in the cache */
   /* replace394_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bcsel', ('ige', 'a', 'b'), 'b', 'a') => ('imin', 'a', 'b') */
   /* search395_0_0 -> 0 in the cache */
   /* search395_0_1 -> 3 in the cache */
   /* search395_0 -> 1051 in the cache */
   /* search395_1 -> 3 in the cache */
   /* search395_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1051, 3, 0 },
      -1,
   } },

   /* replace395_0 -> 0 in the cache */
   /* replace395_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bcsel', ('ige', 'b', 'a'), 'b', 'a') => ('imax', 'a', 'b') */
   /* search396_0_0 -> 1104 in the cache */
   /* search396_0_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1104, 1101 },
      -1,
   } },
   /* search396_1 -> 1104 in the cache */
   /* search396_2 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1293, 1104, 1101 },
      -1,
   } },

   /* replace396_0 -> 1101 in the cache */
   /* replace396_1 -> 1104 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 1101, 1104 },
      -1,
   } },

   /* ('bcsel', ('i2b', 'a'), 'b', 'c') => ('bcsel', ('ine', 'a', 0), 'b', 'c') */
   /* search397_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search397_1 -> 129 in the cache */
   /* search397_2 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1296, 129, 131 },
      -1,
   } },

   /* replace397_0_0 -> 32 in the cache */
   /* replace397_0_1 -> 61 in the cache */
   /* replace397_0 -> 1220 in the cache */
   /* replace397_1 -> 129 in the cache */
   /* replace397_2 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1220, 129, 131 },
      -1,
   } },

   /* ('bcsel', ('inot', 'a'), 'b', 'c') => ('bcsel', 'a', 'c', 'b') */
   /* search398_0_0 -> 753 in the cache */
   /* search398_0 -> 1118 in the cache */
   /* search398_1 -> 129 in the cache */
   /* search398_2 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1118, 129, 131 },
      -1,
   } },

   /* replace398_0 -> 753 in the cache */
   /* replace398_1 -> 131 in the cache */
   /* replace398_2 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 131, 129 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel', 'a', 'b', 'c'), 'd') => ('bcsel', 'a', 'b', 'd') */
   /* search399_0 -> 753 in the cache */
   /* search399_1_0 -> 753 in the cache */
   /* search399_1_1 -> 152 in the cache */
   /* search399_1_2 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 152, 154 },
      -1,
   } },
   /* search399_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1301, 155 },
      -1,
   } },

   /* replace399_0 -> 753 in the cache */
   /* replace399_1 -> 152 in the cache */
   /* replace399_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 152, 155 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', ('bcsel', 'a', 'c', 'd')) => ('bcsel', 'a', 'b', 'd') */
   /* search400_0 -> 753 in the cache */
   /* search400_1 -> 152 in the cache */
   /* search400_2_0 -> 753 in the cache */
   /* search400_2_1 -> 154 in the cache */
   /* search400_2_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 152, 1304 },
      -1,
   } },

   /* replace400_0 -> 753 in the cache */
   /* replace400_1 -> 152 in the cache */
   /* replace400_2 -> 155 in the cache */
   /* replace400 -> 1303 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search401_0 -> 753 in the cache */
   /* search401_1_0 -> 1121 in the cache */
   /* search401_1_1 -> 746 in the cache */
   /* search401_1_2 -> 755 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1121, 746, 755 },
      -1,
   } },
   /* search401_2_0 -> 1121 in the cache */
   /* search401_2_1 -> 746 in the cache */
   /* search401_2_2 -> 757 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1121, 746, 757 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1306, 1307 },
      -1,
   } },

   /* replace401_0 -> 1121 in the cache */
   /* replace401_1 -> 746 in the cache */
   /* replace401_2_0 -> 753 in the cache */
   /* replace401_2_1 -> 755 in the cache */
   /* replace401_2_2 -> 757 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 755, 757 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1121, 746, 1309 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search402_0 -> 753 in the cache */
   /* search402_1_0 -> 1121 in the cache */
   /* search402_1_1 -> 746 in the cache */
   /* search402_1_2 -> 755 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1121, 746, 755 },
      0,
   } },
   /* search402_2_0 -> 1121 in the cache */
   /* search402_2_1 -> 746 in the cache */
   /* search402_2_2 -> 757 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1121, 746, 757 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1311, 1312 },
      -1,
   } },

   /* replace402_0 -> 1121 in the cache */
   /* replace402_1 -> 746 in the cache */
   /* replace402_2_0 -> 753 in the cache */
   /* replace402_2_1 -> 755 in the cache */
   /* replace402_2_2 -> 757 in the cache */
   /* replace402_2 -> 1309 in the cache */
   /* replace402 -> 1310 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search403_0 -> 753 in the cache */
   /* search403_1_0 -> 1121 in the cache */
   /* search403_1_1 -> 154 in the cache */
   /* search403_1_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1121, 154, 155 },
      -1,
   } },
   /* search403_2_0 -> 1121 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search403_2_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1121, 1315, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1314, 1316 },
      -1,
   } },

   /* replace403_0 -> 1121 in the cache */
   /* replace403_1_0 -> 753 in the cache */
   /* replace403_1_1 -> 154 in the cache */
   /* replace403_1_2 -> 1315 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 154, 1315 },
      -1,
   } },
   /* replace403_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1121, 1318, 155 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search404_0 -> 753 in the cache */
   /* search404_1_0 -> 1121 in the cache */
   /* search404_1_1 -> 154 in the cache */
   /* search404_1_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1121, 154, 155 },
      0,
   } },
   /* search404_2_0 -> 1121 in the cache */
   /* search404_2_1 -> 1315 in the cache */
   /* search404_2_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1121, 1315, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1320, 1321 },
      -1,
   } },

   /* replace404_0 -> 1121 in the cache */
   /* replace404_1_0 -> 753 in the cache */
   /* replace404_1_1 -> 154 in the cache */
   /* replace404_1_2 -> 1315 in the cache */
   /* replace404_1 -> 1318 in the cache */
   /* replace404_2 -> 155 in the cache */
   /* replace404 -> 1319 in the cache */

   /* ('bcsel', 'a', True, 'b') => ('ior', 'a', 'b') */
   /* search405_0 -> 753 in the cache */
   /* search405_1 -> 1224 in the cache */
   /* search405_2 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1224, 1121 },
      -1,
   } },

   /* replace405_0 -> 753 in the cache */
   /* replace405_1 -> 1121 in the cache */
   /* replace405 -> 1125 in the cache */

   /* ('bcsel', 'a', 'a', 'b') => ('ior', 'a', 'b') */
   /* search406_0 -> 753 in the cache */
   /* search406_1 -> 753 in the cache */
   /* search406_2 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 753, 1121 },
      -1,
   } },

   /* replace406_0 -> 753 in the cache */
   /* replace406_1 -> 1121 in the cache */
   /* replace406 -> 1125 in the cache */

   /* ('bcsel', 'a', 'b', False) => ('iand', 'a', 'b') */
   /* search407_0 -> 753 in the cache */
   /* search407_1 -> 1121 in the cache */
   /* search407_2 -> 1070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1121, 1070 },
      -1,
   } },

   /* replace407_0 -> 753 in the cache */
   /* replace407_1 -> 1121 in the cache */
   /* replace407 -> 1133 in the cache */

   /* ('bcsel', 'a', 'b', 'a') => ('iand', 'a', 'b') */
   /* search408_0 -> 753 in the cache */
   /* search408_1 -> 1121 in the cache */
   /* search408_2 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1121, 753 },
      -1,
   } },

   /* replace408_0 -> 753 in the cache */
   /* replace408_1 -> 1121 in the cache */
   /* replace408 -> 1133 in the cache */

   /* ('~fmin', 'a', 'a') => a */
   /* search409_0 -> 32 in the cache */
   /* search409_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace409 -> 32 in the cache */

   /* ('~fmax', 'a', 'a') => a */
   /* search410_0 -> 32 in the cache */
   /* search410_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace410 -> 32 in the cache */

   /* ('imin', 'a', 'a') => a */
   /* search411_0 -> 32 in the cache */
   /* search411_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace411 -> 32 in the cache */

   /* ('imax', 'a', 'a') => a */
   /* search412_0 -> 32 in the cache */
   /* search412_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace412 -> 32 in the cache */

   /* ('umin', 'a', 'a') => a */
   /* search413_0 -> 32 in the cache */
   /* search413_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace413 -> 32 in the cache */

   /* ('umin', 'a', 0) => 0 */
   /* search414_0 -> 32 in the cache */
   /* search414_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace414 -> 61 in the cache */

   /* ('umin', 'a', -1) => a */
   /* search415_0 -> 32 in the cache */
   /* search415_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace415 -> 32 in the cache */

   /* ('umax', 'a', 'a') => a */
   /* search416_0 -> 32 in the cache */
   /* search416_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace416 -> 32 in the cache */

   /* ('umax', 'a', 0) => a */
   /* search417_0 -> 32 in the cache */
   /* search417_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace417 -> 32 in the cache */

   /* ('umax', 'a', -1) => -1 */
   /* search418_0 -> 32 in the cache */
   /* search418_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace418 -> 63 in the cache */

   /* ('fmax', ('fmax', 'a', 'b'), 'b') => ('fmax', 'a', 'b') */
   /* search419_0_0 -> 0 in the cache */
   /* search419_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search419_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1337, 3 },
      -1,
   } },

   /* replace419_0 -> 0 in the cache */
   /* replace419_1 -> 3 in the cache */
   /* replace419 -> 1270 in the cache */

   /* ('umax', ('umax', 'a', 'b'), 'b') => ('umax', 'a', 'b') */
   /* search420_0_0 -> 0 in the cache */
   /* search420_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search420_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 2,
      { 1339, 3 },
      -1,
   } },

   /* replace420_0 -> 0 in the cache */
   /* replace420_1 -> 3 in the cache */
   /* replace420 -> 1280 in the cache */

   /* ('imax', ('imax', 'a', 'b'), 'b') => ('imax', 'a', 'b') */
   /* search421_0_0 -> 0 in the cache */
   /* search421_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search421_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 1341, 3 },
      -1,
   } },

   /* replace421_0 -> 0 in the cache */
   /* replace421_1 -> 3 in the cache */
   /* replace421 -> 1290 in the cache */

   /* ('fmin', ('fmin', 'a', 'b'), 'b') => ('fmin', 'a', 'b') */
   /* search422_0_0 -> 0 in the cache */
   /* search422_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search422_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1343, 3 },
      -1,
   } },

   /* replace422_0 -> 0 in the cache */
   /* replace422_1 -> 3 in the cache */
   /* replace422 -> 1272 in the cache */

   /* ('umin', ('umin', 'a', 'b'), 'b') => ('umin', 'a', 'b') */
   /* search423_0_0 -> 0 in the cache */
   /* search423_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search423_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1345, 3 },
      -1,
   } },

   /* replace423_0 -> 0 in the cache */
   /* replace423_1 -> 3 in the cache */
   /* replace423 -> 1282 in the cache */

   /* ('imin', ('imin', 'a', 'b'), 'b') => ('imin', 'a', 'b') */
   /* search424_0_0 -> 0 in the cache */
   /* search424_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search424_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1347, 3 },
      -1,
   } },

   /* replace424_0 -> 0 in the cache */
   /* replace424_1 -> 3 in the cache */
   /* replace424 -> 1292 in the cache */

   /* ('fmax', ('fmax', ('fmax', 'a', 'b'), 'c'), 'a') => ('fmax', ('fmax', 'a', 'b'), 'c') */
   /* search425_0_0_0 -> 128 in the cache */
   /* search425_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      2, 1,
      { 128, 129 },
      -1,
   } },
   /* search425_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 2,
      { 1349, 131 },
      -1,
   } },
   /* search425_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 1350, 128 },
      -1,
   } },

   /* replace425_0_0 -> 128 in the cache */
   /* replace425_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* replace425_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1352, 131 },
      -1,
   } },

   /* ('umax', ('umax', ('umax', 'a', 'b'), 'c'), 'a') => ('umax', ('umax', 'a', 'b'), 'c') */
   /* search426_0_0_0 -> 128 in the cache */
   /* search426_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      2, 1,
      { 128, 129 },
      -1,
   } },
   /* search426_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      1, 2,
      { 1354, 131 },
      -1,
   } },
   /* search426_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 3,
      { 1355, 128 },
      -1,
   } },

   /* replace426_0_0 -> 128 in the cache */
   /* replace426_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* replace426_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 2,
      { 1357, 131 },
      -1,
   } },

   /* ('imax', ('imax', ('imax', 'a', 'b'), 'c'), 'a') => ('imax', ('imax', 'a', 'b'), 'c') */
   /* search427_0_0_0 -> 128 in the cache */
   /* search427_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      2, 1,
      { 128, 129 },
      -1,
   } },
   /* search427_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      1, 2,
      { 1359, 131 },
      -1,
   } },
   /* search427_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 3,
      { 1360, 128 },
      -1,
   } },

   /* replace427_0_0 -> 128 in the cache */
   /* replace427_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* replace427_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 1362, 131 },
      -1,
   } },

   /* ('fmin', ('fmin', ('fmin', 'a', 'b'), 'c'), 'a') => ('fmin', ('fmin', 'a', 'b'), 'c') */
   /* search428_0_0_0 -> 128 in the cache */
   /* search428_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      2, 1,
      { 128, 129 },
      -1,
   } },
   /* search428_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 2,
      { 1364, 131 },
      -1,
   } },
   /* search428_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 1365, 128 },
      -1,
   } },

   /* replace428_0_0 -> 128 in the cache */
   /* replace428_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* replace428_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1367, 131 },
      -1,
   } },

   /* ('umin', ('umin', ('umin', 'a', 'b'), 'c'), 'a') => ('umin', ('umin', 'a', 'b'), 'c') */
   /* search429_0_0_0 -> 128 in the cache */
   /* search429_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      2, 1,
      { 128, 129 },
      -1,
   } },
   /* search429_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      1, 2,
      { 1369, 131 },
      -1,
   } },
   /* search429_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 3,
      { 1370, 128 },
      -1,
   } },

   /* replace429_0_0 -> 128 in the cache */
   /* replace429_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* replace429_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1372, 131 },
      -1,
   } },

   /* ('imin', ('imin', ('imin', 'a', 'b'), 'c'), 'a') => ('imin', ('imin', 'a', 'b'), 'c') */
   /* search430_0_0_0 -> 128 in the cache */
   /* search430_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      2, 1,
      { 128, 129 },
      -1,
   } },
   /* search430_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      1, 2,
      { 1374, 131 },
      -1,
   } },
   /* search430_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 3,
      { 1375, 128 },
      -1,
   } },

   /* replace430_0_0 -> 128 in the cache */
   /* replace430_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 128, 129 },
      -1,
   } },
   /* replace430_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1377, 131 },
      -1,
   } },

   /* ('ieq', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ieq', 'a', 'b') */
   /* search431_0_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 753 },
      -1,
   } },
   /* search431_1_0 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 1121 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1379, 1380 },
      -1,
   } },

   /* replace431_0 -> 753 in the cache */
   /* replace431_1 -> 1121 in the cache */
   /* replace431 -> 1149 in the cache */

   /* ('ine', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ine', 'a', 'b') */
   /* search432_0_0 -> 753 in the cache */
   /* search432_0 -> 1379 in the cache */
   /* search432_1_0 -> 1121 in the cache */
   /* search432_1 -> 1380 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1379, 1380 },
      -1,
   } },

   /* replace432_0 -> 753 in the cache */
   /* replace432_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 753, 1121 },
      -1,
   } },

   /* ('ieq', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ieq', 'a', 'b') */
   /* search433_0_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 753 },
      -1,
   } },
   /* search433_1_0 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1121 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1384, 1385 },
      -1,
   } },

   /* replace433_0 -> 753 in the cache */
   /* replace433_1 -> 1121 in the cache */
   /* replace433 -> 1149 in the cache */

   /* ('ine', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ine', 'a', 'b') */
   /* search434_0_0 -> 753 in the cache */
   /* search434_0 -> 1384 in the cache */
   /* search434_1_0 -> 1121 in the cache */
   /* search434_1 -> 1385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1384, 1385 },
      -1,
   } },

   /* replace434_0 -> 753 in the cache */
   /* replace434_1 -> 1121 in the cache */
   /* replace434 -> 1383 in the cache */

   /* ('ieq', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ieq', 'a', 'b') */
   /* search435_0_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 753 },
      -1,
   } },
   /* search435_1_0 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1121 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1388, 1389 },
      -1,
   } },

   /* replace435_0 -> 753 in the cache */
   /* replace435_1 -> 1121 in the cache */
   /* replace435 -> 1149 in the cache */

   /* ('ine', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ine', 'a', 'b') */
   /* search436_0_0 -> 753 in the cache */
   /* search436_0 -> 1388 in the cache */
   /* search436_1_0 -> 1121 in the cache */
   /* search436_1 -> 1389 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1388, 1389 },
      -1,
   } },

   /* replace436_0 -> 753 in the cache */
   /* replace436_1 -> 1121 in the cache */
   /* replace436 -> 1383 in the cache */

   /* ('ieq', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ieq', 'a', 'b') */
   /* search437_0_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 753 },
      -1,
   } },
   /* search437_1_0 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1121 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1392, 1393 },
      -1,
   } },

   /* replace437_0 -> 753 in the cache */
   /* replace437_1 -> 1121 in the cache */
   /* replace437 -> 1149 in the cache */

   /* ('ine', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ine', 'a', 'b') */
   /* search438_0_0 -> 753 in the cache */
   /* search438_0 -> 1392 in the cache */
   /* search438_1_0 -> 1121 in the cache */
   /* search438_1 -> 1393 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1392, 1393 },
      -1,
   } },

   /* replace438_0 -> 753 in the cache */
   /* replace438_1 -> 1121 in the cache */
   /* replace438 -> 1383 in the cache */

   /* ('feq', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ieq', 'a', 'b') */
   /* search439_0_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 753 },
      -1,
   } },
   /* search439_1_0 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 1121 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1396, 1397 },
      -1,
   } },

   /* replace439_0 -> 753 in the cache */
   /* replace439_1 -> 1121 in the cache */
   /* replace439 -> 1149 in the cache */

   /* ('fneu', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ine', 'a', 'b') */
   /* search440_0_0 -> 753 in the cache */
   /* search440_0 -> 1396 in the cache */
   /* search440_1_0 -> 1121 in the cache */
   /* search440_1 -> 1397 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1396, 1397 },
      -1,
   } },

   /* replace440_0 -> 753 in the cache */
   /* replace440_1 -> 1121 in the cache */
   /* replace440 -> 1383 in the cache */

   /* ('feq', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ieq', 'a', 'b') */
   /* search441_0_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 753 },
      -1,
   } },
   /* search441_1_0 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 1121 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1400, 1401 },
      -1,
   } },

   /* replace441_0 -> 753 in the cache */
   /* replace441_1 -> 1121 in the cache */
   /* replace441 -> 1149 in the cache */

   /* ('fneu', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ine', 'a', 'b') */
   /* search442_0_0 -> 753 in the cache */
   /* search442_0 -> 1400 in the cache */
   /* search442_1_0 -> 1121 in the cache */
   /* search442_1 -> 1401 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1400, 1401 },
      -1,
   } },

   /* replace442_0 -> 753 in the cache */
   /* replace442_1 -> 1121 in the cache */
   /* replace442 -> 1383 in the cache */

   /* ('feq', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ieq', 'a', 'b') */
   /* search443_0_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 753 },
      -1,
   } },
   /* search443_1_0 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 1121 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1404, 1405 },
      -1,
   } },

   /* replace443_0 -> 753 in the cache */
   /* replace443_1 -> 1121 in the cache */
   /* replace443 -> 1149 in the cache */

   /* ('fneu', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ine', 'a', 'b') */
   /* search444_0_0 -> 753 in the cache */
   /* search444_0 -> 1404 in the cache */
   /* search444_1_0 -> 1121 in the cache */
   /* search444_1 -> 1405 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1404, 1405 },
      -1,
   } },

   /* replace444_0 -> 753 in the cache */
   /* replace444_1 -> 1121 in the cache */
   /* replace444 -> 1383 in the cache */

   /* ('iand@8', 'a', ('inot', ('ishr', 'a', 7))) => ('imax', 'a', 0) */
   /* search445_0 -> 6 in the cache */
   /* search445_1_0_0 -> 6 in the cache */
   /* search445_1_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 6, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1408 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6, 1409 },
      -1,
   } },

   /* replace445_0 -> 6 in the cache */
   /* replace445_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 6, 828 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@8', 128), 0) => ('ige', 'a', 0) */
   /* search446_0_0 -> 6 in the cache */
   /* search446_0_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 6, 7 },
      -1,
   } },
   /* search446_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1412, 828 },
      -1,
   } },

   /* replace446_0 -> 6 in the cache */
   /* replace446_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 828 },
      -1,
   } },

   /* ('ine', ('iand', 'a@8', 128), 128) => ('ige', 'a', 0) */
   /* search447_0_0 -> 6 in the cache */
   /* search447_0_1 -> 7 in the cache */
   /* search447_0 -> 1412 in the cache */
   /* search447_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1412, 7 },
      -1,
   } },

   /* replace447_0 -> 6 in the cache */
   /* replace447_1 -> 828 in the cache */
   /* replace447 -> 1414 in the cache */

   /* ('ine', ('iand', 'a@8', 128), 0) => ('ilt', 'a', 0) */
   /* search448_0_0 -> 6 in the cache */
   /* search448_0_1 -> 7 in the cache */
   /* search448_0 -> 1412 in the cache */
   /* search448_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1412, 828 },
      -1,
   } },

   /* replace448_0 -> 6 in the cache */
   /* replace448_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 828 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@8', 128), 128) => ('ilt', 'a', 0) */
   /* search449_0_0 -> 6 in the cache */
   /* search449_0_1 -> 7 in the cache */
   /* search449_0 -> 1412 in the cache */
   /* search449_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1412, 7 },
      -1,
   } },

   /* replace449_0 -> 6 in the cache */
   /* replace449_1 -> 828 in the cache */
   /* replace449 -> 1417 in the cache */

   /* ('ine', ('ushr', 'a@8', 7), 0) => ('ilt', 'a', 0) */
   /* search450_0_0 -> 6 in the cache */
   /* search450_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 9 },
      -1,
   } },
   /* search450_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1419, 828 },
      -1,
   } },

   /* replace450_0 -> 6 in the cache */
   /* replace450_1 -> 828 in the cache */
   /* replace450 -> 1417 in the cache */

   /* ('ieq', ('ushr', 'a@8', 7), 0) => ('ige', 'a', 0) */
   /* search451_0_0 -> 6 in the cache */
   /* search451_0_1 -> 9 in the cache */
   /* search451_0 -> 1419 in the cache */
   /* search451_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1419, 828 },
      -1,
   } },

   /* replace451_0 -> 6 in the cache */
   /* replace451_1 -> 828 in the cache */
   /* replace451 -> 1414 in the cache */

   /* ('ieq', ('ushr', 'a@8', 7), 1) => ('ilt', 'a', 0) */
   /* search452_0_0 -> 6 in the cache */
   /* search452_0_1 -> 9 in the cache */
   /* search452_0 -> 1419 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1419, 1422 },
      -1,
   } },

   /* replace452_0 -> 6 in the cache */
   /* replace452_1 -> 828 in the cache */
   /* replace452 -> 1417 in the cache */

   /* ('ine', ('ushr', 'a@8', 7), 1) => ('ige', 'a', 0) */
   /* search453_0_0 -> 6 in the cache */
   /* search453_0_1 -> 9 in the cache */
   /* search453_0 -> 1419 in the cache */
   /* search453_1 -> 1422 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1419, 1422 },
      -1,
   } },

   /* replace453_0 -> 6 in the cache */
   /* replace453_1 -> 828 in the cache */
   /* replace453 -> 1414 in the cache */

   /* ('ine', ('ishr', 'a@8', 7), 0) => ('ilt', 'a', 0) */
   /* search454_0_0 -> 6 in the cache */
   /* search454_0_1 -> 9 in the cache */
   /* search454_0 -> 1408 in the cache */
   /* search454_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1408, 828 },
      -1,
   } },

   /* replace454_0 -> 6 in the cache */
   /* replace454_1 -> 828 in the cache */
   /* replace454 -> 1417 in the cache */

   /* ('ieq', ('ishr', 'a@8', 7), 0) => ('ige', 'a', 0) */
   /* search455_0_0 -> 6 in the cache */
   /* search455_0_1 -> 9 in the cache */
   /* search455_0 -> 1408 in the cache */
   /* search455_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1408, 828 },
      -1,
   } },

   /* replace455_0 -> 6 in the cache */
   /* replace455_1 -> 828 in the cache */
   /* replace455 -> 1414 in the cache */

   /* ('ieq', ('ishr', 'a@8', 7), -1) => ('ilt', 'a', 0) */
   /* search456_0_0 -> 6 in the cache */
   /* search456_0_1 -> 9 in the cache */
   /* search456_0 -> 1408 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1408, 1427 },
      -1,
   } },

   /* replace456_0 -> 6 in the cache */
   /* replace456_1 -> 828 in the cache */
   /* replace456 -> 1417 in the cache */

   /* ('ine', ('ishr', 'a@8', 7), -1) => ('ige', 'a', 0) */
   /* search457_0_0 -> 6 in the cache */
   /* search457_0_1 -> 9 in the cache */
   /* search457_0 -> 1408 in the cache */
   /* search457_1 -> 1427 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1408, 1427 },
      -1,
   } },

   /* replace457_0 -> 6 in the cache */
   /* replace457_1 -> 828 in the cache */
   /* replace457 -> 1414 in the cache */

   /* ('iand@16', 'a', ('inot', ('ishr', 'a', 15))) => ('imax', 'a', 0) */
   /* search458_0 -> 11 in the cache */
   /* search458_1_0_0 -> 11 in the cache */
   /* search458_1_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1430 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 1431 },
      -1,
   } },

   /* replace458_0 -> 11 in the cache */
   /* replace458_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 11, 849 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@16', 32768), 0) => ('ige', 'a', 0) */
   /* search459_0_0 -> 11 in the cache */
   /* search459_0_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 11, 12 },
      -1,
   } },
   /* search459_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1434, 849 },
      -1,
   } },

   /* replace459_0 -> 11 in the cache */
   /* replace459_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 849 },
      -1,
   } },

   /* ('ine', ('iand', 'a@16', 32768), 32768) => ('ige', 'a', 0) */
   /* search460_0_0 -> 11 in the cache */
   /* search460_0_1 -> 12 in the cache */
   /* search460_0 -> 1434 in the cache */
   /* search460_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1434, 12 },
      -1,
   } },

   /* replace460_0 -> 11 in the cache */
   /* replace460_1 -> 849 in the cache */
   /* replace460 -> 1436 in the cache */

   /* ('ine', ('iand', 'a@16', 32768), 0) => ('ilt', 'a', 0) */
   /* search461_0_0 -> 11 in the cache */
   /* search461_0_1 -> 12 in the cache */
   /* search461_0 -> 1434 in the cache */
   /* search461_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1434, 849 },
      -1,
   } },

   /* replace461_0 -> 11 in the cache */
   /* replace461_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 849 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@16', 32768), 32768) => ('ilt', 'a', 0) */
   /* search462_0_0 -> 11 in the cache */
   /* search462_0_1 -> 12 in the cache */
   /* search462_0 -> 1434 in the cache */
   /* search462_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1434, 12 },
      -1,
   } },

   /* replace462_0 -> 11 in the cache */
   /* replace462_1 -> 849 in the cache */
   /* replace462 -> 1439 in the cache */

   /* ('ine', ('ushr', 'a@16', 15), 0) => ('ilt', 'a', 0) */
   /* search463_0_0 -> 11 in the cache */
   /* search463_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 14 },
      -1,
   } },
   /* search463_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1441, 849 },
      -1,
   } },

   /* replace463_0 -> 11 in the cache */
   /* replace463_1 -> 849 in the cache */
   /* replace463 -> 1439 in the cache */

   /* ('ieq', ('ushr', 'a@16', 15), 0) => ('ige', 'a', 0) */
   /* search464_0_0 -> 11 in the cache */
   /* search464_0_1 -> 14 in the cache */
   /* search464_0 -> 1441 in the cache */
   /* search464_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1441, 849 },
      -1,
   } },

   /* replace464_0 -> 11 in the cache */
   /* replace464_1 -> 849 in the cache */
   /* replace464 -> 1436 in the cache */

   /* ('ieq', ('ushr', 'a@16', 15), 1) => ('ilt', 'a', 0) */
   /* search465_0_0 -> 11 in the cache */
   /* search465_0_1 -> 14 in the cache */
   /* search465_0 -> 1441 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1441, 1444 },
      -1,
   } },

   /* replace465_0 -> 11 in the cache */
   /* replace465_1 -> 849 in the cache */
   /* replace465 -> 1439 in the cache */

   /* ('ine', ('ushr', 'a@16', 15), 1) => ('ige', 'a', 0) */
   /* search466_0_0 -> 11 in the cache */
   /* search466_0_1 -> 14 in the cache */
   /* search466_0 -> 1441 in the cache */
   /* search466_1 -> 1444 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1441, 1444 },
      -1,
   } },

   /* replace466_0 -> 11 in the cache */
   /* replace466_1 -> 849 in the cache */
   /* replace466 -> 1436 in the cache */

   /* ('ine', ('ishr', 'a@16', 15), 0) => ('ilt', 'a', 0) */
   /* search467_0_0 -> 11 in the cache */
   /* search467_0_1 -> 14 in the cache */
   /* search467_0 -> 1430 in the cache */
   /* search467_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1430, 849 },
      -1,
   } },

   /* replace467_0 -> 11 in the cache */
   /* replace467_1 -> 849 in the cache */
   /* replace467 -> 1439 in the cache */

   /* ('ieq', ('ishr', 'a@16', 15), 0) => ('ige', 'a', 0) */
   /* search468_0_0 -> 11 in the cache */
   /* search468_0_1 -> 14 in the cache */
   /* search468_0 -> 1430 in the cache */
   /* search468_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1430, 849 },
      -1,
   } },

   /* replace468_0 -> 11 in the cache */
   /* replace468_1 -> 849 in the cache */
   /* replace468 -> 1436 in the cache */

   /* ('ieq', ('ishr', 'a@16', 15), -1) => ('ilt', 'a', 0) */
   /* search469_0_0 -> 11 in the cache */
   /* search469_0_1 -> 14 in the cache */
   /* search469_0 -> 1430 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1430, 1449 },
      -1,
   } },

   /* replace469_0 -> 11 in the cache */
   /* replace469_1 -> 849 in the cache */
   /* replace469 -> 1439 in the cache */

   /* ('ine', ('ishr', 'a@16', 15), -1) => ('ige', 'a', 0) */
   /* search470_0_0 -> 11 in the cache */
   /* search470_0_1 -> 14 in the cache */
   /* search470_0 -> 1430 in the cache */
   /* search470_1 -> 1449 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1430, 1449 },
      -1,
   } },

   /* replace470_0 -> 11 in the cache */
   /* replace470_1 -> 849 in the cache */
   /* replace470 -> 1436 in the cache */

   /* ('iand@32', 'a', ('inot', ('ishr', 'a', 31))) => ('imax', 'a', 0) */
   /* search471_0 -> 16 in the cache */
   /* search471_1_0_0 -> 16 in the cache */
   /* search471_1_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1452 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 1453 },
      -1,
   } },

   /* replace471_0 -> 16 in the cache */
   /* replace471_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 16, 124 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@32', 2147483648), 0) => ('ige', 'a', 0) */
   /* search472_0_0 -> 16 in the cache */
   /* search472_0_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 17 },
      -1,
   } },
   /* search472_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1456, 124 },
      -1,
   } },

   /* replace472_0 -> 16 in the cache */
   /* replace472_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 124 },
      -1,
   } },

   /* ('ine', ('iand', 'a@32', 2147483648), 2147483648) => ('ige', 'a', 0) */
   /* search473_0_0 -> 16 in the cache */
   /* search473_0_1 -> 17 in the cache */
   /* search473_0 -> 1456 in the cache */
   /* search473_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1456, 17 },
      -1,
   } },

   /* replace473_0 -> 16 in the cache */
   /* replace473_1 -> 124 in the cache */
   /* replace473 -> 1458 in the cache */

   /* ('ine', ('iand', 'a@32', 2147483648), 0) => ('ilt', 'a', 0) */
   /* search474_0_0 -> 16 in the cache */
   /* search474_0_1 -> 17 in the cache */
   /* search474_0 -> 1456 in the cache */
   /* search474_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1456, 124 },
      -1,
   } },

   /* replace474_0 -> 16 in the cache */
   /* replace474_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 124 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@32', 2147483648), 2147483648) => ('ilt', 'a', 0) */
   /* search475_0_0 -> 16 in the cache */
   /* search475_0_1 -> 17 in the cache */
   /* search475_0 -> 1456 in the cache */
   /* search475_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1456, 17 },
      -1,
   } },

   /* replace475_0 -> 16 in the cache */
   /* replace475_1 -> 124 in the cache */
   /* replace475 -> 1461 in the cache */

   /* ('ine', ('ushr', 'a@32', 31), 0) => ('ilt', 'a', 0) */
   /* search476_0_0 -> 16 in the cache */
   /* search476_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 19 },
      -1,
   } },
   /* search476_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1463, 124 },
      -1,
   } },

   /* replace476_0 -> 16 in the cache */
   /* replace476_1 -> 124 in the cache */
   /* replace476 -> 1461 in the cache */

   /* ('ieq', ('ushr', 'a@32', 31), 0) => ('ige', 'a', 0) */
   /* search477_0_0 -> 16 in the cache */
   /* search477_0_1 -> 19 in the cache */
   /* search477_0 -> 1463 in the cache */
   /* search477_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1463, 124 },
      -1,
   } },

   /* replace477_0 -> 16 in the cache */
   /* replace477_1 -> 124 in the cache */
   /* replace477 -> 1458 in the cache */

   /* ('ieq', ('ushr', 'a@32', 31), 1) => ('ilt', 'a', 0) */
   /* search478_0_0 -> 16 in the cache */
   /* search478_0_1 -> 19 in the cache */
   /* search478_0 -> 1463 in the cache */
   /* search478_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1463, 398 },
      -1,
   } },

   /* replace478_0 -> 16 in the cache */
   /* replace478_1 -> 124 in the cache */
   /* replace478 -> 1461 in the cache */

   /* ('ine', ('ushr', 'a@32', 31), 1) => ('ige', 'a', 0) */
   /* search479_0_0 -> 16 in the cache */
   /* search479_0_1 -> 19 in the cache */
   /* search479_0 -> 1463 in the cache */
   /* search479_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1463, 398 },
      -1,
   } },

   /* replace479_0 -> 16 in the cache */
   /* replace479_1 -> 124 in the cache */
   /* replace479 -> 1458 in the cache */

   /* ('ine', ('ishr', 'a@32', 31), 0) => ('ilt', 'a', 0) */
   /* search480_0_0 -> 16 in the cache */
   /* search480_0_1 -> 19 in the cache */
   /* search480_0 -> 1452 in the cache */
   /* search480_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1452, 124 },
      -1,
   } },

   /* replace480_0 -> 16 in the cache */
   /* replace480_1 -> 124 in the cache */
   /* replace480 -> 1461 in the cache */

   /* ('ieq', ('ishr', 'a@32', 31), 0) => ('ige', 'a', 0) */
   /* search481_0_0 -> 16 in the cache */
   /* search481_0_1 -> 19 in the cache */
   /* search481_0 -> 1452 in the cache */
   /* search481_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1452, 124 },
      -1,
   } },

   /* replace481_0 -> 16 in the cache */
   /* replace481_1 -> 124 in the cache */
   /* replace481 -> 1458 in the cache */

   /* ('ieq', ('ishr', 'a@32', 31), -1) => ('ilt', 'a', 0) */
   /* search482_0_0 -> 16 in the cache */
   /* search482_0_1 -> 19 in the cache */
   /* search482_0 -> 1452 in the cache */
   /* search482_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1452, 126 },
      -1,
   } },

   /* replace482_0 -> 16 in the cache */
   /* replace482_1 -> 124 in the cache */
   /* replace482 -> 1461 in the cache */

   /* ('ine', ('ishr', 'a@32', 31), -1) => ('ige', 'a', 0) */
   /* search483_0_0 -> 16 in the cache */
   /* search483_0_1 -> 19 in the cache */
   /* search483_0 -> 1452 in the cache */
   /* search483_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1452, 126 },
      -1,
   } },

   /* replace483_0 -> 16 in the cache */
   /* replace483_1 -> 124 in the cache */
   /* replace483 -> 1458 in the cache */

   /* ('iand@64', 'a', ('inot', ('ishr', 'a', 63))) => ('imax', 'a', 0) */
   /* search484_0 -> 21 in the cache */
   /* search484_1_0_0 -> 21 in the cache */
   /* search484_1_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1472 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 1473 },
      -1,
   } },

   /* replace484_0 -> 21 in the cache */
   /* replace484_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 21, 890 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@64', 9223372036854775808), 0) => ('ige', 'a', 0) */
   /* search485_0_0 -> 21 in the cache */
   /* search485_0_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 21, 22 },
      -1,
   } },
   /* search485_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1476, 890 },
      -1,
   } },

   /* replace485_0 -> 21 in the cache */
   /* replace485_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 890 },
      -1,
   } },

   /* ('ine', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ige', 'a', 0) */
   /* search486_0_0 -> 21 in the cache */
   /* search486_0_1 -> 22 in the cache */
   /* search486_0 -> 1476 in the cache */
   /* search486_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1476, 22 },
      -1,
   } },

   /* replace486_0 -> 21 in the cache */
   /* replace486_1 -> 890 in the cache */
   /* replace486 -> 1478 in the cache */

   /* ('ine', ('iand', 'a@64', 9223372036854775808), 0) => ('ilt', 'a', 0) */
   /* search487_0_0 -> 21 in the cache */
   /* search487_0_1 -> 22 in the cache */
   /* search487_0 -> 1476 in the cache */
   /* search487_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1476, 890 },
      -1,
   } },

   /* replace487_0 -> 21 in the cache */
   /* replace487_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 890 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ilt', 'a', 0) */
   /* search488_0_0 -> 21 in the cache */
   /* search488_0_1 -> 22 in the cache */
   /* search488_0 -> 1476 in the cache */
   /* search488_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1476, 22 },
      -1,
   } },

   /* replace488_0 -> 21 in the cache */
   /* replace488_1 -> 890 in the cache */
   /* replace488 -> 1481 in the cache */

   /* ('ine', ('ushr', 'a@64', 63), 0) => ('ilt', 'a', 0) */
   /* search489_0_0 -> 21 in the cache */
   /* search489_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 24 },
      -1,
   } },
   /* search489_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1483, 890 },
      -1,
   } },

   /* replace489_0 -> 21 in the cache */
   /* replace489_1 -> 890 in the cache */
   /* replace489 -> 1481 in the cache */

   /* ('ieq', ('ushr', 'a@64', 63), 0) => ('ige', 'a', 0) */
   /* search490_0_0 -> 21 in the cache */
   /* search490_0_1 -> 24 in the cache */
   /* search490_0 -> 1483 in the cache */
   /* search490_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1483, 890 },
      -1,
   } },

   /* replace490_0 -> 21 in the cache */
   /* replace490_1 -> 890 in the cache */
   /* replace490 -> 1478 in the cache */

   /* ('ieq', ('ushr', 'a@64', 63), 1) => ('ilt', 'a', 0) */
   /* search491_0_0 -> 21 in the cache */
   /* search491_0_1 -> 24 in the cache */
   /* search491_0 -> 1483 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1483, 1486 },
      -1,
   } },

   /* replace491_0 -> 21 in the cache */
   /* replace491_1 -> 890 in the cache */
   /* replace491 -> 1481 in the cache */

   /* ('ine', ('ushr', 'a@64', 63), 1) => ('ige', 'a', 0) */
   /* search492_0_0 -> 21 in the cache */
   /* search492_0_1 -> 24 in the cache */
   /* search492_0 -> 1483 in the cache */
   /* search492_1 -> 1486 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1483, 1486 },
      -1,
   } },

   /* replace492_0 -> 21 in the cache */
   /* replace492_1 -> 890 in the cache */
   /* replace492 -> 1478 in the cache */

   /* ('ine', ('ishr', 'a@64', 63), 0) => ('ilt', 'a', 0) */
   /* search493_0_0 -> 21 in the cache */
   /* search493_0_1 -> 24 in the cache */
   /* search493_0 -> 1472 in the cache */
   /* search493_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1472, 890 },
      -1,
   } },

   /* replace493_0 -> 21 in the cache */
   /* replace493_1 -> 890 in the cache */
   /* replace493 -> 1481 in the cache */

   /* ('ieq', ('ishr', 'a@64', 63), 0) => ('ige', 'a', 0) */
   /* search494_0_0 -> 21 in the cache */
   /* search494_0_1 -> 24 in the cache */
   /* search494_0 -> 1472 in the cache */
   /* search494_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1472, 890 },
      -1,
   } },

   /* replace494_0 -> 21 in the cache */
   /* replace494_1 -> 890 in the cache */
   /* replace494 -> 1478 in the cache */

   /* ('ieq', ('ishr', 'a@64', 63), -1) => ('ilt', 'a', 0) */
   /* search495_0_0 -> 21 in the cache */
   /* search495_0_1 -> 24 in the cache */
   /* search495_0 -> 1472 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1472, 1491 },
      -1,
   } },

   /* replace495_0 -> 21 in the cache */
   /* replace495_1 -> 890 in the cache */
   /* replace495 -> 1481 in the cache */

   /* ('ine', ('ishr', 'a@64', 63), -1) => ('ige', 'a', 0) */
   /* search496_0_0 -> 21 in the cache */
   /* search496_0_1 -> 24 in the cache */
   /* search496_0 -> 1472 in the cache */
   /* search496_1 -> 1491 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1472, 1491 },
      -1,
   } },

   /* replace496_0 -> 21 in the cache */
   /* replace496_1 -> 890 in the cache */
   /* replace496 -> 1478 in the cache */

   /* ('fmin', 'a', ('fneg', 'a')) => ('fneg', ('fabs', 'a')) */
   /* search497_0 -> 32 in the cache */
   /* search497_1_0 -> 32 in the cache */
   /* search497_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 32, 98 },
      -1,
   } },

   /* replace497_0_0 -> 32 in the cache */
   /* replace497_0 -> 103 in the cache */
   /* replace497 -> 1243 in the cache */

   /* ('imin', 'a', ('ineg', 'a')) => ('ineg', ('iabs', 'a')) */
   /* search498_0 -> 32 in the cache */
   /* search498_1_0 -> 32 in the cache */
   /* search498_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 32, 100 },
      -1,
   } },

   /* replace498_0_0 -> 32 in the cache */
   /* replace498_0 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 106 },
      -1,
   } },

   /* ('fmin', 'a', ('fneg', ('fabs', 'a'))) => ('fneg', ('fabs', 'a')) */
   /* search499_0 -> 32 in the cache */
   /* search499_1_0_0 -> 32 in the cache */
   /* search499_1_0 -> 103 in the cache */
   /* search499_1 -> 1243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 32, 1243 },
      -1,
   } },

   /* replace499_0_0 -> 32 in the cache */
   /* replace499_0 -> 103 in the cache */
   /* replace499 -> 1243 in the cache */

   /* ('imin', 'a', ('ineg', ('iabs', 'a'))) => ('ineg', ('iabs', 'a')) */
   /* search500_0 -> 32 in the cache */
   /* search500_1_0_0 -> 32 in the cache */
   /* search500_1_0 -> 106 in the cache */
   /* search500_1 -> 1496 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 32, 1496 },
      -1,
   } },

   /* replace500_0_0 -> 32 in the cache */
   /* replace500_0 -> 106 in the cache */
   /* replace500 -> 1496 in the cache */

   /* ('~fmin', 'a', ('fabs', 'a')) => a */
   /* search501_0 -> 32 in the cache */
   /* search501_1_0 -> 32 in the cache */
   /* search501_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 32, 103 },
      -1,
   } },

   /* replace501 -> 32 in the cache */

   /* ('imin', 'a', ('iabs', 'a')) => a */
   /* search502_0 -> 32 in the cache */
   /* search502_1_0 -> 32 in the cache */
   /* search502_1 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 32, 106 },
      -1,
   } },

   /* replace502 -> 32 in the cache */

   /* ('~fmax', 'a', ('fneg', ('fabs', 'a'))) => a */
   /* search503_0 -> 32 in the cache */
   /* search503_1_0_0 -> 32 in the cache */
   /* search503_1_0 -> 103 in the cache */
   /* search503_1 -> 1243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 1243 },
      -1,
   } },

   /* replace503 -> 32 in the cache */

   /* ('imax', 'a', ('ineg', ('iabs', 'a'))) => a */
   /* search504_0 -> 32 in the cache */
   /* search504_1_0_0 -> 32 in the cache */
   /* search504_1_0 -> 106 in the cache */
   /* search504_1 -> 1496 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 32, 1496 },
      -1,
   } },

   /* replace504 -> 32 in the cache */

   /* ('fmax', 'a', ('fabs', 'a')) => ('fabs', 'a') */
   /* search505_0 -> 32 in the cache */
   /* search505_1_0 -> 32 in the cache */
   /* search505_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 103 },
      -1,
   } },

   /* replace505_0 -> 32 in the cache */
   /* replace505 -> 103 in the cache */

   /* ('imax', 'a', ('iabs', 'a')) => ('iabs', 'a') */
   /* search506_0 -> 32 in the cache */
   /* search506_1_0 -> 32 in the cache */
   /* search506_1 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 32, 106 },
      -1,
   } },

   /* replace506_0 -> 32 in the cache */
   /* replace506 -> 106 in the cache */

   /* ('fmax', 'a', ('fneg', 'a')) => ('fabs', 'a') */
   /* search507_0 -> 32 in the cache */
   /* search507_1_0 -> 32 in the cache */
   /* search507_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 98 },
      -1,
   } },

   /* replace507_0 -> 32 in the cache */
   /* replace507 -> 103 in the cache */

   /* ('imax', 'a', ('ineg', 'a')) => ('iabs', 'a') */
   /* search508_0 -> 32 in the cache */
   /* search508_1_0 -> 32 in the cache */
   /* search508_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 32, 100 },
      -1,
   } },

   /* replace508_0 -> 32 in the cache */
   /* replace508 -> 106 in the cache */

   /* ('~fmax', ('fabs', 'a'), 0.0) => ('fabs', 'a') */
   /* search509_0_0 -> 32 in the cache */
   /* search509_0 -> 103 in the cache */
   /* search509_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 103, 113 },
      -1,
   } },

   /* replace509_0 -> 32 in the cache */
   /* replace509 -> 103 in the cache */

   /* ('fmin', ('fmax', 'a', 0.0), 1.0) => ('fsat', 'a') */
   /* search510_0_0 -> 32 in the cache */
   /* search510_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 32, 113 },
      -1,
   } },
   /* search510_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1508, 243 },
      -1,
   } },

   /* replace510_0 -> 32 in the cache */
   /* replace510 -> 219 in the cache */

   /* ('~fmax', ('fmin', 'a', 1.0), 0.0) => ('fsat', 'a') */
   /* search511_0_0 -> 32 in the cache */
   /* search511_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 32, 243 },
      -1,
   } },
   /* search511_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1510, 113 },
      -1,
   } },

   /* replace511_0 -> 32 in the cache */
   /* replace511 -> 219 in the cache */

   /* ('~fmin', ('fmax', 'a', -1.0), 0.0) => ('fneg', ('fsat', ('fneg', 'a'))) */
   /* search512_0_0 -> 32 in the cache */
   /* search512_0_1 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 32, 249 },
      -1,
   } },
   /* search512_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1512, 113 },
      -1,
   } },

   /* replace512_0_0_0 -> 32 in the cache */
   /* replace512_0_0 -> 98 in the cache */
   /* replace512_0 -> 220 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 220 },
      -1,
   } },

   /* ('~fmax', ('fmin', 'a', 0.0), -1.0) => ('fneg', ('fsat', ('fneg', 'a'))) */
   /* search513_0_0 -> 32 in the cache */
   /* search513_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 32, 113 },
      -1,
   } },
   /* search513_1 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1515, 249 },
      -1,
   } },

   /* replace513_0_0_0 -> 32 in the cache */
   /* replace513_0_0 -> 98 in the cache */
   /* replace513_0 -> 220 in the cache */
   /* replace513 -> 1514 in the cache */

   /* ('fsat', ('fsign', 'a')) => ('b2f', ('!flt', 0.0, 'a')) */
   /* search514_0_0 -> 32 in the cache */
   /* search514_0 -> 252 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 252 },
      -1,
   } },

   /* replace514_0_0 -> 113 in the cache */
   /* replace514_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1518 },
      -1,
   } },

   /* ('fsat', ('b2f', 'a')) => ('b2f', 'a') */
   /* search515_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 1520 },
      -1,
   } },

   /* replace515_0 -> 32 in the cache */
   /* replace515 -> 1520 in the cache */

   /* ('fsat', 'a') => ('fmin', ('fmax', 'a', 0.0), 1.0) */
   /* search516_0 -> 32 in the cache */
   /* search516 -> 219 in the cache */

   /* replace516_0_0 -> 32 in the cache */
   /* replace516_0_1 -> 113 in the cache */
   /* replace516_0 -> 1508 in the cache */
   /* replace516_1 -> 243 in the cache */
   /* replace516 -> 1509 in the cache */

   /* ('fsat', ('fsat', 'a')) => ('fsat', 'a') */
   /* search517_0_0 -> 32 in the cache */
   /* search517_0 -> 219 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 219 },
      -1,
   } },

   /* replace517_0 -> 32 in the cache */
   /* replace517 -> 219 in the cache */

   /* ('fsat', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fsat', ('fadd', ('fneg', 'a'), ('fneg', 'b'))) */
   /* search518_0_0_0 -> 0 in the cache */
   /* search518_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1523 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1524 },
      -1,
   } },

   /* replace518_0_0_0 -> 0 in the cache */
   /* replace518_0_0 -> 214 in the cache */
   /* replace518_0_1_0 -> 3 in the cache */
   /* replace518_0_1 -> 1080 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 214, 1080 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1526 },
      -1,
   } },

   /* ('fsat', ('fneg(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fneg', 'a'), 'b')) */
   /* search519_0_0_0 -> 0 in the cache */
   /* search519_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1528 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1529 },
      -1,
   } },

   /* replace519_0_0_0 -> 0 in the cache */
   /* replace519_0_0 -> 214 in the cache */
   /* replace519_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 214, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1531 },
      -1,
   } },

   /* ('fsat', ('fneg(is_used_once)', ('fmulz(is_used_once)', 'a', 'b'))) => ('fsat', ('fmulz', ('fneg', 'a'), 'b')) */
   /* search520_0_0_0 -> 16 in the cache */
   /* search520_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1533 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1534 },
      -1,
   } },

   /* replace520_0_0_0 -> 16 in the cache */
   /* replace520_0_0 -> 282 in the cache */
   /* replace520_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 282, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1536 },
      -1,
   } },

   /* ('fsat', ('fabs(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fabs', 'a'), ('fabs', 'b'))) */
   /* search521_0_0_0 -> 0 in the cache */
   /* search521_0_0_1 -> 3 in the cache */
   /* search521_0_0 -> 1528 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 1528 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1538 },
      -1,
   } },

   /* replace521_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace521_0_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1540, 1541 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1542 },
      -1,
   } },

   /* ('fmin', ('fmax', ('fmin', ('fmax', 'a', 'b'), 'c'), 'b'), 'c') => ('fmin', ('fmax', 'a', 'b'), 'c') */
   /* search522_0_0_0_0 -> 128 in the cache */
   /* search522_0_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      3, 1,
      { 128, 129 },
      -1,
   } },
   /* search522_0_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      2, 2,
      { 1544, 131 },
      -1,
   } },
   /* search522_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 3,
      { 1545, 129 },
      -1,
   } },
   /* search522_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 4,
      { 1546, 131 },
      -1,
   } },

   /* replace522_0_0 -> 128 in the cache */
   /* replace522_0_1 -> 129 in the cache */
   /* replace522_0 -> 1352 in the cache */
   /* replace522_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1352, 131 },
      -1,
   } },

   /* ('imin', ('imax', ('imin', ('imax', 'a', 'b'), 'c'), 'b'), 'c') => ('imin', ('imax', 'a', 'b'), 'c') */
   /* search523_0_0_0_0 -> 128 in the cache */
   /* search523_0_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      3, 1,
      { 128, 129 },
      -1,
   } },
   /* search523_0_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      2, 2,
      { 1549, 131 },
      -1,
   } },
   /* search523_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      1, 3,
      { 1550, 129 },
      -1,
   } },
   /* search523_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 1551, 131 },
      -1,
   } },

   /* replace523_0_0 -> 128 in the cache */
   /* replace523_0_1 -> 129 in the cache */
   /* replace523_0 -> 1362 in the cache */
   /* replace523_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1362, 131 },
      -1,
   } },

   /* ('umin', ('umax', ('umin', ('umax', 'a', 'b'), 'c'), 'b'), 'c') => ('umin', ('umax', 'a', 'b'), 'c') */
   /* search524_0_0_0_0 -> 128 in the cache */
   /* search524_0_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      3, 1,
      { 128, 129 },
      -1,
   } },
   /* search524_0_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      2, 2,
      { 1554, 131 },
      -1,
   } },
   /* search524_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      1, 3,
      { 1555, 129 },
      -1,
   } },
   /* search524_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 4,
      { 1556, 131 },
      -1,
   } },

   /* replace524_0_0 -> 128 in the cache */
   /* replace524_0_1 -> 129 in the cache */
   /* replace524_0 -> 1357 in the cache */
   /* replace524_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1357, 131 },
      -1,
   } },

   /* ('fmax', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmax', 'a', 'b')) */
   /* search525_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      18,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1559, 1560 },
      -1,
   } },

   /* replace525_0_0 -> 0 in the cache */
   /* replace525_0_1 -> 3 in the cache */
   /* replace525_0 -> 1270 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1270 },
      -1,
   } },

   /* ('~fmin', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmin', 'a', 'b')) */
   /* search526_0_0 -> 0 in the cache */
   /* search526_0 -> 1559 in the cache */
   /* search526_1 -> 1560 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1559, 1560 },
      -1,
   } },

   /* replace526_0_0 -> 0 in the cache */
   /* replace526_0_1 -> 3 in the cache */
   /* replace526_0 -> 1272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1272 },
      -1,
   } },

   /* ('fmax', ('fneg', ('fmin', 'b', 'a')), 'b') => ('fmax', ('fabs', 'b'), ('fneg', 'a')) */
   /* search527_0_0_0 -> 1104 in the cache */
   /* search527_0_0_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 1104, 1101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1565 },
      -1,
   } },
   /* search527_1 -> 1104 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1566, 1104 },
      -1,
   } },

   /* replace527_0_0 -> 1104 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 1104 },
      -1,
   } },
   /* replace527_1_0 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1568, 1569 },
      -1,
   } },

   /* ('fmin', ('fneg', ('fmax', 'b', 'a')), 'b') => ('fmin', ('fneg', ('fabs', 'b')), ('fneg', 'a')) */
   /* search528_0_0_0 -> 1104 in the cache */
   /* search528_0_0_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 1104, 1101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1571 },
      -1,
   } },
   /* search528_1 -> 1104 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1572, 1104 },
      -1,
   } },

   /* replace528_0_0_0 -> 1104 in the cache */
   /* replace528_0_0 -> 1568 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1568 },
      -1,
   } },
   /* replace528_1_0 -> 1101 in the cache */
   /* replace528_1 -> 1569 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1574, 1569 },
      -1,
   } },

   /* ('fmax', ('fadd(is_used_once)', ('fneg', 'a(is_not_negative)'), '#b(is_zero_to_one)'), 0.0) => ('fsat', ('fadd', ('fneg', 'a'), 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1576 },
      -1,
   } },
   /* search529_0_1 -> 1560 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1577, 1560 },
      0,
   } },
   /* search529_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1578, 258 },
      -1,
   } },

   /* replace529_0_0_0 -> 0 in the cache */
   /* replace529_0_0 -> 214 in the cache */
   /* replace529_0_1 -> 3 in the cache */
   /* replace529_0 -> 279 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 279 },
      -1,
   } },

   /* ('extract_u8', ('imin', ('imax', 'a', 0), 255), 0) => ('imin', ('imax', 'a', 0), 255) */
   /* search530_0_0_0 -> 32 in the cache */
   /* search530_0_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 32, 61 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1581, 1582 },
      -1,
   } },
   /* search530_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 2,
      { 1583, 61 },
      -1,
   } },

   /* replace530_0_0 -> 32 in the cache */
   /* replace530_0_1 -> 61 in the cache */
   /* replace530_0 -> 1581 in the cache */
   /* replace530_1 -> 1582 in the cache */
   /* replace530 -> 1583 in the cache */

   /* ('ior', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('!fmax', 'b', 'c')) */
   /* search531_0_0 -> 128 in the cache */
   /* search531_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 128, 129 },
      0,
   } },
   /* search531_1_0 -> 128 in the cache */
   /* search531_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1585, 1586 },
      -1,
   } },

   /* replace531_0 -> 128 in the cache */
   /* replace531_1_0 -> 129 in the cache */
   /* replace531_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      true,
      false,
      nir_op_fmax,
      0, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 128, 1588 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c') */
   /* search532_0_0 -> 0 in the cache */
   /* search532_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 686 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search532_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1591, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1590, 1592 },
      -1,
   } },

   /* replace532_0_0 -> 0 in the cache */
   /* replace532_0_1 -> 1591 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 1591 },
      -1,
   } },
   /* replace532_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1594, 686 },
      -1,
   } },

   /* ('ior', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('!fmin', 'b', 'c')) */
   /* search533_0_0 -> 128 in the cache */
   /* search533_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 128, 129 },
      0,
   } },
   /* search533_1_0 -> 128 in the cache */
   /* search533_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1596, 1597 },
      -1,
   } },

   /* replace533_0 -> 128 in the cache */
   /* replace533_1_0 -> 129 in the cache */
   /* replace533_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      true,
      false,
      nir_op_fmin,
      0, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 128, 1599 },
      -1,
   } },

   /* ('ior', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c') */
   /* search534_0_0 -> 0 in the cache */
   /* search534_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 686 },
      0,
   } },
   /* search534_1_0 -> 1591 in the cache */
   /* search534_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1591, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1601, 1602 },
      -1,
   } },

   /* replace534_0_0 -> 0 in the cache */
   /* replace534_0_1 -> 1591 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 1591 },
      -1,
   } },
   /* replace534_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1604, 686 },
      -1,
   } },

   /* ('ior', ('flt', 'a', '#b'), ('flt', 'a', '#c')) => ('flt', 'a', ('!fmax', 'b', 'c')) */
   /* search535_0_0 -> 128 in the cache */
   /* search535_0_1 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 128, 285 },
      -1,
   } },
   /* search535_1_0 -> 128 in the cache */
   /* search535_1_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 128, 807 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1606, 1607 },
      -1,
   } },

   /* replace535_0 -> 128 in the cache */
   /* replace535_1_0 -> 129 in the cache */
   /* replace535_1_1 -> 131 in the cache */
   /* replace535_1 -> 1588 in the cache */
   /* replace535 -> 1589 in the cache */

   /* ('ior', ('flt', '#a', 'c'), ('flt', '#b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search536_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1609, 686 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search536_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1611, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1610, 1612 },
      -1,
   } },

   /* replace536_0_0 -> 0 in the cache */
   /* replace536_0_1 -> 1591 in the cache */
   /* replace536_0 -> 1594 in the cache */
   /* replace536_1 -> 686 in the cache */
   /* replace536 -> 1595 in the cache */

   /* ('ior', ('fge', 'a', '#b'), ('fge', 'a', '#c')) => ('fge', 'a', ('!fmin', 'b', 'c')) */
   /* search537_0_0 -> 128 in the cache */
   /* search537_0_1 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 128, 285 },
      -1,
   } },
   /* search537_1_0 -> 128 in the cache */
   /* search537_1_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 128, 807 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1614, 1615 },
      -1,
   } },

   /* replace537_0 -> 128 in the cache */
   /* replace537_1_0 -> 129 in the cache */
   /* replace537_1_1 -> 131 in the cache */
   /* replace537_1 -> 1599 in the cache */
   /* replace537 -> 1600 in the cache */

   /* ('ior', ('fge', '#a', 'c'), ('fge', '#b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c') */
   /* search538_0_0 -> 1609 in the cache */
   /* search538_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1609, 686 },
      -1,
   } },
   /* search538_1_0 -> 1611 in the cache */
   /* search538_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1611, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1617, 1618 },
      -1,
   } },

   /* replace538_0_0 -> 0 in the cache */
   /* replace538_0_1 -> 1591 in the cache */
   /* replace538_0 -> 1604 in the cache */
   /* replace538_1 -> 686 in the cache */
   /* replace538 -> 1605 in the cache */

   /* ('~iand', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('fmin', 'b', 'c')) */
   /* search539_0_0 -> 128 in the cache */
   /* search539_0_1 -> 129 in the cache */
   /* search539_0 -> 1585 in the cache */
   /* search539_1_0 -> 128 in the cache */
   /* search539_1_1 -> 131 in the cache */
   /* search539_1 -> 1586 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1585, 1586 },
      -1,
   } },

   /* replace539_0 -> 128 in the cache */
   /* replace539_1_0 -> 129 in the cache */
   /* replace539_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 128, 1621 },
      -1,
   } },

   /* ('~iand', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c') */
   /* search540_0_0 -> 0 in the cache */
   /* search540_0_1 -> 686 in the cache */
   /* search540_0 -> 1590 in the cache */
   /* search540_1_0 -> 1591 in the cache */
   /* search540_1_1 -> 686 in the cache */
   /* search540_1 -> 1592 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1590, 1592 },
      -1,
   } },

   /* replace540_0_0 -> 0 in the cache */
   /* replace540_0_1 -> 1591 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 1591 },
      -1,
   } },
   /* replace540_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1624, 686 },
      -1,
   } },

   /* ('~iand', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('fmax', 'b', 'c')) */
   /* search541_0_0 -> 128 in the cache */
   /* search541_0_1 -> 129 in the cache */
   /* search541_0 -> 1596 in the cache */
   /* search541_1_0 -> 128 in the cache */
   /* search541_1_1 -> 131 in the cache */
   /* search541_1 -> 1597 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1596, 1597 },
      -1,
   } },

   /* replace541_0 -> 128 in the cache */
   /* replace541_1_0 -> 129 in the cache */
   /* replace541_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 128, 1627 },
      -1,
   } },

   /* ('~iand', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c') */
   /* search542_0_0 -> 0 in the cache */
   /* search542_0_1 -> 686 in the cache */
   /* search542_0 -> 1601 in the cache */
   /* search542_1_0 -> 1591 in the cache */
   /* search542_1_1 -> 686 in the cache */
   /* search542_1 -> 1602 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1601, 1602 },
      -1,
   } },

   /* replace542_0_0 -> 0 in the cache */
   /* replace542_0_1 -> 1591 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 1591 },
      -1,
   } },
   /* replace542_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1630, 686 },
      -1,
   } },

   /* ('iand', ('flt', 'a', '#b(is_a_number)'), ('flt', 'a', '#c(is_a_number)')) => ('flt', 'a', ('fmin', 'b', 'c')) */
   /* search543_0_0 -> 128 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 128, 1632 },
      -1,
   } },
   /* search543_1_0 -> 128 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 128, 1634 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1633, 1635 },
      -1,
   } },

   /* replace543_0 -> 128 in the cache */
   /* replace543_1_0 -> 129 in the cache */
   /* replace543_1_1 -> 131 in the cache */
   /* replace543_1 -> 1621 in the cache */
   /* replace543 -> 1622 in the cache */

   /* ('iand', ('flt', '#a(is_a_number)', 'c'), ('flt', '#b(is_a_number)', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search544_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1637, 686 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search544_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1639, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1638, 1640 },
      -1,
   } },

   /* replace544_0_0 -> 0 in the cache */
   /* replace544_0_1 -> 1591 in the cache */
   /* replace544_0 -> 1624 in the cache */
   /* replace544_1 -> 686 in the cache */
   /* replace544 -> 1625 in the cache */

   /* ('iand', ('fge', 'a', '#b(is_a_number)'), ('fge', 'a', '#c(is_a_number)')) => ('fge', 'a', ('fmax', 'b', 'c')) */
   /* search545_0_0 -> 128 in the cache */
   /* search545_0_1 -> 1632 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 128, 1632 },
      -1,
   } },
   /* search545_1_0 -> 128 in the cache */
   /* search545_1_1 -> 1634 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 128, 1634 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1642, 1643 },
      -1,
   } },

   /* replace545_0 -> 128 in the cache */
   /* replace545_1_0 -> 129 in the cache */
   /* replace545_1_1 -> 131 in the cache */
   /* replace545_1 -> 1627 in the cache */
   /* replace545 -> 1628 in the cache */

   /* ('iand', ('fge', '#a(is_a_number)', 'c'), ('fge', '#b(is_a_number)', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c') */
   /* search546_0_0 -> 1637 in the cache */
   /* search546_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1637, 686 },
      -1,
   } },
   /* search546_1_0 -> 1639 in the cache */
   /* search546_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1639, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1645, 1646 },
      -1,
   } },

   /* replace546_0_0 -> 0 in the cache */
   /* replace546_0_1 -> 1591 in the cache */
   /* replace546_0 -> 1630 in the cache */
   /* replace546_1 -> 686 in the cache */
   /* replace546 -> 1631 in the cache */

   /* ('ior', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imax', 'b', 'c')) */
   /* search547_0_0 -> 128 in the cache */
   /* search547_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 128, 129 },
      0,
   } },
   /* search547_1_0 -> 128 in the cache */
   /* search547_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1648, 1649 },
      -1,
   } },

   /* replace547_0 -> 128 in the cache */
   /* replace547_1_0 -> 129 in the cache */
   /* replace547_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 128, 1651 },
      -1,
   } },

   /* ('ior', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imin', 'a', 'b'), 'c') */
   /* search548_0_0 -> 0 in the cache */
   /* search548_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 686 },
      0,
   } },
   /* search548_1_0 -> 1591 in the cache */
   /* search548_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1591, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1653, 1654 },
      -1,
   } },

   /* replace548_0_0 -> 0 in the cache */
   /* replace548_0_1 -> 1591 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 0, 1591 },
      -1,
   } },
   /* replace548_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1656, 686 },
      -1,
   } },

   /* ('ior', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imin', 'b', 'c')) */
   /* search549_0_0 -> 128 in the cache */
   /* search549_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 128, 129 },
      0,
   } },
   /* search549_1_0 -> 128 in the cache */
   /* search549_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1658, 1659 },
      -1,
   } },

   /* replace549_0 -> 128 in the cache */
   /* replace549_1_0 -> 129 in the cache */
   /* replace549_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 128, 1661 },
      -1,
   } },

   /* ('ior', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imax', 'a', 'b'), 'c') */
   /* search550_0_0 -> 0 in the cache */
   /* search550_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 686 },
      0,
   } },
   /* search550_1_0 -> 1591 in the cache */
   /* search550_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1591, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1663, 1664 },
      -1,
   } },

   /* replace550_0_0 -> 0 in the cache */
   /* replace550_0_1 -> 1591 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 0, 1591 },
      -1,
   } },
   /* replace550_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1666, 686 },
      -1,
   } },

   /* ('ior', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umax', 'b', 'c')) */
   /* search551_0_0 -> 128 in the cache */
   /* search551_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 128, 129 },
      0,
   } },
   /* search551_1_0 -> 128 in the cache */
   /* search551_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1668, 1669 },
      -1,
   } },

   /* replace551_0 -> 128 in the cache */
   /* replace551_1_0 -> 129 in the cache */
   /* replace551_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 128, 1671 },
      -1,
   } },

   /* ('ior', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umin', 'a', 'b'), 'c') */
   /* search552_0_0 -> 0 in the cache */
   /* search552_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 686 },
      0,
   } },
   /* search552_1_0 -> 1591 in the cache */
   /* search552_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1591, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1673, 1674 },
      -1,
   } },

   /* replace552_0_0 -> 0 in the cache */
   /* replace552_0_1 -> 1591 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 0, 1591 },
      -1,
   } },
   /* replace552_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1676, 686 },
      -1,
   } },

   /* ('ior', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umin', 'b', 'c')) */
   /* search553_0_0 -> 128 in the cache */
   /* search553_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 128, 129 },
      0,
   } },
   /* search553_1_0 -> 128 in the cache */
   /* search553_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 128, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1678, 1679 },
      -1,
   } },

   /* replace553_0 -> 128 in the cache */
   /* replace553_1_0 -> 129 in the cache */
   /* replace553_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 128, 1681 },
      -1,
   } },

   /* ('ior', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umax', 'a', 'b'), 'c') */
   /* search554_0_0 -> 0 in the cache */
   /* search554_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 686 },
      0,
   } },
   /* search554_1_0 -> 1591 in the cache */
   /* search554_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1591, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1683, 1684 },
      -1,
   } },

   /* replace554_0_0 -> 0 in the cache */
   /* replace554_0_1 -> 1591 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 0, 1591 },
      -1,
   } },
   /* replace554_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1686, 686 },
      -1,
   } },

   /* ('iand', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imin', 'b', 'c')) */
   /* search555_0_0 -> 128 in the cache */
   /* search555_0_1 -> 129 in the cache */
   /* search555_0 -> 1648 in the cache */
   /* search555_1_0 -> 128 in the cache */
   /* search555_1_1 -> 131 in the cache */
   /* search555_1 -> 1649 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1648, 1649 },
      -1,
   } },

   /* replace555_0 -> 128 in the cache */
   /* replace555_1_0 -> 129 in the cache */
   /* replace555_1_1 -> 131 in the cache */
   /* replace555_1 -> 1661 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 128, 1661 },
      -1,
   } },

   /* ('iand', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imax', 'a', 'b'), 'c') */
   /* search556_0_0 -> 0 in the cache */
   /* search556_0_1 -> 686 in the cache */
   /* search556_0 -> 1653 in the cache */
   /* search556_1_0 -> 1591 in the cache */
   /* search556_1_1 -> 686 in the cache */
   /* search556_1 -> 1654 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1653, 1654 },
      -1,
   } },

   /* replace556_0_0 -> 0 in the cache */
   /* replace556_0_1 -> 1591 in the cache */
   /* replace556_0 -> 1666 in the cache */
   /* replace556_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1666, 686 },
      -1,
   } },

   /* ('iand', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imax', 'b', 'c')) */
   /* search557_0_0 -> 128 in the cache */
   /* search557_0_1 -> 129 in the cache */
   /* search557_0 -> 1658 in the cache */
   /* search557_1_0 -> 128 in the cache */
   /* search557_1_1 -> 131 in the cache */
   /* search557_1 -> 1659 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1658, 1659 },
      -1,
   } },

   /* replace557_0 -> 128 in the cache */
   /* replace557_1_0 -> 129 in the cache */
   /* replace557_1_1 -> 131 in the cache */
   /* replace557_1 -> 1651 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 128, 1651 },
      -1,
   } },

   /* ('iand', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imin', 'a', 'b'), 'c') */
   /* search558_0_0 -> 0 in the cache */
   /* search558_0_1 -> 686 in the cache */
   /* search558_0 -> 1663 in the cache */
   /* search558_1_0 -> 1591 in the cache */
   /* search558_1_1 -> 686 in the cache */
   /* search558_1 -> 1664 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1663, 1664 },
      -1,
   } },

   /* replace558_0_0 -> 0 in the cache */
   /* replace558_0_1 -> 1591 in the cache */
   /* replace558_0 -> 1656 in the cache */
   /* replace558_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1656, 686 },
      -1,
   } },

   /* ('iand', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umin', 'b', 'c')) */
   /* search559_0_0 -> 128 in the cache */
   /* search559_0_1 -> 129 in the cache */
   /* search559_0 -> 1668 in the cache */
   /* search559_1_0 -> 128 in the cache */
   /* search559_1_1 -> 131 in the cache */
   /* search559_1 -> 1669 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1668, 1669 },
      -1,
   } },

   /* replace559_0 -> 128 in the cache */
   /* replace559_1_0 -> 129 in the cache */
   /* replace559_1_1 -> 131 in the cache */
   /* replace559_1 -> 1681 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 128, 1681 },
      -1,
   } },

   /* ('iand', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umax', 'a', 'b'), 'c') */
   /* search560_0_0 -> 0 in the cache */
   /* search560_0_1 -> 686 in the cache */
   /* search560_0 -> 1673 in the cache */
   /* search560_1_0 -> 1591 in the cache */
   /* search560_1_1 -> 686 in the cache */
   /* search560_1 -> 1674 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1673, 1674 },
      -1,
   } },

   /* replace560_0_0 -> 0 in the cache */
   /* replace560_0_1 -> 1591 in the cache */
   /* replace560_0 -> 1686 in the cache */
   /* replace560_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1686, 686 },
      -1,
   } },

   /* ('iand', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umax', 'b', 'c')) */
   /* search561_0_0 -> 128 in the cache */
   /* search561_0_1 -> 129 in the cache */
   /* search561_0 -> 1678 in the cache */
   /* search561_1_0 -> 128 in the cache */
   /* search561_1_1 -> 131 in the cache */
   /* search561_1 -> 1679 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1678, 1679 },
      -1,
   } },

   /* replace561_0 -> 128 in the cache */
   /* replace561_1_0 -> 129 in the cache */
   /* replace561_1_1 -> 131 in the cache */
   /* replace561_1 -> 1671 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 128, 1671 },
      -1,
   } },

   /* ('iand', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umin', 'a', 'b'), 'c') */
   /* search562_0_0 -> 0 in the cache */
   /* search562_0_1 -> 686 in the cache */
   /* search562_0 -> 1683 in the cache */
   /* search562_1_0 -> 1591 in the cache */
   /* search562_1_1 -> 686 in the cache */
   /* search562_1 -> 1684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1683, 1684 },
      -1,
   } },

   /* replace562_0_0 -> 0 in the cache */
   /* replace562_0_1 -> 1591 in the cache */
   /* replace562_0 -> 1676 in the cache */
   /* replace562_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1676, 686 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'c'), 'd'), ('flt', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd') */
   /* search563_0_0_0 -> 0 in the cache */
   /* search563_0_0_1 -> 686 in the cache */
   /* search563_0_0 -> 1590 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1590, 1704 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      3, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search563_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1706, 686 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1705, 1707 },
      -1,
   } },

   /* replace563_0_0_0 -> 0 in the cache */
   /* replace563_0_0_1 -> 1706 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      nir_op_fmin,
      1, 1,
      { 0, 1706 },
      -1,
   } },
   /* replace563_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1709, 686 },
      -1,
   } },
   /* replace563_1 -> 1704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1710, 1704 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt', 'a', 'c'), 'd'), ('flt(is_used_once)', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd') */
   /* search564_0_0_0 -> 0 in the cache */
   /* search564_0_0_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 686 },
      -1,
   } },
   /* search564_0_1 -> 1704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1712, 1704 },
      0,
   } },
   /* search564_1_0 -> 1706 in the cache */
   /* search564_1_1 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1706, 686 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1713, 1714 },
      -1,
   } },

   /* replace564_0_0_0 -> 0 in the cache */
   /* replace564_0_0_1 -> 1706 in the cache */
   /* replace564_0_0 -> 1709 in the cache */
   /* replace564_0_1 -> 686 in the cache */
   /* replace564_0 -> 1710 in the cache */
   /* replace564_1 -> 1704 in the cache */
   /* replace564 -> 1711 in the cache */

   /* ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'b'), 'd'), ('flt', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd') */
   /* search565_0_0_0 -> 151 in the cache */
   /* search565_0_0_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 151, 152 },
      0,
   } },
   /* search565_0_1 -> 1704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1716, 1704 },
      0,
   } },
   /* search565_1_0 -> 151 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 151, 1718 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1717, 1719 },
      -1,
   } },

   /* replace565_0_0 -> 151 in the cache */
   /* replace565_0_1_0 -> 152 in the cache */
   /* replace565_0_1_1 -> 1718 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      true,
      false,
      nir_op_fmax,
      1, 1,
      { 152, 1718 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 151, 1721 },
      -1,
   } },
   /* replace565_1 -> 1704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1722, 1704 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt', 'a', 'b'), 'd'), ('flt(is_used_once)', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd') */
   /* search566_0_0_0 -> 151 in the cache */
   /* search566_0_0_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 151, 152 },
      -1,
   } },
   /* search566_0_1 -> 1704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1724, 1704 },
      0,
   } },
   /* search566_1_0 -> 151 in the cache */
   /* search566_1_1 -> 1718 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 151, 1718 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1725, 1726 },
      -1,
   } },

   /* replace566_0_0 -> 151 in the cache */
   /* replace566_0_1_0 -> 152 in the cache */
   /* replace566_0_1_1 -> 1718 in the cache */
   /* replace566_0_1 -> 1721 in the cache */
   /* replace566_0 -> 1722 in the cache */
   /* replace566_1 -> 1704 in the cache */
   /* replace566 -> 1723 in the cache */

   /* ('ior', ('flt', 'a(is_a_number)', 'b(is_a_number)'), ('flt', 'b', 'a')) => ('fneu', 'a', 'b') */
   /* search567_0_0 -> 1035 in the cache */
   /* search567_0_1 -> 1036 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1035, 1036 },
      -1,
   } },
   /* search567_1_0 -> 3 in the cache */
   /* search567_1_1 -> 0 in the cache */
   /* search567_1 -> 1071 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1728, 1071 },
      -1,
   } },

   /* replace567_0 -> 0 in the cache */
   /* replace567_1 -> 3 in the cache */
   /* replace567 -> 1045 in the cache */

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search568_0_0 -> 115 in the cache */
   /* search568_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 115, 11 },
      0,
   } },
   /* search568_1_0 -> 260 in the cache */
   /* search568_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 260, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1730, 1731 },
      -1,
   } },

   /* replace568_0 -> 115 in the cache */
   /* replace568_1_0 -> 11 in the cache */
   /* replace568_1_1_0 -> 260 in the cache */
   /* replace568_1_1 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 11, 536 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 115, 1733 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search569_0_0 -> 115 in the cache */
   /* search569_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 115, 11 },
      -1,
   } },
   /* search569_1_0 -> 260 in the cache */
   /* search569_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 260, 115 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1735, 1736 },
      -1,
   } },

   /* replace569_0 -> 115 in the cache */
   /* replace569_1_0 -> 11 in the cache */
   /* replace569_1_1_0 -> 260 in the cache */
   /* replace569_1_1 -> 536 in the cache */
   /* replace569_1 -> 1733 in the cache */
   /* replace569 -> 1734 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search570_0_0 -> 115 in the cache */
   /* search570_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 115, 11 },
      0,
   } },
   /* search570_1_0 -> 260 in the cache */
   /* search570_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 260, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1738, 1739 },
      -1,
   } },

   /* replace570_0 -> 115 in the cache */
   /* replace570_1_0 -> 11 in the cache */
   /* replace570_1_1_0 -> 260 in the cache */
   /* replace570_1_1 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 11, 536 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 115, 1741 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search571_0_0 -> 115 in the cache */
   /* search571_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 115, 11 },
      -1,
   } },
   /* search571_1_0 -> 260 in the cache */
   /* search571_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 260, 115 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1743, 1744 },
      -1,
   } },

   /* replace571_0 -> 115 in the cache */
   /* replace571_1_0 -> 11 in the cache */
   /* replace571_1_1_0 -> 260 in the cache */
   /* replace571_1_1 -> 536 in the cache */
   /* replace571_1 -> 1741 in the cache */
   /* replace571 -> 1742 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search572_0_0 -> 115 in the cache */
   /* search572_0_1 -> 11 in the cache */
   /* search572_0 -> 1730 in the cache */
   /* search572_1_0 -> 260 in the cache */
   /* search572_1_1 -> 115 in the cache */
   /* search572_1 -> 1731 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1730, 1731 },
      -1,
   } },

   /* replace572_0 -> 115 in the cache */
   /* replace572_1_0 -> 11 in the cache */
   /* replace572_1_1_0 -> 260 in the cache */
   /* replace572_1_1 -> 536 in the cache */
   /* replace572_1 -> 1741 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 115, 1741 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search573_0_0 -> 115 in the cache */
   /* search573_0_1 -> 11 in the cache */
   /* search573_0 -> 1735 in the cache */
   /* search573_1_0 -> 260 in the cache */
   /* search573_1_1 -> 115 in the cache */
   /* search573_1 -> 1736 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1735, 1736 },
      -1,
   } },

   /* replace573_0 -> 115 in the cache */
   /* replace573_1_0 -> 11 in the cache */
   /* replace573_1_1_0 -> 260 in the cache */
   /* replace573_1_1 -> 536 in the cache */
   /* replace573_1 -> 1741 in the cache */
   /* replace573 -> 1747 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search574_0_0 -> 115 in the cache */
   /* search574_0_1 -> 11 in the cache */
   /* search574_0 -> 1738 in the cache */
   /* search574_1_0 -> 260 in the cache */
   /* search574_1_1 -> 115 in the cache */
   /* search574_1 -> 1739 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1738, 1739 },
      -1,
   } },

   /* replace574_0 -> 115 in the cache */
   /* replace574_1_0 -> 11 in the cache */
   /* replace574_1_1_0 -> 260 in the cache */
   /* replace574_1_1 -> 536 in the cache */
   /* replace574_1 -> 1733 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 115, 1733 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search575_0_0 -> 115 in the cache */
   /* search575_0_1 -> 11 in the cache */
   /* search575_0 -> 1743 in the cache */
   /* search575_1_0 -> 260 in the cache */
   /* search575_1_1 -> 115 in the cache */
   /* search575_1 -> 1744 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1743, 1744 },
      -1,
   } },

   /* replace575_0 -> 115 in the cache */
   /* replace575_1_0 -> 11 in the cache */
   /* replace575_1_1_0 -> 260 in the cache */
   /* replace575_1_1 -> 536 in the cache */
   /* replace575_1 -> 1733 in the cache */
   /* replace575 -> 1750 in the cache */

   /* ('bcsel@16', ('feq', 'a', 0.0), 1.0, ('i2f16', ('iadd', ('b2i16', ('flt', 0.0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0.0)))))) => ('i2f16', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search576_0_0 -> 11 in the cache */
   /* search576_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 11, 115 },
      -1,
   } },
   /* search576_1 -> 483 in the cache */
   /* search576_2_0_0_0_0 -> 115 in the cache */
   /* search576_2_0_0_0_1 -> 11 in the cache */
   /* search576_2_0_0_0 -> 1735 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1735 },
      -1,
   } },
   /* search576_2_0_1_0_0_0 -> 11 in the cache */
   /* search576_2_0_1_0_0_1 -> 115 in the cache */
   /* search576_2_0_1_0_0 -> 691 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 691 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1754 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1753, 1755 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 1,
      { 1756 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1752, 483, 1757 },
      -1,
   } },

   /* replace576_0_0_0_0 -> 11 in the cache */
   /* replace576_0_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 11, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1759 },
      -1,
   } },
   /* replace576_0_1_0_0_0 -> 11 in the cache */
   /* replace576_0_1_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1761 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1762 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1760, 1763 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 1,
      { 1764 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@16'), ('b2f', 'c@16')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search577_0 -> 753 in the cache */
   /* search577_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 260 },
      0,
   } },
   /* search577_2_0 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 471 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1766, 1767 },
      -1,
   } },

   /* replace577_0_0 -> 753 in the cache */
   /* replace577_0_1 -> 260 in the cache */
   /* replace577_0_2 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 260, 471 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1769 },
      -1,
   } },

   /* ('~i2f16', ('f2i', 'a@16')) => ('ftrunc', 'a') */
   /* search578_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 1771 },
      -1,
   } },

   /* replace578_0 -> 11 in the cache */
   /* replace578 -> 690 in the cache */

   /* ('~f2i16', ('i2f', 'a@16')) => a */
   /* search579_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1773 },
      -1,
   } },

   /* replace579 -> 11 in the cache */

   /* ('~f2i16', ('u2f', 'a@16')) => a */
   /* search580_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1775 },
      -1,
   } },

   /* replace580 -> 11 in the cache */

   /* ('~f2u16', ('i2f', 'a@16')) => a */
   /* search581_0_0 -> 11 in the cache */
   /* search581_0 -> 1773 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1773 },
      -1,
   } },

   /* replace581 -> 11 in the cache */

   /* ('~f2u16', ('u2f', 'a@16')) => a */
   /* search582_0_0 -> 11 in the cache */
   /* search582_0 -> 1775 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1775 },
      -1,
   } },

   /* replace582 -> 11 in the cache */

   /* ('fadd', ('b2f16', ('flt', 0.0, 'a@16')), ('fneg', ('b2f16', ('flt', 'a@16', 0.0)))) => ('fsign', 'a') */
   /* search583_0_0_0 -> 115 in the cache */
   /* search583_0_0_1 -> 11 in the cache */
   /* search583_0_0 -> 1735 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 1735 },
      -1,
   } },
   /* search583_1_0_0_0 -> 11 in the cache */
   /* search583_1_0_0_1 -> 115 in the cache */
   /* search583_1_0_0 -> 691 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 691 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1780 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1779, 1781 },
      -1,
   } },

   /* replace583_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('iadd', ('b2i16', ('flt', 0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0)))) => ('f2i16', ('fsign', 'a')) */
   /* search584_0_0_0 -> 849 in the cache */
   /* search584_0_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 849, 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1784 },
      -1,
   } },
   /* search584_1_0_0_0 -> 11 in the cache */
   /* search584_1_0_0_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 849 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1786 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1787 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1785, 1788 },
      -1,
   } },

   /* replace584_0_0 -> 11 in the cache */
   /* replace584_0 -> 1783 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1783 },
      -1,
   } },

   /* ('f2f16', ('f2f32', 'a@16')) => a */
   /* search585_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1791 },
      -1,
   } },

   /* replace585 -> 11 in the cache */

   /* ('i2i16', ('i2i32', 'a@16')) => a */
   /* search586_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1793 },
      -1,
   } },

   /* replace586 -> 11 in the cache */

   /* ('u2u16', ('u2u32', 'a@16')) => a */
   /* search587_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1795 },
      -1,
   } },

   /* replace587 -> 11 in the cache */

   /* ('f2f16', ('b2f32', 'a@1')) => ('b2f16', 'a') */
   /* search588_0_0 -> 753 in the cache */
   /* search588_0 -> 1400 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1400 },
      -1,
   } },

   /* replace588_0 -> 753 in the cache */
   /* replace588 -> 1396 in the cache */

   /* ('i2i16', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search589_0_0 -> 753 in the cache */
   /* search589_0 -> 1388 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1388 },
      -1,
   } },

   /* replace589_0 -> 753 in the cache */
   /* replace589 -> 1384 in the cache */

   /* ('u2u16', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search590_0_0 -> 753 in the cache */
   /* search590_0 -> 1388 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1388 },
      -1,
   } },

   /* replace590_0 -> 753 in the cache */
   /* replace590 -> 1384 in the cache */

   /* ('f2u32', ('f2f32', 'a@16')) => ('f2u32', 'a') */
   /* search591_0_0 -> 11 in the cache */
   /* search591_0 -> 1791 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1791 },
      -1,
   } },

   /* replace591_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2i32', ('f2f32', 'a@16')) => ('f2i32', 'a') */
   /* search592_0_0 -> 11 in the cache */
   /* search592_0 -> 1791 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1791 },
      -1,
   } },

   /* replace592_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('u2f32', 'a')) => ('u2f16', 'a') */
   /* search593_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1804 },
      -1,
   } },

   /* replace593_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('f2f16', ('i2f32', 'a')) => ('i2f16', 'a') */
   /* search594_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1807 },
      -1,
   } },

   /* replace594_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('u2f32', ('u2u32', 'a@16')) => ('u2f32', 'a') */
   /* search595_0_0 -> 11 in the cache */
   /* search595_0 -> 1795 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 1795 },
      -1,
   } },

   /* replace595_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2f32', ('i2i32', 'a@16')) => ('i2f32', 'a') */
   /* search596_0_0 -> 11 in the cache */
   /* search596_0 -> 1793 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 1793 },
      -1,
   } },

   /* replace596_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('f2f64', 'a@16')) => a */
   /* search597_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1814 },
      -1,
   } },

   /* replace597 -> 11 in the cache */

   /* ('i2i16', ('i2i64', 'a@16')) => a */
   /* search598_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1816 },
      -1,
   } },

   /* replace598 -> 11 in the cache */

   /* ('u2u16', ('u2u64', 'a@16')) => a */
   /* search599_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1818 },
      -1,
   } },

   /* replace599 -> 11 in the cache */

   /* ('f2f16', ('b2f64', 'a@1')) => ('b2f16', 'a') */
   /* search600_0_0 -> 753 in the cache */
   /* search600_0 -> 1404 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1404 },
      -1,
   } },

   /* replace600_0 -> 753 in the cache */
   /* replace600 -> 1396 in the cache */

   /* ('i2i16', ('b2i64', 'a@1')) => ('b2i16', 'a') */
   /* search601_0_0 -> 753 in the cache */
   /* search601_0 -> 1392 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1392 },
      -1,
   } },

   /* replace601_0 -> 753 in the cache */
   /* replace601 -> 1384 in the cache */

   /* ('u2u16', ('b2i64', 'a@1')) => ('b2i16', 'a') */
   /* search602_0_0 -> 753 in the cache */
   /* search602_0 -> 1392 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1392 },
      -1,
   } },

   /* replace602_0 -> 753 in the cache */
   /* replace602 -> 1384 in the cache */

   /* ('f2u64', ('f2f64', 'a@16')) => ('f2u64', 'a') */
   /* search603_0_0 -> 11 in the cache */
   /* search603_0 -> 1814 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1814 },
      -1,
   } },

   /* replace603_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2i64', ('f2f64', 'a@16')) => ('f2i64', 'a') */
   /* search604_0_0 -> 11 in the cache */
   /* search604_0 -> 1814 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1814 },
      -1,
   } },

   /* replace604_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('u2f64', 'a')) => ('u2f16', 'a') */
   /* search605_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1827 },
      -1,
   } },

   /* replace605_0 -> 32 in the cache */
   /* replace605 -> 1806 in the cache */

   /* ('f2f16', ('i2f64', 'a')) => ('i2f16', 'a') */
   /* search606_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1829 },
      -1,
   } },

   /* replace606_0 -> 32 in the cache */
   /* replace606 -> 1809 in the cache */

   /* ('u2f64', ('u2u64', 'a@16')) => ('u2f64', 'a') */
   /* search607_0_0 -> 11 in the cache */
   /* search607_0 -> 1818 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 1818 },
      -1,
   } },

   /* replace607_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2f64', ('i2i64', 'a@16')) => ('i2f64', 'a') */
   /* search608_0_0 -> 11 in the cache */
   /* search608_0 -> 1816 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 1816 },
      -1,
   } },

   /* replace608_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search609_0_0 -> 117 in the cache */
   /* search609_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 117, 16 },
      0,
   } },
   /* search609_1_0 -> 36 in the cache */
   /* search609_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 36, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1835, 1836 },
      -1,
   } },

   /* replace609_0 -> 117 in the cache */
   /* replace609_1_0 -> 16 in the cache */
   /* replace609_1_1_0 -> 36 in the cache */
   /* replace609_1_1 -> 602 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 16, 602 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 117, 1838 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search610_0_0 -> 117 in the cache */
   /* search610_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 117, 16 },
      -1,
   } },
   /* search610_1_0 -> 36 in the cache */
   /* search610_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 36, 117 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1840, 1841 },
      -1,
   } },

   /* replace610_0 -> 117 in the cache */
   /* replace610_1_0 -> 16 in the cache */
   /* replace610_1_1_0 -> 36 in the cache */
   /* replace610_1_1 -> 602 in the cache */
   /* replace610_1 -> 1838 in the cache */
   /* replace610 -> 1839 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search611_0_0 -> 117 in the cache */
   /* search611_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 117, 16 },
      0,
   } },
   /* search611_1_0 -> 36 in the cache */
   /* search611_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 36, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1843, 1844 },
      -1,
   } },

   /* replace611_0 -> 117 in the cache */
   /* replace611_1_0 -> 16 in the cache */
   /* replace611_1_1_0 -> 36 in the cache */
   /* replace611_1_1 -> 602 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 16, 602 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 117, 1846 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search612_0_0 -> 117 in the cache */
   /* search612_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 117, 16 },
      -1,
   } },
   /* search612_1_0 -> 36 in the cache */
   /* search612_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 36, 117 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1848, 1849 },
      -1,
   } },

   /* replace612_0 -> 117 in the cache */
   /* replace612_1_0 -> 16 in the cache */
   /* replace612_1_1_0 -> 36 in the cache */
   /* replace612_1_1 -> 602 in the cache */
   /* replace612_1 -> 1846 in the cache */
   /* replace612 -> 1847 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search613_0_0 -> 117 in the cache */
   /* search613_0_1 -> 16 in the cache */
   /* search613_0 -> 1835 in the cache */
   /* search613_1_0 -> 36 in the cache */
   /* search613_1_1 -> 117 in the cache */
   /* search613_1 -> 1836 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1835, 1836 },
      -1,
   } },

   /* replace613_0 -> 117 in the cache */
   /* replace613_1_0 -> 16 in the cache */
   /* replace613_1_1_0 -> 36 in the cache */
   /* replace613_1_1 -> 602 in the cache */
   /* replace613_1 -> 1846 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 117, 1846 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search614_0_0 -> 117 in the cache */
   /* search614_0_1 -> 16 in the cache */
   /* search614_0 -> 1840 in the cache */
   /* search614_1_0 -> 36 in the cache */
   /* search614_1_1 -> 117 in the cache */
   /* search614_1 -> 1841 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1840, 1841 },
      -1,
   } },

   /* replace614_0 -> 117 in the cache */
   /* replace614_1_0 -> 16 in the cache */
   /* replace614_1_1_0 -> 36 in the cache */
   /* replace614_1_1 -> 602 in the cache */
   /* replace614_1 -> 1846 in the cache */
   /* replace614 -> 1852 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search615_0_0 -> 117 in the cache */
   /* search615_0_1 -> 16 in the cache */
   /* search615_0 -> 1843 in the cache */
   /* search615_1_0 -> 36 in the cache */
   /* search615_1_1 -> 117 in the cache */
   /* search615_1 -> 1844 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1843, 1844 },
      -1,
   } },

   /* replace615_0 -> 117 in the cache */
   /* replace615_1_0 -> 16 in the cache */
   /* replace615_1_1_0 -> 36 in the cache */
   /* replace615_1_1 -> 602 in the cache */
   /* replace615_1 -> 1838 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 117, 1838 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search616_0_0 -> 117 in the cache */
   /* search616_0_1 -> 16 in the cache */
   /* search616_0 -> 1848 in the cache */
   /* search616_1_0 -> 36 in the cache */
   /* search616_1_1 -> 117 in the cache */
   /* search616_1 -> 1849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1848, 1849 },
      -1,
   } },

   /* replace616_0 -> 117 in the cache */
   /* replace616_1_0 -> 16 in the cache */
   /* replace616_1_1_0 -> 36 in the cache */
   /* replace616_1_1 -> 602 in the cache */
   /* replace616_1 -> 1838 in the cache */
   /* replace616 -> 1855 in the cache */

   /* ('bcsel@32', ('feq', 'a', 0.0), 1.0, ('i2f32', ('iadd', ('b2i32', ('flt', 0.0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0.0)))))) => ('i2f32', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search617_0_0 -> 16 in the cache */
   /* search617_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 16, 117 },
      -1,
   } },
   /* search617_1 -> 245 in the cache */
   /* search617_2_0_0_0_0 -> 117 in the cache */
   /* search617_2_0_0_0_1 -> 16 in the cache */
   /* search617_2_0_0_0 -> 1840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1840 },
      -1,
   } },
   /* search617_2_0_1_0_0_0 -> 16 in the cache */
   /* search617_2_0_1_0_0_1 -> 117 in the cache */
   /* search617_2_0_1_0_0 -> 697 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 697 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1859 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1858, 1860 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 1,
      { 1861 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1857, 245, 1862 },
      -1,
   } },

   /* replace617_0_0_0_0 -> 16 in the cache */
   /* replace617_0_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1864 },
      -1,
   } },
   /* replace617_0_1_0_0_0 -> 16 in the cache */
   /* replace617_0_1_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1866 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1867 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1865, 1868 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 1,
      { 1869 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@32'), ('b2f', 'c@32')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search618_0 -> 753 in the cache */
   /* search618_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 36 },
      0,
   } },
   /* search618_2_0 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1871, 1872 },
      -1,
   } },

   /* replace618_0_0 -> 753 in the cache */
   /* replace618_0_1 -> 36 in the cache */
   /* replace618_0_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 36, 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1874 },
      -1,
   } },

   /* ('~i2f32', ('f2i', 'a@32')) => ('ftrunc', 'a') */
   /* search619_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 1876 },
      -1,
   } },

   /* replace619_0 -> 16 in the cache */
   /* replace619 -> 696 in the cache */

   /* ('~f2i32', ('i2f', 'a@32')) => a */
   /* search620_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1878 },
      -1,
   } },

   /* replace620 -> 16 in the cache */

   /* ('~f2i32', ('u2f', 'a@32')) => a */
   /* search621_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1880 },
      -1,
   } },

   /* replace621 -> 16 in the cache */

   /* ('~f2u32', ('i2f', 'a@32')) => a */
   /* search622_0_0 -> 16 in the cache */
   /* search622_0 -> 1878 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1878 },
      -1,
   } },

   /* replace622 -> 16 in the cache */

   /* ('~f2u32', ('u2f', 'a@32')) => a */
   /* search623_0_0 -> 16 in the cache */
   /* search623_0 -> 1880 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1880 },
      -1,
   } },

   /* replace623 -> 16 in the cache */

   /* ('fadd', ('b2f32', ('flt', 0.0, 'a@32')), ('fneg', ('b2f32', ('flt', 'a@32', 0.0)))) => ('fsign', 'a') */
   /* search624_0_0_0 -> 117 in the cache */
   /* search624_0_0_1 -> 16 in the cache */
   /* search624_0_0 -> 1840 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 1840 },
      -1,
   } },
   /* search624_1_0_0_0 -> 16 in the cache */
   /* search624_1_0_0_1 -> 117 in the cache */
   /* search624_1_0_0 -> 697 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 697 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1885 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1884, 1886 },
      -1,
   } },

   /* replace624_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('iadd', ('b2i32', ('flt', 0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0)))) => ('f2i32', ('fsign', 'a')) */
   /* search625_0_0_0 -> 124 in the cache */
   /* search625_0_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1889 },
      -1,
   } },
   /* search625_1_0_0_0 -> 16 in the cache */
   /* search625_1_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 124 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1891 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1892 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1890, 1893 },
      -1,
   } },

   /* replace625_0_0 -> 16 in the cache */
   /* replace625_0 -> 1888 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1888 },
      -1,
   } },

   /* ('f2f32', ('f2f64', 'a@32')) => a */
   /* search626_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1896 },
      -1,
   } },

   /* replace626 -> 16 in the cache */

   /* ('i2i32', ('i2i64', 'a@32')) => a */
   /* search627_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1898 },
      -1,
   } },

   /* replace627 -> 16 in the cache */

   /* ('u2u32', ('u2u64', 'a@32')) => a */
   /* search628_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1900 },
      -1,
   } },

   /* replace628 -> 16 in the cache */

   /* ('f2f32', ('b2f64', 'a@1')) => ('b2f32', 'a') */
   /* search629_0_0 -> 753 in the cache */
   /* search629_0 -> 1404 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1404 },
      -1,
   } },

   /* replace629_0 -> 753 in the cache */
   /* replace629 -> 1400 in the cache */

   /* ('i2i32', ('b2i64', 'a@1')) => ('b2i32', 'a') */
   /* search630_0_0 -> 753 in the cache */
   /* search630_0 -> 1392 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1392 },
      -1,
   } },

   /* replace630_0 -> 753 in the cache */
   /* replace630 -> 1388 in the cache */

   /* ('u2u32', ('b2i64', 'a@1')) => ('b2i32', 'a') */
   /* search631_0_0 -> 753 in the cache */
   /* search631_0 -> 1392 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1392 },
      -1,
   } },

   /* replace631_0 -> 753 in the cache */
   /* replace631 -> 1388 in the cache */

   /* ('f2u64', ('f2f64', 'a@32')) => ('f2u64', 'a') */
   /* search632_0_0 -> 16 in the cache */
   /* search632_0 -> 1896 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1896 },
      -1,
   } },

   /* replace632_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2i64', ('f2f64', 'a@32')) => ('f2i64', 'a') */
   /* search633_0_0 -> 16 in the cache */
   /* search633_0 -> 1896 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1896 },
      -1,
   } },

   /* replace633_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2f32', ('u2f64', 'a')) => ('u2f32', 'a') */
   /* search634_0_0 -> 32 in the cache */
   /* search634_0 -> 1827 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1827 },
      -1,
   } },

   /* replace634_0 -> 32 in the cache */
   /* replace634 -> 1804 in the cache */

   /* ('f2f32', ('i2f64', 'a')) => ('i2f32', 'a') */
   /* search635_0_0 -> 32 in the cache */
   /* search635_0 -> 1829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1829 },
      -1,
   } },

   /* replace635_0 -> 32 in the cache */
   /* replace635 -> 1807 in the cache */

   /* ('u2f64', ('u2u64', 'a@32')) => ('u2f64', 'a') */
   /* search636_0_0 -> 16 in the cache */
   /* search636_0 -> 1900 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 1900 },
      -1,
   } },

   /* replace636_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2f64', ('i2i64', 'a@32')) => ('i2f64', 'a') */
   /* search637_0_0 -> 16 in the cache */
   /* search637_0 -> 1898 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 1898 },
      -1,
   } },

   /* replace637_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search638_0_0 -> 703 in the cache */
   /* search638_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 703, 21 },
      0,
   } },
   /* search638_1_0 -> 41 in the cache */
   /* search638_1_1 -> 703 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 41, 703 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1915, 1916 },
      -1,
   } },

   /* replace638_0 -> 703 in the cache */
   /* replace638_1_0 -> 21 in the cache */
   /* replace638_1_1_0 -> 41 in the cache */
   /* replace638_1_1 -> 675 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 21, 675 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 703, 1918 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search639_0_0 -> 703 in the cache */
   /* search639_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 703, 21 },
      -1,
   } },
   /* search639_1_0 -> 41 in the cache */
   /* search639_1_1 -> 703 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 41, 703 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1920, 1921 },
      -1,
   } },

   /* replace639_0 -> 703 in the cache */
   /* replace639_1_0 -> 21 in the cache */
   /* replace639_1_1_0 -> 41 in the cache */
   /* replace639_1_1 -> 675 in the cache */
   /* replace639_1 -> 1918 in the cache */
   /* replace639 -> 1919 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search640_0_0 -> 703 in the cache */
   /* search640_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 703, 21 },
      0,
   } },
   /* search640_1_0 -> 41 in the cache */
   /* search640_1_1 -> 703 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 41, 703 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1923, 1924 },
      -1,
   } },

   /* replace640_0 -> 703 in the cache */
   /* replace640_1_0 -> 21 in the cache */
   /* replace640_1_1_0 -> 41 in the cache */
   /* replace640_1_1 -> 675 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 21, 675 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 703, 1926 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search641_0_0 -> 703 in the cache */
   /* search641_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 703, 21 },
      -1,
   } },
   /* search641_1_0 -> 41 in the cache */
   /* search641_1_1 -> 703 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 41, 703 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1928, 1929 },
      -1,
   } },

   /* replace641_0 -> 703 in the cache */
   /* replace641_1_0 -> 21 in the cache */
   /* replace641_1_1_0 -> 41 in the cache */
   /* replace641_1_1 -> 675 in the cache */
   /* replace641_1 -> 1926 in the cache */
   /* replace641 -> 1927 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search642_0_0 -> 703 in the cache */
   /* search642_0_1 -> 21 in the cache */
   /* search642_0 -> 1915 in the cache */
   /* search642_1_0 -> 41 in the cache */
   /* search642_1_1 -> 703 in the cache */
   /* search642_1 -> 1916 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1915, 1916 },
      -1,
   } },

   /* replace642_0 -> 703 in the cache */
   /* replace642_1_0 -> 21 in the cache */
   /* replace642_1_1_0 -> 41 in the cache */
   /* replace642_1_1 -> 675 in the cache */
   /* replace642_1 -> 1926 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 703, 1926 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search643_0_0 -> 703 in the cache */
   /* search643_0_1 -> 21 in the cache */
   /* search643_0 -> 1920 in the cache */
   /* search643_1_0 -> 41 in the cache */
   /* search643_1_1 -> 703 in the cache */
   /* search643_1 -> 1921 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1920, 1921 },
      -1,
   } },

   /* replace643_0 -> 703 in the cache */
   /* replace643_1_0 -> 21 in the cache */
   /* replace643_1_1_0 -> 41 in the cache */
   /* replace643_1_1 -> 675 in the cache */
   /* replace643_1 -> 1926 in the cache */
   /* replace643 -> 1932 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search644_0_0 -> 703 in the cache */
   /* search644_0_1 -> 21 in the cache */
   /* search644_0 -> 1923 in the cache */
   /* search644_1_0 -> 41 in the cache */
   /* search644_1_1 -> 703 in the cache */
   /* search644_1 -> 1924 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1923, 1924 },
      -1,
   } },

   /* replace644_0 -> 703 in the cache */
   /* replace644_1_0 -> 21 in the cache */
   /* replace644_1_1_0 -> 41 in the cache */
   /* replace644_1_1 -> 675 in the cache */
   /* replace644_1 -> 1918 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 703, 1918 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search645_0_0 -> 703 in the cache */
   /* search645_0_1 -> 21 in the cache */
   /* search645_0 -> 1928 in the cache */
   /* search645_1_0 -> 41 in the cache */
   /* search645_1_1 -> 703 in the cache */
   /* search645_1 -> 1929 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1928, 1929 },
      -1,
   } },

   /* replace645_0 -> 703 in the cache */
   /* replace645_1_0 -> 21 in the cache */
   /* replace645_1_1_0 -> 41 in the cache */
   /* replace645_1_1 -> 675 in the cache */
   /* replace645_1 -> 1918 in the cache */
   /* replace645 -> 1935 in the cache */

   /* ('bcsel@64', ('feq', 'a', 0.0), 1.0, ('i2f64', ('iadd', ('b2i64', ('flt', 0.0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0.0)))))) => ('i2f64', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search646_0_0 -> 21 in the cache */
   /* search646_0_1 -> 703 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 21, 703 },
      -1,
   } },
   /* search646_1 -> 624 in the cache */
   /* search646_2_0_0_0_0 -> 703 in the cache */
   /* search646_2_0_0_0_1 -> 21 in the cache */
   /* search646_2_0_0_0 -> 1920 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1920 },
      -1,
   } },
   /* search646_2_0_1_0_0_0 -> 21 in the cache */
   /* search646_2_0_1_0_0_1 -> 703 in the cache */
   /* search646_2_0_1_0_0 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 704 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1939 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1938, 1940 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 1,
      { 1941 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1937, 624, 1942 },
      -1,
   } },

   /* replace646_0_0_0_0 -> 21 in the cache */
   /* replace646_0_0_0_1 -> 703 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 21, 703 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1944 },
      -1,
   } },
   /* replace646_0_1_0_0_0 -> 21 in the cache */
   /* replace646_0_1_0_0_1 -> 703 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 21, 703 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1946 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1947 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1945, 1948 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 1,
      { 1949 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@64'), ('b2f', 'c@64')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search647_0 -> 753 in the cache */
   /* search647_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 41 },
      0,
   } },
   /* search647_2_0 -> 612 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 612 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1951, 1952 },
      -1,
   } },

   /* replace647_0_0 -> 753 in the cache */
   /* replace647_0_1 -> 41 in the cache */
   /* replace647_0_2 -> 612 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 41, 612 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1954 },
      -1,
   } },

   /* ('~i2f64', ('f2i', 'a@64')) => ('ftrunc', 'a') */
   /* search648_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 1956 },
      -1,
   } },

   /* replace648_0 -> 21 in the cache */
   /* replace648 -> 702 in the cache */

   /* ('~f2i64', ('i2f', 'a@64')) => a */
   /* search649_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1958 },
      -1,
   } },

   /* replace649 -> 21 in the cache */

   /* ('~f2i64', ('u2f', 'a@64')) => a */
   /* search650_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1960 },
      -1,
   } },

   /* replace650 -> 21 in the cache */

   /* ('~f2u64', ('i2f', 'a@64')) => a */
   /* search651_0_0 -> 21 in the cache */
   /* search651_0 -> 1958 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1958 },
      -1,
   } },

   /* replace651 -> 21 in the cache */

   /* ('~f2u64', ('u2f', 'a@64')) => a */
   /* search652_0_0 -> 21 in the cache */
   /* search652_0 -> 1960 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1960 },
      -1,
   } },

   /* replace652 -> 21 in the cache */

   /* ('fadd', ('b2f64', ('flt', 0.0, 'a@64')), ('fneg', ('b2f64', ('flt', 'a@64', 0.0)))) => ('fsign', 'a') */
   /* search653_0_0_0 -> 703 in the cache */
   /* search653_0_0_1 -> 21 in the cache */
   /* search653_0_0 -> 1920 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 1920 },
      -1,
   } },
   /* search653_1_0_0_0 -> 21 in the cache */
   /* search653_1_0_0_1 -> 703 in the cache */
   /* search653_1_0_0 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 704 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1965 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1964, 1966 },
      -1,
   } },

   /* replace653_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('iadd', ('b2i64', ('flt', 0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0)))) => ('f2i64', ('fsign', 'a')) */
   /* search654_0_0_0 -> 890 in the cache */
   /* search654_0_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 890, 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1969 },
      -1,
   } },
   /* search654_1_0_0_0 -> 21 in the cache */
   /* search654_1_0_0_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 21, 890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1971 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1972 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1970, 1973 },
      -1,
   } },

   /* replace654_0_0 -> 21 in the cache */
   /* replace654_0 -> 1968 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1968 },
      -1,
   } },

   /* ('f2fmp', ('u2f32', 'a@32')) => ('u2fmp', 'a') */
   /* search655_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1976 },
      -1,
   } },

   /* replace655_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2fmp', ('i2f32', 'a@32')) => ('i2fmp', 'a') */
   /* search656_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1979 },
      -1,
   } },

   /* replace656_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2u16', ('f2fmp', 'a@32')) => ('f2u16', 'a') */
   /* search657_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1982 },
      -1,
   } },

   /* replace657_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2i16', ('f2fmp', 'a@32')) => ('f2i16', 'a') */
   /* search658_0_0 -> 16 in the cache */
   /* search658_0 -> 1982 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1982 },
      -1,
   } },

   /* replace658_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2imp', ('f2u32', 'a@32')) => ('f2ump', 'a') */
   /* search659_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1987 },
      -1,
   } },

   /* replace659_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2imp', ('f2i32', 'a@32')) => ('f2imp', 'a') */
   /* search660_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1990 },
      -1,
   } },

   /* replace660_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('u2f16', ('i2imp', 'a@32')) => ('u2f16', 'a') */
   /* search661_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 1993 },
      -1,
   } },

   /* replace661_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2f16', ('i2imp', 'a@32')) => ('i2f16', 'a') */
   /* search662_0_0 -> 16 in the cache */
   /* search662_0 -> 1993 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 1993 },
      -1,
   } },

   /* replace662_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('iand', ('u2u16', ('u2u8', 'a@16')), '#b') => ('iand', 'a', ('iand', 'b', 255)) */
   /* search663_0_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1998 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1999, 2000 },
      -1,
   } },

   /* replace663_0 -> 11 in the cache */
   /* replace663_1_0 -> 260 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 260, 2002 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 11, 2003 },
      -1,
   } },

   /* ('u2u16', ('u2u8(is_used_once)', ('iand', 'a@16', '#b'))) => ('iand', 'a', ('iand', 'b', 255)) */
   /* search664_0_0_0 -> 11 in the cache */
   /* search664_0_0_1 -> 2000 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 2000 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2005 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 1,
      { 2006 },
      -1,
   } },

   /* replace664_0 -> 11 in the cache */
   /* replace664_1_0 -> 260 in the cache */
   /* replace664_1_1 -> 2002 in the cache */
   /* replace664_1 -> 2003 in the cache */
   /* replace664 -> 2004 in the cache */

   /* ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('iand', 'a', 'b')) */
   /* search665_0_0_0_0 -> 11 in the cache */
   /* search665_0_0_0 -> 1998 in the cache */
   /* search665_0_0 -> 1999 in the cache */
   /* search665_0_1_0_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2008 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1999, 2009 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2010 },
      -1,
   } },

   /* replace665_0_0 -> 11 in the cache */
   /* replace665_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2012 },
      -1,
   } },

   /* ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('iand', 'a', 'b')) */
   /* search666_0_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2014 },
      -1,
   } },
   /* search666_0_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2016 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2015, 2017 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2018 },
      -1,
   } },

   /* replace666_0_0 -> 16 in the cache */
   /* replace666_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2020 },
      -1,
   } },

   /* ('iand', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('iand', 'a', 'c'), 'b') */
   /* search667_0_0 -> 0 in the cache */
   /* search667_0_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 814 },
      -1,
   } },
   /* search667_1_0 -> 142 in the cache */
   /* search667_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 142, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2022, 2023 },
      -1,
   } },

   /* replace667_0_0 -> 0 in the cache */
   /* replace667_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 142 },
      -1,
   } },
   /* replace667_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 2025, 3 },
      -1,
   } },

   /* ('iand', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('iand', 'a', 'c'), 'b') */
   /* search668_0_0 -> 0 in the cache */
   /* search668_0_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 814 },
      -1,
   } },
   /* search668_1_0 -> 142 in the cache */
   /* search668_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 142, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2027, 2028 },
      -1,
   } },

   /* replace668_0_0 -> 0 in the cache */
   /* replace668_0_1 -> 142 in the cache */
   /* replace668_0 -> 2025 in the cache */
   /* replace668_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 2025, 3 },
      -1,
   } },

   /* ('iand', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('iand', 'a', 'c'), 'b') */
   /* search669_0_0 -> 0 in the cache */
   /* search669_0_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 0, 814 },
      -1,
   } },
   /* search669_1_0 -> 142 in the cache */
   /* search669_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 142, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2031, 2032 },
      -1,
   } },

   /* replace669_0_0 -> 0 in the cache */
   /* replace669_0_1 -> 142 in the cache */
   /* replace669_0 -> 2025 in the cache */
   /* replace669_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 2025, 3 },
      -1,
   } },

   /* ('iand', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('iand', 'a', 'c'), 'b') */
   /* search670_0_0 -> 0 in the cache */
   /* search670_0_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 814 },
      -1,
   } },
   /* search670_1_0 -> 142 in the cache */
   /* search670_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 142, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2035, 2036 },
      -1,
   } },

   /* replace670_0_0 -> 0 in the cache */
   /* replace670_0_1 -> 142 in the cache */
   /* replace670_0 -> 2025 in the cache */
   /* replace670_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 2025, 3 },
      -1,
   } },

   /* ('iand', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('iand', 'a', 'c'), 'b') */
   /* search671_0_0 -> 128 in the cache */
   /* search671_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 128, 33 },
      0,
   } },
   /* search671_1_0 -> 131 in the cache */
   /* search671_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 131, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2039, 2040 },
      -1,
   } },

   /* replace671_0_0 -> 128 in the cache */
   /* replace671_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 128, 131 },
      -1,
   } },
   /* replace671_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2042, 36 },
      -1,
   } },

   /* ('iand', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('iand', 'a', 'c'), 'b') */
   /* search672_0_0 -> 128 in the cache */
   /* search672_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 128, 33 },
      0,
   } },
   /* search672_1_0 -> 131 in the cache */
   /* search672_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 131, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2044, 2045 },
      -1,
   } },

   /* replace672_0_0 -> 128 in the cache */
   /* replace672_0_1 -> 131 in the cache */
   /* replace672_0 -> 2042 in the cache */
   /* replace672_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2042, 36 },
      -1,
   } },

   /* ('iand', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('iand', 'a', 'c'), 'b') */
   /* search673_0_0 -> 128 in the cache */
   /* search673_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 128, 33 },
      0,
   } },
   /* search673_1_0 -> 131 in the cache */
   /* search673_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 131, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2048, 2049 },
      -1,
   } },

   /* replace673_0_0 -> 128 in the cache */
   /* replace673_0_1 -> 131 in the cache */
   /* replace673_0 -> 2042 in the cache */
   /* replace673_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2042, 36 },
      -1,
   } },

   /* ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ior', 'a', 'b')) */
   /* search674_0_0_0_0 -> 11 in the cache */
   /* search674_0_0_0 -> 1998 in the cache */
   /* search674_0_0 -> 1999 in the cache */
   /* search674_0_1_0_0 -> 260 in the cache */
   /* search674_0_1_0 -> 2008 in the cache */
   /* search674_0_1 -> 2009 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1999, 2009 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2052 },
      -1,
   } },

   /* replace674_0_0 -> 11 in the cache */
   /* replace674_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 11, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2054 },
      -1,
   } },

   /* ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ior', 'a', 'b')) */
   /* search675_0_0_0_0 -> 16 in the cache */
   /* search675_0_0_0 -> 2014 in the cache */
   /* search675_0_0 -> 2015 in the cache */
   /* search675_0_1_0_0 -> 36 in the cache */
   /* search675_0_1_0 -> 2016 in the cache */
   /* search675_0_1 -> 2017 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2015, 2017 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2056 },
      -1,
   } },

   /* replace675_0_0 -> 16 in the cache */
   /* replace675_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2058 },
      -1,
   } },

   /* ('ior', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ior', 'a', 'c'), 'b') */
   /* search676_0_0 -> 0 in the cache */
   /* search676_0_1 -> 814 in the cache */
   /* search676_0 -> 2022 in the cache */
   /* search676_1_0 -> 142 in the cache */
   /* search676_1_1 -> 3 in the cache */
   /* search676_1 -> 2023 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2022, 2023 },
      -1,
   } },

   /* replace676_0_0 -> 0 in the cache */
   /* replace676_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 0, 142 },
      -1,
   } },
   /* replace676_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 2061, 3 },
      -1,
   } },

   /* ('ior', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ior', 'a', 'c'), 'b') */
   /* search677_0_0 -> 0 in the cache */
   /* search677_0_1 -> 814 in the cache */
   /* search677_0 -> 2027 in the cache */
   /* search677_1_0 -> 142 in the cache */
   /* search677_1_1 -> 3 in the cache */
   /* search677_1 -> 2028 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2027, 2028 },
      -1,
   } },

   /* replace677_0_0 -> 0 in the cache */
   /* replace677_0_1 -> 142 in the cache */
   /* replace677_0 -> 2061 in the cache */
   /* replace677_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 2061, 3 },
      -1,
   } },

   /* ('ior', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ior', 'a', 'c'), 'b') */
   /* search678_0_0 -> 0 in the cache */
   /* search678_0_1 -> 814 in the cache */
   /* search678_0 -> 2031 in the cache */
   /* search678_1_0 -> 142 in the cache */
   /* search678_1_1 -> 3 in the cache */
   /* search678_1 -> 2032 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2031, 2032 },
      -1,
   } },

   /* replace678_0_0 -> 0 in the cache */
   /* replace678_0_1 -> 142 in the cache */
   /* replace678_0 -> 2061 in the cache */
   /* replace678_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 2061, 3 },
      -1,
   } },

   /* ('ior', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ior', 'a', 'c'), 'b') */
   /* search679_0_0 -> 0 in the cache */
   /* search679_0_1 -> 814 in the cache */
   /* search679_0 -> 2035 in the cache */
   /* search679_1_0 -> 142 in the cache */
   /* search679_1_1 -> 3 in the cache */
   /* search679_1 -> 2036 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2035, 2036 },
      -1,
   } },

   /* replace679_0_0 -> 0 in the cache */
   /* replace679_0_1 -> 142 in the cache */
   /* replace679_0 -> 2061 in the cache */
   /* replace679_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 2061, 3 },
      -1,
   } },

   /* ('ior', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ior', 'a', 'c'), 'b') */
   /* search680_0_0 -> 128 in the cache */
   /* search680_0_1 -> 33 in the cache */
   /* search680_0 -> 2039 in the cache */
   /* search680_1_0 -> 131 in the cache */
   /* search680_1_1 -> 36 in the cache */
   /* search680_1 -> 2040 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2039, 2040 },
      -1,
   } },

   /* replace680_0_0 -> 128 in the cache */
   /* replace680_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 128, 131 },
      -1,
   } },
   /* replace680_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2070, 36 },
      -1,
   } },

   /* ('ior', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ior', 'a', 'c'), 'b') */
   /* search681_0_0 -> 128 in the cache */
   /* search681_0_1 -> 33 in the cache */
   /* search681_0 -> 2044 in the cache */
   /* search681_1_0 -> 131 in the cache */
   /* search681_1_1 -> 36 in the cache */
   /* search681_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2044, 2045 },
      -1,
   } },

   /* replace681_0_0 -> 128 in the cache */
   /* replace681_0_1 -> 131 in the cache */
   /* replace681_0 -> 2070 in the cache */
   /* replace681_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2070, 36 },
      -1,
   } },

   /* ('ior', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ior', 'a', 'c'), 'b') */
   /* search682_0_0 -> 128 in the cache */
   /* search682_0_1 -> 33 in the cache */
   /* search682_0 -> 2048 in the cache */
   /* search682_1_0 -> 131 in the cache */
   /* search682_1_1 -> 36 in the cache */
   /* search682_1 -> 2049 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2048, 2049 },
      -1,
   } },

   /* replace682_0_0 -> 128 in the cache */
   /* replace682_0_1 -> 131 in the cache */
   /* replace682_0 -> 2070 in the cache */
   /* replace682_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2070, 36 },
      -1,
   } },

   /* ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ixor', 'a', 'b')) */
   /* search683_0_0_0_0 -> 11 in the cache */
   /* search683_0_0_0 -> 1998 in the cache */
   /* search683_0_0 -> 1999 in the cache */
   /* search683_0_1_0_0 -> 260 in the cache */
   /* search683_0_1_0 -> 2008 in the cache */
   /* search683_0_1 -> 2009 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1999, 2009 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2076 },
      -1,
   } },

   /* replace683_0_0 -> 11 in the cache */
   /* replace683_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 11, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2078 },
      -1,
   } },

   /* ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ixor', 'a', 'b')) */
   /* search684_0_0_0_0 -> 16 in the cache */
   /* search684_0_0_0 -> 2014 in the cache */
   /* search684_0_0 -> 2015 in the cache */
   /* search684_0_1_0_0 -> 36 in the cache */
   /* search684_0_1_0 -> 2016 in the cache */
   /* search684_0_1 -> 2017 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2015, 2017 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2080 },
      -1,
   } },

   /* replace684_0_0 -> 16 in the cache */
   /* replace684_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2082 },
      -1,
   } },

   /* ('ixor', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ixor', 'a', 'c'), 'b') */
   /* search685_0_0 -> 0 in the cache */
   /* search685_0_1 -> 814 in the cache */
   /* search685_0 -> 2022 in the cache */
   /* search685_1_0 -> 142 in the cache */
   /* search685_1_1 -> 3 in the cache */
   /* search685_1 -> 2023 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2022, 2023 },
      -1,
   } },

   /* replace685_0_0 -> 0 in the cache */
   /* replace685_0_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 0, 142 },
      -1,
   } },
   /* replace685_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 2085, 3 },
      -1,
   } },

   /* ('ixor', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ixor', 'a', 'c'), 'b') */
   /* search686_0_0 -> 0 in the cache */
   /* search686_0_1 -> 814 in the cache */
   /* search686_0 -> 2027 in the cache */
   /* search686_1_0 -> 142 in the cache */
   /* search686_1_1 -> 3 in the cache */
   /* search686_1 -> 2028 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2027, 2028 },
      -1,
   } },

   /* replace686_0_0 -> 0 in the cache */
   /* replace686_0_1 -> 142 in the cache */
   /* replace686_0 -> 2085 in the cache */
   /* replace686_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 2085, 3 },
      -1,
   } },

   /* ('ixor', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ixor', 'a', 'c'), 'b') */
   /* search687_0_0 -> 0 in the cache */
   /* search687_0_1 -> 814 in the cache */
   /* search687_0 -> 2031 in the cache */
   /* search687_1_0 -> 142 in the cache */
   /* search687_1_1 -> 3 in the cache */
   /* search687_1 -> 2032 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2031, 2032 },
      -1,
   } },

   /* replace687_0_0 -> 0 in the cache */
   /* replace687_0_1 -> 142 in the cache */
   /* replace687_0 -> 2085 in the cache */
   /* replace687_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 2085, 3 },
      -1,
   } },

   /* ('ixor', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ixor', 'a', 'c'), 'b') */
   /* search688_0_0 -> 0 in the cache */
   /* search688_0_1 -> 814 in the cache */
   /* search688_0 -> 2035 in the cache */
   /* search688_1_0 -> 142 in the cache */
   /* search688_1_1 -> 3 in the cache */
   /* search688_1 -> 2036 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2035, 2036 },
      -1,
   } },

   /* replace688_0_0 -> 0 in the cache */
   /* replace688_0_1 -> 142 in the cache */
   /* replace688_0 -> 2085 in the cache */
   /* replace688_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 2085, 3 },
      -1,
   } },

   /* ('ixor', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ixor', 'a', 'c'), 'b') */
   /* search689_0_0 -> 128 in the cache */
   /* search689_0_1 -> 33 in the cache */
   /* search689_0 -> 2039 in the cache */
   /* search689_1_0 -> 131 in the cache */
   /* search689_1_1 -> 36 in the cache */
   /* search689_1 -> 2040 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2039, 2040 },
      -1,
   } },

   /* replace689_0_0 -> 128 in the cache */
   /* replace689_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 128, 131 },
      -1,
   } },
   /* replace689_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2094, 36 },
      -1,
   } },

   /* ('ixor', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ixor', 'a', 'c'), 'b') */
   /* search690_0_0 -> 128 in the cache */
   /* search690_0_1 -> 33 in the cache */
   /* search690_0 -> 2044 in the cache */
   /* search690_1_0 -> 131 in the cache */
   /* search690_1_1 -> 36 in the cache */
   /* search690_1 -> 2045 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2044, 2045 },
      -1,
   } },

   /* replace690_0_0 -> 128 in the cache */
   /* replace690_0_1 -> 131 in the cache */
   /* replace690_0 -> 2094 in the cache */
   /* replace690_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2094, 36 },
      -1,
   } },

   /* ('ixor', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ixor', 'a', 'c'), 'b') */
   /* search691_0_0 -> 128 in the cache */
   /* search691_0_1 -> 33 in the cache */
   /* search691_0 -> 2048 in the cache */
   /* search691_1_0 -> 131 in the cache */
   /* search691_1_1 -> 36 in the cache */
   /* search691_1 -> 2049 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2048, 2049 },
      -1,
   } },

   /* replace691_0_0 -> 128 in the cache */
   /* replace691_0_1 -> 131 in the cache */
   /* replace691_0 -> 2094 in the cache */
   /* replace691_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2094, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search692_0_0 -> 6 in the cache */
   /* search692_0_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 828 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search692_1_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 2101, 828 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2100, 2102 },
      -1,
   } },

   /* replace692_0_0 -> 6 in the cache */
   /* replace692_0_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 6, 2101 },
      -1,
   } },
   /* replace692_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2104, 828 },
      -1,
   } },

   /* ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search693_0_0 -> 6 in the cache */
   /* search693_0_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 828 },
      -1,
   } },
   /* search693_1_0 -> 2101 in the cache */
   /* search693_1_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 2101, 828 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2106, 2107 },
      -1,
   } },

   /* replace693_0_0 -> 6 in the cache */
   /* replace693_0_1 -> 2101 in the cache */
   /* replace693_0 -> 2104 in the cache */
   /* replace693_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2104, 828 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search694_0_0 -> 6 in the cache */
   /* search694_0_1 -> 828 in the cache */
   /* search694_0 -> 2100 in the cache */
   /* search694_1_0 -> 2101 in the cache */
   /* search694_1_1 -> 828 in the cache */
   /* search694_1 -> 2102 in the cache */
   /* search694 -> 2103 in the cache */

   /* replace694_0_0 -> 6 in the cache */
   /* replace694_0_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 6, 2101 },
      -1,
   } },
   /* replace694_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2110, 828 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search695_0_0 -> 6 in the cache */
   /* search695_0_1 -> 828 in the cache */
   /* search695_0 -> 2100 in the cache */
   /* search695_1_0 -> 2101 in the cache */
   /* search695_1_1 -> 828 in the cache */
   /* search695_1 -> 2102 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2100, 2102 },
      -1,
   } },

   /* replace695_0_0 -> 6 in the cache */
   /* replace695_0_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 6, 2101 },
      -1,
   } },
   /* replace695_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2113, 828 },
      -1,
   } },

   /* ('iand', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search696_0_0 -> 6 in the cache */
   /* search696_0_1 -> 828 in the cache */
   /* search696_0 -> 2106 in the cache */
   /* search696_1_0 -> 2101 in the cache */
   /* search696_1_1 -> 828 in the cache */
   /* search696_1 -> 2107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2106, 2107 },
      -1,
   } },

   /* replace696_0_0 -> 6 in the cache */
   /* replace696_0_1 -> 2101 in the cache */
   /* replace696_0 -> 2113 in the cache */
   /* replace696_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2113, 828 },
      -1,
   } },

   /* ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search697_0_0 -> 6 in the cache */
   /* search697_0_1 -> 828 in the cache */
   /* search697_0 -> 2106 in the cache */
   /* search697_1_0 -> 2101 in the cache */
   /* search697_1_1 -> 828 in the cache */
   /* search697_1 -> 2107 in the cache */
   /* search697 -> 2108 in the cache */

   /* replace697_0_0 -> 6 in the cache */
   /* replace697_0_1 -> 2101 in the cache */
   /* replace697_0 -> 2110 in the cache */
   /* replace697_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2110, 828 },
      -1,
   } },

   /* ('ineg', ('b2i8', 'a@8')) => a */
   /* search698_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2118 },
      -1,
   } },

   /* replace698 -> 6 in the cache */

   /* ('ishl', 'a@8', ('iand', 7, 'b')) => ('ishl', 'a', 'b') */
   /* search699_0 -> 6 in the cache */
   /* search699_1_0 -> 9 in the cache */
   /* search699_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 9, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 6, 2120 },
      -1,
   } },

   /* replace699_0 -> 6 in the cache */
   /* replace699_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('ishr', 'a@8', ('iand', 7, 'b')) => ('ishr', 'a', 'b') */
   /* search700_0 -> 6 in the cache */
   /* search700_1_0 -> 9 in the cache */
   /* search700_1_1 -> 36 in the cache */
   /* search700_1 -> 2120 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 6, 2120 },
      -1,
   } },

   /* replace700_0 -> 6 in the cache */
   /* replace700_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('ushr', 'a@8', ('iand', 7, 'b')) => ('ushr', 'a', 'b') */
   /* search701_0 -> 6 in the cache */
   /* search701_1_0 -> 9 in the cache */
   /* search701_1_1 -> 36 in the cache */
   /* search701_1 -> 2120 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 6, 2120 },
      -1,
   } },

   /* replace701_0 -> 6 in the cache */
   /* replace701_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('ushr', 'a@8', ('ishl(is_used_once)', ('iand', 'b', 1), 2)) => ('ushr', 'a', ('ishl', 'b', 2)) */
   /* search702_0 -> 6 in the cache */
   /* search702_1_0_0 -> 36 in the cache */
   /* search702_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 36, 398 },
      -1,
   } },
   /* search702_1_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2127, 403 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 6, 2128 },
      -1,
   } },

   /* replace702_0 -> 6 in the cache */
   /* replace702_1_0 -> 36 in the cache */
   /* replace702_1_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 36, 403 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 2130 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search703_0_0 -> 11 in the cache */
   /* search703_0_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 849 },
      -1,
   } },
   /* search703_1_0 -> 260 in the cache */
   /* search703_1_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 260, 849 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2132, 2133 },
      -1,
   } },

   /* replace703_0_0 -> 11 in the cache */
   /* replace703_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 11, 260 },
      -1,
   } },
   /* replace703_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2135, 849 },
      -1,
   } },

   /* ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search704_0_0 -> 11 in the cache */
   /* search704_0_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 849 },
      -1,
   } },
   /* search704_1_0 -> 260 in the cache */
   /* search704_1_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 260, 849 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2137, 2138 },
      -1,
   } },

   /* replace704_0_0 -> 11 in the cache */
   /* replace704_0_1 -> 260 in the cache */
   /* replace704_0 -> 2135 in the cache */
   /* replace704_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2135, 849 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search705_0_0 -> 11 in the cache */
   /* search705_0_1 -> 849 in the cache */
   /* search705_0 -> 2132 in the cache */
   /* search705_1_0 -> 260 in the cache */
   /* search705_1_1 -> 849 in the cache */
   /* search705_1 -> 2133 in the cache */
   /* search705 -> 2134 in the cache */

   /* replace705_0_0 -> 11 in the cache */
   /* replace705_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 11, 260 },
      -1,
   } },
   /* replace705_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2141, 849 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search706_0_0 -> 11 in the cache */
   /* search706_0_1 -> 849 in the cache */
   /* search706_0 -> 2132 in the cache */
   /* search706_1_0 -> 260 in the cache */
   /* search706_1_1 -> 849 in the cache */
   /* search706_1 -> 2133 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2132, 2133 },
      -1,
   } },

   /* replace706_0_0 -> 11 in the cache */
   /* replace706_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 11, 260 },
      -1,
   } },
   /* replace706_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2144, 849 },
      -1,
   } },

   /* ('iand', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search707_0_0 -> 11 in the cache */
   /* search707_0_1 -> 849 in the cache */
   /* search707_0 -> 2137 in the cache */
   /* search707_1_0 -> 260 in the cache */
   /* search707_1_1 -> 849 in the cache */
   /* search707_1 -> 2138 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2137, 2138 },
      -1,
   } },

   /* replace707_0_0 -> 11 in the cache */
   /* replace707_0_1 -> 260 in the cache */
   /* replace707_0 -> 2144 in the cache */
   /* replace707_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2144, 849 },
      -1,
   } },

   /* ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search708_0_0 -> 11 in the cache */
   /* search708_0_1 -> 849 in the cache */
   /* search708_0 -> 2137 in the cache */
   /* search708_1_0 -> 260 in the cache */
   /* search708_1_1 -> 849 in the cache */
   /* search708_1 -> 2138 in the cache */
   /* search708 -> 2139 in the cache */

   /* replace708_0_0 -> 11 in the cache */
   /* replace708_0_1 -> 260 in the cache */
   /* replace708_0 -> 2141 in the cache */
   /* replace708_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2141, 849 },
      -1,
   } },

   /* ('ineg', ('b2i16', 'a@16')) => a */
   /* search709_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2149 },
      -1,
   } },

   /* replace709 -> 11 in the cache */

   /* ('ishl', 'a@16', ('iand', 15, 'b')) => ('ishl', 'a', 'b') */
   /* search710_0 -> 11 in the cache */
   /* search710_1_0 -> 14 in the cache */
   /* search710_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 14, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 2151 },
      -1,
   } },

   /* replace710_0 -> 11 in the cache */
   /* replace710_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ishr', 'a@16', ('iand', 15, 'b')) => ('ishr', 'a', 'b') */
   /* search711_0 -> 11 in the cache */
   /* search711_1_0 -> 14 in the cache */
   /* search711_1_1 -> 36 in the cache */
   /* search711_1 -> 2151 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 11, 2151 },
      -1,
   } },

   /* replace711_0 -> 11 in the cache */
   /* replace711_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ushr', 'a@16', ('iand', 15, 'b')) => ('ushr', 'a', 'b') */
   /* search712_0 -> 11 in the cache */
   /* search712_1_0 -> 14 in the cache */
   /* search712_1_1 -> 36 in the cache */
   /* search712_1 -> 2151 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 2151 },
      -1,
   } },

   /* replace712_0 -> 11 in the cache */
   /* replace712_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ushr', 'a@16', ('ishl(is_used_once)', ('iand', 'b', 1), 3)) => ('ushr', 'a', ('ishl', 'b', 3)) */
   /* search713_0 -> 11 in the cache */
   /* search713_1_0_0 -> 36 in the cache */
   /* search713_1_0_1 -> 398 in the cache */
   /* search713_1_0 -> 2127 in the cache */
   /* search713_1_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2127, 407 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 2158 },
      -1,
   } },

   /* replace713_0 -> 11 in the cache */
   /* replace713_1_0 -> 36 in the cache */
   /* replace713_1_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 36, 407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 2160 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search714_0_0 -> 16 in the cache */
   /* search714_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 16, 124 },
      -1,
   } },
   /* search714_1_0 -> 36 in the cache */
   /* search714_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 36, 124 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2162, 2163 },
      -1,
   } },

   /* replace714_0_0 -> 16 in the cache */
   /* replace714_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace714_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2165, 124 },
      -1,
   } },

   /* ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search715_0_0 -> 16 in the cache */
   /* search715_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 16, 124 },
      -1,
   } },
   /* search715_1_0 -> 36 in the cache */
   /* search715_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 36, 124 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2167, 2168 },
      -1,
   } },

   /* replace715_0_0 -> 16 in the cache */
   /* replace715_0_1 -> 36 in the cache */
   /* replace715_0 -> 2165 in the cache */
   /* replace715_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2165, 124 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search716_0_0 -> 16 in the cache */
   /* search716_0_1 -> 124 in the cache */
   /* search716_0 -> 2162 in the cache */
   /* search716_1_0 -> 36 in the cache */
   /* search716_1_1 -> 124 in the cache */
   /* search716_1 -> 2163 in the cache */
   /* search716 -> 2164 in the cache */

   /* replace716_0_0 -> 16 in the cache */
   /* replace716_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace716_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2171, 124 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search717_0_0 -> 16 in the cache */
   /* search717_0_1 -> 124 in the cache */
   /* search717_0 -> 2162 in the cache */
   /* search717_1_0 -> 36 in the cache */
   /* search717_1_1 -> 124 in the cache */
   /* search717_1 -> 2163 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2162, 2163 },
      -1,
   } },

   /* replace717_0_0 -> 16 in the cache */
   /* replace717_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace717_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2174, 124 },
      -1,
   } },

   /* ('iand', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search718_0_0 -> 16 in the cache */
   /* search718_0_1 -> 124 in the cache */
   /* search718_0 -> 2167 in the cache */
   /* search718_1_0 -> 36 in the cache */
   /* search718_1_1 -> 124 in the cache */
   /* search718_1 -> 2168 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2167, 2168 },
      -1,
   } },

   /* replace718_0_0 -> 16 in the cache */
   /* replace718_0_1 -> 36 in the cache */
   /* replace718_0 -> 2174 in the cache */
   /* replace718_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2174, 124 },
      -1,
   } },

   /* ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search719_0_0 -> 16 in the cache */
   /* search719_0_1 -> 124 in the cache */
   /* search719_0 -> 2167 in the cache */
   /* search719_1_0 -> 36 in the cache */
   /* search719_1_1 -> 124 in the cache */
   /* search719_1 -> 2168 in the cache */
   /* search719 -> 2169 in the cache */

   /* replace719_0_0 -> 16 in the cache */
   /* replace719_0_1 -> 36 in the cache */
   /* replace719_0 -> 2171 in the cache */
   /* replace719_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2171, 124 },
      -1,
   } },

   /* ('ineg', ('b2i32', 'a@32')) => a */
   /* search720_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2179 },
      -1,
   } },

   /* replace720 -> 16 in the cache */

   /* ('ishl', 'a@32', ('iand', 31, 'b')) => ('ishl', 'a', 'b') */
   /* search721_0 -> 16 in the cache */
   /* search721_1_0 -> 19 in the cache */
   /* search721_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 2181 },
      -1,
   } },

   /* replace721_0 -> 16 in the cache */
   /* replace721_1 -> 36 in the cache */
   /* replace721 -> 939 in the cache */

   /* ('ishr', 'a@32', ('iand', 31, 'b')) => ('ishr', 'a', 'b') */
   /* search722_0 -> 16 in the cache */
   /* search722_1_0 -> 19 in the cache */
   /* search722_1_1 -> 36 in the cache */
   /* search722_1 -> 2181 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 16, 2181 },
      -1,
   } },

   /* replace722_0 -> 16 in the cache */
   /* replace722_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ushr', 'a@32', ('iand', 31, 'b')) => ('ushr', 'a', 'b') */
   /* search723_0 -> 16 in the cache */
   /* search723_1_0 -> 19 in the cache */
   /* search723_1_1 -> 36 in the cache */
   /* search723_1 -> 2181 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 2181 },
      -1,
   } },

   /* replace723_0 -> 16 in the cache */
   /* replace723_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ushr', 'a@32', ('ishl(is_used_once)', ('iand', 'b', 1), 4)) => ('ushr', 'a', ('ishl', 'b', 4)) */
   /* search724_0 -> 16 in the cache */
   /* search724_1_0_0 -> 36 in the cache */
   /* search724_1_0_1 -> 398 in the cache */
   /* search724_1_0 -> 2127 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x4 /* 4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2127, 2187 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 2188 },
      -1,
   } },

   /* replace724_0 -> 16 in the cache */
   /* replace724_1_0 -> 36 in the cache */
   /* replace724_1_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 36, 2187 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 2190 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search725_0_0 -> 21 in the cache */
   /* search725_0_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 21, 890 },
      -1,
   } },
   /* search725_1_0 -> 41 in the cache */
   /* search725_1_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 41, 890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2192, 2193 },
      -1,
   } },

   /* replace725_0_0 -> 21 in the cache */
   /* replace725_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace725_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2195, 890 },
      -1,
   } },

   /* ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search726_0_0 -> 21 in the cache */
   /* search726_0_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 21, 890 },
      -1,
   } },
   /* search726_1_0 -> 41 in the cache */
   /* search726_1_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 41, 890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2197, 2198 },
      -1,
   } },

   /* replace726_0_0 -> 21 in the cache */
   /* replace726_0_1 -> 41 in the cache */
   /* replace726_0 -> 2195 in the cache */
   /* replace726_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2195, 890 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search727_0_0 -> 21 in the cache */
   /* search727_0_1 -> 890 in the cache */
   /* search727_0 -> 2192 in the cache */
   /* search727_1_0 -> 41 in the cache */
   /* search727_1_1 -> 890 in the cache */
   /* search727_1 -> 2193 in the cache */
   /* search727 -> 2194 in the cache */

   /* replace727_0_0 -> 21 in the cache */
   /* replace727_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace727_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2201, 890 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search728_0_0 -> 21 in the cache */
   /* search728_0_1 -> 890 in the cache */
   /* search728_0 -> 2192 in the cache */
   /* search728_1_0 -> 41 in the cache */
   /* search728_1_1 -> 890 in the cache */
   /* search728_1 -> 2193 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2192, 2193 },
      -1,
   } },

   /* replace728_0_0 -> 21 in the cache */
   /* replace728_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace728_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2204, 890 },
      -1,
   } },

   /* ('iand', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search729_0_0 -> 21 in the cache */
   /* search729_0_1 -> 890 in the cache */
   /* search729_0 -> 2197 in the cache */
   /* search729_1_0 -> 41 in the cache */
   /* search729_1_1 -> 890 in the cache */
   /* search729_1 -> 2198 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2197, 2198 },
      -1,
   } },

   /* replace729_0_0 -> 21 in the cache */
   /* replace729_0_1 -> 41 in the cache */
   /* replace729_0 -> 2204 in the cache */
   /* replace729_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2204, 890 },
      -1,
   } },

   /* ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search730_0_0 -> 21 in the cache */
   /* search730_0_1 -> 890 in the cache */
   /* search730_0 -> 2197 in the cache */
   /* search730_1_0 -> 41 in the cache */
   /* search730_1_1 -> 890 in the cache */
   /* search730_1 -> 2198 in the cache */
   /* search730 -> 2199 in the cache */

   /* replace730_0_0 -> 21 in the cache */
   /* replace730_0_1 -> 41 in the cache */
   /* replace730_0 -> 2201 in the cache */
   /* replace730_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2201, 890 },
      -1,
   } },

   /* ('ineg', ('b2i64', 'a@64')) => a */
   /* search731_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2209 },
      -1,
   } },

   /* replace731 -> 21 in the cache */

   /* ('ishl', 'a@64', ('iand', 63, 'b')) => ('ishl', 'a', 'b') */
   /* search732_0 -> 21 in the cache */
   /* search732_1_0 -> 24 in the cache */
   /* search732_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 24, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 21, 2211 },
      -1,
   } },

   /* replace732_0 -> 21 in the cache */
   /* replace732_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ishr', 'a@64', ('iand', 63, 'b')) => ('ishr', 'a', 'b') */
   /* search733_0 -> 21 in the cache */
   /* search733_1_0 -> 24 in the cache */
   /* search733_1_1 -> 36 in the cache */
   /* search733_1 -> 2211 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 21, 2211 },
      -1,
   } },

   /* replace733_0 -> 21 in the cache */
   /* replace733_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ushr', 'a@64', ('iand', 63, 'b')) => ('ushr', 'a', 'b') */
   /* search734_0 -> 21 in the cache */
   /* search734_1_0 -> 24 in the cache */
   /* search734_1_1 -> 36 in the cache */
   /* search734_1 -> 2211 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 21, 2211 },
      -1,
   } },

   /* replace734_0 -> 21 in the cache */
   /* replace734_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ushr', 'a@64', ('ishl(is_used_once)', ('iand', 'b', 1), 5)) => ('ushr', 'a', ('ishl', 'b', 5)) */
   /* search735_0 -> 21 in the cache */
   /* search735_1_0_0 -> 36 in the cache */
   /* search735_1_0_1 -> 398 in the cache */
   /* search735_1_0 -> 2127 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x5 /* 5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2127, 2218 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 21, 2219 },
      -1,
   } },

   /* replace735_0 -> 21 in the cache */
   /* replace735_1_0 -> 36 in the cache */
   /* replace735_1_1 -> 2218 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 36, 2218 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 2221 },
      -1,
   } },

   /* ('ior', ('ieq', 'a', 0), ('ieq', 'a', 1)) => ('uge', 1, 'a') */
   /* search736_0_0 -> 32 in the cache */
   /* search736_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 32, 61 },
      -1,
   } },
   /* search736_1_0 -> 32 in the cache */
   /* search736_1_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2223, 2224 },
      -1,
   } },

   /* replace736_0 -> 35 in the cache */
   /* replace736_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 35, 32 },
      -1,
   } },

   /* ('ior', ('uge', 1, 'a'), ('ieq', 'a', 2)) => ('uge', 2, 'a') */
   /* search737_0_0 -> 35 in the cache */
   /* search737_0_1 -> 32 in the cache */
   /* search737_0 -> 2226 in the cache */
   /* search737_1_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 32, 2227 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2226, 2228 },
      -1,
   } },

   /* replace737_0 -> 2227 in the cache */
   /* replace737_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2227, 32 },
      -1,
   } },

   /* ('ior', ('uge', 2, 'a'), ('ieq', 'a', 3)) => ('uge', 3, 'a') */
   /* search738_0_0 -> 2227 in the cache */
   /* search738_0_1 -> 32 in the cache */
   /* search738_0 -> 2230 in the cache */
   /* search738_1_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 32, 2231 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2230, 2232 },
      -1,
   } },

   /* replace738_0 -> 2231 in the cache */
   /* replace738_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2231, 32 },
      -1,
   } },

   /* ('ior', 'a', ('ieq', 'a', False)) => True */
   /* search739_0 -> 753 in the cache */
   /* search739_1_0 -> 753 in the cache */
   /* search739_1_1 -> 1070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 753, 1070 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 753, 2235 },
      -1,
   } },

   /* replace739 -> 1224 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ine', 'a', 'b') */
   /* search740_0_0_0 -> 753 in the cache */
   /* search740_0_0 -> 1215 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1215 },
      -1,
   } },
   /* search740_1_0_0 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1121 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2238 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2237, 2239 },
      -1,
   } },

   /* replace740_0 -> 753 in the cache */
   /* replace740_1 -> 1121 in the cache */
   /* replace740 -> 1383 in the cache */

   /* ('b2i', ('ine', 'a@1', 'b@1')) => ('b2i', ('ixor', 'a', 'b')) */
   /* search741_0_0 -> 753 in the cache */
   /* search741_0_1 -> 1121 in the cache */
   /* search741_0 -> 1383 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1383 },
      -1,
   } },

   /* replace741_0_0 -> 753 in the cache */
   /* replace741_0_1 -> 1121 in the cache */
   /* replace741_0 -> 1138 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1138 },
      -1,
   } },

   /* ('iand', ('inot', ('iand', ('ior', ('ieq', 'a', 0), 'b'), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', 'b', 'c')), ('ilt', 'a', 0)) */
   /* search742_0_0_0_0_0 -> 32 in the cache */
   /* search742_0_0_0_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 32, 61 },
      -1,
   } },
   /* search742_0_0_0_1 -> 1121 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      2, 2,
      { 2243, 1121 },
      -1,
   } },
   /* search742_0_0_1 -> 466 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 3,
      { 2244, 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 2245 },
      -1,
   } },
   /* search742_1_0 -> 32 in the cache */
   /* search742_1_1 -> 61 in the cache */
   /* search742_1 -> 1238 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2246, 1238 },
      -1,
   } },

   /* replace742_0_0_0 -> 1121 in the cache */
   /* replace742_0_0_1 -> 466 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1121, 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2248 },
      -1,
   } },
   /* replace742_1_0 -> 32 in the cache */
   /* replace742_1_1 -> 61 in the cache */
   /* replace742_1 -> 1238 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 2249, 1238 },
      -1,
   } },

   /* ('iand', ('inot', ('iand', ('ieq', ('umin', 'a', 'b'), 0), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', ('ieq', 'b', 0), 'c')), ('ilt', 'a', 0)) */
   /* search743_0_0_0_0_0 -> 0 in the cache */
   /* search743_0_0_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      3, 1,
      { 0, 3 },
      -1,
   } },
   /* search743_0_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 2,
      { 2251, 86 },
      -1,
   } },
   /* search743_0_0_1 -> 466 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 3,
      { 2252, 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 2253 },
      -1,
   } },
   /* search743_1_0 -> 0 in the cache */
   /* search743_1_1 -> 86 in the cache */
   /* search743_1 -> 90 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2254, 90 },
      -1,
   } },

   /* replace743_0_0_0_0 -> 3 in the cache */
   /* replace743_0_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 3, 86 },
      -1,
   } },
   /* replace743_0_0_1 -> 466 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 2,
      { 2256, 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 2,
      { 2257 },
      -1,
   } },
   /* replace743_1_0 -> 0 in the cache */
   /* replace743_1_1 -> 86 in the cache */
   /* replace743_1 -> 90 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2258, 90 },
      -1,
   } },

   /* ('flt', 'a', ('fmax', 'b', 'a')) => ('flt', 'a', 'b') */
   /* search744_0 -> 32 in the cache */
   { .variable = {
      { nir_search_value_variable, -1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search744_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 2260, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 32, 2261 },
      -1,
   } },

   /* replace744_0 -> 32 in the cache */
   /* replace744_1 -> 2260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 2260 },
      -1,
   } },

   /* ('flt', ('fmin', 'a', 'b'), 'a') => ('flt', 'b', 'a') */
   /* search745_0_0 -> 0 in the cache */
   /* search745_0_1 -> 3 in the cache */
   /* search745_0 -> 1272 in the cache */
   /* search745_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1272, 0 },
      -1,
   } },

   /* replace745_0 -> 3 in the cache */
   /* replace745_1 -> 0 in the cache */
   /* replace745 -> 1071 in the cache */

   /* ('~fge', 'a', ('fmin', 'b', 'a')) => True */
   /* search746_0 -> 32 in the cache */
   /* search746_1_0 -> 2260 in the cache */
   /* search746_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 2260, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 32, 2265 },
      -1,
   } },

   /* replace746 -> 1224 in the cache */

   /* ('~fge', ('fmax', 'a', 'b'), 'a') => True */
   /* search747_0_0 -> 0 in the cache */
   /* search747_0_1 -> 3 in the cache */
   /* search747_0 -> 1270 in the cache */
   /* search747_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1270, 0 },
      -1,
   } },

   /* replace747 -> 1224 in the cache */

   /* ('flt', 'a', ('fmin', 'b', 'a')) => False */
   /* search748_0 -> 32 in the cache */
   /* search748_1_0 -> 2260 in the cache */
   /* search748_1_1 -> 32 in the cache */
   /* search748_1 -> 2265 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 32, 2265 },
      -1,
   } },

   /* replace748 -> 1070 in the cache */

   /* ('flt', ('fmax', 'a', 'b'), 'a') => False */
   /* search749_0_0 -> 0 in the cache */
   /* search749_0_1 -> 3 in the cache */
   /* search749_0 -> 1270 in the cache */
   /* search749_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1270, 0 },
      -1,
   } },

   /* replace749 -> 1070 in the cache */

   /* ('~fge', 'a', ('fmax', 'b', 'a')) => ('fge', 'a', 'b') */
   /* search750_0 -> 32 in the cache */
   /* search750_1_0 -> 2260 in the cache */
   /* search750_1_1 -> 32 in the cache */
   /* search750_1 -> 2261 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 32, 2261 },
      -1,
   } },

   /* replace750_0 -> 32 in the cache */
   /* replace750_1 -> 2260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 2260 },
      -1,
   } },

   /* ('~fge', ('fmin', 'a', 'b'), 'a') => ('fge', 'b', 'a') */
   /* search751_0_0 -> 0 in the cache */
   /* search751_0_1 -> 3 in the cache */
   /* search751_0 -> 1272 in the cache */
   /* search751_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1272, 0 },
      -1,
   } },

   /* replace751_0 -> 3 in the cache */
   /* replace751_1 -> 0 in the cache */
   /* replace751 -> 1083 in the cache */

   /* ('ilt', 'a', ('imax', 'b', 'a')) => ('ilt', 'a', 'b') */
   /* search752_0 -> 32 in the cache */
   /* search752_1_0 -> 2260 in the cache */
   /* search752_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2260, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 32, 2273 },
      -1,
   } },

   /* replace752_0 -> 32 in the cache */
   /* replace752_1 -> 2260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 32, 2260 },
      -1,
   } },

   /* ('ilt', ('imin', 'a', 'b'), 'a') => ('ilt', 'b', 'a') */
   /* search753_0_0 -> 0 in the cache */
   /* search753_0_1 -> 3 in the cache */
   /* search753_0 -> 1292 in the cache */
   /* search753_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1292, 0 },
      -1,
   } },

   /* replace753_0 -> 3 in the cache */
   /* replace753_1 -> 0 in the cache */
   /* replace753 -> 1076 in the cache */

   /* ('ige', 'a', ('imin', 'b', 'a')) => True */
   /* search754_0 -> 32 in the cache */
   /* search754_1_0 -> 2260 in the cache */
   /* search754_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2260, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 32, 2277 },
      -1,
   } },

   /* replace754 -> 1224 in the cache */

   /* ('ige', ('imax', 'a', 'b'), 'a') => True */
   /* search755_0_0 -> 0 in the cache */
   /* search755_0_1 -> 3 in the cache */
   /* search755_0 -> 1290 in the cache */
   /* search755_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1290, 0 },
      -1,
   } },

   /* replace755 -> 1224 in the cache */

   /* ('ult', 'a', ('umax', 'b', 'a')) => ('ult', 'a', 'b') */
   /* search756_0 -> 32 in the cache */
   /* search756_1_0 -> 2260 in the cache */
   /* search756_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 2260, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 32, 2280 },
      -1,
   } },

   /* replace756_0 -> 32 in the cache */
   /* replace756_1 -> 2260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 2260 },
      -1,
   } },

   /* ('ult', ('umin', 'a', 'b'), 'a') => ('ult', 'b', 'a') */
   /* search757_0_0 -> 0 in the cache */
   /* search757_0_1 -> 3 in the cache */
   /* search757_0 -> 1282 in the cache */
   /* search757_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1282, 0 },
      -1,
   } },

   /* replace757_0 -> 3 in the cache */
   /* replace757_1 -> 0 in the cache */
   /* replace757 -> 1078 in the cache */

   /* ('uge', 'a', ('umin', 'b', 'a')) => True */
   /* search758_0 -> 32 in the cache */
   /* search758_1_0 -> 2260 in the cache */
   /* search758_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 2260, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 32, 2284 },
      -1,
   } },

   /* replace758 -> 1224 in the cache */

   /* ('uge', ('umax', 'a', 'b'), 'a') => True */
   /* search759_0_0 -> 0 in the cache */
   /* search759_0_1 -> 3 in the cache */
   /* search759_0 -> 1280 in the cache */
   /* search759_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1280, 0 },
      -1,
   } },

   /* replace759 -> 1224 in the cache */

   /* ('ilt', 'a', ('imin', 'b', 'a')) => False */
   /* search760_0 -> 32 in the cache */
   /* search760_1_0 -> 2260 in the cache */
   /* search760_1_1 -> 32 in the cache */
   /* search760_1 -> 2277 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 32, 2277 },
      -1,
   } },

   /* replace760 -> 1070 in the cache */

   /* ('ilt', ('imax', 'a', 'b'), 'a') => False */
   /* search761_0_0 -> 0 in the cache */
   /* search761_0_1 -> 3 in the cache */
   /* search761_0 -> 1290 in the cache */
   /* search761_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1290, 0 },
      -1,
   } },

   /* replace761 -> 1070 in the cache */

   /* ('ige', 'a', ('imax', 'b', 'a')) => ('ige', 'a', 'b') */
   /* search762_0 -> 32 in the cache */
   /* search762_1_0 -> 2260 in the cache */
   /* search762_1_1 -> 32 in the cache */
   /* search762_1 -> 2273 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 32, 2273 },
      -1,
   } },

   /* replace762_0 -> 32 in the cache */
   /* replace762_1 -> 2260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 32, 2260 },
      -1,
   } },

   /* ('ige', ('imin', 'a', 'b'), 'a') => ('ige', 'b', 'a') */
   /* search763_0_0 -> 0 in the cache */
   /* search763_0_1 -> 3 in the cache */
   /* search763_0 -> 1292 in the cache */
   /* search763_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1292, 0 },
      -1,
   } },

   /* replace763_0 -> 3 in the cache */
   /* replace763_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('ult', 'a', ('umin', 'b', 'a')) => False */
   /* search764_0 -> 32 in the cache */
   /* search764_1_0 -> 2260 in the cache */
   /* search764_1_1 -> 32 in the cache */
   /* search764_1 -> 2284 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 32, 2284 },
      -1,
   } },

   /* replace764 -> 1070 in the cache */

   /* ('ult', ('umax', 'a', 'b'), 'a') => False */
   /* search765_0_0 -> 0 in the cache */
   /* search765_0_1 -> 3 in the cache */
   /* search765_0 -> 1280 in the cache */
   /* search765_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1280, 0 },
      -1,
   } },

   /* replace765 -> 1070 in the cache */

   /* ('uge', 'a', ('umax', 'b', 'a')) => ('uge', 'a', 'b') */
   /* search766_0 -> 32 in the cache */
   /* search766_1_0 -> 2260 in the cache */
   /* search766_1_1 -> 32 in the cache */
   /* search766_1 -> 2280 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 32, 2280 },
      -1,
   } },

   /* replace766_0 -> 32 in the cache */
   /* replace766_1 -> 2260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 32, 2260 },
      -1,
   } },

   /* ('uge', ('umin', 'a', 'b'), 'a') => ('uge', 'b', 'a') */
   /* search767_0_0 -> 0 in the cache */
   /* search767_0_1 -> 3 in the cache */
   /* search767_0 -> 1282 in the cache */
   /* search767_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1282, 0 },
      -1,
   } },

   /* replace767_0 -> 3 in the cache */
   /* replace767_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('ult', 'a', ('iand', 'b', 'a')) => False */
   /* search768_0 -> 32 in the cache */
   /* search768_1_0 -> 2260 in the cache */
   /* search768_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2260, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 32, 2299 },
      -1,
   } },

   /* replace768 -> 1070 in the cache */

   /* ('ult', ('ior', 'a', 'b'), 'a') => False */
   /* search769_0_0 -> 0 in the cache */
   /* search769_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 0, 3 },
      -1,
   } },
   /* search769_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2301, 0 },
      -1,
   } },

   /* replace769 -> 1070 in the cache */

   /* ('uge', 'a', ('iand', 'b', 'a')) => True */
   /* search770_0 -> 32 in the cache */
   /* search770_1_0 -> 2260 in the cache */
   /* search770_1_1 -> 32 in the cache */
   /* search770_1 -> 2299 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 32, 2299 },
      -1,
   } },

   /* replace770 -> 1224 in the cache */

   /* ('uge', ('ior', 'a', 'b'), 'a') => True */
   /* search771_0_0 -> 0 in the cache */
   /* search771_0_1 -> 3 in the cache */
   /* search771_0 -> 2301 in the cache */
   /* search771_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2301, 0 },
      -1,
   } },

   /* replace771 -> 1224 in the cache */

   /* ('ilt', '#a', ('imax', '#b', 'c')) => ('ior', ('ilt', 'a', 'b'), ('ilt', 'a', 'c')) */
   /* search772_0 -> 284 in the cache */
   /* search772_1_0 -> 285 in the cache */
   /* search772_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 285, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 284, 2305 },
      -1,
   } },

   /* replace772_0_0 -> 128 in the cache */
   /* replace772_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 128, 129 },
      -1,
   } },
   /* replace772_1_0 -> 128 in the cache */
   /* replace772_1_1 -> 131 in the cache */
   /* replace772_1 -> 1649 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2307, 1649 },
      -1,
   } },

   /* ('ilt', ('imin', '#a', 'b'), '#c') => ('ior', ('ilt', 'a', 'c'), ('ilt', 'b', 'c')) */
   /* search773_0_0 -> 284 in the cache */
   /* search773_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 284, 129 },
      -1,
   } },
   /* search773_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 2309, 807 },
      -1,
   } },

   /* replace773_0_0 -> 128 in the cache */
   /* replace773_0_1 -> 131 in the cache */
   /* replace773_0 -> 1649 in the cache */
   /* replace773_1_0 -> 129 in the cache */
   /* replace773_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1649, 2311 },
      -1,
   } },

   /* ('ige', '#a', ('imin', '#b', 'c')) => ('ior', ('ige', 'a', 'b'), ('ige', 'a', 'c')) */
   /* search774_0 -> 284 in the cache */
   /* search774_1_0 -> 285 in the cache */
   /* search774_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 285, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 284, 2313 },
      -1,
   } },

   /* replace774_0_0 -> 128 in the cache */
   /* replace774_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 128, 129 },
      -1,
   } },
   /* replace774_1_0 -> 128 in the cache */
   /* replace774_1_1 -> 131 in the cache */
   /* replace774_1 -> 1659 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2315, 1659 },
      -1,
   } },

   /* ('ige', ('imax', '#a', 'b'), '#c') => ('ior', ('ige', 'a', 'c'), ('ige', 'b', 'c')) */
   /* search775_0_0 -> 284 in the cache */
   /* search775_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 284, 129 },
      -1,
   } },
   /* search775_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 2317, 807 },
      -1,
   } },

   /* replace775_0_0 -> 128 in the cache */
   /* replace775_0_1 -> 131 in the cache */
   /* replace775_0 -> 1659 in the cache */
   /* replace775_1_0 -> 129 in the cache */
   /* replace775_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1659, 2319 },
      -1,
   } },

   /* ('ult', '#a', ('umax', '#b', 'c')) => ('ior', ('ult', 'a', 'b'), ('ult', 'a', 'c')) */
   /* search776_0 -> 284 in the cache */
   /* search776_1_0 -> 285 in the cache */
   /* search776_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 285, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 284, 2321 },
      -1,
   } },

   /* replace776_0_0 -> 128 in the cache */
   /* replace776_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 128, 129 },
      -1,
   } },
   /* replace776_1_0 -> 128 in the cache */
   /* replace776_1_1 -> 131 in the cache */
   /* replace776_1 -> 1669 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2323, 1669 },
      -1,
   } },

   /* ('ult', ('umin', '#a', 'b'), '#c') => ('ior', ('ult', 'a', 'c'), ('ult', 'b', 'c')) */
   /* search777_0_0 -> 284 in the cache */
   /* search777_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 284, 129 },
      -1,
   } },
   /* search777_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2325, 807 },
      -1,
   } },

   /* replace777_0_0 -> 128 in the cache */
   /* replace777_0_1 -> 131 in the cache */
   /* replace777_0 -> 1669 in the cache */
   /* replace777_1_0 -> 129 in the cache */
   /* replace777_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1669, 2327 },
      -1,
   } },

   /* ('uge', '#a', ('umin', '#b', 'c')) => ('ior', ('uge', 'a', 'b'), ('uge', 'a', 'c')) */
   /* search778_0 -> 284 in the cache */
   /* search778_1_0 -> 285 in the cache */
   /* search778_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 285, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 284, 2329 },
      -1,
   } },

   /* replace778_0_0 -> 128 in the cache */
   /* replace778_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 128, 129 },
      -1,
   } },
   /* replace778_1_0 -> 128 in the cache */
   /* replace778_1_1 -> 131 in the cache */
   /* replace778_1 -> 1679 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2331, 1679 },
      -1,
   } },

   /* ('uge', ('umax', '#a', 'b'), '#c') => ('ior', ('uge', 'a', 'c'), ('uge', 'b', 'c')) */
   /* search779_0_0 -> 284 in the cache */
   /* search779_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 284, 129 },
      -1,
   } },
   /* search779_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2333, 807 },
      -1,
   } },

   /* replace779_0_0 -> 128 in the cache */
   /* replace779_0_1 -> 131 in the cache */
   /* replace779_0 -> 1679 in the cache */
   /* replace779_1_0 -> 129 in the cache */
   /* replace779_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 129, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1679, 2335 },
      -1,
   } },

   /* ('ilt', '#a', ('imin', '#b', 'c')) => ('iand', ('ilt', 'a', 'b'), ('ilt', 'a', 'c')) */
   /* search780_0 -> 284 in the cache */
   /* search780_1_0 -> 285 in the cache */
   /* search780_1_1 -> 131 in the cache */
   /* search780_1 -> 2313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 284, 2313 },
      -1,
   } },

   /* replace780_0_0 -> 128 in the cache */
   /* replace780_0_1 -> 129 in the cache */
   /* replace780_0 -> 2307 in the cache */
   /* replace780_1_0 -> 128 in the cache */
   /* replace780_1_1 -> 131 in the cache */
   /* replace780_1 -> 1649 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2307, 1649 },
      -1,
   } },

   /* ('ilt', ('imax', '#a', 'b'), '#c') => ('iand', ('ilt', 'a', 'c'), ('ilt', 'b', 'c')) */
   /* search781_0_0 -> 284 in the cache */
   /* search781_0_1 -> 129 in the cache */
   /* search781_0 -> 2317 in the cache */
   /* search781_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 2317, 807 },
      -1,
   } },

   /* replace781_0_0 -> 128 in the cache */
   /* replace781_0_1 -> 131 in the cache */
   /* replace781_0 -> 1649 in the cache */
   /* replace781_1_0 -> 129 in the cache */
   /* replace781_1_1 -> 131 in the cache */
   /* replace781_1 -> 2311 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1649, 2311 },
      -1,
   } },

   /* ('ige', '#a', ('imax', '#b', 'c')) => ('iand', ('ige', 'a', 'b'), ('ige', 'a', 'c')) */
   /* search782_0 -> 284 in the cache */
   /* search782_1_0 -> 285 in the cache */
   /* search782_1_1 -> 131 in the cache */
   /* search782_1 -> 2305 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 284, 2305 },
      -1,
   } },

   /* replace782_0_0 -> 128 in the cache */
   /* replace782_0_1 -> 129 in the cache */
   /* replace782_0 -> 2315 in the cache */
   /* replace782_1_0 -> 128 in the cache */
   /* replace782_1_1 -> 131 in the cache */
   /* replace782_1 -> 1659 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2315, 1659 },
      -1,
   } },

   /* ('ige', ('imin', '#a', 'b'), '#c') => ('iand', ('ige', 'a', 'c'), ('ige', 'b', 'c')) */
   /* search783_0_0 -> 284 in the cache */
   /* search783_0_1 -> 129 in the cache */
   /* search783_0 -> 2309 in the cache */
   /* search783_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 2309, 807 },
      -1,
   } },

   /* replace783_0_0 -> 128 in the cache */
   /* replace783_0_1 -> 131 in the cache */
   /* replace783_0 -> 1659 in the cache */
   /* replace783_1_0 -> 129 in the cache */
   /* replace783_1_1 -> 131 in the cache */
   /* replace783_1 -> 2319 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1659, 2319 },
      -1,
   } },

   /* ('ult', '#a', ('umin', '#b', 'c')) => ('iand', ('ult', 'a', 'b'), ('ult', 'a', 'c')) */
   /* search784_0 -> 284 in the cache */
   /* search784_1_0 -> 285 in the cache */
   /* search784_1_1 -> 131 in the cache */
   /* search784_1 -> 2329 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 284, 2329 },
      -1,
   } },

   /* replace784_0_0 -> 128 in the cache */
   /* replace784_0_1 -> 129 in the cache */
   /* replace784_0 -> 2323 in the cache */
   /* replace784_1_0 -> 128 in the cache */
   /* replace784_1_1 -> 131 in the cache */
   /* replace784_1 -> 1669 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2323, 1669 },
      -1,
   } },

   /* ('ult', ('umax', '#a', 'b'), '#c') => ('iand', ('ult', 'a', 'c'), ('ult', 'b', 'c')) */
   /* search785_0_0 -> 284 in the cache */
   /* search785_0_1 -> 129 in the cache */
   /* search785_0 -> 2333 in the cache */
   /* search785_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2333, 807 },
      -1,
   } },

   /* replace785_0_0 -> 128 in the cache */
   /* replace785_0_1 -> 131 in the cache */
   /* replace785_0 -> 1669 in the cache */
   /* replace785_1_0 -> 129 in the cache */
   /* replace785_1_1 -> 131 in the cache */
   /* replace785_1 -> 2327 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1669, 2327 },
      -1,
   } },

   /* ('uge', '#a', ('umax', '#b', 'c')) => ('iand', ('uge', 'a', 'b'), ('uge', 'a', 'c')) */
   /* search786_0 -> 284 in the cache */
   /* search786_1_0 -> 285 in the cache */
   /* search786_1_1 -> 131 in the cache */
   /* search786_1 -> 2321 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 284, 2321 },
      -1,
   } },

   /* replace786_0_0 -> 128 in the cache */
   /* replace786_0_1 -> 129 in the cache */
   /* replace786_0 -> 2331 in the cache */
   /* replace786_1_0 -> 128 in the cache */
   /* replace786_1_1 -> 131 in the cache */
   /* replace786_1 -> 1679 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2331, 1679 },
      -1,
   } },

   /* ('uge', ('umin', '#a', 'b'), '#c') => ('iand', ('uge', 'a', 'c'), ('uge', 'b', 'c')) */
   /* search787_0_0 -> 284 in the cache */
   /* search787_0_1 -> 129 in the cache */
   /* search787_0 -> 2325 in the cache */
   /* search787_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2325, 807 },
      -1,
   } },

   /* replace787_0_0 -> 128 in the cache */
   /* replace787_0_1 -> 131 in the cache */
   /* replace787_0 -> 1679 in the cache */
   /* replace787_1_0 -> 129 in the cache */
   /* replace787_1_1 -> 131 in the cache */
   /* replace787_1 -> 2335 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1679, 2335 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a', 0), ('ineg', ('ishr', 'a', 'b')), ('ishr', 'a', 'b')) => ('iabs', ('ishr', 'a', 'b')) */
   /* search788_0_0 -> 32 in the cache */
   /* search788_0_1 -> 61 in the cache */
   /* search788_0 -> 1238 in the cache */
   /* search788_1_0_0 -> 32 in the cache */
   /* search788_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 32, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2353 },
      -1,
   } },
   /* search788_2_0 -> 32 in the cache */
   /* search788_2_1 -> 36 in the cache */
   /* search788_2 -> 2353 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1238, 2354, 2353 },
      -1,
   } },

   /* replace788_0_0 -> 32 in the cache */
   /* replace788_0_1 -> 36 in the cache */
   /* replace788_0 -> 2353 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 2353 },
      -1,
   } },

   /* ('iabs', ('ishr', ('iabs', 'a'), 'b')) => ('ishr', ('iabs', 'a'), 'b') */
   /* search789_0_0_0 -> 32 in the cache */
   /* search789_0_0 -> 106 in the cache */
   /* search789_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 106, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 2357 },
      -1,
   } },

   /* replace789_0_0 -> 32 in the cache */
   /* replace789_0 -> 106 in the cache */
   /* replace789_1 -> 36 in the cache */
   /* replace789 -> 2357 in the cache */

   /* ('fabs', ('slt', 'a', 'b')) => ('slt', 'a', 'b') */
   /* search790_0_0 -> 0 in the cache */
   /* search790_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2359 },
      -1,
   } },

   /* replace790_0 -> 0 in the cache */
   /* replace790_1 -> 3 in the cache */
   /* replace790 -> 2359 in the cache */

   /* ('fabs', ('sge', 'a', 'b')) => ('sge', 'a', 'b') */
   /* search791_0_0 -> 0 in the cache */
   /* search791_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2361 },
      -1,
   } },

   /* replace791_0 -> 0 in the cache */
   /* replace791_1 -> 3 in the cache */
   /* replace791 -> 2361 in the cache */

   /* ('fabs', ('seq', 'a', 'b')) => ('seq', 'a', 'b') */
   /* search792_0_0 -> 0 in the cache */
   /* search792_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 2363 },
      -1,
   } },

   /* replace792_0 -> 0 in the cache */
   /* replace792_1 -> 3 in the cache */
   /* replace792 -> 2363 in the cache */

   /* ('fabs', ('sne', 'a', 'b')) => ('sne', 'a', 'b') */
   /* search793_0_0 -> 0 in the cache */
   /* search793_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 2365 },
      -1,
   } },

   /* replace793_0 -> 0 in the cache */
   /* replace793_1 -> 3 in the cache */
   /* replace793 -> 2365 in the cache */

   /* ('slt', 'a', 'b') => ('b2f', ('flt', 'a', 'b')) */
   /* search794_0 -> 0 in the cache */
   /* search794_1 -> 3 in the cache */
   /* search794 -> 2359 in the cache */

   /* replace794_0_0 -> 0 in the cache */
   /* replace794_0_1 -> 3 in the cache */
   /* replace794_0 -> 1042 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1042 },
      -1,
   } },

   /* ('sge', 'a', 'b') => ('b2f', ('fge', 'a', 'b')) */
   /* search795_0 -> 0 in the cache */
   /* search795_1 -> 3 in the cache */
   /* search795 -> 2361 in the cache */

   /* replace795_0_0 -> 0 in the cache */
   /* replace795_0_1 -> 3 in the cache */
   /* replace795_0 -> 1039 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1039 },
      -1,
   } },

   /* ('seq', 'a', 'b') => ('b2f', ('feq', 'a', 'b')) */
   /* search796_0 -> 0 in the cache */
   /* search796_1 -> 3 in the cache */
   /* search796 -> 2363 in the cache */

   /* replace796_0_0 -> 0 in the cache */
   /* replace796_0_1 -> 3 in the cache */
   /* replace796_0 -> 1048 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1048 },
      -1,
   } },

   /* ('sne', 'a', 'b') => ('b2f', ('fneu', 'a', 'b')) */
   /* search797_0 -> 0 in the cache */
   /* search797_1 -> 3 in the cache */
   /* search797 -> 2365 in the cache */

   /* replace797_0_0 -> 0 in the cache */
   /* replace797_0_1 -> 3 in the cache */
   /* replace797_0 -> 1045 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1045 },
      -1,
   } },

   /* ('seq', ('seq', 'a', 'b'), 1.0) => ('seq', 'a', 'b') */
   /* search798_0_0 -> 0 in the cache */
   /* search798_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search798_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2371, 272 },
      -1,
   } },

   /* replace798_0 -> 0 in the cache */
   /* replace798_1 -> 3 in the cache */
   /* replace798 -> 2363 in the cache */

   /* ('seq', ('sne', 'a', 'b'), 1.0) => ('sne', 'a', 'b') */
   /* search799_0_0 -> 0 in the cache */
   /* search799_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search799_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2373, 272 },
      -1,
   } },

   /* replace799_0 -> 0 in the cache */
   /* replace799_1 -> 3 in the cache */
   /* replace799 -> 2365 in the cache */

   /* ('seq', ('slt', 'a', 'b'), 1.0) => ('slt', 'a', 'b') */
   /* search800_0_0 -> 0 in the cache */
   /* search800_0_1 -> 3 in the cache */
   /* search800_0 -> 2359 in the cache */
   /* search800_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2359, 272 },
      -1,
   } },

   /* replace800_0 -> 0 in the cache */
   /* replace800_1 -> 3 in the cache */
   /* replace800 -> 2359 in the cache */

   /* ('seq', ('sge', 'a', 'b'), 1.0) => ('sge', 'a', 'b') */
   /* search801_0_0 -> 0 in the cache */
   /* search801_0_1 -> 3 in the cache */
   /* search801_0 -> 2361 in the cache */
   /* search801_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2361, 272 },
      -1,
   } },

   /* replace801_0 -> 0 in the cache */
   /* replace801_1 -> 3 in the cache */
   /* replace801 -> 2361 in the cache */

   /* ('sne', ('seq', 'a', 'b'), 0.0) => ('seq', 'a', 'b') */
   /* search802_0_0 -> 0 in the cache */
   /* search802_0_1 -> 3 in the cache */
   /* search802_0 -> 2371 in the cache */
   /* search802_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2371, 258 },
      -1,
   } },

   /* replace802_0 -> 0 in the cache */
   /* replace802_1 -> 3 in the cache */
   /* replace802 -> 2363 in the cache */

   /* ('sne', ('sne', 'a', 'b'), 0.0) => ('sne', 'a', 'b') */
   /* search803_0_0 -> 0 in the cache */
   /* search803_0_1 -> 3 in the cache */
   /* search803_0 -> 2373 in the cache */
   /* search803_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2373, 258 },
      -1,
   } },

   /* replace803_0 -> 0 in the cache */
   /* replace803_1 -> 3 in the cache */
   /* replace803 -> 2365 in the cache */

   /* ('sne', ('slt', 'a', 'b'), 0.0) => ('slt', 'a', 'b') */
   /* search804_0_0 -> 0 in the cache */
   /* search804_0_1 -> 3 in the cache */
   /* search804_0 -> 2359 in the cache */
   /* search804_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2359, 258 },
      -1,
   } },

   /* replace804_0 -> 0 in the cache */
   /* replace804_1 -> 3 in the cache */
   /* replace804 -> 2359 in the cache */

   /* ('sne', ('sge', 'a', 'b'), 0.0) => ('sge', 'a', 'b') */
   /* search805_0_0 -> 0 in the cache */
   /* search805_0_1 -> 3 in the cache */
   /* search805_0 -> 2361 in the cache */
   /* search805_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2361, 258 },
      -1,
   } },

   /* replace805_0 -> 0 in the cache */
   /* replace805_1 -> 3 in the cache */
   /* replace805 -> 2361 in the cache */

   /* ('seq', ('seq', 'a', 'b'), 0.0) => ('sne', 'a', 'b') */
   /* search806_0_0 -> 0 in the cache */
   /* search806_0_1 -> 3 in the cache */
   /* search806_0 -> 2371 in the cache */
   /* search806_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2371, 258 },
      -1,
   } },

   /* replace806_0 -> 0 in the cache */
   /* replace806_1 -> 3 in the cache */
   /* replace806 -> 2365 in the cache */

   /* ('seq', ('sne', 'a', 'b'), 0.0) => ('seq', 'a', 'b') */
   /* search807_0_0 -> 0 in the cache */
   /* search807_0_1 -> 3 in the cache */
   /* search807_0 -> 2373 in the cache */
   /* search807_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2373, 258 },
      -1,
   } },

   /* replace807_0 -> 0 in the cache */
   /* replace807_1 -> 3 in the cache */
   /* replace807 -> 2363 in the cache */

   /* ('seq', ('slt', 'a', 'b'), 0.0) => ('sge', 'a', 'b') */
   /* search808_0_0 -> 0 in the cache */
   /* search808_0_1 -> 3 in the cache */
   /* search808_0 -> 2359 in the cache */
   /* search808_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2359, 258 },
      -1,
   } },

   /* replace808_0 -> 0 in the cache */
   /* replace808_1 -> 3 in the cache */
   /* replace808 -> 2361 in the cache */

   /* ('seq', ('sge', 'a', 'b'), 0.0) => ('slt', 'a', 'b') */
   /* search809_0_0 -> 0 in the cache */
   /* search809_0_1 -> 3 in the cache */
   /* search809_0 -> 2361 in the cache */
   /* search809_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2361, 258 },
      -1,
   } },

   /* replace809_0 -> 0 in the cache */
   /* replace809_1 -> 3 in the cache */
   /* replace809 -> 2359 in the cache */

   /* ('sne', ('seq', 'a', 'b'), 1.0) => ('sne', 'a', 'b') */
   /* search810_0_0 -> 0 in the cache */
   /* search810_0_1 -> 3 in the cache */
   /* search810_0 -> 2371 in the cache */
   /* search810_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2371, 272 },
      -1,
   } },

   /* replace810_0 -> 0 in the cache */
   /* replace810_1 -> 3 in the cache */
   /* replace810 -> 2365 in the cache */

   /* ('sne', ('sne', 'a', 'b'), 1.0) => ('seq', 'a', 'b') */
   /* search811_0_0 -> 0 in the cache */
   /* search811_0_1 -> 3 in the cache */
   /* search811_0 -> 2373 in the cache */
   /* search811_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2373, 272 },
      -1,
   } },

   /* replace811_0 -> 0 in the cache */
   /* replace811_1 -> 3 in the cache */
   /* replace811 -> 2363 in the cache */

   /* ('sne', ('slt', 'a', 'b'), 1.0) => ('sge', 'a', 'b') */
   /* search812_0_0 -> 0 in the cache */
   /* search812_0_1 -> 3 in the cache */
   /* search812_0 -> 2359 in the cache */
   /* search812_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2359, 272 },
      -1,
   } },

   /* replace812_0 -> 0 in the cache */
   /* replace812_1 -> 3 in the cache */
   /* replace812 -> 2361 in the cache */

   /* ('sne', ('sge', 'a', 'b'), 1.0) => ('slt', 'a', 'b') */
   /* search813_0_0 -> 0 in the cache */
   /* search813_0_1 -> 3 in the cache */
   /* search813_0 -> 2361 in the cache */
   /* search813_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2361, 272 },
      -1,
   } },

   /* replace813_0 -> 0 in the cache */
   /* replace813_1 -> 3 in the cache */
   /* replace813 -> 2359 in the cache */

   /* ('fall_equal2', 'a', 'b') => ('fmin', ('seq', 'a.x', 'b.x'), ('seq', 'a.y', 'b.y')) */
   /* search814_0 -> 16 in the cache */
   /* search814_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal2,
      0, 1,
      { 16, 36 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2390, 2391 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      1, 1,
      { 2393, 2394 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      -1, 2,
      { 2392, 2395 },
      -1,
   } },

   /* ('fall_equal3', 'a', 'b') => ('seq', ('fany_nequal3', 'a', 'b'), 0.0) */
   /* search815_0 -> 16 in the cache */
   /* search815_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal3,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace815_0_0 -> 16 in the cache */
   /* replace815_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal3,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace815_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2398, 117 },
      -1,
   } },

   /* ('fall_equal4', 'a', 'b') => ('seq', ('fany_nequal4', 'a', 'b'), 0.0) */
   /* search816_0 -> 16 in the cache */
   /* search816_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal4,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace816_0_0 -> 16 in the cache */
   /* replace816_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal4,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace816_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2401, 117 },
      -1,
   } },

   /* ('fall_equal8', 'a', 'b') => ('seq', ('fany_nequal8', 'a', 'b'), 0.0) */
   /* search817_0 -> 16 in the cache */
   /* search817_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal8,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace817_0_0 -> 16 in the cache */
   /* replace817_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal8,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace817_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2404, 117 },
      -1,
   } },

   /* ('fall_equal16', 'a', 'b') => ('seq', ('fany_nequal16', 'a', 'b'), 0.0) */
   /* search818_0 -> 16 in the cache */
   /* search818_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal16,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace818_0_0 -> 16 in the cache */
   /* replace818_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal16,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace818_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2407, 117 },
      -1,
   } },

   /* ('fany_nequal2', 'a', 'b') => ('fmax', ('sne', 'a.x', 'b.x'), ('sne', 'a.y', 'b.y')) */
   /* search819_0 -> 16 in the cache */
   /* search819_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal2,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace819_0_0 -> 2390 in the cache */
   /* replace819_0_1 -> 2391 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2390, 2391 },
      -1,
   } },
   /* replace819_1_0 -> 2393 in the cache */
   /* replace819_1_1 -> 2394 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 2393, 2394 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      -1, 2,
      { 2410, 2411 },
      -1,
   } },

   /* ('fany_nequal3', 'a', 'b') => ('fsat', ('fdot3', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search820_0 -> 16 in the cache */
   /* search820_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal3,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace820_0_0_0 -> 16 in the cache */
   /* replace820_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 16, 36 },
      -1,
   } },
   /* replace820_0_1_0 -> 16 in the cache */
   /* replace820_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdot3,
      -1, 2,
      { 2414, 2415 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2416 },
      -1,
   } },

   /* ('fany_nequal4', 'a', 'b') => ('fsat', ('fdot4', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search821_0 -> 16 in the cache */
   /* search821_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal4,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace821_0_0_0 -> 16 in the cache */
   /* replace821_0_0_1 -> 36 in the cache */
   /* replace821_0_0 -> 2414 in the cache */
   /* replace821_0_1_0 -> 16 in the cache */
   /* replace821_0_1_1 -> 36 in the cache */
   /* replace821_0_1 -> 2415 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdot4,
      -1, 2,
      { 2414, 2415 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2419 },
      -1,
   } },

   /* ('fany_nequal8', 'a', 'b') => ('fsat', ('fdot8', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search822_0 -> 16 in the cache */
   /* search822_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal8,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace822_0_0_0 -> 16 in the cache */
   /* replace822_0_0_1 -> 36 in the cache */
   /* replace822_0_0 -> 2414 in the cache */
   /* replace822_0_1_0 -> 16 in the cache */
   /* replace822_0_1_1 -> 36 in the cache */
   /* replace822_0_1 -> 2415 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdot8,
      -1, 2,
      { 2414, 2415 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2422 },
      -1,
   } },

   /* ('fany_nequal16', 'a', 'b') => ('fsat', ('fdot16', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search823_0 -> 16 in the cache */
   /* search823_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal16,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace823_0_0_0 -> 16 in the cache */
   /* replace823_0_0_1 -> 36 in the cache */
   /* replace823_0_0 -> 2414 in the cache */
   /* replace823_0_1_0 -> 16 in the cache */
   /* replace823_0_1_1 -> 36 in the cache */
   /* replace823_0_1 -> 2415 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdot16,
      -1, 2,
      { 2414, 2415 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2425 },
      -1,
   } },

   /* ('ball_iequal2', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')) */
   /* search824_0 -> 0 in the cache */
   /* search824_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace824_0_0 -> 762 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 762, 2428 },
      -1,
   } },
   /* replace824_1_0 -> 763 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 763, 2430 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2429, 2431 },
      -1,
   } },

   /* ('ball_iequal3', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('iand', ('ieq', 'a.y', 'b.y'), ('ieq', 'a.z', 'b.z'))) */
   /* search825_0 -> 0 in the cache */
   /* search825_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace825_0_0 -> 762 in the cache */
   /* replace825_0_1 -> 2428 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 762, 2428 },
      -1,
   } },
   /* replace825_1_0_0 -> 763 in the cache */
   /* replace825_1_0_1 -> 2430 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 763, 2430 },
      -1,
   } },
   /* replace825_1_1_0 -> 764 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {2},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 764, 2436 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2435, 2437 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2434, 2438 },
      -1,
   } },

   /* ('ball_iequal4', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('iand', ('ieq', 'a.z', 'b.z'), ('ieq', 'a.w', 'b.w'))) */
   /* search826_0 -> 0 in the cache */
   /* search826_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace826_0_0_0 -> 762 in the cache */
   /* replace826_0_0_1 -> 2428 in the cache */
   /* replace826_0_0 -> 2429 in the cache */
   /* replace826_0_1_0 -> 763 in the cache */
   /* replace826_0_1_1 -> 2430 in the cache */
   /* replace826_0_1 -> 2431 in the cache */
   /* replace826_0 -> 2432 in the cache */
   /* replace826_1_0_0 -> 764 in the cache */
   /* replace826_1_0_1 -> 2436 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 764, 2436 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {3},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {3},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 2442, 2443 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2441, 2444 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2432, 2445 },
      -1,
   } },

   /* ('ball_iequal8', 'a', 'b') => ('iand', ('iand', ('iand', ('ieq', 'a.a', 'b.a'), ('ieq', 'a.b', 'b.b')), ('iand', ('ieq', 'a.c', 'b.c'), ('ieq', 'a.d', 'b.d'))), ('iand', ('iand', ('ieq', 'a.e', 'b.e'), ('ieq', 'a.f', 'b.f')), ('iand', ('ieq', 'a.g', 'b.g'), ('ieq', 'a.h', 'b.h')))) */
   /* search827_0 -> 0 in the cache */
   /* search827_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace827_0_0_0_0 -> 762 in the cache */
   /* replace827_0_0_0_1 -> 2428 in the cache */
   /* replace827_0_0_0 -> 2429 in the cache */
   /* replace827_0_0_1_0 -> 763 in the cache */
   /* replace827_0_0_1_1 -> 2430 in the cache */
   /* replace827_0_0_1 -> 2431 in the cache */
   /* replace827_0_0 -> 2432 in the cache */
   /* replace827_0_1_0_0 -> 764 in the cache */
   /* replace827_0_1_0_1 -> 2436 in the cache */
   /* replace827_0_1_0 -> 2441 in the cache */
   /* replace827_0_1_1_0 -> 2442 in the cache */
   /* replace827_0_1_1_1 -> 2443 in the cache */
   /* replace827_0_1_1 -> 2444 in the cache */
   /* replace827_0_1 -> 2445 in the cache */
   /* replace827_0 -> 2446 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {4},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {4},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      4, 1,
      { 2448, 2449 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {5},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {5},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      5, 1,
      { 2451, 2452 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2450, 2453 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {6},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {6},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      6, 1,
      { 2455, 2456 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {7},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {7},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      7, 1,
      { 2458, 2459 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2457, 2460 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2454, 2461 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 8,
      { 2446, 2462 },
      -1,
   } },

   /* ('ball_iequal16', 'a', 'b') => ('iand', ('iand', ('iand', ('iand', ('ieq', 'a.a', 'b.a'), ('ieq', 'a.b', 'b.b')), ('iand', ('ieq', 'a.c', 'b.c'), ('ieq', 'a.d', 'b.d'))), ('iand', ('iand', ('ieq', 'a.e', 'b.e'), ('ieq', 'a.f', 'b.f')), ('iand', ('ieq', 'a.g', 'b.g'), ('ieq', 'a.h', 'b.h')))), ('iand', ('iand', ('iand', ('ieq', 'a.i', 'b.i'), ('ieq', 'a.j', 'b.j')), ('iand', ('ieq', 'a.k', 'b.k'), ('ieq', 'a.l', 'b.l'))), ('iand', ('iand', ('ieq', 'a.m', 'b.m'), ('ieq', 'a.n', 'b.n')), ('iand', ('ieq', 'a.o', 'b.o'), ('ieq', 'a.p', 'b.p'))))) */
   /* search828_0 -> 0 in the cache */
   /* search828_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace828_0_0_0_0_0 -> 762 in the cache */
   /* replace828_0_0_0_0_1 -> 2428 in the cache */
   /* replace828_0_0_0_0 -> 2429 in the cache */
   /* replace828_0_0_0_1_0 -> 763 in the cache */
   /* replace828_0_0_0_1_1 -> 2430 in the cache */
   /* replace828_0_0_0_1 -> 2431 in the cache */
   /* replace828_0_0_0 -> 2432 in the cache */
   /* replace828_0_0_1_0_0 -> 764 in the cache */
   /* replace828_0_0_1_0_1 -> 2436 in the cache */
   /* replace828_0_0_1_0 -> 2441 in the cache */
   /* replace828_0_0_1_1_0 -> 2442 in the cache */
   /* replace828_0_0_1_1_1 -> 2443 in the cache */
   /* replace828_0_0_1_1 -> 2444 in the cache */
   /* replace828_0_0_1 -> 2445 in the cache */
   /* replace828_0_0 -> 2446 in the cache */
   /* replace828_0_1_0_0_0 -> 2448 in the cache */
   /* replace828_0_1_0_0_1 -> 2449 in the cache */
   /* replace828_0_1_0_0 -> 2450 in the cache */
   /* replace828_0_1_0_1_0 -> 2451 in the cache */
   /* replace828_0_1_0_1_1 -> 2452 in the cache */
   /* replace828_0_1_0_1 -> 2453 in the cache */
   /* replace828_0_1_0 -> 2454 in the cache */
   /* replace828_0_1_1_0_0 -> 2455 in the cache */
   /* replace828_0_1_1_0_1 -> 2456 in the cache */
   /* replace828_0_1_1_0 -> 2457 in the cache */
   /* replace828_0_1_1_1_0 -> 2458 in the cache */
   /* replace828_0_1_1_1_1 -> 2459 in the cache */
   /* replace828_0_1_1_1 -> 2460 in the cache */
   /* replace828_0_1_1 -> 2461 in the cache */
   /* replace828_0_1 -> 2462 in the cache */
   /* replace828_0 -> 2463 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {8},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {8},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      8, 1,
      { 2465, 2466 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {9},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {9},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      9, 1,
      { 2468, 2469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2467, 2470 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {10},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {10},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      10, 1,
      { 2472, 2473 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {11},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {11},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      11, 1,
      { 2475, 2476 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2474, 2477 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2471, 2478 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {12},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {12},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      12, 1,
      { 2480, 2481 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {13},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {13},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      13, 1,
      { 2483, 2484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2482, 2485 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {14},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {14},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      14, 1,
      { 2487, 2488 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      15, 1,
      { 2490, 2491 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2489, 2492 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2486, 2493 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 8,
      { 2479, 2494 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 16,
      { 2463, 2495 },
      -1,
   } },

   /* ('ball_fequal2', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')) */
   /* search829_0 -> 0 in the cache */
   /* search829_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace829_0_0 -> 762 in the cache */
   /* replace829_0_1 -> 2428 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 762, 2428 },
      -1,
   } },
   /* replace829_1_0 -> 763 in the cache */
   /* replace829_1_1 -> 2430 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 763, 2430 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2498, 2499 },
      -1,
   } },

   /* ('ball_fequal3', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('iand', ('feq', 'a.y', 'b.y'), ('feq', 'a.z', 'b.z'))) */
   /* search830_0 -> 0 in the cache */
   /* search830_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace830_0_0 -> 762 in the cache */
   /* replace830_0_1 -> 2428 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 762, 2428 },
      -1,
   } },
   /* replace830_1_0_0 -> 763 in the cache */
   /* replace830_1_0_1 -> 2430 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 763, 2430 },
      -1,
   } },
   /* replace830_1_1_0 -> 764 in the cache */
   /* replace830_1_1_1 -> 2436 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      3, 1,
      { 764, 2436 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2503, 2504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2502, 2505 },
      -1,
   } },

   /* ('ball_fequal4', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('iand', ('feq', 'a.z', 'b.z'), ('feq', 'a.w', 'b.w'))) */
   /* search831_0 -> 0 in the cache */
   /* search831_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace831_0_0_0 -> 762 in the cache */
   /* replace831_0_0_1 -> 2428 in the cache */
   /* replace831_0_0 -> 2498 in the cache */
   /* replace831_0_1_0 -> 763 in the cache */
   /* replace831_0_1_1 -> 2430 in the cache */
   /* replace831_0_1 -> 2499 in the cache */
   /* replace831_0 -> 2500 in the cache */
   /* replace831_1_0_0 -> 764 in the cache */
   /* replace831_1_0_1 -> 2436 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 764, 2436 },
      -1,
   } },
   /* replace831_1_1_0 -> 2442 in the cache */
   /* replace831_1_1_1 -> 2443 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      3, 1,
      { 2442, 2443 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2508, 2509 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2500, 2510 },
      -1,
   } },

   /* ('ball_fequal8', 'a', 'b') => ('iand', ('iand', ('iand', ('feq', 'a.a', 'b.a'), ('feq', 'a.b', 'b.b')), ('iand', ('feq', 'a.c', 'b.c'), ('feq', 'a.d', 'b.d'))), ('iand', ('iand', ('feq', 'a.e', 'b.e'), ('feq', 'a.f', 'b.f')), ('iand', ('feq', 'a.g', 'b.g'), ('feq', 'a.h', 'b.h')))) */
   /* search832_0 -> 0 in the cache */
   /* search832_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace832_0_0_0_0 -> 762 in the cache */
   /* replace832_0_0_0_1 -> 2428 in the cache */
   /* replace832_0_0_0 -> 2498 in the cache */
   /* replace832_0_0_1_0 -> 763 in the cache */
   /* replace832_0_0_1_1 -> 2430 in the cache */
   /* replace832_0_0_1 -> 2499 in the cache */
   /* replace832_0_0 -> 2500 in the cache */
   /* replace832_0_1_0_0 -> 764 in the cache */
   /* replace832_0_1_0_1 -> 2436 in the cache */
   /* replace832_0_1_0 -> 2508 in the cache */
   /* replace832_0_1_1_0 -> 2442 in the cache */
   /* replace832_0_1_1_1 -> 2443 in the cache */
   /* replace832_0_1_1 -> 2509 in the cache */
   /* replace832_0_1 -> 2510 in the cache */
   /* replace832_0 -> 2511 in the cache */
   /* replace832_1_0_0_0 -> 2448 in the cache */
   /* replace832_1_0_0_1 -> 2449 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      4, 1,
      { 2448, 2449 },
      -1,
   } },
   /* replace832_1_0_1_0 -> 2451 in the cache */
   /* replace832_1_0_1_1 -> 2452 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      5, 1,
      { 2451, 2452 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2513, 2514 },
      -1,
   } },
   /* replace832_1_1_0_0 -> 2455 in the cache */
   /* replace832_1_1_0_1 -> 2456 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      6, 1,
      { 2455, 2456 },
      -1,
   } },
   /* replace832_1_1_1_0 -> 2458 in the cache */
   /* replace832_1_1_1_1 -> 2459 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      7, 1,
      { 2458, 2459 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2516, 2517 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2515, 2518 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 8,
      { 2511, 2519 },
      -1,
   } },

   /* ('ball_fequal16', 'a', 'b') => ('iand', ('iand', ('iand', ('iand', ('feq', 'a.a', 'b.a'), ('feq', 'a.b', 'b.b')), ('iand', ('feq', 'a.c', 'b.c'), ('feq', 'a.d', 'b.d'))), ('iand', ('iand', ('feq', 'a.e', 'b.e'), ('feq', 'a.f', 'b.f')), ('iand', ('feq', 'a.g', 'b.g'), ('feq', 'a.h', 'b.h')))), ('iand', ('iand', ('iand', ('feq', 'a.i', 'b.i'), ('feq', 'a.j', 'b.j')), ('iand', ('feq', 'a.k', 'b.k'), ('feq', 'a.l', 'b.l'))), ('iand', ('iand', ('feq', 'a.m', 'b.m'), ('feq', 'a.n', 'b.n')), ('iand', ('feq', 'a.o', 'b.o'), ('feq', 'a.p', 'b.p'))))) */
   /* search833_0 -> 0 in the cache */
   /* search833_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace833_0_0_0_0_0 -> 762 in the cache */
   /* replace833_0_0_0_0_1 -> 2428 in the cache */
   /* replace833_0_0_0_0 -> 2498 in the cache */
   /* replace833_0_0_0_1_0 -> 763 in the cache */
   /* replace833_0_0_0_1_1 -> 2430 in the cache */
   /* replace833_0_0_0_1 -> 2499 in the cache */
   /* replace833_0_0_0 -> 2500 in the cache */
   /* replace833_0_0_1_0_0 -> 764 in the cache */
   /* replace833_0_0_1_0_1 -> 2436 in the cache */
   /* replace833_0_0_1_0 -> 2508 in the cache */
   /* replace833_0_0_1_1_0 -> 2442 in the cache */
   /* replace833_0_0_1_1_1 -> 2443 in the cache */
   /* replace833_0_0_1_1 -> 2509 in the cache */
   /* replace833_0_0_1 -> 2510 in the cache */
   /* replace833_0_0 -> 2511 in the cache */
   /* replace833_0_1_0_0_0 -> 2448 in the cache */
   /* replace833_0_1_0_0_1 -> 2449 in the cache */
   /* replace833_0_1_0_0 -> 2513 in the cache */
   /* replace833_0_1_0_1_0 -> 2451 in the cache */
   /* replace833_0_1_0_1_1 -> 2452 in the cache */
   /* replace833_0_1_0_1 -> 2514 in the cache */
   /* replace833_0_1_0 -> 2515 in the cache */
   /* replace833_0_1_1_0_0 -> 2455 in the cache */
   /* replace833_0_1_1_0_1 -> 2456 in the cache */
   /* replace833_0_1_1_0 -> 2516 in the cache */
   /* replace833_0_1_1_1_0 -> 2458 in the cache */
   /* replace833_0_1_1_1_1 -> 2459 in the cache */
   /* replace833_0_1_1_1 -> 2517 in the cache */
   /* replace833_0_1_1 -> 2518 in the cache */
   /* replace833_0_1 -> 2519 in the cache */
   /* replace833_0 -> 2520 in the cache */
   /* replace833_1_0_0_0_0 -> 2465 in the cache */
   /* replace833_1_0_0_0_1 -> 2466 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      8, 1,
      { 2465, 2466 },
      -1,
   } },
   /* replace833_1_0_0_1_0 -> 2468 in the cache */
   /* replace833_1_0_0_1_1 -> 2469 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      9, 1,
      { 2468, 2469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2522, 2523 },
      -1,
   } },
   /* replace833_1_0_1_0_0 -> 2472 in the cache */
   /* replace833_1_0_1_0_1 -> 2473 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      10, 1,
      { 2472, 2473 },
      -1,
   } },
   /* replace833_1_0_1_1_0 -> 2475 in the cache */
   /* replace833_1_0_1_1_1 -> 2476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      11, 1,
      { 2475, 2476 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2525, 2526 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2524, 2527 },
      -1,
   } },
   /* replace833_1_1_0_0_0 -> 2480 in the cache */
   /* replace833_1_1_0_0_1 -> 2481 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      12, 1,
      { 2480, 2481 },
      -1,
   } },
   /* replace833_1_1_0_1_0 -> 2483 in the cache */
   /* replace833_1_1_0_1_1 -> 2484 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      13, 1,
      { 2483, 2484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2529, 2530 },
      -1,
   } },
   /* replace833_1_1_1_0_0 -> 2487 in the cache */
   /* replace833_1_1_1_0_1 -> 2488 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      14, 1,
      { 2487, 2488 },
      -1,
   } },
   /* replace833_1_1_1_1_0 -> 2490 in the cache */
   /* replace833_1_1_1_1_1 -> 2491 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      15, 1,
      { 2490, 2491 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2532, 2533 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2531, 2534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 8,
      { 2528, 2535 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 16,
      { 2520, 2536 },
      -1,
   } },

   /* ('bany_inequal2', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')) */
   /* search834_0 -> 0 in the cache */
   /* search834_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace834_0_0 -> 762 in the cache */
   /* replace834_0_1 -> 2428 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 762, 2428 },
      -1,
   } },
   /* replace834_1_0 -> 763 in the cache */
   /* replace834_1_1 -> 2430 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 763, 2430 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2539, 2540 },
      -1,
   } },

   /* ('bany_inequal3', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ior', ('ine', 'a.y', 'b.y'), ('ine', 'a.z', 'b.z'))) */
   /* search835_0 -> 0 in the cache */
   /* search835_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace835_0_0 -> 762 in the cache */
   /* replace835_0_1 -> 2428 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 762, 2428 },
      -1,
   } },
   /* replace835_1_0_0 -> 763 in the cache */
   /* replace835_1_0_1 -> 2430 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 763, 2430 },
      -1,
   } },
   /* replace835_1_1_0 -> 764 in the cache */
   /* replace835_1_1_1 -> 2436 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      3, 1,
      { 764, 2436 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2544, 2545 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 4,
      { 2543, 2546 },
      -1,
   } },

   /* ('bany_inequal4', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ior', ('ine', 'a.z', 'b.z'), ('ine', 'a.w', 'b.w'))) */
   /* search836_0 -> 0 in the cache */
   /* search836_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace836_0_0_0 -> 762 in the cache */
   /* replace836_0_0_1 -> 2428 in the cache */
   /* replace836_0_0 -> 2539 in the cache */
   /* replace836_0_1_0 -> 763 in the cache */
   /* replace836_0_1_1 -> 2430 in the cache */
   /* replace836_0_1 -> 2540 in the cache */
   /* replace836_0 -> 2541 in the cache */
   /* replace836_1_0_0 -> 764 in the cache */
   /* replace836_1_0_1 -> 2436 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 764, 2436 },
      -1,
   } },
   /* replace836_1_1_0 -> 2442 in the cache */
   /* replace836_1_1_1 -> 2443 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      3, 1,
      { 2442, 2443 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2549, 2550 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2541, 2551 },
      -1,
   } },

   /* ('bany_inequal8', 'a', 'b') => ('ior', ('ior', ('ior', ('ine', 'a.a', 'b.a'), ('ine', 'a.b', 'b.b')), ('ior', ('ine', 'a.c', 'b.c'), ('ine', 'a.d', 'b.d'))), ('ior', ('ior', ('ine', 'a.e', 'b.e'), ('ine', 'a.f', 'b.f')), ('ior', ('ine', 'a.g', 'b.g'), ('ine', 'a.h', 'b.h')))) */
   /* search837_0 -> 0 in the cache */
   /* search837_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace837_0_0_0_0 -> 762 in the cache */
   /* replace837_0_0_0_1 -> 2428 in the cache */
   /* replace837_0_0_0 -> 2539 in the cache */
   /* replace837_0_0_1_0 -> 763 in the cache */
   /* replace837_0_0_1_1 -> 2430 in the cache */
   /* replace837_0_0_1 -> 2540 in the cache */
   /* replace837_0_0 -> 2541 in the cache */
   /* replace837_0_1_0_0 -> 764 in the cache */
   /* replace837_0_1_0_1 -> 2436 in the cache */
   /* replace837_0_1_0 -> 2549 in the cache */
   /* replace837_0_1_1_0 -> 2442 in the cache */
   /* replace837_0_1_1_1 -> 2443 in the cache */
   /* replace837_0_1_1 -> 2550 in the cache */
   /* replace837_0_1 -> 2551 in the cache */
   /* replace837_0 -> 2552 in the cache */
   /* replace837_1_0_0_0 -> 2448 in the cache */
   /* replace837_1_0_0_1 -> 2449 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      4, 1,
      { 2448, 2449 },
      -1,
   } },
   /* replace837_1_0_1_0 -> 2451 in the cache */
   /* replace837_1_0_1_1 -> 2452 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      5, 1,
      { 2451, 2452 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2554, 2555 },
      -1,
   } },
   /* replace837_1_1_0_0 -> 2455 in the cache */
   /* replace837_1_1_0_1 -> 2456 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      6, 1,
      { 2455, 2456 },
      -1,
   } },
   /* replace837_1_1_1_0 -> 2458 in the cache */
   /* replace837_1_1_1_1 -> 2459 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      7, 1,
      { 2458, 2459 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2557, 2558 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2556, 2559 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 8,
      { 2552, 2560 },
      -1,
   } },

   /* ('bany_inequal16', 'a', 'b') => ('ior', ('ior', ('ior', ('ior', ('ine', 'a.a', 'b.a'), ('ine', 'a.b', 'b.b')), ('ior', ('ine', 'a.c', 'b.c'), ('ine', 'a.d', 'b.d'))), ('ior', ('ior', ('ine', 'a.e', 'b.e'), ('ine', 'a.f', 'b.f')), ('ior', ('ine', 'a.g', 'b.g'), ('ine', 'a.h', 'b.h')))), ('ior', ('ior', ('ior', ('ine', 'a.i', 'b.i'), ('ine', 'a.j', 'b.j')), ('ior', ('ine', 'a.k', 'b.k'), ('ine', 'a.l', 'b.l'))), ('ior', ('ior', ('ine', 'a.m', 'b.m'), ('ine', 'a.n', 'b.n')), ('ior', ('ine', 'a.o', 'b.o'), ('ine', 'a.p', 'b.p'))))) */
   /* search838_0 -> 0 in the cache */
   /* search838_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace838_0_0_0_0_0 -> 762 in the cache */
   /* replace838_0_0_0_0_1 -> 2428 in the cache */
   /* replace838_0_0_0_0 -> 2539 in the cache */
   /* replace838_0_0_0_1_0 -> 763 in the cache */
   /* replace838_0_0_0_1_1 -> 2430 in the cache */
   /* replace838_0_0_0_1 -> 2540 in the cache */
   /* replace838_0_0_0 -> 2541 in the cache */
   /* replace838_0_0_1_0_0 -> 764 in the cache */
   /* replace838_0_0_1_0_1 -> 2436 in the cache */
   /* replace838_0_0_1_0 -> 2549 in the cache */
   /* replace838_0_0_1_1_0 -> 2442 in the cache */
   /* replace838_0_0_1_1_1 -> 2443 in the cache */
   /* replace838_0_0_1_1 -> 2550 in the cache */
   /* replace838_0_0_1 -> 2551 in the cache */
   /* replace838_0_0 -> 2552 in the cache */
   /* replace838_0_1_0_0_0 -> 2448 in the cache */
   /* replace838_0_1_0_0_1 -> 2449 in the cache */
   /* replace838_0_1_0_0 -> 2554 in the cache */
   /* replace838_0_1_0_1_0 -> 2451 in the cache */
   /* replace838_0_1_0_1_1 -> 2452 in the cache */
   /* replace838_0_1_0_1 -> 2555 in the cache */
   /* replace838_0_1_0 -> 2556 in the cache */
   /* replace838_0_1_1_0_0 -> 2455 in the cache */
   /* replace838_0_1_1_0_1 -> 2456 in the cache */
   /* replace838_0_1_1_0 -> 2557 in the cache */
   /* replace838_0_1_1_1_0 -> 2458 in the cache */
   /* replace838_0_1_1_1_1 -> 2459 in the cache */
   /* replace838_0_1_1_1 -> 2558 in the cache */
   /* replace838_0_1_1 -> 2559 in the cache */
   /* replace838_0_1 -> 2560 in the cache */
   /* replace838_0 -> 2561 in the cache */
   /* replace838_1_0_0_0_0 -> 2465 in the cache */
   /* replace838_1_0_0_0_1 -> 2466 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      8, 1,
      { 2465, 2466 },
      -1,
   } },
   /* replace838_1_0_0_1_0 -> 2468 in the cache */
   /* replace838_1_0_0_1_1 -> 2469 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      9, 1,
      { 2468, 2469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2563, 2564 },
      -1,
   } },
   /* replace838_1_0_1_0_0 -> 2472 in the cache */
   /* replace838_1_0_1_0_1 -> 2473 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      10, 1,
      { 2472, 2473 },
      -1,
   } },
   /* replace838_1_0_1_1_0 -> 2475 in the cache */
   /* replace838_1_0_1_1_1 -> 2476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      11, 1,
      { 2475, 2476 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2566, 2567 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2565, 2568 },
      -1,
   } },
   /* replace838_1_1_0_0_0 -> 2480 in the cache */
   /* replace838_1_1_0_0_1 -> 2481 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      12, 1,
      { 2480, 2481 },
      -1,
   } },
   /* replace838_1_1_0_1_0 -> 2483 in the cache */
   /* replace838_1_1_0_1_1 -> 2484 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      13, 1,
      { 2483, 2484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2570, 2571 },
      -1,
   } },
   /* replace838_1_1_1_0_0 -> 2487 in the cache */
   /* replace838_1_1_1_0_1 -> 2488 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      14, 1,
      { 2487, 2488 },
      -1,
   } },
   /* replace838_1_1_1_1_0 -> 2490 in the cache */
   /* replace838_1_1_1_1_1 -> 2491 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      15, 1,
      { 2490, 2491 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2573, 2574 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2572, 2575 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 8,
      { 2569, 2576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 16,
      { 2561, 2577 },
      -1,
   } },

   /* ('bany_fnequal2', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')) */
   /* search839_0 -> 0 in the cache */
   /* search839_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace839_0_0 -> 762 in the cache */
   /* replace839_0_1 -> 2428 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 762, 2428 },
      -1,
   } },
   /* replace839_1_0 -> 763 in the cache */
   /* replace839_1_1 -> 2430 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 763, 2430 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2580, 2581 },
      -1,
   } },

   /* ('bany_fnequal3', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('ior', ('fneu', 'a.y', 'b.y'), ('fneu', 'a.z', 'b.z'))) */
   /* search840_0 -> 0 in the cache */
   /* search840_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace840_0_0 -> 762 in the cache */
   /* replace840_0_1 -> 2428 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 762, 2428 },
      -1,
   } },
   /* replace840_1_0_0 -> 763 in the cache */
   /* replace840_1_0_1 -> 2430 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 763, 2430 },
      -1,
   } },
   /* replace840_1_1_0 -> 764 in the cache */
   /* replace840_1_1_1 -> 2436 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      3, 1,
      { 764, 2436 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2585, 2586 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 4,
      { 2584, 2587 },
      -1,
   } },

   /* ('bany_fnequal4', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('ior', ('fneu', 'a.z', 'b.z'), ('fneu', 'a.w', 'b.w'))) */
   /* search841_0 -> 0 in the cache */
   /* search841_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace841_0_0_0 -> 762 in the cache */
   /* replace841_0_0_1 -> 2428 in the cache */
   /* replace841_0_0 -> 2580 in the cache */
   /* replace841_0_1_0 -> 763 in the cache */
   /* replace841_0_1_1 -> 2430 in the cache */
   /* replace841_0_1 -> 2581 in the cache */
   /* replace841_0 -> 2582 in the cache */
   /* replace841_1_0_0 -> 764 in the cache */
   /* replace841_1_0_1 -> 2436 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 764, 2436 },
      -1,
   } },
   /* replace841_1_1_0 -> 2442 in the cache */
   /* replace841_1_1_1 -> 2443 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      3, 1,
      { 2442, 2443 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2590, 2591 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2582, 2592 },
      -1,
   } },

   /* ('bany_fnequal8', 'a', 'b') => ('ior', ('ior', ('ior', ('fneu', 'a.a', 'b.a'), ('fneu', 'a.b', 'b.b')), ('ior', ('fneu', 'a.c', 'b.c'), ('fneu', 'a.d', 'b.d'))), ('ior', ('ior', ('fneu', 'a.e', 'b.e'), ('fneu', 'a.f', 'b.f')), ('ior', ('fneu', 'a.g', 'b.g'), ('fneu', 'a.h', 'b.h')))) */
   /* search842_0 -> 0 in the cache */
   /* search842_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace842_0_0_0_0 -> 762 in the cache */
   /* replace842_0_0_0_1 -> 2428 in the cache */
   /* replace842_0_0_0 -> 2580 in the cache */
   /* replace842_0_0_1_0 -> 763 in the cache */
   /* replace842_0_0_1_1 -> 2430 in the cache */
   /* replace842_0_0_1 -> 2581 in the cache */
   /* replace842_0_0 -> 2582 in the cache */
   /* replace842_0_1_0_0 -> 764 in the cache */
   /* replace842_0_1_0_1 -> 2436 in the cache */
   /* replace842_0_1_0 -> 2590 in the cache */
   /* replace842_0_1_1_0 -> 2442 in the cache */
   /* replace842_0_1_1_1 -> 2443 in the cache */
   /* replace842_0_1_1 -> 2591 in the cache */
   /* replace842_0_1 -> 2592 in the cache */
   /* replace842_0 -> 2593 in the cache */
   /* replace842_1_0_0_0 -> 2448 in the cache */
   /* replace842_1_0_0_1 -> 2449 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      4, 1,
      { 2448, 2449 },
      -1,
   } },
   /* replace842_1_0_1_0 -> 2451 in the cache */
   /* replace842_1_0_1_1 -> 2452 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      5, 1,
      { 2451, 2452 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2595, 2596 },
      -1,
   } },
   /* replace842_1_1_0_0 -> 2455 in the cache */
   /* replace842_1_1_0_1 -> 2456 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      6, 1,
      { 2455, 2456 },
      -1,
   } },
   /* replace842_1_1_1_0 -> 2458 in the cache */
   /* replace842_1_1_1_1 -> 2459 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      7, 1,
      { 2458, 2459 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2598, 2599 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2597, 2600 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 8,
      { 2593, 2601 },
      -1,
   } },

   /* ('bany_fnequal16', 'a', 'b') => ('ior', ('ior', ('ior', ('ior', ('fneu', 'a.a', 'b.a'), ('fneu', 'a.b', 'b.b')), ('ior', ('fneu', 'a.c', 'b.c'), ('fneu', 'a.d', 'b.d'))), ('ior', ('ior', ('fneu', 'a.e', 'b.e'), ('fneu', 'a.f', 'b.f')), ('ior', ('fneu', 'a.g', 'b.g'), ('fneu', 'a.h', 'b.h')))), ('ior', ('ior', ('ior', ('fneu', 'a.i', 'b.i'), ('fneu', 'a.j', 'b.j')), ('ior', ('fneu', 'a.k', 'b.k'), ('fneu', 'a.l', 'b.l'))), ('ior', ('ior', ('fneu', 'a.m', 'b.m'), ('fneu', 'a.n', 'b.n')), ('ior', ('fneu', 'a.o', 'b.o'), ('fneu', 'a.p', 'b.p'))))) */
   /* search843_0 -> 0 in the cache */
   /* search843_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace843_0_0_0_0_0 -> 762 in the cache */
   /* replace843_0_0_0_0_1 -> 2428 in the cache */
   /* replace843_0_0_0_0 -> 2580 in the cache */
   /* replace843_0_0_0_1_0 -> 763 in the cache */
   /* replace843_0_0_0_1_1 -> 2430 in the cache */
   /* replace843_0_0_0_1 -> 2581 in the cache */
   /* replace843_0_0_0 -> 2582 in the cache */
   /* replace843_0_0_1_0_0 -> 764 in the cache */
   /* replace843_0_0_1_0_1 -> 2436 in the cache */
   /* replace843_0_0_1_0 -> 2590 in the cache */
   /* replace843_0_0_1_1_0 -> 2442 in the cache */
   /* replace843_0_0_1_1_1 -> 2443 in the cache */
   /* replace843_0_0_1_1 -> 2591 in the cache */
   /* replace843_0_0_1 -> 2592 in the cache */
   /* replace843_0_0 -> 2593 in the cache */
   /* replace843_0_1_0_0_0 -> 2448 in the cache */
   /* replace843_0_1_0_0_1 -> 2449 in the cache */
   /* replace843_0_1_0_0 -> 2595 in the cache */
   /* replace843_0_1_0_1_0 -> 2451 in the cache */
   /* replace843_0_1_0_1_1 -> 2452 in the cache */
   /* replace843_0_1_0_1 -> 2596 in the cache */
   /* replace843_0_1_0 -> 2597 in the cache */
   /* replace843_0_1_1_0_0 -> 2455 in the cache */
   /* replace843_0_1_1_0_1 -> 2456 in the cache */
   /* replace843_0_1_1_0 -> 2598 in the cache */
   /* replace843_0_1_1_1_0 -> 2458 in the cache */
   /* replace843_0_1_1_1_1 -> 2459 in the cache */
   /* replace843_0_1_1_1 -> 2599 in the cache */
   /* replace843_0_1_1 -> 2600 in the cache */
   /* replace843_0_1 -> 2601 in the cache */
   /* replace843_0 -> 2602 in the cache */
   /* replace843_1_0_0_0_0 -> 2465 in the cache */
   /* replace843_1_0_0_0_1 -> 2466 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      8, 1,
      { 2465, 2466 },
      -1,
   } },
   /* replace843_1_0_0_1_0 -> 2468 in the cache */
   /* replace843_1_0_0_1_1 -> 2469 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      9, 1,
      { 2468, 2469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2604, 2605 },
      -1,
   } },
   /* replace843_1_0_1_0_0 -> 2472 in the cache */
   /* replace843_1_0_1_0_1 -> 2473 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      10, 1,
      { 2472, 2473 },
      -1,
   } },
   /* replace843_1_0_1_1_0 -> 2475 in the cache */
   /* replace843_1_0_1_1_1 -> 2476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      11, 1,
      { 2475, 2476 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2607, 2608 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2606, 2609 },
      -1,
   } },
   /* replace843_1_1_0_0_0 -> 2480 in the cache */
   /* replace843_1_1_0_0_1 -> 2481 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      12, 1,
      { 2480, 2481 },
      -1,
   } },
   /* replace843_1_1_0_1_0 -> 2483 in the cache */
   /* replace843_1_1_0_1_1 -> 2484 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      13, 1,
      { 2483, 2484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2611, 2612 },
      -1,
   } },
   /* replace843_1_1_1_0_0 -> 2487 in the cache */
   /* replace843_1_1_1_0_1 -> 2488 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      14, 1,
      { 2487, 2488 },
      -1,
   } },
   /* replace843_1_1_1_1_0 -> 2490 in the cache */
   /* replace843_1_1_1_1_1 -> 2491 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      15, 1,
      { 2490, 2491 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2614, 2615 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2613, 2616 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 8,
      { 2610, 2617 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 16,
      { 2602, 2618 },
      -1,
   } },

   /* ('feq', ('seq', 'a', 'b'), 1.0) => ('feq', 'a', 'b') */
   /* search844_0_0 -> 0 in the cache */
   /* search844_0_1 -> 3 in the cache */
   /* search844_0 -> 2371 in the cache */
   /* search844_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2371, 272 },
      -1,
   } },

   /* replace844_0 -> 0 in the cache */
   /* replace844_1 -> 3 in the cache */
   /* replace844 -> 1048 in the cache */

   /* ('feq', ('sne', 'a', 'b'), 1.0) => ('fneu', 'a', 'b') */
   /* search845_0_0 -> 0 in the cache */
   /* search845_0_1 -> 3 in the cache */
   /* search845_0 -> 2373 in the cache */
   /* search845_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2373, 272 },
      -1,
   } },

   /* replace845_0 -> 0 in the cache */
   /* replace845_1 -> 3 in the cache */
   /* replace845 -> 1045 in the cache */

   /* ('feq', ('slt', 'a', 'b'), 1.0) => ('flt', 'a', 'b') */
   /* search846_0_0 -> 0 in the cache */
   /* search846_0_1 -> 3 in the cache */
   /* search846_0 -> 2359 in the cache */
   /* search846_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2359, 272 },
      -1,
   } },

   /* replace846_0 -> 0 in the cache */
   /* replace846_1 -> 3 in the cache */
   /* replace846 -> 1042 in the cache */

   /* ('feq', ('sge', 'a', 'b'), 1.0) => ('fge', 'a', 'b') */
   /* search847_0_0 -> 0 in the cache */
   /* search847_0_1 -> 3 in the cache */
   /* search847_0 -> 2361 in the cache */
   /* search847_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2361, 272 },
      -1,
   } },

   /* replace847_0 -> 0 in the cache */
   /* replace847_1 -> 3 in the cache */
   /* replace847 -> 1039 in the cache */

   /* ('fneu', ('seq', 'a', 'b'), 0.0) => ('feq', 'a', 'b') */
   /* search848_0_0 -> 0 in the cache */
   /* search848_0_1 -> 3 in the cache */
   /* search848_0 -> 2371 in the cache */
   /* search848_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2371, 258 },
      -1,
   } },

   /* replace848_0 -> 0 in the cache */
   /* replace848_1 -> 3 in the cache */
   /* replace848 -> 1048 in the cache */

   /* ('fneu', ('sne', 'a', 'b'), 0.0) => ('fneu', 'a', 'b') */
   /* search849_0_0 -> 0 in the cache */
   /* search849_0_1 -> 3 in the cache */
   /* search849_0 -> 2373 in the cache */
   /* search849_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2373, 258 },
      -1,
   } },

   /* replace849_0 -> 0 in the cache */
   /* replace849_1 -> 3 in the cache */
   /* replace849 -> 1045 in the cache */

   /* ('fneu', ('slt', 'a', 'b'), 0.0) => ('flt', 'a', 'b') */
   /* search850_0_0 -> 0 in the cache */
   /* search850_0_1 -> 3 in the cache */
   /* search850_0 -> 2359 in the cache */
   /* search850_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2359, 258 },
      -1,
   } },

   /* replace850_0 -> 0 in the cache */
   /* replace850_1 -> 3 in the cache */
   /* replace850 -> 1042 in the cache */

   /* ('fneu', ('sge', 'a', 'b'), 0.0) => ('fge', 'a', 'b') */
   /* search851_0_0 -> 0 in the cache */
   /* search851_0_1 -> 3 in the cache */
   /* search851_0 -> 2361 in the cache */
   /* search851_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2361, 258 },
      -1,
   } },

   /* replace851_0 -> 0 in the cache */
   /* replace851_1 -> 3 in the cache */
   /* replace851 -> 1039 in the cache */

   /* ('feq', ('seq', 'a', 'b'), 0.0) => ('fneu', 'a', 'b') */
   /* search852_0_0 -> 0 in the cache */
   /* search852_0_1 -> 3 in the cache */
   /* search852_0 -> 2371 in the cache */
   /* search852_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2371, 258 },
      -1,
   } },

   /* replace852_0 -> 0 in the cache */
   /* replace852_1 -> 3 in the cache */
   /* replace852 -> 1045 in the cache */

   /* ('feq', ('sne', 'a', 'b'), 0.0) => ('feq', 'a', 'b') */
   /* search853_0_0 -> 0 in the cache */
   /* search853_0_1 -> 3 in the cache */
   /* search853_0 -> 2373 in the cache */
   /* search853_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2373, 258 },
      -1,
   } },

   /* replace853_0 -> 0 in the cache */
   /* replace853_1 -> 3 in the cache */
   /* replace853 -> 1048 in the cache */

   /* ('feq', ('slt', 'a', 'b'), 0.0) => ('fge', 'a', 'b') */
   /* search854_0_0 -> 0 in the cache */
   /* search854_0_1 -> 3 in the cache */
   /* search854_0 -> 2359 in the cache */
   /* search854_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2359, 258 },
      -1,
   } },

   /* replace854_0 -> 0 in the cache */
   /* replace854_1 -> 3 in the cache */
   /* replace854 -> 1039 in the cache */

   /* ('feq', ('sge', 'a', 'b'), 0.0) => ('flt', 'a', 'b') */
   /* search855_0_0 -> 0 in the cache */
   /* search855_0_1 -> 3 in the cache */
   /* search855_0 -> 2361 in the cache */
   /* search855_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2361, 258 },
      -1,
   } },

   /* replace855_0 -> 0 in the cache */
   /* replace855_1 -> 3 in the cache */
   /* replace855 -> 1042 in the cache */

   /* ('fneu', ('seq', 'a', 'b'), 1.0) => ('fneu', 'a', 'b') */
   /* search856_0_0 -> 0 in the cache */
   /* search856_0_1 -> 3 in the cache */
   /* search856_0 -> 2371 in the cache */
   /* search856_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2371, 272 },
      -1,
   } },

   /* replace856_0 -> 0 in the cache */
   /* replace856_1 -> 3 in the cache */
   /* replace856 -> 1045 in the cache */

   /* ('fneu', ('sne', 'a', 'b'), 1.0) => ('feq', 'a', 'b') */
   /* search857_0_0 -> 0 in the cache */
   /* search857_0_1 -> 3 in the cache */
   /* search857_0 -> 2373 in the cache */
   /* search857_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2373, 272 },
      -1,
   } },

   /* replace857_0 -> 0 in the cache */
   /* replace857_1 -> 3 in the cache */
   /* replace857 -> 1048 in the cache */

   /* ('fneu', ('slt', 'a', 'b'), 1.0) => ('fge', 'a', 'b') */
   /* search858_0_0 -> 0 in the cache */
   /* search858_0_1 -> 3 in the cache */
   /* search858_0 -> 2359 in the cache */
   /* search858_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2359, 272 },
      -1,
   } },

   /* replace858_0 -> 0 in the cache */
   /* replace858_1 -> 3 in the cache */
   /* replace858 -> 1039 in the cache */

   /* ('fneu', ('sge', 'a', 'b'), 1.0) => ('flt', 'a', 'b') */
   /* search859_0_0 -> 0 in the cache */
   /* search859_0_1 -> 3 in the cache */
   /* search859_0 -> 2361 in the cache */
   /* search859_1 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2361, 272 },
      -1,
   } },

   /* replace859_0 -> 0 in the cache */
   /* replace859_1 -> 3 in the cache */
   /* replace859 -> 1042 in the cache */

   /* ('fneu', ('fneg', 'a'), 'a') => ('fneu', 'a', 0.0) */
   /* search860_0_0 -> 32 in the cache */
   /* search860_0 -> 98 in the cache */
   /* search860_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace860_0 -> 32 in the cache */
   /* replace860_1 -> 113 in the cache */
   /* replace860 -> 1242 in the cache */

   /* ('feq', ('fneg', 'a'), 'a') => ('feq', 'a', 0.0) */
   /* search861_0_0 -> 32 in the cache */
   /* search861_0 -> 98 in the cache */
   /* search861_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace861_0 -> 32 in the cache */
   /* replace861_1 -> 113 in the cache */
   /* replace861 -> 1246 in the cache */

   /* ('imul', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b')) */
   /* search862_0_0 -> 753 in the cache */
   /* search862_0 -> 1215 in the cache */
   /* search862_1_0 -> 1121 in the cache */
   /* search862_1 -> 2238 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 1215, 2238 },
      -1,
   } },

   /* replace862_0_0 -> 753 in the cache */
   /* replace862_0_1 -> 1121 in the cache */
   /* replace862_0 -> 1133 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1133 },
      -1,
   } },

   /* ('iand', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b')) */
   /* search863_0_0 -> 753 in the cache */
   /* search863_0 -> 1215 in the cache */
   /* search863_1_0 -> 1121 in the cache */
   /* search863_1 -> 2238 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1215, 2238 },
      -1,
   } },

   /* replace863_0_0 -> 753 in the cache */
   /* replace863_0_1 -> 1121 in the cache */
   /* replace863_0 -> 1133 in the cache */
   /* replace863 -> 2639 in the cache */

   /* ('ior', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b')) */
   /* search864_0_0 -> 753 in the cache */
   /* search864_0 -> 1215 in the cache */
   /* search864_1_0 -> 1121 in the cache */
   /* search864_1 -> 2238 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1215, 2238 },
      -1,
   } },

   /* replace864_0_0 -> 753 in the cache */
   /* replace864_0_1 -> 1121 in the cache */
   /* replace864_0 -> 1125 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1125 },
      -1,
   } },

   /* ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b')) */
   /* search865_0_0 -> 753 in the cache */
   /* search865_0 -> 1116 in the cache */
   /* search865_1_0 -> 1121 in the cache */
   /* search865_1 -> 1122 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1116, 1122 },
      -1,
   } },

   /* replace865_0_0 -> 753 in the cache */
   /* replace865_0_1 -> 1121 in the cache */
   /* replace865_0 -> 1133 in the cache */
   /* replace865 -> 1255 in the cache */

   /* ('fsat', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('b2f', ('ior', 'a', 'b')) */
   /* search866_0_0_0 -> 753 in the cache */
   /* search866_0_0 -> 1116 in the cache */
   /* search866_0_1_0 -> 1121 in the cache */
   /* search866_0_1 -> 1122 in the cache */
   /* search866_0 -> 1152 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1152 },
      -1,
   } },

   /* replace866_0_0 -> 753 in the cache */
   /* replace866_0_1 -> 1121 in the cache */
   /* replace866_0 -> 1125 in the cache */
   /* replace866 -> 1252 in the cache */

   /* ('iand', 'a@bool16', 1.0) => ('b2f', 'a') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search867_1 -> 483 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2645, 483 },
      -1,
   } },

   /* replace867_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('iand', 'a@bool32', 1.0) => ('b2f', 'a') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search868_1 -> 245 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2648, 245 },
      -1,
   } },

   /* replace868_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('flt', ('fneg', ('b2f', 'a@1')), 0) => a */
   /* search869_0_0_0 -> 753 in the cache */
   /* search869_0_0 -> 1116 in the cache */
   /* search869_0 -> 1119 in the cache */
   /* search869_1 -> 1216 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1119, 1216 },
      -1,
   } },

   /* replace869 -> 753 in the cache */

   /* ('ilt', 'a', 'a') => False */
   /* search870_0 -> 32 in the cache */
   /* search870_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace870 -> 1070 in the cache */

   /* ('ige', 'a', 'a') => True */
   /* search871_0 -> 32 in the cache */
   /* search871_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace871 -> 1224 in the cache */

   /* ('ieq', 'a', 'a') => True */
   /* search872_0 -> 32 in the cache */
   /* search872_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace872 -> 1224 in the cache */

   /* ('ine', 'a', 'a') => False */
   /* search873_0 -> 32 in the cache */
   /* search873_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace873 -> 1070 in the cache */

   /* ('ult', 'a', 'a') => False */
   /* search874_0 -> 32 in the cache */
   /* search874_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace874 -> 1070 in the cache */

   /* ('uge', 'a', 'a') => True */
   /* search875_0 -> 32 in the cache */
   /* search875_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace875 -> 1224 in the cache */

   /* ('flt', 'a', 'a') => False */
   /* search876_0 -> 32 in the cache */
   /* search876_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace876 -> 1070 in the cache */

   /* ('fge', 'a(is_a_number)', 'a') => True */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search877_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2659, 32 },
      -1,
   } },

   /* replace877 -> 1224 in the cache */

   /* ('feq', 'a(is_a_number)', 'a') => True */
   /* search878_0 -> 2659 in the cache */
   /* search878_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 2659, 32 },
      -1,
   } },

   /* replace878 -> 1224 in the cache */

   /* ('fneu', 'a(is_a_number)', 'a') => False */
   /* search879_0 -> 2659 in the cache */
   /* search879_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 2659, 32 },
      -1,
   } },

   /* replace879 -> 1070 in the cache */

   /* ('iand', 'a', 'a') => a */
   /* search880_0 -> 32 in the cache */
   /* search880_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace880 -> 32 in the cache */

   /* ('iand', 'a', 0) => 0 */
   /* search881_0 -> 32 in the cache */
   /* search881_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace881 -> 61 in the cache */

   /* ('iand', 'a', -1) => a */
   /* search882_0 -> 32 in the cache */
   /* search882_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace882 -> 32 in the cache */

   /* ('iand', 'a', ('inot', 'a')) => 0 */
   /* search883_0 -> 32 in the cache */
   /* search883_1_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 2666 },
      -1,
   } },

   /* replace883 -> 61 in the cache */

   /* ('ior', 'a', 'a') => a */
   /* search884_0 -> 32 in the cache */
   /* search884_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace884 -> 32 in the cache */

   /* ('ior', 'a', 0) => a */
   /* search885_0 -> 32 in the cache */
   /* search885_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace885 -> 32 in the cache */

   /* ('ior', 'a', -1) => -1 */
   /* search886_0 -> 32 in the cache */
   /* search886_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace886 -> 63 in the cache */

   /* ('ior', 'a', ('inot', 'a')) => -1 */
   /* search887_0 -> 32 in the cache */
   /* search887_1_0 -> 32 in the cache */
   /* search887_1 -> 2666 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 32, 2666 },
      -1,
   } },

   /* replace887 -> 63 in the cache */

   /* ('ixor', 'a', 'a') => 0 */
   /* search888_0 -> 32 in the cache */
   /* search888_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ixor,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace888 -> 61 in the cache */

   /* ('ixor', 'a', 0) => a */
   /* search889_0 -> 32 in the cache */
   /* search889_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace889 -> 32 in the cache */

   /* ('ixor', 'a', ('ixor', 'a', 'b')) => b */
   /* search890_0 -> 0 in the cache */
   /* search890_1_0 -> 0 in the cache */
   /* search890_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 2,
      { 0, 2674 },
      -1,
   } },

   /* replace890 -> 3 in the cache */

   /* ('ixor', 'a', -1) => ('inot', 'a') */
   /* search891_0 -> 32 in the cache */
   /* search891_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace891_0 -> 32 in the cache */
   /* replace891 -> 2666 in the cache */

   /* ('inot', ('inot', 'a')) => a */
   /* search892_0_0 -> 32 in the cache */
   /* search892_0 -> 2666 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 2666 },
      -1,
   } },

   /* replace892 -> 32 in the cache */

   /* ('ior', ('iand', 'a', 'b'), 'b') => b */
   /* search893_0_0 -> 0 in the cache */
   /* search893_0_1 -> 3 in the cache */
   /* search893_0 -> 203 in the cache */
   /* search893_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 203, 3 },
      -1,
   } },

   /* replace893 -> 3 in the cache */

   /* ('ior', ('ior', 'a', 'b'), 'b') => ('ior', 'a', 'b') */
   /* search894_0_0 -> 0 in the cache */
   /* search894_0_1 -> 3 in the cache */
   /* search894_0 -> 84 in the cache */
   /* search894_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 84, 3 },
      -1,
   } },

   /* replace894_0 -> 0 in the cache */
   /* replace894_1 -> 3 in the cache */
   /* replace894 -> 2301 in the cache */

   /* ('iand', ('ior', 'a', 'b'), 'b') => b */
   /* search895_0_0 -> 0 in the cache */
   /* search895_0_1 -> 3 in the cache */
   /* search895_0 -> 84 in the cache */
   /* search895_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 84, 3 },
      -1,
   } },

   /* replace895 -> 3 in the cache */

   /* ('iand', ('iand', 'a', 'b'), 'b') => ('iand', 'a', 'b') */
   /* search896_0_0 -> 0 in the cache */
   /* search896_0_1 -> 3 in the cache */
   /* search896_0 -> 203 in the cache */
   /* search896_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 203, 3 },
      -1,
   } },

   /* replace896_0 -> 0 in the cache */
   /* replace896_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('inot', 'a'), ('inot', 'b')) => ('inot', ('ior', 'a', 'b')) */
   /* search897_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search897_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2683, 2684 },
      -1,
   } },

   /* replace897_0_0 -> 0 in the cache */
   /* replace897_0_1 -> 3 in the cache */
   /* replace897_0 -> 2301 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2301 },
      -1,
   } },

   /* ('ior', ('inot', 'a'), ('inot', 'b')) => ('inot', ('iand', 'a', 'b')) */
   /* search898_0_0 -> 0 in the cache */
   /* search898_0 -> 2683 in the cache */
   /* search898_1_0 -> 3 in the cache */
   /* search898_1 -> 2684 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2683, 2684 },
      -1,
   } },

   /* replace898_0_0 -> 0 in the cache */
   /* replace898_0_1 -> 3 in the cache */
   /* replace898_0 -> 2682 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2682 },
      -1,
   } },

   /* ('ishl', 0, 'a') => 0 */
   /* search899_0 -> 1216 in the cache */
   /* search899_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 1216, 16 },
      -1,
   } },

   /* replace899 -> 1216 in the cache */

   /* ('ishl', 'a', 0) => a */
   /* search900_0 -> 32 in the cache */
   /* search900_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 32, 124 },
      -1,
   } },

   /* replace900 -> 32 in the cache */

   /* ('ishr', 0, 'a') => 0 */
   /* search901_0 -> 1216 in the cache */
   /* search901_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 1216, 16 },
      -1,
   } },

   /* replace901 -> 1216 in the cache */

   /* ('ishr', -1, 'a') => -1 */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   /* search902_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 2692, 16 },
      -1,
   } },

   /* replace902 -> 2692 in the cache */

   /* ('ishr', 'a', 0) => a */
   /* search903_0 -> 32 in the cache */
   /* search903_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 32, 124 },
      -1,
   } },

   /* replace903 -> 32 in the cache */

   /* ('ushr', 0, 'a') => 0 */
   /* search904_0 -> 1216 in the cache */
   /* search904_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 1216, 16 },
      -1,
   } },

   /* replace904 -> 1216 in the cache */

   /* ('ushr', 'a', 0) => a */
   /* search905_0 -> 32 in the cache */
   /* search905_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 32, 124 },
      -1,
   } },

   /* replace905 -> 32 in the cache */

   /* ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('urol', 'a', 'b') */
   /* search906_0_0 -> 11 in the cache */
   /* search906_0_1 -> 36 in the cache */
   /* search906_0 -> 2153 in the cache */
   /* search906_1_0 -> 11 in the cache */
   /* search906_1_1_0 -> 846 in the cache */
   /* search906_1_1_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 846, 2697 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 2698 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2153, 2699 },
      -1,
   } },

   /* replace906_0 -> 11 in the cache */
   /* replace906_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('isub', 16, 'b'))) => ('urol', 'a', 'b') */
   /* search907_0_0 -> 11 in the cache */
   /* search907_0_1 -> 36 in the cache */
   /* search907_0 -> 2153 in the cache */
   /* search907_1_0 -> 11 in the cache */
   /* search907_1_1_0 -> 846 in the cache */
   /* search907_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 846, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 2702 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2153, 2703 },
      -1,
   } },

   /* replace907_0 -> 11 in the cache */
   /* replace907_1 -> 36 in the cache */
   /* replace907 -> 2701 in the cache */

   /* ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('urol', 'a', 'b') */
   /* search908_0_0 -> 16 in the cache */
   /* search908_0_1 -> 36 in the cache */
   /* search908_0 -> 939 in the cache */
   /* search908_1_0 -> 16 in the cache */
   /* search908_1_1_0 -> 867 in the cache */
   /* search908_1_1_1_0 -> 36 in the cache */
   /* search908_1_1_1 -> 2697 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 867, 2697 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 2705 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 939, 2706 },
      -1,
   } },

   /* replace908_0 -> 16 in the cache */
   /* replace908_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('isub', 32, 'b'))) => ('urol', 'a', 'b') */
   /* search909_0_0 -> 16 in the cache */
   /* search909_0_1 -> 36 in the cache */
   /* search909_0 -> 939 in the cache */
   /* search909_1_0 -> 16 in the cache */
   /* search909_1_1_0 -> 867 in the cache */
   /* search909_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 867, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 2709 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 939, 2710 },
      -1,
   } },

   /* replace909_0 -> 16 in the cache */
   /* replace909_1 -> 36 in the cache */
   /* replace909 -> 2708 in the cache */

   /* ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('uror', 'a', 'b') */
   /* search910_0_0 -> 11 in the cache */
   /* search910_0_1 -> 36 in the cache */
   /* search910_0 -> 2157 in the cache */
   /* search910_1_0 -> 11 in the cache */
   /* search910_1_1_0 -> 846 in the cache */
   /* search910_1_1_1_0 -> 36 in the cache */
   /* search910_1_1_1 -> 2697 in the cache */
   /* search910_1_1 -> 2698 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 2698 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2157, 2712 },
      -1,
   } },

   /* replace910_0 -> 11 in the cache */
   /* replace910_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('isub', 16, 'b'))) => ('uror', 'a', 'b') */
   /* search911_0_0 -> 11 in the cache */
   /* search911_0_1 -> 36 in the cache */
   /* search911_0 -> 2157 in the cache */
   /* search911_1_0 -> 11 in the cache */
   /* search911_1_1_0 -> 846 in the cache */
   /* search911_1_1_1 -> 36 in the cache */
   /* search911_1_1 -> 2702 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 2702 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2157, 2715 },
      -1,
   } },

   /* replace911_0 -> 11 in the cache */
   /* replace911_1 -> 36 in the cache */
   /* replace911 -> 2714 in the cache */

   /* ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('uror', 'a', 'b') */
   /* search912_0_0 -> 16 in the cache */
   /* search912_0_1 -> 36 in the cache */
   /* search912_0 -> 2186 in the cache */
   /* search912_1_0 -> 16 in the cache */
   /* search912_1_1_0 -> 867 in the cache */
   /* search912_1_1_1_0 -> 36 in the cache */
   /* search912_1_1_1 -> 2697 in the cache */
   /* search912_1_1 -> 2705 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 2705 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2186, 2717 },
      -1,
   } },

   /* replace912_0 -> 16 in the cache */
   /* replace912_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('isub', 32, 'b'))) => ('uror', 'a', 'b') */
   /* search913_0_0 -> 16 in the cache */
   /* search913_0_1 -> 36 in the cache */
   /* search913_0 -> 2186 in the cache */
   /* search913_1_0 -> 16 in the cache */
   /* search913_1_1_0 -> 867 in the cache */
   /* search913_1_1_1 -> 36 in the cache */
   /* search913_1_1 -> 2709 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 2709 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2186, 2720 },
      -1,
   } },

   /* replace913_0 -> 16 in the cache */
   /* replace913_1 -> 36 in the cache */
   /* replace913 -> 2719 in the cache */

   /* ('urol@8', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 8, 'b'))) */
   /* search914_0 -> 6 in the cache */
   /* search914_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* replace914_0_0 -> 6 in the cache */
   /* replace914_0_1 -> 36 in the cache */
   /* replace914_0 -> 2122 in the cache */
   /* replace914_1_0 -> 6 in the cache */
   /* replace914_1_1_0 -> 824 in the cache */
   /* replace914_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 824, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 2723 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2122, 2724 },
      -1,
   } },

   /* ('urol@16', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 16, 'b'))) */
   /* search915_0 -> 11 in the cache */
   /* search915_1 -> 36 in the cache */
   /* search915 -> 2701 in the cache */

   /* replace915_0_0 -> 11 in the cache */
   /* replace915_0_1 -> 36 in the cache */
   /* replace915_0 -> 2153 in the cache */
   /* replace915_1_0 -> 11 in the cache */
   /* replace915_1_1_0 -> 846 in the cache */
   /* replace915_1_1_1 -> 36 in the cache */
   /* replace915_1_1 -> 2702 in the cache */
   /* replace915_1 -> 2703 in the cache */
   /* replace915 -> 2704 in the cache */

   /* ('urol@32', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 32, 'b'))) */
   /* search916_0 -> 16 in the cache */
   /* search916_1 -> 36 in the cache */
   /* search916 -> 2708 in the cache */

   /* replace916_0_0 -> 16 in the cache */
   /* replace916_0_1 -> 36 in the cache */
   /* replace916_0 -> 939 in the cache */
   /* replace916_1_0 -> 16 in the cache */
   /* replace916_1_1_0 -> 867 in the cache */
   /* replace916_1_1_1 -> 36 in the cache */
   /* replace916_1_1 -> 2709 in the cache */
   /* replace916_1 -> 2710 in the cache */
   /* replace916 -> 2711 in the cache */

   /* ('urol@64', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 64, 'b'))) */
   /* search917_0 -> 21 in the cache */
   /* search917_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* replace917_0_0 -> 21 in the cache */
   /* replace917_0_1 -> 36 in the cache */
   /* replace917_0 -> 2213 in the cache */
   /* replace917_1_0 -> 21 in the cache */
   /* replace917_1_1_0 -> 887 in the cache */
   /* replace917_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 887, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 2727 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2213, 2728 },
      -1,
   } },

   /* ('uror@8', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 8, 'b'))) */
   /* search918_0 -> 6 in the cache */
   /* search918_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* replace918_0_0 -> 6 in the cache */
   /* replace918_0_1 -> 36 in the cache */
   /* replace918_0 -> 2126 in the cache */
   /* replace918_1_0 -> 6 in the cache */
   /* replace918_1_1_0 -> 824 in the cache */
   /* replace918_1_1_1 -> 36 in the cache */
   /* replace918_1_1 -> 2723 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 2723 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2126, 2731 },
      -1,
   } },

   /* ('uror@16', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 16, 'b'))) */
   /* search919_0 -> 11 in the cache */
   /* search919_1 -> 36 in the cache */
   /* search919 -> 2714 in the cache */

   /* replace919_0_0 -> 11 in the cache */
   /* replace919_0_1 -> 36 in the cache */
   /* replace919_0 -> 2157 in the cache */
   /* replace919_1_0 -> 11 in the cache */
   /* replace919_1_1_0 -> 846 in the cache */
   /* replace919_1_1_1 -> 36 in the cache */
   /* replace919_1_1 -> 2702 in the cache */
   /* replace919_1 -> 2715 in the cache */
   /* replace919 -> 2716 in the cache */

   /* ('uror@32', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 32, 'b'))) */
   /* search920_0 -> 16 in the cache */
   /* search920_1 -> 36 in the cache */
   /* search920 -> 2719 in the cache */

   /* replace920_0_0 -> 16 in the cache */
   /* replace920_0_1 -> 36 in the cache */
   /* replace920_0 -> 2186 in the cache */
   /* replace920_1_0 -> 16 in the cache */
   /* replace920_1_1_0 -> 867 in the cache */
   /* replace920_1_1_1 -> 36 in the cache */
   /* replace920_1_1 -> 2709 in the cache */
   /* replace920_1 -> 2720 in the cache */
   /* replace920 -> 2721 in the cache */

   /* ('uror@64', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 64, 'b'))) */
   /* search921_0 -> 21 in the cache */
   /* search921_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* replace921_0_0 -> 21 in the cache */
   /* replace921_0_1 -> 36 in the cache */
   /* replace921_0 -> 2217 in the cache */
   /* replace921_1_0 -> 21 in the cache */
   /* replace921_1_1_0 -> 887 in the cache */
   /* replace921_1_1_1 -> 36 in the cache */
   /* replace921_1_1 -> 2727 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 2727 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2217, 2734 },
      -1,
   } },

   /* ('~fexp2', ('flog2', 'a')) => a */
   /* search922_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 2736 },
      -1,
   } },

   /* replace922 -> 32 in the cache */

   /* ('~flog2', ('fexp2', 'a')) => a */
   /* search923_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2738 },
      -1,
   } },

   /* replace923 -> 32 in the cache */

   /* ('fpow', 'a', 'b') => ('fexp2', ('fmul', ('flog2', 'a'), 'b')) */
   /* search924_0 -> 0 in the cache */
   /* search924_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace924_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace924_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2741, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2742 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 'b')) => ('fpow', 'a', 'b') */
   /* search925_0_0_0 -> 0 in the cache */
   /* search925_0_0 -> 2741 in the cache */
   /* search925_0_1 -> 3 in the cache */
   /* search925_0 -> 2742 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2742 },
      -1,
   } },

   /* replace925_0 -> 0 in the cache */
   /* replace925_1 -> 3 in the cache */
   /* replace925 -> 2740 in the cache */

   /* ('~fexp2', ('fadd', ('fmul', ('flog2', 'a'), 'b'), ('fmul', ('flog2', 'c'), 'd'))) => ('~fmul', ('fpow', 'a', 'b'), ('fpow', 'c', 'd')) */
   /* search926_0_0_0_0 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 151 },
      -1,
   } },
   /* search926_0_0_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 2745, 152 },
      -1,
   } },
   /* search926_0_1_0_0 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 154 },
      -1,
   } },
   /* search926_0_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 2747, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 2746, 2748 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 3,
      { 2749 },
      -1,
   } },

   /* replace926_0_0 -> 151 in the cache */
   /* replace926_0_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 151, 152 },
      -1,
   } },
   /* replace926_1_0 -> 154 in the cache */
   /* replace926_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2751, 2752 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 0.5)) => ('fsqrt', 'a') */
   /* search927_0_0_0 -> 32 in the cache */
   /* search927_0_0 -> 2736 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe0000000000000 /* 0.5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2736, 2754 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2755 },
      -1,
   } },

   /* replace927_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 2.0)) => ('fmul', 'a', 'a') */
   /* search928_0_0_0 -> 32 in the cache */
   /* search928_0_0 -> 2736 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4000000000000000 /* 2.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2736, 2758 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2759 },
      -1,
   } },

   /* replace928_0 -> 32 in the cache */
   /* replace928_1 -> 32 in the cache */
   /* replace928 -> 253 in the cache */

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 4.0)) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')) */
   /* search929_0_0_0 -> 32 in the cache */
   /* search929_0_0 -> 2736 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4010000000000000 /* 4.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2736, 2761 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2762 },
      -1,
   } },

   /* replace929_0_0 -> 32 in the cache */
   /* replace929_0_1 -> 32 in the cache */
   /* replace929_0 -> 253 in the cache */
   /* replace929_1_0 -> 32 in the cache */
   /* replace929_1_1 -> 32 in the cache */
   /* replace929_1 -> 253 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 253, 253 },
      -1,
   } },

   /* ('~fpow', 'a', 1.0) => a */
   /* search930_0 -> 32 in the cache */
   /* search930_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 243 },
      -1,
   } },

   /* replace930 -> 32 in the cache */

   /* ('~fpow', 'a', 2.0) => ('fmul', 'a', 'a') */
   /* search931_0 -> 32 in the cache */
   /* search931_1 -> 2758 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 2758 },
      -1,
   } },

   /* replace931_0 -> 32 in the cache */
   /* replace931_1 -> 32 in the cache */
   /* replace931 -> 253 in the cache */

   /* ('~fpow', 'a', 4.0) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')) */
   /* search932_0 -> 32 in the cache */
   /* search932_1 -> 2761 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 2761 },
      -1,
   } },

   /* replace932_0_0 -> 32 in the cache */
   /* replace932_0_1 -> 32 in the cache */
   /* replace932_0 -> 253 in the cache */
   /* replace932_1_0 -> 32 in the cache */
   /* replace932_1_1 -> 32 in the cache */
   /* replace932_1 -> 253 in the cache */
   /* replace932 -> 2764 in the cache */

   /* ('~fpow', 2.0, 'a') => ('fexp2', 'a') */
   /* search933_0 -> 2758 in the cache */
   /* search933_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 2758, 32 },
      -1,
   } },

   /* replace933_0 -> 32 in the cache */
   /* replace933 -> 2738 in the cache */

   /* ('~fpow', ('fpow', 'a', 2.2), 0.454545) => a */
   /* search934_0_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x400199999999999a /* 2.2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 2769 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fdd1743e963dc48 /* 0.454545 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 2770, 2771 },
      -1,
   } },

   /* replace934 -> 32 in the cache */

   /* ('~fpow', ('fabs', ('fpow', 'a', 2.2)), 0.454545) => ('fabs', 'a') */
   /* search935_0_0_0 -> 32 in the cache */
   /* search935_0_0_1 -> 2769 in the cache */
   /* search935_0_0 -> 2770 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2770 },
      -1,
   } },
   /* search935_1 -> 2771 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 2773, 2771 },
      -1,
   } },

   /* replace935_0 -> 32 in the cache */
   /* replace935 -> 103 in the cache */

   /* ('~fsqrt', ('fexp2', 'a')) => ('fexp2', ('fmul', 0.5, 'a')) */
   /* search936_0_0 -> 32 in the cache */
   /* search936_0 -> 2738 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 2738 },
      -1,
   } },

   /* replace936_0_0 -> 2754 in the cache */
   /* replace936_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2754, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2776 },
      -1,
   } },

   /* ('~frcp', ('fexp2', 'a')) => ('fexp2', ('fneg', 'a')) */
   /* search937_0_0 -> 32 in the cache */
   /* search937_0 -> 2738 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2738 },
      -1,
   } },

   /* replace937_0_0 -> 32 in the cache */
   /* replace937_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 98 },
      -1,
   } },

   /* ('~frsq', ('fexp2', 'a')) => ('fexp2', ('fmul', -0.5, 'a')) */
   /* search938_0_0 -> 32 in the cache */
   /* search938_0 -> 2738 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 2738 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbfe0000000000000 /* -0.5 */ },
   } },
   /* replace938_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2781, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2782 },
      -1,
   } },

   /* ('~flog2', ('fsqrt', 'a')) => ('fmul', 0.5, ('flog2', 'a')) */
   /* search939_0_0 -> 32 in the cache */
   /* search939_0 -> 2757 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2757 },
      -1,
   } },

   /* replace939_0 -> 2754 in the cache */
   /* replace939_1_0 -> 32 in the cache */
   /* replace939_1 -> 2736 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2754, 2736 },
      -1,
   } },

   /* ('~flog2', ('frcp', 'a')) => ('fneg', ('flog2', 'a')) */
   /* search940_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2786 },
      -1,
   } },

   /* replace940_0_0 -> 32 in the cache */
   /* replace940_0 -> 2736 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2736 },
      -1,
   } },

   /* ('~flog2', ('frsq', 'a')) => ('fmul', -0.5, ('flog2', 'a')) */
   /* search941_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2789 },
      -1,
   } },

   /* replace941_0 -> 2781 in the cache */
   /* replace941_1_0 -> 32 in the cache */
   /* replace941_1 -> 2736 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2781, 2736 },
      -1,
   } },

   /* ('~flog2', ('fpow', 'a', 'b')) => ('fmul', 'b', ('flog2', 'a')) */
   /* search942_0_0 -> 0 in the cache */
   /* search942_0_1 -> 3 in the cache */
   /* search942_0 -> 2740 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2740 },
      -1,
   } },

   /* replace942_0 -> 3 in the cache */
   /* replace942_1_0 -> 0 in the cache */
   /* replace942_1 -> 2741 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3, 2741 },
      -1,
   } },

   /* ('~fmul', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('fadd', 'a', 'b')) */
   /* search943_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 0 },
      0,
   } },
   /* search943_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2794, 2795 },
      -1,
   } },

   /* replace943_0_0 -> 0 in the cache */
   /* replace943_0_1 -> 3 in the cache */
   /* replace943_0 -> 274 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 274 },
      -1,
   } },

   /* ('bcsel', ('flt', 'a', 0.0), 0.0, ('fsqrt', 'a')) => ('fsqrt', ('fmax', 'a', 0.0)) */
   /* search944_0_0 -> 32 in the cache */
   /* search944_0_1 -> 113 in the cache */
   /* search944_0 -> 1159 in the cache */
   /* search944_1 -> 113 in the cache */
   /* search944_2_0 -> 32 in the cache */
   /* search944_2 -> 2757 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1159, 113, 2757 },
      -1,
   } },

   /* replace944_0_0 -> 32 in the cache */
   /* replace944_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 1,
      { 2799 },
      -1,
   } },

   /* ('~fmul', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a') */
   /* search945_0_0 -> 32 in the cache */
   /* search945_0 -> 2757 in the cache */
   /* search945_1_0 -> 32 in the cache */
   /* search945_1 -> 2757 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 2757, 2757 },
      -1,
   } },

   /* replace945_0 -> 32 in the cache */
   /* replace945 -> 103 in the cache */

   /* ('~fmulz', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a') */
   /* search946_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search946_1_0 -> 16 in the cache */
   /* search946_1 -> 2802 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      -1, 0,
      { 2802, 2802 },
      -1,
   } },

   /* replace946_0 -> 16 in the cache */
   /* replace946 -> 698 in the cache */

   /* ('~fdiv', 1.0, 'a') => ('frcp', 'a') */
   /* search947_0 -> 243 in the cache */
   /* search947_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 243, 32 },
      -1,
   } },

   /* replace947_0 -> 32 in the cache */
   /* replace947 -> 2786 in the cache */

   /* ('fdiv', 'a', 'b') => ('fmul', 'a', ('frcp', 'b')) */
   /* search948_0 -> 0 in the cache */
   /* search948_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace948_0 -> 0 in the cache */
   /* replace948_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2806 },
      -1,
   } },

   /* ('~frcp', ('frcp', 'a')) => a */
   /* search949_0_0 -> 32 in the cache */
   /* search949_0 -> 2786 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2786 },
      -1,
   } },

   /* replace949 -> 32 in the cache */

   /* ('~frcp', ('fsqrt', 'a')) => ('frsq', 'a') */
   /* search950_0_0 -> 32 in the cache */
   /* search950_0 -> 2757 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2757 },
      -1,
   } },

   /* replace950_0 -> 32 in the cache */
   /* replace950 -> 2789 in the cache */

   /* ('fsqrt', 'a') => ('frcp', ('frsq', 'a')) */
   /* search951_0 -> 32 in the cache */
   /* search951 -> 2757 in the cache */

   /* replace951_0_0 -> 32 in the cache */
   /* replace951_0 -> 2789 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2789 },
      -1,
   } },

   /* ('~frcp', ('frsq', 'a')) => ('fsqrt', 'a') */
   /* search952_0_0 -> 32 in the cache */
   /* search952_0 -> 2789 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2789 },
      -1,
   } },

   /* replace952_0 -> 32 in the cache */
   /* replace952 -> 2757 in the cache */

   /* ('fsin', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)) */
   /* search953_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace953_0_0_0_0_0_0 -> 2758 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fc45f306dc9c883 /* 0.15915494309189535 */ },
   } },
   /* replace953_0_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      5, 1,
      { 2813, 32 },
      -1,
   } },
   /* replace953_0_0_0_0_0_1_0_1 -> 2754 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      4, 2,
      { 2814, 2754 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2815 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 3,
      { 2758, 2816 },
      -1,
   } },
   /* replace953_0_0_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2817, 243 },
      -1,
   } },
   /* replace953_0_0_0_1_0_0_0 -> 2758 in the cache */
   /* replace953_0_0_0_1_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace953_0_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      9, 1,
      { 2813, 32 },
      -1,
   } },
   /* replace953_0_0_0_1_0_0_1_0_1 -> 2754 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      8, 2,
      { 2819, 2754 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2820 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      7, 3,
      { 2758, 2821 },
      -1,
   } },
   /* replace953_0_0_0_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2822, 243 },
      -1,
   } },
   /* replace953_0_0_0_1_1_0_0_0 -> 2758 in the cache */
   /* replace953_0_0_0_1_1_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace953_0_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      12, 1,
      { 2813, 32 },
      -1,
   } },
   /* replace953_0_0_0_1_1_0_0_1_0_1 -> 2754 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      11, 2,
      { 2824, 2754 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2825 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      10, 3,
      { 2758, 2826 },
      -1,
   } },
   /* replace953_0_0_0_1_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2827, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2828 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      6, 7,
      { 2823, 2829 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2818, 2830 },
      -1,
   } },
   /* replace953_0_0_1 -> 2761 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 11,
      { 2831, 2761 },
      -1,
   } },
   /* replace953_0_1_0_0_0_0_0 -> 2758 in the cache */
   /* replace953_0_1_0_0_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace953_0_1_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      16, 1,
      { 2813, 32 },
      -1,
   } },
   /* replace953_0_1_0_0_0_0_1_0_1 -> 2754 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      15, 2,
      { 2833, 2754 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2834 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      14, 3,
      { 2758, 2835 },
      -1,
   } },
   /* replace953_0_1_0_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2836, 243 },
      -1,
   } },
   /* replace953_0_1_0_0_1_0_0_0 -> 2758 in the cache */
   /* replace953_0_1_0_0_1_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace953_0_1_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      20, 1,
      { 2813, 32 },
      -1,
   } },
   /* replace953_0_1_0_0_1_0_0_1_0_1 -> 2754 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      19, 2,
      { 2838, 2754 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2839 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      18, 3,
      { 2758, 2840 },
      -1,
   } },
   /* replace953_0_1_0_0_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2841, 243 },
      -1,
   } },
   /* replace953_0_1_0_0_1_1_0_0_0 -> 2758 in the cache */
   /* replace953_0_1_0_0_1_1_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace953_0_1_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      23, 1,
      { 2813, 32 },
      -1,
   } },
   /* replace953_0_1_0_0_1_1_0_0_1_0_1 -> 2754 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      22, 2,
      { 2843, 2754 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2844 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      21, 3,
      { 2758, 2845 },
      -1,
   } },
   /* replace953_0_1_0_0_1_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2846, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      17, 7,
      { 2842, 2848 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2837, 2849 },
      -1,
   } },
   /* replace953_0_1_0_1 -> 2761 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      13, 11,
      { 2850, 2761 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 11,
      { 2851 },
      -1,
   } },
   /* replace953_0_2_0_0_0_0_0 -> 2758 in the cache */
   /* replace953_0_2_0_0_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace953_0_2_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      27, 1,
      { 2813, 32 },
      -1,
   } },
   /* replace953_0_2_0_0_0_0_1_0_1 -> 2754 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      26, 2,
      { 2853, 2754 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2854 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      25, 3,
      { 2758, 2855 },
      -1,
   } },
   /* replace953_0_2_0_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2856, 243 },
      -1,
   } },
   /* replace953_0_2_0_0_1_0_0_0 -> 2758 in the cache */
   /* replace953_0_2_0_0_1_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace953_0_2_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      31, 1,
      { 2813, 32 },
      -1,
   } },
   /* replace953_0_2_0_0_1_0_0_1_0_1 -> 2754 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      30, 2,
      { 2858, 2754 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2859 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      29, 3,
      { 2758, 2860 },
      -1,
   } },
   /* replace953_0_2_0_0_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2861, 243 },
      -1,
   } },
   /* replace953_0_2_0_0_1_1_0_0_0 -> 2758 in the cache */
   /* replace953_0_2_0_0_1_1_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace953_0_2_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      34, 1,
      { 2813, 32 },
      -1,
   } },
   /* replace953_0_2_0_0_1_1_0_0_1_0_1 -> 2754 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      33, 2,
      { 2863, 2754 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2864 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      32, 3,
      { 2758, 2865 },
      -1,
   } },
   /* replace953_0_2_0_0_1_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2866, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2867 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      28, 7,
      { 2862, 2868 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2857, 2869 },
      -1,
   } },
   /* replace953_0_2_0_1 -> 2761 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      24, 11,
      { 2870, 2761 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 11,
      { 2871 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 34,
      { 2832, 2852, 2872 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fcccccccccccccd /* 0.225 */ },
   } },
   /* replace953_2_0_0_0_0 -> 2758 in the cache */
   /* replace953_2_0_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace953_2_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      38, 1,
      { 2813, 32 },
      -1,
   } },
   /* replace953_2_0_0_0_1_0_1 -> 2754 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      37, 2,
      { 2875, 2754 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2876 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      36, 3,
      { 2758, 2877 },
      -1,
   } },
   /* replace953_2_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2878, 243 },
      -1,
   } },
   /* replace953_2_0_1_0_0_0 -> 2758 in the cache */
   /* replace953_2_0_1_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace953_2_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      42, 1,
      { 2813, 32 },
      -1,
   } },
   /* replace953_2_0_1_0_0_1_0_1 -> 2754 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      41, 2,
      { 2880, 2754 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2881 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      40, 3,
      { 2758, 2882 },
      -1,
   } },
   /* replace953_2_0_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2883, 243 },
      -1,
   } },
   /* replace953_2_0_1_1_0_0_0 -> 2758 in the cache */
   /* replace953_2_0_1_1_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace953_2_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      45, 1,
      { 2813, 32 },
      -1,
   } },
   /* replace953_2_0_1_1_0_0_1_0_1 -> 2754 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      44, 2,
      { 2885, 2754 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2886 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      43, 3,
      { 2758, 2887 },
      -1,
   } },
   /* replace953_2_0_1_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2888, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2889 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      39, 7,
      { 2884, 2890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2879, 2891 },
      -1,
   } },
   /* replace953_2_1 -> 2761 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      35, 11,
      { 2892, 2761 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 46,
      { 2873, 2874, 2893 },
      -1,
   } },

   /* ('fcos', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)) */
   /* search954_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace954_0_0_0_0_0_0 -> 2758 in the cache */
   /* replace954_0_0_0_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace954_0_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace954_0_0_0_0_0_1_0_0 -> 2814 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe8000000000000 /* 0.75 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      4, 2,
      { 2814, 2896 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 3,
      { 2758, 2898 },
      -1,
   } },
   /* replace954_0_0_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2899, 243 },
      -1,
   } },
   /* replace954_0_0_0_1_0_0_0 -> 2758 in the cache */
   /* replace954_0_0_0_1_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace954_0_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace954_0_0_0_1_0_0_1_0_0 -> 2819 in the cache */
   /* replace954_0_0_0_1_0_0_1_0_1 -> 2896 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      8, 2,
      { 2819, 2896 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2901 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      7, 3,
      { 2758, 2902 },
      -1,
   } },
   /* replace954_0_0_0_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2903, 243 },
      -1,
   } },
   /* replace954_0_0_0_1_1_0_0_0 -> 2758 in the cache */
   /* replace954_0_0_0_1_1_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace954_0_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace954_0_0_0_1_1_0_0_1_0_0 -> 2824 in the cache */
   /* replace954_0_0_0_1_1_0_0_1_0_1 -> 2896 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      11, 2,
      { 2824, 2896 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2905 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      10, 3,
      { 2758, 2906 },
      -1,
   } },
   /* replace954_0_0_0_1_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2907, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2908 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      6, 7,
      { 2904, 2909 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2900, 2910 },
      -1,
   } },
   /* replace954_0_0_1 -> 2761 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 11,
      { 2911, 2761 },
      -1,
   } },
   /* replace954_0_1_0_0_0_0_0 -> 2758 in the cache */
   /* replace954_0_1_0_0_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace954_0_1_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace954_0_1_0_0_0_0_1_0_0 -> 2833 in the cache */
   /* replace954_0_1_0_0_0_0_1_0_1 -> 2896 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      15, 2,
      { 2833, 2896 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2913 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      14, 3,
      { 2758, 2914 },
      -1,
   } },
   /* replace954_0_1_0_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2915, 243 },
      -1,
   } },
   /* replace954_0_1_0_0_1_0_0_0 -> 2758 in the cache */
   /* replace954_0_1_0_0_1_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace954_0_1_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace954_0_1_0_0_1_0_0_1_0_0 -> 2838 in the cache */
   /* replace954_0_1_0_0_1_0_0_1_0_1 -> 2896 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      19, 2,
      { 2838, 2896 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2917 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      18, 3,
      { 2758, 2918 },
      -1,
   } },
   /* replace954_0_1_0_0_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2919, 243 },
      -1,
   } },
   /* replace954_0_1_0_0_1_1_0_0_0 -> 2758 in the cache */
   /* replace954_0_1_0_0_1_1_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace954_0_1_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace954_0_1_0_0_1_1_0_0_1_0_0 -> 2843 in the cache */
   /* replace954_0_1_0_0_1_1_0_0_1_0_1 -> 2896 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      22, 2,
      { 2843, 2896 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2921 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      21, 3,
      { 2758, 2922 },
      -1,
   } },
   /* replace954_0_1_0_0_1_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2923, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2924 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      17, 7,
      { 2920, 2925 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2916, 2926 },
      -1,
   } },
   /* replace954_0_1_0_1 -> 2761 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      13, 11,
      { 2927, 2761 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 11,
      { 2928 },
      -1,
   } },
   /* replace954_0_2_0_0_0_0_0 -> 2758 in the cache */
   /* replace954_0_2_0_0_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace954_0_2_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace954_0_2_0_0_0_0_1_0_0 -> 2853 in the cache */
   /* replace954_0_2_0_0_0_0_1_0_1 -> 2896 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      26, 2,
      { 2853, 2896 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2930 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      25, 3,
      { 2758, 2931 },
      -1,
   } },
   /* replace954_0_2_0_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2932, 243 },
      -1,
   } },
   /* replace954_0_2_0_0_1_0_0_0 -> 2758 in the cache */
   /* replace954_0_2_0_0_1_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace954_0_2_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace954_0_2_0_0_1_0_0_1_0_0 -> 2858 in the cache */
   /* replace954_0_2_0_0_1_0_0_1_0_1 -> 2896 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      30, 2,
      { 2858, 2896 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2934 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      29, 3,
      { 2758, 2935 },
      -1,
   } },
   /* replace954_0_2_0_0_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2936, 243 },
      -1,
   } },
   /* replace954_0_2_0_0_1_1_0_0_0 -> 2758 in the cache */
   /* replace954_0_2_0_0_1_1_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace954_0_2_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace954_0_2_0_0_1_1_0_0_1_0_0 -> 2863 in the cache */
   /* replace954_0_2_0_0_1_1_0_0_1_0_1 -> 2896 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      33, 2,
      { 2863, 2896 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2938 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      32, 3,
      { 2758, 2939 },
      -1,
   } },
   /* replace954_0_2_0_0_1_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2940, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2941 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      28, 7,
      { 2937, 2942 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2933, 2943 },
      -1,
   } },
   /* replace954_0_2_0_1 -> 2761 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      24, 11,
      { 2944, 2761 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 11,
      { 2945 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 34,
      { 2912, 2929, 2946 },
      -1,
   } },
   /* replace954_1 -> 2874 in the cache */
   /* replace954_2_0_0_0_0 -> 2758 in the cache */
   /* replace954_2_0_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace954_2_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace954_2_0_0_0_1_0_0 -> 2875 in the cache */
   /* replace954_2_0_0_0_1_0_1 -> 2896 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      37, 2,
      { 2875, 2896 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2948 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      36, 3,
      { 2758, 2949 },
      -1,
   } },
   /* replace954_2_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2950, 243 },
      -1,
   } },
   /* replace954_2_0_1_0_0_0 -> 2758 in the cache */
   /* replace954_2_0_1_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace954_2_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace954_2_0_1_0_0_1_0_0 -> 2880 in the cache */
   /* replace954_2_0_1_0_0_1_0_1 -> 2896 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      41, 2,
      { 2880, 2896 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2952 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      40, 3,
      { 2758, 2953 },
      -1,
   } },
   /* replace954_2_0_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2954, 243 },
      -1,
   } },
   /* replace954_2_0_1_1_0_0_0 -> 2758 in the cache */
   /* replace954_2_0_1_1_0_0_1_0_0_0 -> 2813 in the cache */
   /* replace954_2_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace954_2_0_1_1_0_0_1_0_0 -> 2885 in the cache */
   /* replace954_2_0_1_1_0_0_1_0_1 -> 2896 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      44, 2,
      { 2885, 2896 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2956 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      43, 3,
      { 2758, 2957 },
      -1,
   } },
   /* replace954_2_0_1_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2958, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2959 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      39, 7,
      { 2955, 2960 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2951, 2961 },
      -1,
   } },
   /* replace954_2_1 -> 2761 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      35, 11,
      { 2962, 2761 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 46,
      { 2947, 2874, 2963 },
      -1,
   } },

   /* ('i2b16(is_used_by_if)', 'a') => ('ine16', 'a', 0) */
   /* search955_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2b16,
      -1, 0,
      { 32 },
      2,
   } },

   /* replace955_0 -> 32 in the cache */
   /* replace955_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ine16,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('i2b32(is_used_by_if)', 'a') => ('ine32', 'a', 0) */
   /* search956_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2b32,
      -1, 0,
      { 32 },
      2,
   } },

   /* replace956_0 -> 32 in the cache */
   /* replace956_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ine32,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('i2b1(is_used_by_if)', 'a') => ('ine', 'a', 0) */
   /* search957_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2b1,
      -1, 0,
      { 32 },
      2,
   } },

   /* replace957_0 -> 32 in the cache */
   /* replace957_1 -> 61 in the cache */
   /* replace957 -> 1220 in the cache */

   /* ('ieq', 'a', True) => a */
   /* search958_0 -> 753 in the cache */
   /* search958_1 -> 1224 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 753, 1224 },
      -1,
   } },

   /* replace958 -> 753 in the cache */

   /* ('ine(is_not_used_by_if)', 'a', True) => ('inot', 'a') */
   /* search959_0 -> 753 in the cache */
   /* search959_1 -> 1224 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 753, 1224 },
      3,
   } },

   /* replace959_0 -> 753 in the cache */
   /* replace959 -> 1118 in the cache */

   /* ('ine', 'a', False) => a */
   /* search960_0 -> 753 in the cache */
   /* search960_1 -> 1070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 753, 1070 },
      -1,
   } },

   /* replace960 -> 753 in the cache */

   /* ('ieq(is_not_used_by_if)', 'a', False) => ('inot', 'a') */
   /* search961_0 -> 753 in the cache */
   /* search961_1 -> 1070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 753, 1070 },
      3,
   } },

   /* replace961_0 -> 753 in the cache */
   /* replace961 -> 1118 in the cache */

   /* ('bcsel', 'a', True, False) => a */
   /* search962_0 -> 753 in the cache */
   /* search962_1 -> 1224 in the cache */
   /* search962_2 -> 1070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1224, 1070 },
      -1,
   } },

   /* replace962 -> 753 in the cache */

   /* ('bcsel', 'a', False, True) => ('inot', 'a') */
   /* search963_0 -> 753 in the cache */
   /* search963_1 -> 1070 in the cache */
   /* search963_2 -> 1224 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1070, 1224 },
      -1,
   } },

   /* replace963_0 -> 753 in the cache */
   /* replace963 -> 1118 in the cache */

   /* ('bcsel', True, 'b', 'c') => b */
   /* search964_0 -> 1224 in the cache */
   /* search964_1 -> 1104 in the cache */
   /* search964_2 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1224, 1104, 686 },
      -1,
   } },

   /* replace964 -> 1104 in the cache */

   /* ('bcsel', False, 'b', 'c') => c */
   /* search965_0 -> 1070 in the cache */
   /* search965_1 -> 1104 in the cache */
   /* search965_2 -> 686 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1070, 1104, 686 },
      -1,
   } },

   /* replace965 -> 686 in the cache */

   /* ('bcsel@16', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search966_0 -> 753 in the cache */
   /* search966_1 -> 483 in the cache */
   /* search966_2 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 483, 115 },
      -1,
   } },

   /* replace966_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 753 },
      -1,
   } },

   /* ('bcsel@16', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search967_0 -> 753 in the cache */
   /* search967_1 -> 115 in the cache */
   /* search967_2 -> 483 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 115, 483 },
      -1,
   } },

   /* replace967_0_0 -> 753 in the cache */
   /* replace967_0 -> 1118 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1118 },
      -1,
   } },

   /* ('bcsel@16', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search968_0 -> 753 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 2982, 2983 },
      -1,
   } },

   /* replace968_0_0 -> 753 in the cache */
   /* replace968_0 -> 2979 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2979 },
      -1,
   } },

   /* ('bcsel@16', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search969_0 -> 753 in the cache */
   /* search969_1 -> 2983 in the cache */
   /* search969_2 -> 2982 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 2983, 2982 },
      -1,
   } },

   /* replace969_0_0_0 -> 753 in the cache */
   /* replace969_0_0 -> 1118 in the cache */
   /* replace969_0 -> 2981 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2981 },
      -1,
   } },

   /* ('bcsel@32', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search970_0 -> 753 in the cache */
   /* search970_1 -> 245 in the cache */
   /* search970_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 245, 117 },
      -1,
   } },

   /* replace970_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 753 },
      -1,
   } },

   /* ('bcsel@32', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search971_0 -> 753 in the cache */
   /* search971_1 -> 117 in the cache */
   /* search971_2 -> 245 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 117, 245 },
      -1,
   } },

   /* replace971_0_0 -> 753 in the cache */
   /* replace971_0 -> 1118 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1118 },
      -1,
   } },

   /* ('bcsel@32', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search972_0 -> 753 in the cache */
   /* search972_1 -> 280 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 280, 2992 },
      -1,
   } },

   /* replace972_0_0 -> 753 in the cache */
   /* replace972_0 -> 2989 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2989 },
      -1,
   } },

   /* ('bcsel@32', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search973_0 -> 753 in the cache */
   /* search973_1 -> 2992 in the cache */
   /* search973_2 -> 280 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 2992, 280 },
      -1,
   } },

   /* replace973_0_0_0 -> 753 in the cache */
   /* replace973_0_0 -> 1118 in the cache */
   /* replace973_0 -> 2991 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2991 },
      -1,
   } },

   /* ('bcsel@64', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search974_0 -> 753 in the cache */
   /* search974_1 -> 624 in the cache */
   /* search974_2 -> 703 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 624, 703 },
      -1,
   } },

   /* replace974_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 753 },
      -1,
   } },

   /* ('bcsel@64', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search975_0 -> 753 in the cache */
   /* search975_1 -> 703 in the cache */
   /* search975_2 -> 624 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 703, 624 },
      -1,
   } },

   /* replace975_0_0 -> 753 in the cache */
   /* replace975_0 -> 1118 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1118 },
      -1,
   } },

   /* ('bcsel@64', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search976_0 -> 753 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 3001, 3002 },
      -1,
   } },

   /* replace976_0_0 -> 753 in the cache */
   /* replace976_0 -> 2998 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2998 },
      -1,
   } },

   /* ('bcsel@64', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search977_0 -> 753 in the cache */
   /* search977_1 -> 3002 in the cache */
   /* search977_2 -> 3001 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 3002, 3001 },
      -1,
   } },

   /* replace977_0_0_0 -> 753 in the cache */
   /* replace977_0_0 -> 1118 in the cache */
   /* replace977_0 -> 3000 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3000 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', 'b') => b */
   /* search978_0 -> 753 in the cache */
   /* search978_1 -> 3 in the cache */
   /* search978_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 3, 3 },
      -1,
   } },

   /* replace978 -> 3 in the cache */

   /* ('~fcsel', 'a', 'b', 'b') => b */
   /* search979_0 -> 16 in the cache */
   /* search979_1 -> 36 in the cache */
   /* search979_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 16, 36, 36 },
      -1,
   } },

   /* replace979 -> 36 in the cache */

   /* ('bcsel', 'a', -1, 0) => ('ineg', ('b2i', 'a@1')) */
   /* search980_0 -> 753 in the cache */
   /* search980_1 -> 2692 in the cache */
   /* search980_2 -> 1216 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 2692, 1216 },
      -1,
   } },

   /* replace980_0_0 -> 753 in the cache */
   /* replace980_0 -> 1215 in the cache */
   /* replace980 -> 2237 in the cache */

   /* ('bcsel', 'a', 0, -1) => ('ineg', ('b2i', ('inot', 'a'))) */
   /* search981_0 -> 753 in the cache */
   /* search981_1 -> 1216 in the cache */
   /* search981_2 -> 2692 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1216, 2692 },
      -1,
   } },

   /* replace981_0_0_0 -> 753 in the cache */
   /* replace981_0_0 -> 1118 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1118 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3011 },
      -1,
   } },

   /* ('bcsel', 'a', 1, 0) => ('b2i', 'a@1') */
   /* search982_0 -> 753 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   /* search982_2 -> 1216 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 3013, 1216 },
      -1,
   } },

   /* replace982_0 -> 753 in the cache */
   /* replace982 -> 1215 in the cache */

   /* ('bcsel', 'a', 0, 1) => ('b2i', ('inot', 'a')) */
   /* search983_0 -> 753 in the cache */
   /* search983_1 -> 1216 in the cache */
   /* search983_2 -> 3013 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1216, 3013 },
      -1,
   } },

   /* replace983_0_0 -> 753 in the cache */
   /* replace983_0 -> 1118 in the cache */
   /* replace983 -> 3011 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search984_0_0_0 -> 753 in the cache */
   /* search984_0_0 -> 1215 in the cache */
   /* search984_0 -> 2237 in the cache */
   /* search984_1_0_0 -> 1121 in the cache */
   /* search984_1_0 -> 2238 in the cache */
   /* search984_1 -> 2239 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2237, 2239 },
      -1,
   } },

   /* replace984_0_0_0 -> 753 in the cache */
   /* replace984_0_0_1 -> 1121 in the cache */
   /* replace984_0_0 -> 1133 in the cache */
   /* replace984_0 -> 2639 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 2639 },
      -1,
   } },

   /* ('ior', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search985_0_0_0 -> 753 in the cache */
   /* search985_0_0 -> 1215 in the cache */
   /* search985_0 -> 2237 in the cache */
   /* search985_1_0_0 -> 1121 in the cache */
   /* search985_1_0 -> 2238 in the cache */
   /* search985_1 -> 2239 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2237, 2239 },
      -1,
   } },

   /* replace985_0_0_0 -> 753 in the cache */
   /* replace985_0_0_1 -> 1121 in the cache */
   /* replace985_0_0 -> 1125 in the cache */
   /* replace985_0 -> 2642 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 2642 },
      -1,
   } },

   /* ('ieq', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a') */
   /* search986_0_0_0 -> 753 in the cache */
   /* search986_0_0 -> 1215 in the cache */
   /* search986_0 -> 2237 in the cache */
   /* search986_1 -> 1216 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2237, 1216 },
      -1,
   } },

   /* replace986_0 -> 753 in the cache */
   /* replace986 -> 1118 in the cache */

   /* ('ieq', ('ineg', ('b2i', 'a@1')), -1) => a */
   /* search987_0_0_0 -> 753 in the cache */
   /* search987_0_0 -> 1215 in the cache */
   /* search987_0 -> 2237 in the cache */
   /* search987_1 -> 2692 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2237, 2692 },
      -1,
   } },

   /* replace987 -> 753 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), 0) => a */
   /* search988_0_0_0 -> 753 in the cache */
   /* search988_0_0 -> 1215 in the cache */
   /* search988_0 -> 2237 in the cache */
   /* search988_1 -> 1216 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2237, 1216 },
      -1,
   } },

   /* replace988 -> 753 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), -1) => ('inot', 'a') */
   /* search989_0_0_0 -> 753 in the cache */
   /* search989_0_0 -> 1215 in the cache */
   /* search989_0 -> 2237 in the cache */
   /* search989_1 -> 2692 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2237, 2692 },
      -1,
   } },

   /* replace989_0 -> 753 in the cache */
   /* replace989 -> 1118 in the cache */

   /* ('ige', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a') */
   /* search990_0_0_0 -> 753 in the cache */
   /* search990_0_0 -> 1215 in the cache */
   /* search990_0 -> 2237 in the cache */
   /* search990_1 -> 1216 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2237, 1216 },
      -1,
   } },

   /* replace990_0 -> 753 in the cache */
   /* replace990 -> 1118 in the cache */

   /* ('ilt', ('ineg', ('b2i', 'a@1')), 0) => a */
   /* search991_0_0_0 -> 753 in the cache */
   /* search991_0_0 -> 1215 in the cache */
   /* search991_0 -> 2237 in the cache */
   /* search991_1 -> 1216 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2237, 1216 },
      -1,
   } },

   /* replace991 -> 753 in the cache */

   /* ('ult', 0, ('ineg', ('b2i', 'a@1'))) => a */
   /* search992_0 -> 1216 in the cache */
   /* search992_1_0_0 -> 753 in the cache */
   /* search992_1_0 -> 1215 in the cache */
   /* search992_1 -> 2237 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1216, 2237 },
      -1,
   } },

   /* replace992 -> 753 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a')), 1.0) => ('b2f', 'a') */
   /* search993_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3027 },
      -1,
   } },
   /* search993_1 -> 1126 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3028, 1126 },
      -1,
   } },

   /* replace993_0 -> 32 in the cache */
   /* replace993 -> 1520 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a')), 1) => ('b2i', 'a') */
   /* search994_0_0_0 -> 32 in the cache */
   /* search994_0_0 -> 3027 in the cache */
   /* search994_0 -> 3028 in the cache */
   /* search994_1 -> 3013 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3028, 3013 },
      -1,
   } },

   /* replace994_0 -> 32 in the cache */
   /* replace994 -> 3027 in the cache */

   /* ('imax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search995_0_0_0 -> 753 in the cache */
   /* search995_0_0 -> 1215 in the cache */
   /* search995_0 -> 2237 in the cache */
   /* search995_1_0_0 -> 1121 in the cache */
   /* search995_1_0 -> 2238 in the cache */
   /* search995_1 -> 2239 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2237, 2239 },
      -1,
   } },

   /* replace995_0_0_0 -> 753 in the cache */
   /* replace995_0_0_1 -> 1121 in the cache */
   /* replace995_0_0 -> 1133 in the cache */
   /* replace995_0 -> 2639 in the cache */
   /* replace995 -> 3017 in the cache */

   /* ('imin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search996_0_0_0 -> 753 in the cache */
   /* search996_0_0 -> 1215 in the cache */
   /* search996_0 -> 2237 in the cache */
   /* search996_1_0_0 -> 1121 in the cache */
   /* search996_1_0 -> 2238 in the cache */
   /* search996_1 -> 2239 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2237, 2239 },
      -1,
   } },

   /* replace996_0_0_0 -> 753 in the cache */
   /* replace996_0_0_1 -> 1121 in the cache */
   /* replace996_0_0 -> 1125 in the cache */
   /* replace996_0 -> 2642 in the cache */
   /* replace996 -> 3019 in the cache */

   /* ('umax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search997_0_0_0 -> 753 in the cache */
   /* search997_0_0 -> 1215 in the cache */
   /* search997_0 -> 2237 in the cache */
   /* search997_1_0_0 -> 1121 in the cache */
   /* search997_1_0 -> 2238 in the cache */
   /* search997_1 -> 2239 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 2237, 2239 },
      -1,
   } },

   /* replace997_0_0_0 -> 753 in the cache */
   /* replace997_0_0_1 -> 1121 in the cache */
   /* replace997_0_0 -> 1125 in the cache */
   /* replace997_0 -> 2642 in the cache */
   /* replace997 -> 3019 in the cache */

   /* ('umin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search998_0_0_0 -> 753 in the cache */
   /* search998_0_0 -> 1215 in the cache */
   /* search998_0 -> 2237 in the cache */
   /* search998_1_0_0 -> 1121 in the cache */
   /* search998_1_0 -> 2238 in the cache */
   /* search998_1 -> 2239 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 2237, 2239 },
      -1,
   } },

   /* replace998_0_0_0 -> 753 in the cache */
   /* replace998_0_0_1 -> 1121 in the cache */
   /* replace998_0_0 -> 1133 in the cache */
   /* replace998_0 -> 2639 in the cache */
   /* replace998 -> 3017 in the cache */

   /* ('i2b16', ('b2i', 'a@16')) => a */
   /* search999_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2b16,
      -1, 0,
      { 3035 },
      -1,
   } },

   /* replace999 -> 11 in the cache */

   /* ('i2b32', ('b2i', 'a@32')) => a */
   /* search1000_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2b32,
      -1, 0,
      { 3037 },
      -1,
   } },

   /* replace1000 -> 16 in the cache */

   /* ('f2i', ('ftrunc', 'a')) => ('f2i', 'a') */
   /* search1001_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 3039 },
      -1,
   } },

   /* replace1001_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('f2u', ('ftrunc', 'a')) => ('f2u', 'a') */
   /* search1002_0_0 -> 32 in the cache */
   /* search1002_0 -> 3039 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 3039 },
      -1,
   } },

   /* replace1002_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2b', ('ineg', 'a')) => ('i2b', 'a') */
   /* search1003_0_0 -> 32 in the cache */
   /* search1003_0 -> 100 in the cache */
   /* search1003 -> 111 in the cache */

   /* replace1003_0 -> 32 in the cache */
   /* replace1003 -> 112 in the cache */

   /* ('i2b', ('iabs', 'a')) => ('i2b', 'a') */
   /* search1004_0_0 -> 32 in the cache */
   /* search1004_0 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 106 },
      -1,
   } },

   /* replace1004_0 -> 32 in the cache */
   /* replace1004 -> 112 in the cache */

   /* ('inot', ('f2b1', 'a')) => ('feq', 'a', 0.0) */
   /* search1005_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_f2b1,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3045 },
      -1,
   } },

   /* replace1005_0 -> 32 in the cache */
   /* replace1005_1 -> 113 in the cache */
   /* replace1005 -> 1246 in the cache */

   /* ('f2fmp', ('f2f32', 'a@16')) => a */
   /* search1006_0_0 -> 11 in the cache */
   /* search1006_0 -> 1791 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1791 },
      -1,
   } },

   /* replace1006 -> 11 in the cache */

   /* ('i2imp', ('i2i32', 'a@16')) => a */
   /* search1007_0_0 -> 11 in the cache */
   /* search1007_0 -> 1793 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1793 },
      -1,
   } },

   /* replace1007 -> 11 in the cache */

   /* ('i2imp', ('u2u32', 'a@16')) => a */
   /* search1008_0_0 -> 11 in the cache */
   /* search1008_0 -> 1795 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1795 },
      -1,
   } },

   /* replace1008 -> 11 in the cache */

   /* ('f2imp', ('f2f32', 'a@16')) => ('f2i16', 'a') */
   /* search1009_0_0 -> 11 in the cache */
   /* search1009_0 -> 1791 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 1791 },
      -1,
   } },

   /* replace1009_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2ump', ('f2f32', 'a@16')) => ('f2u16', 'a') */
   /* search1010_0_0 -> 11 in the cache */
   /* search1010_0 -> 1791 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 1791 },
      -1,
   } },

   /* replace1010_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2fmp', ('i2i32', 'a@16')) => ('i2f16', 'a') */
   /* search1011_0_0 -> 11 in the cache */
   /* search1011_0 -> 1793 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 1793 },
      -1,
   } },

   /* replace1011_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('u2fmp', ('u2u32', 'a@16')) => ('u2f16', 'a') */
   /* search1012_0_0 -> 11 in the cache */
   /* search1012_0 -> 1795 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 1795 },
      -1,
   } },

   /* replace1012_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2fmp', ('b2f32', 'a@1')) => ('b2f16', 'a') */
   /* search1013_0_0 -> 753 in the cache */
   /* search1013_0 -> 1400 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1400 },
      -1,
   } },

   /* replace1013_0 -> 753 in the cache */
   /* replace1013 -> 1396 in the cache */

   /* ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search1014_0_0 -> 753 in the cache */
   /* search1014_0 -> 1388 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1388 },
      -1,
   } },

   /* replace1014_0 -> 753 in the cache */
   /* replace1014 -> 1384 in the cache */

   /* ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search1015_0_0 -> 753 in the cache */
   /* search1015_0 -> 1388 in the cache */
   /* search1015 -> 3059 in the cache */

   /* replace1015_0 -> 753 in the cache */
   /* replace1015 -> 1384 in the cache */

   /* ('f2imp', ('b2f32', 'a@1')) => ('b2i16', 'a') */
   /* search1016_0_0 -> 753 in the cache */
   /* search1016_0 -> 1400 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 1400 },
      -1,
   } },

   /* replace1016_0 -> 753 in the cache */
   /* replace1016 -> 1384 in the cache */

   /* ('f2ump', ('b2f32', 'a@1')) => ('b2i16', 'a') */
   /* search1017_0_0 -> 753 in the cache */
   /* search1017_0 -> 1400 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 1400 },
      -1,
   } },

   /* replace1017_0 -> 753 in the cache */
   /* replace1017 -> 1384 in the cache */

   /* ('i2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a') */
   /* search1018_0_0 -> 753 in the cache */
   /* search1018_0 -> 1388 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 1388 },
      -1,
   } },

   /* replace1018_0 -> 753 in the cache */
   /* replace1018 -> 1396 in the cache */

   /* ('u2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a') */
   /* search1019_0_0 -> 753 in the cache */
   /* search1019_0 -> 1388 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 1388 },
      -1,
   } },

   /* replace1019_0 -> 753 in the cache */
   /* replace1019 -> 1396 in the cache */

   /* ('f2f32', ('f2fmp', 'a@32')) => a */
   /* search1020_0_0 -> 16 in the cache */
   /* search1020_0 -> 1982 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1982 },
      -1,
   } },

   /* replace1020 -> 16 in the cache */

   /* ('i2i32', ('i2imp', 'a@32')) => a */
   /* search1021_0_0 -> 16 in the cache */
   /* search1021_0 -> 1993 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1993 },
      -1,
   } },

   /* replace1021 -> 16 in the cache */

   /* ('u2u32', ('i2imp', 'a@32')) => a */
   /* search1022_0_0 -> 16 in the cache */
   /* search1022_0 -> 1993 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1993 },
      -1,
   } },

   /* replace1022 -> 16 in the cache */

   /* ('i2i32', ('f2imp', 'a@32')) => ('f2i32', 'a') */
   /* search1023_0_0 -> 16 in the cache */
   /* search1023_0 -> 1992 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1992 },
      -1,
   } },

   /* replace1023_0 -> 16 in the cache */
   /* replace1023 -> 1990 in the cache */

   /* ('u2u32', ('f2ump', 'a@32')) => ('f2u32', 'a') */
   /* search1024_0_0 -> 16 in the cache */
   /* search1024_0 -> 1989 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1989 },
      -1,
   } },

   /* replace1024_0 -> 16 in the cache */
   /* replace1024 -> 1987 in the cache */

   /* ('f2f32', ('i2fmp', 'a@32')) => ('i2f32', 'a') */
   /* search1025_0_0 -> 16 in the cache */
   /* search1025_0 -> 1981 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1981 },
      -1,
   } },

   /* replace1025_0 -> 16 in the cache */
   /* replace1025 -> 1979 in the cache */

   /* ('f2f32', ('u2fmp', 'a@32')) => ('u2f32', 'a') */
   /* search1026_0_0 -> 16 in the cache */
   /* search1026_0 -> 1978 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1978 },
      -1,
   } },

   /* replace1026_0 -> 16 in the cache */
   /* replace1026 -> 1976 in the cache */

   /* ('~f2f32', ('f2f64', 'a@32')) => a */
   /* search1027_0_0 -> 16 in the cache */
   /* search1027_0 -> 1896 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1896 },
      -1,
   } },

   /* replace1027 -> 16 in the cache */

   /* ('ffloor', 'a(is_integral)') => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      20,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 3072 },
      -1,
   } },

   /* replace1028 -> 32 in the cache */

   /* ('fceil', 'a(is_integral)') => a */
   /* search1029_0 -> 3072 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 3072 },
      -1,
   } },

   /* replace1029 -> 32 in the cache */

   /* ('ftrunc', 'a(is_integral)') => a */
   /* search1030_0 -> 3072 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 3072 },
      -1,
   } },

   /* replace1030 -> 32 in the cache */

   /* ('fround_even', 'a(is_integral)') => a */
   /* search1031_0 -> 3072 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 3072 },
      -1,
   } },

   /* replace1031 -> 32 in the cache */

   /* ('~ffract', 'a(is_integral)') => 0.0 */
   /* search1032_0 -> 3072 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 3072 },
      -1,
   } },

   /* replace1032 -> 113 in the cache */

   /* ('fabs', 'a(is_not_negative)') => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 3078 },
      -1,
   } },

   /* replace1033 -> 32 in the cache */

   /* ('iabs', 'a(is_not_negative)') => a */
   /* search1034_0 -> 3078 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 3078 },
      -1,
   } },

   /* replace1034 -> 32 in the cache */

   /* ('fsat', 'a(is_not_positive)') => 0.0 */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 3081 },
      -1,
   } },

   /* replace1035 -> 113 in the cache */

   /* ('~fmin', 'a(is_not_negative)', 1.0) => ('fsat', 'a') */
   /* search1036_0 -> 3078 in the cache */
   /* search1036_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 3078, 243 },
      -1,
   } },

   /* replace1036_0 -> 32 in the cache */
   /* replace1036 -> 219 in the cache */

   /* ('flt', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => False */
   /* search1037_0_0_0_0 -> 32 in the cache */
   /* search1037_0_0_0 -> 219 in the cache */
   /* search1037_0_0_1_0_0 -> 32 in the cache */
   /* search1037_0_0_1_0 -> 219 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 219 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 219, 3084 },
      -1,
   } },
   /* search1037_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3085, 243 },
      -1,
   } },
   /* search1037_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 2,
      { 3086, 113 },
      -1,
   } },

   /* replace1037 -> 1070 in the cache */

   /* ('flt', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => False */
   /* search1038_0_0_0_0_0 -> 32 in the cache */
   /* search1038_0_0_0_0 -> 219 in the cache */
   /* search1038_0_0_0_1_0 -> 32 in the cache */
   /* search1038_0_0_0_1 -> 219 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 219, 219 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3088 },
      -1,
   } },
   /* search1038_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 3089, 243 },
      -1,
   } },
   /* search1038_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 3090, 113 },
      -1,
   } },

   /* replace1038 -> 1070 in the cache */

   /* ('fmax', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0) */
   /* search1039_0_0_0_0 -> 32 in the cache */
   /* search1039_0_0_0 -> 219 in the cache */
   /* search1039_0_0_1_0_0 -> 32 in the cache */
   /* search1039_0_0_1_0 -> 219 in the cache */
   /* search1039_0_0_1 -> 3084 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 219, 3084 },
      -1,
   } },
   /* search1039_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 3092, 243 },
      -1,
   } },
   /* search1039_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 3093, 113 },
      -1,
   } },

   /* replace1039_0_0_0 -> 32 in the cache */
   /* replace1039_0_0 -> 219 in the cache */
   /* replace1039_0_1_0_0 -> 32 in the cache */
   /* replace1039_0_1_0 -> 219 in the cache */
   /* replace1039_0_1 -> 3084 in the cache */
   /* replace1039_0 -> 3085 in the cache */
   /* replace1039_1 -> 243 in the cache */
   /* replace1039 -> 3086 in the cache */

   /* ('fmax', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0) */
   /* search1040_0_0_0_0_0 -> 32 in the cache */
   /* search1040_0_0_0_0 -> 219 in the cache */
   /* search1040_0_0_0_1_0 -> 32 in the cache */
   /* search1040_0_0_0_1 -> 219 in the cache */
   /* search1040_0_0_0 -> 3088 in the cache */
   /* search1040_0_0 -> 3089 in the cache */
   /* search1040_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3089, 243 },
      -1,
   } },
   /* search1040_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 3095, 113 },
      -1,
   } },

   /* replace1040_0_0_0_0 -> 32 in the cache */
   /* replace1040_0_0_0 -> 219 in the cache */
   /* replace1040_0_0_1_0 -> 32 in the cache */
   /* replace1040_0_0_1 -> 219 in the cache */
   /* replace1040_0_0 -> 3088 in the cache */
   /* replace1040_0 -> 3089 in the cache */
   /* replace1040_1 -> 243 in the cache */
   /* replace1040 -> 3090 in the cache */

   /* ('fneu', 'a(is_not_zero)', 0.0) => True */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      22,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1041_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 3097, 113 },
      -1,
   } },

   /* replace1041 -> 1224 in the cache */

   /* ('feq', 'a(is_not_zero)', 0.0) => False */
   /* search1042_0 -> 3097 in the cache */
   /* search1042_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 3097, 113 },
      -1,
   } },

   /* replace1042 -> 1070 in the cache */

   /* ('fge', 'a(is_a_number_not_negative)', 'b(is_a_number_not_positive)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      23,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      24,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3100, 3101 },
      -1,
   } },

   /* replace1043 -> 1224 in the cache */

   /* ('fge', 'a(is_not_positive)', 'b(is_gt_zero)') => False */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      25,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3103, 3104 },
      -1,
   } },

   /* replace1044 -> 1070 in the cache */

   /* ('fge', 'a(is_lt_zero)', 'b(is_not_negative)') => False */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      26,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3106, 3107 },
      -1,
   } },

   /* replace1045 -> 1070 in the cache */

   /* ('flt', 'a(is_not_negative)', 'b(is_not_positive)') => False */
   /* search1046_0 -> 1576 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1576, 3109 },
      -1,
   } },

   /* replace1046 -> 1070 in the cache */

   /* ('flt', 'a(is_a_number_not_positive)', 'b(is_a_number_gt_zero)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      24,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      27,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3111, 3112 },
      -1,
   } },

   /* replace1047 -> 1224 in the cache */

   /* ('flt', 'a(is_a_number_lt_zero)', 'b(is_a_number_not_negative)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      28,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      23,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3114, 3115 },
      -1,
   } },

   /* replace1048 -> 1224 in the cache */

   /* ('ine', 'a(is_not_zero)', 0) => True */
   /* search1049_0 -> 3097 in the cache */
   /* search1049_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3097, 61 },
      -1,
   } },

   /* replace1049 -> 1224 in the cache */

   /* ('ieq', 'a(is_not_zero)', 0) => False */
   /* search1050_0 -> 3097 in the cache */
   /* search1050_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3097, 61 },
      -1,
   } },

   /* replace1050 -> 1070 in the cache */

   /* ('ige', 'a(is_not_negative)', 'b(is_not_positive)') => True */
   /* search1051_0 -> 1576 in the cache */
   /* search1051_1 -> 3109 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1576, 3109 },
      -1,
   } },

   /* replace1051 -> 1224 in the cache */

   /* ('ige', 'a(is_not_positive)', 'b(is_gt_zero)') => False */
   /* search1052_0 -> 3103 in the cache */
   /* search1052_1 -> 3104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3103, 3104 },
      -1,
   } },

   /* replace1052 -> 1070 in the cache */

   /* ('ige', 'a(is_lt_zero)', 'b(is_not_negative)') => False */
   /* search1053_0 -> 3106 in the cache */
   /* search1053_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3106, 3107 },
      -1,
   } },

   /* replace1053 -> 1070 in the cache */

   /* ('ilt', 'a(is_not_negative)', 'b(is_not_positive)') => False */
   /* search1054_0 -> 1576 in the cache */
   /* search1054_1 -> 3109 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1576, 3109 },
      -1,
   } },

   /* replace1054 -> 1070 in the cache */

   /* ('ilt', 'a(is_not_positive)', 'b(is_gt_zero)') => True */
   /* search1055_0 -> 3103 in the cache */
   /* search1055_1 -> 3104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3103, 3104 },
      -1,
   } },

   /* replace1055 -> 1224 in the cache */

   /* ('ilt', 'a(is_lt_zero)', 'b(is_not_negative)') => True */
   /* search1056_0 -> 3106 in the cache */
   /* search1056_1 -> 3107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3106, 3107 },
      -1,
   } },

   /* replace1056 -> 1224 in the cache */

   /* ('ult', 0, 'a(is_gt_zero)') => True */
   /* search1057_0 -> 61 in the cache */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      25,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 61, 3125 },
      -1,
   } },

   /* replace1057 -> 1224 in the cache */

   /* ('ult', 'a', 0) => False */
   /* search1058_0 -> 32 in the cache */
   /* search1058_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* replace1058 -> 1070 in the cache */

   /* ('unpack_64_2x32_split_x', ('pack_64_2x32_split', 'a', 'b')) => a */
   /* search1059_0_0 -> 16 in the cache */
   /* search1059_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 3128 },
      -1,
   } },

   /* replace1059 -> 16 in the cache */

   /* ('unpack_64_2x32_split_y', ('pack_64_2x32_split', 'a', 'b')) => b */
   /* search1060_0_0 -> 16 in the cache */
   /* search1060_0_1 -> 36 in the cache */
   /* search1060_0 -> 3128 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 3128 },
      -1,
   } },

   /* replace1060 -> 36 in the cache */

   /* ('unpack_64_2x32_split_x', ('pack_64_2x32', 'a')) => a.x */
   /* search1061_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 3131 },
      -1,
   } },

   /* replace1061 -> 2390 in the cache */

   /* ('unpack_64_2x32_split_y', ('pack_64_2x32', 'a')) => a.y */
   /* search1062_0_0 -> 16 in the cache */
   /* search1062_0 -> 3131 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 3131 },
      -1,
   } },

   /* replace1062 -> 2393 in the cache */

   /* ('unpack_64_2x32_split_x', ('u2u64', 'a@32')) => a */
   /* search1063_0_0 -> 16 in the cache */
   /* search1063_0 -> 1900 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 1900 },
      -1,
   } },

   /* replace1063 -> 16 in the cache */

   /* ('unpack_64_2x32_split_y', ('u2u64', 'a')) => 0 */
   /* search1064_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 3135 },
      -1,
   } },

   /* replace1064 -> 124 in the cache */

   /* ('unpack_64_2x32_split_x', ('i2i64', 'a@32')) => a */
   /* search1065_0_0 -> 16 in the cache */
   /* search1065_0 -> 1898 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 1898 },
      -1,
   } },

   /* replace1065 -> 16 in the cache */

   /* ('unpack_64_2x32_split_y', ('i2i64(is_used_once)', 'a@32')) => ('ishr', 'a', 31) */
   /* search1066_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 16 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 3138 },
      -1,
   } },

   /* replace1066_0 -> 16 in the cache */
   /* replace1066_1 -> 19 in the cache */
   /* replace1066 -> 1452 in the cache */

   /* ('unpack_64_2x32', ('pack_64_2x32_split', 'a', 'b')) => ('vec2', 'a', 'b') */
   /* search1067_0_0 -> 16 in the cache */
   /* search1067_0_1 -> 36 in the cache */
   /* search1067_0 -> 3128 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 3128 },
      -1,
   } },

   /* replace1067_0 -> 16 in the cache */
   /* replace1067_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('unpack_64_2x32', ('pack_64_2x32', 'a')) => a */
   /* search1068_0_0 -> 16 in the cache */
   /* search1068_0 -> 3131 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 3131 },
      -1,
   } },

   /* replace1068 -> 16 in the cache */

   /* ('unpack_double_2x32_dxil', ('pack_double_2x32_dxil', 'a')) => a */
   /* search1069_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_double_2x32_dxil,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_double_2x32_dxil,
      -1, 0,
      { 3143 },
      -1,
   } },

   /* replace1069 -> 16 in the cache */

   /* ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')) => a */
   /* search1070_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 21 },
      -1,
   } },
   /* search1070_1_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 3145, 3146 },
      -1,
   } },

   /* replace1070 -> 21 in the cache */

   /* ('pack_64_2x32', ('vec2', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a'))) => a */
   /* search1071_0_0_0 -> 21 in the cache */
   /* search1071_0_0 -> 3145 in the cache */
   /* search1071_0_1_0 -> 21 in the cache */
   /* search1071_0_1 -> 3146 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3145, 3146 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 3148 },
      -1,
   } },

   /* replace1071 -> 21 in the cache */

   /* ('pack_64_2x32', ('unpack_64_2x32', 'a')) => a */
   /* search1072_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 3150 },
      -1,
   } },

   /* replace1072 -> 21 in the cache */

   /* ('pack_double_2x32_dxil', ('unpack_double_2x32_dxil', 'a')) => a */
   /* search1073_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_double_2x32_dxil,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_double_2x32_dxil,
      -1, 0,
      { 3152 },
      -1,
   } },

   /* replace1073 -> 21 in the cache */

   /* ('iand', ('ieq', ('unpack_32_2x16_split_x', 'a'), '#b'), ('ieq', ('unpack_32_2x16_split_y', 'a'), '#c')) => ('ieq', 'a', ('pack_32_2x16_split', 'b', 'c')) */
   /* search1074_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search1074_0_1 -> 2000 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 3154, 2000 },
      -1,
   } },
   /* search1074_1_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_y,
      -1, 0,
      { 16 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 3156, 3157 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3155, 3158 },
      -1,
   } },

   /* replace1074_0 -> 16 in the cache */
   /* replace1074_1_0 -> 260 in the cache */
   /* replace1074_1_1 -> 471 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_2x16_split,
      -1, 0,
      { 260, 471 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 3160 },
      -1,
   } },

   /* ('ushr', 'a@16', 8) => ('extract_u8', 'a', 1) */
   /* search1075_0 -> 11 in the cache */
   /* search1075_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 824 },
      -1,
   } },

   /* replace1075_0 -> 11 in the cache */
   /* replace1075_1 -> 1444 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 1444 },
      -1,
   } },

   /* ('ushr', 'a@32', 24) => ('extract_u8', 'a', 3) */
   /* search1076_0 -> 16 in the cache */
   /* search1076_1 -> 1005 in the cache */
   /* search1076 -> 1010 in the cache */

   /* replace1076_0 -> 16 in the cache */
   /* replace1076_1 -> 407 in the cache */
   /* replace1076 -> 424 in the cache */

   /* ('ushr', 'a@64', 56) => ('extract_u8', 'a', 7) */
   /* search1077_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x38 /* 56 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 3164 },
      -1,
   } },

   /* replace1077_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7 /* 7 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3166 },
      -1,
   } },

   /* ('ishr', 'a@16', 8) => ('extract_i8', 'a', 1) */
   /* search1078_0 -> 11 in the cache */
   /* search1078_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 824 },
      -1,
   } },

   /* replace1078_0 -> 11 in the cache */
   /* replace1078_1 -> 1444 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 1444 },
      -1,
   } },

   /* ('ishr', 'a@32', 24) => ('extract_i8', 'a', 3) */
   /* search1079_0 -> 16 in the cache */
   /* search1079_1 -> 1005 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 1005 },
      -1,
   } },

   /* replace1079_0 -> 16 in the cache */
   /* replace1079_1 -> 407 in the cache */
   /* replace1079 -> 408 in the cache */

   /* ('ishr', 'a@64', 56) => ('extract_i8', 'a', 7) */
   /* search1080_0 -> 21 in the cache */
   /* search1080_1 -> 3164 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 3164 },
      -1,
   } },

   /* replace1080_0 -> 21 in the cache */
   /* replace1080_1 -> 3166 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3166 },
      -1,
   } },

   /* ('iand', 255, 'a') => ('extract_u8', 'a', 0) */
   /* search1081_0 -> 1582 in the cache */
   /* search1081_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1582, 32 },
      -1,
   } },

   /* replace1081_0 -> 32 in the cache */
   /* replace1081_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('u2u8', ('extract_u16', 'a', 1)) => ('u2u8', ('extract_u8', 'a', 2)) */
   /* search1082_0_0 -> 32 in the cache */
   /* search1082_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3175 },
      -1,
   } },

   /* replace1082_0_0 -> 32 in the cache */
   /* replace1082_0_1 -> 2227 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 2227 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3177 },
      -1,
   } },

   /* ('u2u8', ('ushr', 'a', 8)) => ('u2u8', ('extract_u8', 'a', 1)) */
   /* search1083_0_0 -> 32 in the cache */
   /* search1083_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 32, 824 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3179 },
      -1,
   } },

   /* replace1083_0_0 -> 32 in the cache */
   /* replace1083_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3181 },
      -1,
   } },

   /* ('i2i16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('i2i16', ('extract_i8', 'a', 'b')) */
   /* search1084_0_0_0 -> 0 in the cache */
   /* search1084_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3183 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3184 },
      -1,
   } },

   /* replace1084_0_0 -> 0 in the cache */
   /* replace1084_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3186 },
      -1,
   } },

   /* ('u2u16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('u2u16', ('extract_u8', 'a', 'b')) */
   /* search1085_0_0_0 -> 0 in the cache */
   /* search1085_0_0_1 -> 3 in the cache */
   /* search1085_0_0 -> 3183 in the cache */
   /* search1085_0 -> 3184 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3184 },
      -1,
   } },

   /* replace1085_0_0 -> 0 in the cache */
   /* replace1085_0_1 -> 3 in the cache */
   /* replace1085_0 -> 3183 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3183 },
      -1,
   } },

   /* ('ubfe', 'a', 0, 8) => ('extract_u8', 'a', 0) */
   /* search1086_0 -> 16 in the cache */
   /* search1086_1 -> 124 in the cache */
   /* search1086_2 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 124, 824 },
      -1,
   } },

   /* replace1086_0 -> 16 in the cache */
   /* replace1086_1 -> 124 in the cache */
   /* replace1086 -> 414 in the cache */

   /* ('ubfe', 'a', 8, 8) => ('extract_u8', 'a', 1) */
   /* search1087_0 -> 16 in the cache */
   /* search1087_1 -> 824 in the cache */
   /* search1087_2 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 824, 824 },
      -1,
   } },

   /* replace1087_0 -> 16 in the cache */
   /* replace1087_1 -> 398 in the cache */
   /* replace1087 -> 417 in the cache */

   /* ('ubfe', 'a', 16, 8) => ('extract_u8', 'a', 2) */
   /* search1088_0 -> 16 in the cache */
   /* search1088_1 -> 846 in the cache */
   /* search1088_2 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 846, 824 },
      -1,
   } },

   /* replace1088_0 -> 16 in the cache */
   /* replace1088_1 -> 403 in the cache */
   /* replace1088 -> 421 in the cache */

   /* ('ubfe', 'a', 24, 8) => ('extract_u8', 'a', 3) */
   /* search1089_0 -> 16 in the cache */
   /* search1089_1 -> 1005 in the cache */
   /* search1089_2 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 1005, 824 },
      -1,
   } },

   /* replace1089_0 -> 16 in the cache */
   /* replace1089_1 -> 407 in the cache */
   /* replace1089 -> 424 in the cache */

   /* ('ibfe', 'a', 0, 8) => ('extract_i8', 'a', 0) */
   /* search1090_0 -> 16 in the cache */
   /* search1090_1 -> 124 in the cache */
   /* search1090_2 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 124, 824 },
      -1,
   } },

   /* replace1090_0 -> 16 in the cache */
   /* replace1090_1 -> 124 in the cache */
   /* replace1090 -> 395 in the cache */

   /* ('ibfe', 'a', 8, 8) => ('extract_i8', 'a', 1) */
   /* search1091_0 -> 16 in the cache */
   /* search1091_1 -> 824 in the cache */
   /* search1091_2 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 824, 824 },
      -1,
   } },

   /* replace1091_0 -> 16 in the cache */
   /* replace1091_1 -> 398 in the cache */
   /* replace1091 -> 399 in the cache */

   /* ('ibfe', 'a', 16, 8) => ('extract_i8', 'a', 2) */
   /* search1092_0 -> 16 in the cache */
   /* search1092_1 -> 846 in the cache */
   /* search1092_2 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 846, 824 },
      -1,
   } },

   /* replace1092_0 -> 16 in the cache */
   /* replace1092_1 -> 403 in the cache */
   /* replace1092 -> 404 in the cache */

   /* ('ibfe', 'a', 24, 8) => ('extract_i8', 'a', 3) */
   /* search1093_0 -> 16 in the cache */
   /* search1093_1 -> 1005 in the cache */
   /* search1093_2 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 1005, 824 },
      -1,
   } },

   /* replace1093_0 -> 16 in the cache */
   /* replace1093_1 -> 407 in the cache */
   /* replace1093 -> 408 in the cache */

   /* ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search1094_0_0 -> 0 in the cache */
   /* search1094_0_1 -> 3 in the cache */
   /* search1094_0 -> 3186 in the cache */
   /* search1094_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3186, 86 },
      -1,
   } },

   /* replace1094_0 -> 0 in the cache */
   /* replace1094_1 -> 3 in the cache */
   /* replace1094 -> 3183 in the cache */

   /* ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search1095_0_0 -> 0 in the cache */
   /* search1095_0_1 -> 3 in the cache */
   /* search1095_0 -> 3183 in the cache */
   /* search1095_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3183, 86 },
      -1,
   } },

   /* replace1095_0 -> 0 in the cache */
   /* replace1095_1 -> 3 in the cache */
   /* replace1095 -> 3183 in the cache */

   /* ('ushr', ('ishl', 'a@32', 16), 16) => ('extract_u16', 'a', 0) */
   /* search1096_0_0 -> 16 in the cache */
   /* search1096_0_1 -> 846 in the cache */
   /* search1096_0 -> 998 in the cache */
   /* search1096_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 998, 846 },
      -1,
   } },

   /* replace1096_0 -> 16 in the cache */
   /* replace1096_1 -> 124 in the cache */
   /* replace1096 -> 446 in the cache */

   /* ('ushr', 'a@32', 16) => ('extract_u16', 'a', 1) */
   /* search1097_0 -> 16 in the cache */
   /* search1097_1 -> 846 in the cache */
   /* search1097 -> 1001 in the cache */

   /* replace1097_0 -> 16 in the cache */
   /* replace1097_1 -> 398 in the cache */
   /* replace1097 -> 449 in the cache */

   /* ('ishr', ('ishl', 'a@32', 16), 16) => ('extract_i16', 'a', 0) */
   /* search1098_0_0 -> 16 in the cache */
   /* search1098_0_1 -> 846 in the cache */
   /* search1098_0 -> 998 in the cache */
   /* search1098_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 998, 846 },
      -1,
   } },

   /* replace1098_0 -> 16 in the cache */
   /* replace1098_1 -> 124 in the cache */
   /* replace1098 -> 438 in the cache */

   /* ('ishr', 'a@32', 16) => ('extract_i16', 'a', 1) */
   /* search1099_0 -> 16 in the cache */
   /* search1099_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 846 },
      -1,
   } },

   /* replace1099_0 -> 16 in the cache */
   /* replace1099_1 -> 398 in the cache */
   /* replace1099 -> 441 in the cache */

   /* ('iand', 65535, 'a') => ('extract_u16', 'a', 0) */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* search1100_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3203, 32 },
      -1,
   } },

   /* replace1100_0 -> 32 in the cache */
   /* replace1100_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('ubfe', 'a', 0, 16) => ('extract_u16', 'a', 0) */
   /* search1101_0 -> 16 in the cache */
   /* search1101_1 -> 124 in the cache */
   /* search1101_2 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 124, 846 },
      -1,
   } },

   /* replace1101_0 -> 16 in the cache */
   /* replace1101_1 -> 124 in the cache */
   /* replace1101 -> 446 in the cache */

   /* ('ubfe', 'a', 16, 16) => ('extract_u16', 'a', 1) */
   /* search1102_0 -> 16 in the cache */
   /* search1102_1 -> 846 in the cache */
   /* search1102_2 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 846, 846 },
      -1,
   } },

   /* replace1102_0 -> 16 in the cache */
   /* replace1102_1 -> 398 in the cache */
   /* replace1102 -> 449 in the cache */

   /* ('ibfe', 'a', 0, 16) => ('extract_i16', 'a', 0) */
   /* search1103_0 -> 16 in the cache */
   /* search1103_1 -> 124 in the cache */
   /* search1103_2 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 124, 846 },
      -1,
   } },

   /* replace1103_0 -> 16 in the cache */
   /* replace1103_1 -> 124 in the cache */
   /* replace1103 -> 438 in the cache */

   /* ('ibfe', 'a', 16, 16) => ('extract_i16', 'a', 1) */
   /* search1104_0 -> 16 in the cache */
   /* search1104_1 -> 846 in the cache */
   /* search1104_2 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 846, 846 },
      -1,
   } },

   /* replace1104_0 -> 16 in the cache */
   /* replace1104_1 -> 398 in the cache */
   /* replace1104 -> 441 in the cache */

   /* ('ior', ('ishl', ('u2u32', 'a@8'), 24), ('ior', ('ishl', ('u2u32', 'b@8'), 16), ('ior', ('ishl', ('u2u32', 'c@8'), 8), ('u2u32', 'd@8')))) => ('pack_32_4x8', ('vec4', 'd', 'c', 'b', 'a')) */
   /* search1105_0_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 6 },
      -1,
   } },
   /* search1105_0_1 -> 1005 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3210, 1005 },
      -1,
   } },
   /* search1105_1_0_0_0 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2101 },
      -1,
   } },
   /* search1105_1_0_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3212, 846 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3214 },
      -1,
   } },
   /* search1105_1_1_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3215, 824 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3217 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 3216, 3218 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      1, 2,
      { 3213, 3219 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3211, 3220 },
      -1,
   } },

   /* replace1105_0_0 -> 3217 in the cache */
   /* replace1105_0_1 -> 3214 in the cache */
   /* replace1105_0_2 -> 2101 in the cache */
   /* replace1105_0_3 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3217, 3214, 2101, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_4x8,
      -1, 0,
      { 3222 },
      -1,
   } },

   /* ('extract_u16', ('extract_i16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b') */
   /* search1106_0_0 -> 0 in the cache */
   /* search1106_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   /* search1106_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3224, 86 },
      -1,
   } },

   /* replace1106_0 -> 0 in the cache */
   /* replace1106_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('extract_u16', ('extract_u16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b') */
   /* search1107_0_0 -> 0 in the cache */
   /* search1107_0_1 -> 3 in the cache */
   /* search1107_0 -> 3226 in the cache */
   /* search1107_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3226, 86 },
      -1,
   } },

   /* replace1107_0 -> 0 in the cache */
   /* replace1107_1 -> 3 in the cache */
   /* replace1107 -> 3226 in the cache */

   /* ('pack_64_2x32_split', 'a', 'b') => ('ior', ('u2u64', 'a'), ('ishl', ('u2u64', 'b'), 32)) */
   /* search1108_0 -> 16 in the cache */
   /* search1108_1 -> 36 in the cache */
   /* search1108 -> 3128 in the cache */

   /* replace1108_0_0 -> 16 in the cache */
   /* replace1108_0 -> 1900 in the cache */
   /* replace1108_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 36 },
      -1,
   } },
   /* replace1108_1_1 -> 867 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3228, 867 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1900, 3229 },
      -1,
   } },

   /* ('pack_32_2x16_split', 'a', 'b') => ('ior', ('u2u32', 'a'), ('ishl', ('u2u32', 'b'), 16)) */
   /* search1109_0 -> 11 in the cache */
   /* search1109_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_2x16_split,
      -1, 0,
      { 11, 260 },
      -1,
   } },

   /* replace1109_0_0 -> 11 in the cache */
   /* replace1109_0 -> 1795 in the cache */
   /* replace1109_1_0_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 260 },
      -1,
   } },
   /* replace1109_1_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3232, 846 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1795, 3233 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', 'a') => ('u2u32', 'a') */
   /* search1110_0 -> 21 in the cache */
   /* search1110 -> 3145 in the cache */

   /* replace1110_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('unpack_64_2x32_split_y', 'a') => ('u2u32', ('ushr', 'a', 32)) */
   /* search1111_0 -> 21 in the cache */
   /* search1111 -> 3146 in the cache */

   /* replace1111_0_0 -> 21 in the cache */
   /* replace1111_0_1 -> 867 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 867 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3236 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', 'a') => ('u2u16', 'a') */
   /* search1112_0 -> 16 in the cache */
   /* search1112 -> 3154 in the cache */

   /* replace1112_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_y', 'a') => ('u2u16', ('ushr', 'a', 16)) */
   /* search1113_0 -> 16 in the cache */
   /* search1113 -> 3156 in the cache */

   /* replace1113_0_0 -> 16 in the cache */
   /* replace1113_0_1 -> 846 in the cache */
   /* replace1113_0 -> 1001 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1001 },
      -1,
   } },

   /* ('unpack_half_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_half_2x16_split_x', 'a') */
   /* search1114_0_0 -> 16 in the cache */
   /* search1114_0_1 -> 995 in the cache */
   /* search1114_0 -> 996 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 1,
      { 996 },
      -1,
   } },

   /* replace1114_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_32_2x16_split_x', 'a') */
   /* search1115_0_0 -> 16 in the cache */
   /* search1115_0_1 -> 995 in the cache */
   /* search1115_0 -> 996 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 1,
      { 996 },
      -1,
   } },

   /* replace1115_0 -> 16 in the cache */
   /* replace1115 -> 3154 in the cache */

   /* ('unpack_64_2x32_split_x', ('iand', 'a', 4294967295)) => ('unpack_64_2x32_split_x', 'a') */
   /* search1116_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 3243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 3244 },
      -1,
   } },

   /* replace1116_0 -> 21 in the cache */
   /* replace1116 -> 3145 in the cache */

   /* ('unpack_half_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1117_0_0 -> 16 in the cache */
   /* search1117_0_1 -> 999 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 999 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_y,
      -1, 1,
      { 3246 },
      -1,
   } },

   /* replace1117_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_y,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_32_2x16_split_y', 'a') */
   /* search1118_0_0 -> 16 in the cache */
   /* search1118_0_1 -> 999 in the cache */
   /* search1118_0 -> 3246 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_y,
      -1, 1,
      { 3246 },
      -1,
   } },

   /* replace1118_0 -> 16 in the cache */
   /* replace1118 -> 3156 in the cache */

   /* ('unpack_64_2x32_split_y', ('iand', 'a', 18446744069414584320)) => ('unpack_64_2x32_split_y', 'a') */
   /* search1119_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffff00000000 /* 18446744069414584320 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 3250 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 1,
      { 3251 },
      -1,
   } },

   /* replace1119_0 -> 21 in the cache */
   /* replace1119 -> 3146 in the cache */

   /* ('unpack_half_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_half_2x16_split_x', 'a') */
   /* search1120_0_0 -> 16 in the cache */
   /* search1120_0_1 -> 124 in the cache */
   /* search1120_0 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 446 },
      -1,
   } },

   /* replace1120_0 -> 16 in the cache */
   /* replace1120 -> 3241 in the cache */

   /* ('unpack_half_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1121_0_0 -> 16 in the cache */
   /* search1121_0_1 -> 398 in the cache */
   /* search1121_0 -> 449 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 449 },
      -1,
   } },

   /* replace1121_0 -> 16 in the cache */
   /* replace1121 -> 3248 in the cache */

   /* ('unpack_half_2x16_split_x', ('ushr', 'a', 16)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1122_0_0 -> 16 in the cache */
   /* search1122_0_1 -> 846 in the cache */
   /* search1122_0 -> 1001 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 1001 },
      -1,
   } },

   /* replace1122_0 -> 16 in the cache */
   /* replace1122 -> 3248 in the cache */

   /* ('unpack_32_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_32_2x16_split_x', 'a') */
   /* search1123_0_0 -> 16 in the cache */
   /* search1123_0_1 -> 124 in the cache */
   /* search1123_0 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 446 },
      -1,
   } },

   /* replace1123_0 -> 16 in the cache */
   /* replace1123 -> 3154 in the cache */

   /* ('unpack_32_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_32_2x16_split_y', 'a') */
   /* search1124_0_0 -> 16 in the cache */
   /* search1124_0_1 -> 398 in the cache */
   /* search1124_0 -> 449 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 449 },
      -1,
   } },

   /* replace1124_0 -> 16 in the cache */
   /* replace1124 -> 3156 in the cache */

   /* ('ishl', ('pack_half_2x16', ('vec2', 'a', 0)), 16) => ('pack_half_2x16', ('vec2', 0, 'a')) */
   /* search1125_0_0_0 -> 16 in the cache */
   /* search1125_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 16, 124 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3258 },
      -1,
   } },
   /* search1125_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3259, 846 },
      -1,
   } },

   /* replace1125_0_0 -> 124 in the cache */
   /* replace1125_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 124, 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3261 },
      -1,
   } },

   /* ('ushr', ('pack_half_2x16', ('vec2', 0, 'a')), 16) => ('pack_half_2x16', ('vec2', 'a', 0)) */
   /* search1126_0_0_0 -> 124 in the cache */
   /* search1126_0_0_1 -> 16 in the cache */
   /* search1126_0_0 -> 3261 in the cache */
   /* search1126_0 -> 3262 in the cache */
   /* search1126_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3262, 846 },
      -1,
   } },

   /* replace1126_0_0 -> 16 in the cache */
   /* replace1126_0_1 -> 124 in the cache */
   /* replace1126_0 -> 3258 in the cache */
   /* replace1126 -> 3259 in the cache */

   /* ('iadd', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b')) */
   /* search1127_0_0_0 -> 16 in the cache */
   /* search1127_0_0_1 -> 124 in the cache */
   /* search1127_0_0 -> 3258 in the cache */
   /* search1127_0 -> 3259 in the cache */
   /* search1127_1_0_0 -> 124 in the cache */
   /* search1127_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 124, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3264 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3259, 3265 },
      -1,
   } },

   /* replace1127_0_0 -> 16 in the cache */
   /* replace1127_0_1 -> 36 in the cache */
   /* replace1127_0 -> 3141 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3141 },
      -1,
   } },

   /* ('ior', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b')) */
   /* search1128_0_0_0 -> 16 in the cache */
   /* search1128_0_0_1 -> 124 in the cache */
   /* search1128_0_0 -> 3258 in the cache */
   /* search1128_0 -> 3259 in the cache */
   /* search1128_1_0_0 -> 124 in the cache */
   /* search1128_1_0_1 -> 36 in the cache */
   /* search1128_1_0 -> 3264 in the cache */
   /* search1128_1 -> 3265 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3259, 3265 },
      -1,
   } },

   /* replace1128_0_0 -> 16 in the cache */
   /* replace1128_0_1 -> 36 in the cache */
   /* replace1128_0 -> 3141 in the cache */
   /* replace1128 -> 3267 in the cache */

   /* ('ishl', ('pack_half_2x16_split', 'a', 0), 16) => ('pack_half_2x16_split', 0, 'a') */
   /* search1129_0_0 -> 16 in the cache */
   /* search1129_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 16, 124 },
      -1,
   } },
   /* search1129_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3269, 846 },
      -1,
   } },

   /* replace1129_0 -> 124 in the cache */
   /* replace1129_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 124, 16 },
      -1,
   } },

   /* ('ushr', ('pack_half_2x16_split', 0, 'a'), 16) => ('pack_half_2x16_split', 'a', 0) */
   /* search1130_0_0 -> 124 in the cache */
   /* search1130_0_1 -> 16 in the cache */
   /* search1130_0 -> 3271 in the cache */
   /* search1130_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3271, 846 },
      -1,
   } },

   /* replace1130_0 -> 16 in the cache */
   /* replace1130_1 -> 124 in the cache */
   /* replace1130 -> 3269 in the cache */

   /* ('extract_u16', ('pack_half_2x16_split', 0, 'a'), 1) => ('pack_half_2x16_split', 'a', 0) */
   /* search1131_0_0 -> 124 in the cache */
   /* search1131_0_1 -> 16 in the cache */
   /* search1131_0 -> 3271 in the cache */
   /* search1131_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3271, 398 },
      -1,
   } },

   /* replace1131_0 -> 16 in the cache */
   /* replace1131_1 -> 124 in the cache */
   /* replace1131 -> 3269 in the cache */

   /* ('iadd', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b') */
   /* search1132_0_0 -> 16 in the cache */
   /* search1132_0_1 -> 124 in the cache */
   /* search1132_0 -> 3269 in the cache */
   /* search1132_1_0 -> 124 in the cache */
   /* search1132_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 124, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3269, 3274 },
      -1,
   } },

   /* replace1132_0 -> 16 in the cache */
   /* replace1132_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b') */
   /* search1133_0_0 -> 16 in the cache */
   /* search1133_0_1 -> 124 in the cache */
   /* search1133_0 -> 3269 in the cache */
   /* search1133_1_0 -> 124 in the cache */
   /* search1133_1_1 -> 36 in the cache */
   /* search1133_1 -> 3274 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3269, 3274 },
      -1,
   } },

   /* replace1133_0 -> 16 in the cache */
   /* replace1133_1 -> 36 in the cache */
   /* replace1133 -> 3276 in the cache */

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('i2i', 'a') */
   /* search1134_0_0 -> 6 in the cache */
   /* search1134_0_1 -> 2101 in the cache */
   /* search1134_0_2 -> 3214 in the cache */
   /* search1134_0_3 -> 3217 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_4x8_split,
      -1, 0,
      { 6, 2101, 3214, 3217 },
      -1,
   } },
   /* search1134_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3278, 124 },
      -1,
   } },

   /* replace1134_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('i2i', 'b') */
   /* search1135_0_0 -> 6 in the cache */
   /* search1135_0_1 -> 2101 in the cache */
   /* search1135_0_2 -> 3214 in the cache */
   /* search1135_0_3 -> 3217 in the cache */
   /* search1135_0 -> 3278 in the cache */
   /* search1135_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3278, 398 },
      -1,
   } },

   /* replace1135_0 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 2101 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('i2i', 'c') */
   /* search1136_0_0 -> 6 in the cache */
   /* search1136_0_1 -> 2101 in the cache */
   /* search1136_0_2 -> 3214 in the cache */
   /* search1136_0_3 -> 3217 in the cache */
   /* search1136_0 -> 3278 in the cache */
   /* search1136_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3278, 403 },
      -1,
   } },

   /* replace1136_0 -> 3214 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 3214 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('i2i', 'd') */
   /* search1137_0_0 -> 6 in the cache */
   /* search1137_0_1 -> 2101 in the cache */
   /* search1137_0_2 -> 3214 in the cache */
   /* search1137_0_3 -> 3217 in the cache */
   /* search1137_0 -> 3278 in the cache */
   /* search1137_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3278, 407 },
      -1,
   } },

   /* replace1137_0 -> 3217 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 3217 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('u2u', 'a') */
   /* search1138_0_0 -> 6 in the cache */
   /* search1138_0_1 -> 2101 in the cache */
   /* search1138_0_2 -> 3214 in the cache */
   /* search1138_0_3 -> 3217 in the cache */
   /* search1138_0 -> 3278 in the cache */
   /* search1138_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3278, 124 },
      -1,
   } },

   /* replace1138_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('u2u', 'b') */
   /* search1139_0_0 -> 6 in the cache */
   /* search1139_0_1 -> 2101 in the cache */
   /* search1139_0_2 -> 3214 in the cache */
   /* search1139_0_3 -> 3217 in the cache */
   /* search1139_0 -> 3278 in the cache */
   /* search1139_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3278, 398 },
      -1,
   } },

   /* replace1139_0 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 2101 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('u2u', 'c') */
   /* search1140_0_0 -> 6 in the cache */
   /* search1140_0_1 -> 2101 in the cache */
   /* search1140_0_2 -> 3214 in the cache */
   /* search1140_0_3 -> 3217 in the cache */
   /* search1140_0 -> 3278 in the cache */
   /* search1140_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3278, 403 },
      -1,
   } },

   /* replace1140_0 -> 3214 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 3214 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('u2u', 'd') */
   /* search1141_0_0 -> 6 in the cache */
   /* search1141_0_1 -> 2101 in the cache */
   /* search1141_0_2 -> 3214 in the cache */
   /* search1141_0_3 -> 3217 in the cache */
   /* search1141_0 -> 3278 in the cache */
   /* search1141_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3278, 407 },
      -1,
   } },

   /* replace1141_0 -> 3217 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 3217 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@16', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1142_0_0 -> 11 in the cache */
   /* search1142_0_1 -> 824 in the cache */
   /* search1142_0 -> 3162 in the cache */
   /* search1142_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3162, 849 },
      -1,
   } },

   /* replace1142_0 -> 11 in the cache */
   /* replace1142_1 -> 1444 in the cache */
   /* replace1142 -> 3163 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1143_0_0 -> 16 in the cache */
   /* search1143_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 824 },
      -1,
   } },
   /* search1143_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3296, 124 },
      -1,
   } },

   /* replace1143_0 -> 16 in the cache */
   /* replace1143_1 -> 398 in the cache */
   /* replace1143 -> 417 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1144_0_0 -> 16 in the cache */
   /* search1144_0_1 -> 846 in the cache */
   /* search1144_0 -> 1001 in the cache */
   /* search1144_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 1001, 124 },
      -1,
   } },

   /* replace1144_0 -> 16 in the cache */
   /* replace1144_1 -> 403 in the cache */
   /* replace1144 -> 421 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1145_0_0 -> 16 in the cache */
   /* search1145_0_1 -> 1005 in the cache */
   /* search1145_0 -> 1010 in the cache */
   /* search1145_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 1010, 124 },
      -1,
   } },

   /* replace1145_0 -> 16 in the cache */
   /* replace1145_1 -> 407 in the cache */
   /* replace1145 -> 424 in the cache */

   /* ('extract_u8', ('ushr', 'a@64', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1146_0_0 -> 21 in the cache */
   /* search1146_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 824 },
      -1,
   } },
   /* search1146_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3300, 890 },
      -1,
   } },

   /* replace1146_0 -> 21 in the cache */
   /* replace1146_1 -> 1486 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 1486 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1147_0_0 -> 21 in the cache */
   /* search1147_0_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 846 },
      -1,
   } },
   /* search1147_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3303, 890 },
      -1,
   } },

   /* replace1147_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3305 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1148_0_0 -> 21 in the cache */
   /* search1148_0_1 -> 1005 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 1005 },
      -1,
   } },
   /* search1148_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3307, 890 },
      -1,
   } },

   /* replace1148_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3309 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 32), 0) => ('extract_u8', 'a', 4) */
   /* search1149_0_0 -> 21 in the cache */
   /* search1149_0_1 -> 867 in the cache */
   /* search1149_0 -> 3236 in the cache */
   /* search1149_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3236, 890 },
      -1,
   } },

   /* replace1149_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x4 /* 4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3312 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 40), 0) => ('extract_u8', 'a', 5) */
   /* search1150_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x28 /* 40 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 3314 },
      -1,
   } },
   /* search1150_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3315, 890 },
      -1,
   } },

   /* replace1150_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x5 /* 5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3317 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 48), 0) => ('extract_u8', 'a', 6) */
   /* search1151_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x30 /* 48 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 3319 },
      -1,
   } },
   /* search1151_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3320, 890 },
      -1,
   } },

   /* replace1151_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x6 /* 6 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3322 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 56), 0) => ('extract_u8', 'a', 7) */
   /* search1152_0_0 -> 21 in the cache */
   /* search1152_0_1 -> 3164 in the cache */
   /* search1152_0 -> 3165 in the cache */
   /* search1152_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3165, 890 },
      -1,
   } },

   /* replace1152_0 -> 21 in the cache */
   /* replace1152_1 -> 3166 in the cache */
   /* replace1152 -> 3167 in the cache */

   /* ('extract_u8', ('ishr', 'a@16', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1153_0_0 -> 11 in the cache */
   /* search1153_0_1 -> 824 in the cache */
   /* search1153_0 -> 3168 in the cache */
   /* search1153_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3168, 849 },
      -1,
   } },

   /* replace1153_0 -> 11 in the cache */
   /* replace1153_1 -> 1444 in the cache */
   /* replace1153 -> 3163 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1154_0_0 -> 16 in the cache */
   /* search1154_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 824 },
      -1,
   } },
   /* search1154_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3326, 124 },
      -1,
   } },

   /* replace1154_0 -> 16 in the cache */
   /* replace1154_1 -> 398 in the cache */
   /* replace1154 -> 417 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1155_0_0 -> 16 in the cache */
   /* search1155_0_1 -> 846 in the cache */
   /* search1155_0 -> 3202 in the cache */
   /* search1155_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3202, 124 },
      -1,
   } },

   /* replace1155_0 -> 16 in the cache */
   /* replace1155_1 -> 403 in the cache */
   /* replace1155 -> 421 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1156_0_0 -> 16 in the cache */
   /* search1156_0_1 -> 1005 in the cache */
   /* search1156_0 -> 3170 in the cache */
   /* search1156_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3170, 124 },
      -1,
   } },

   /* replace1156_0 -> 16 in the cache */
   /* replace1156_1 -> 407 in the cache */
   /* replace1156 -> 424 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1157_0_0 -> 21 in the cache */
   /* search1157_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 824 },
      -1,
   } },
   /* search1157_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3330, 890 },
      -1,
   } },

   /* replace1157_0 -> 21 in the cache */
   /* replace1157_1 -> 1486 in the cache */
   /* replace1157 -> 3302 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1158_0_0 -> 21 in the cache */
   /* search1158_0_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 846 },
      -1,
   } },
   /* search1158_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3332, 890 },
      -1,
   } },

   /* replace1158_0 -> 21 in the cache */
   /* replace1158_1 -> 3305 in the cache */
   /* replace1158 -> 3306 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1159_0_0 -> 21 in the cache */
   /* search1159_0_1 -> 1005 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 1005 },
      -1,
   } },
   /* search1159_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3334, 890 },
      -1,
   } },

   /* replace1159_0 -> 21 in the cache */
   /* replace1159_1 -> 3309 in the cache */
   /* replace1159 -> 3310 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 32), 0) => ('extract_u8', 'a', 4) */
   /* search1160_0_0 -> 21 in the cache */
   /* search1160_0_1 -> 867 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 867 },
      -1,
   } },
   /* search1160_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3336, 890 },
      -1,
   } },

   /* replace1160_0 -> 21 in the cache */
   /* replace1160_1 -> 3312 in the cache */
   /* replace1160 -> 3313 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 40), 0) => ('extract_u8', 'a', 5) */
   /* search1161_0_0 -> 21 in the cache */
   /* search1161_0_1 -> 3314 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 3314 },
      -1,
   } },
   /* search1161_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3338, 890 },
      -1,
   } },

   /* replace1161_0 -> 21 in the cache */
   /* replace1161_1 -> 3317 in the cache */
   /* replace1161 -> 3318 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 48), 0) => ('extract_u8', 'a', 6) */
   /* search1162_0_0 -> 21 in the cache */
   /* search1162_0_1 -> 3319 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 3319 },
      -1,
   } },
   /* search1162_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3340, 890 },
      -1,
   } },

   /* replace1162_0 -> 21 in the cache */
   /* replace1162_1 -> 3322 in the cache */
   /* replace1162 -> 3323 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 56), 0) => ('extract_u8', 'a', 7) */
   /* search1163_0_0 -> 21 in the cache */
   /* search1163_0_1 -> 3164 in the cache */
   /* search1163_0 -> 3171 in the cache */
   /* search1163_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3171, 890 },
      -1,
   } },

   /* replace1163_0 -> 21 in the cache */
   /* replace1163_1 -> 3166 in the cache */
   /* replace1163 -> 3167 in the cache */

   /* ('extract_u8', ('extract_u16', 'a', 1), 0) => ('extract_u8', 'a', 2) */
   /* search1164_0_0 -> 32 in the cache */
   /* search1164_0_1 -> 35 in the cache */
   /* search1164_0 -> 3175 in the cache */
   /* search1164_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3175, 61 },
      -1,
   } },

   /* replace1164_0 -> 32 in the cache */
   /* replace1164_1 -> 2227 in the cache */
   /* replace1164 -> 3177 in the cache */

   /* ('extract_u8', ('ishl', 'a@16', 8), 1) => ('extract_u8', 'a', 0) */
   /* search1165_0_0 -> 11 in the cache */
   /* search1165_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 824 },
      -1,
   } },
   /* search1165_1 -> 1444 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3344, 1444 },
      -1,
   } },

   /* replace1165_0 -> 11 in the cache */
   /* replace1165_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 849 },
      -1,
   } },

   /* ('extract_u8', ('ishl', 'a@32', 8), 3) => ('extract_u8', 'a', 2) */
   /* search1166_0_0 -> 16 in the cache */
   /* search1166_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 824 },
      -1,
   } },
   /* search1166_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3347, 407 },
      -1,
   } },

   /* replace1166_0 -> 16 in the cache */
   /* replace1166_1 -> 403 in the cache */
   /* replace1166 -> 421 in the cache */

   /* ('extract_u8', ('ishl', 'a@32', 16), 3) => ('extract_u8', 'a', 1) */
   /* search1167_0_0 -> 16 in the cache */
   /* search1167_0_1 -> 846 in the cache */
   /* search1167_0 -> 998 in the cache */
   /* search1167_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 998, 407 },
      -1,
   } },

   /* replace1167_0 -> 16 in the cache */
   /* replace1167_1 -> 398 in the cache */
   /* replace1167 -> 417 in the cache */

   /* ('extract_u8', ('ishl', 'a@32', 24), 3) => ('extract_u8', 'a', 0) */
   /* search1168_0_0 -> 16 in the cache */
   /* search1168_0_1 -> 1005 in the cache */
   /* search1168_0 -> 1007 in the cache */
   /* search1168_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 1007, 407 },
      -1,
   } },

   /* replace1168_0 -> 16 in the cache */
   /* replace1168_1 -> 124 in the cache */
   /* replace1168 -> 414 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 8), 7) => ('extract_u8', 'a', 6) */
   /* search1169_0_0 -> 21 in the cache */
   /* search1169_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 824 },
      -1,
   } },
   /* search1169_1 -> 3166 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3351, 3166 },
      -1,
   } },

   /* replace1169_0 -> 21 in the cache */
   /* replace1169_1 -> 3322 in the cache */
   /* replace1169 -> 3323 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 16), 7) => ('extract_u8', 'a', 5) */
   /* search1170_0_0 -> 21 in the cache */
   /* search1170_0_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 846 },
      -1,
   } },
   /* search1170_1 -> 3166 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3353, 3166 },
      -1,
   } },

   /* replace1170_0 -> 21 in the cache */
   /* replace1170_1 -> 3317 in the cache */
   /* replace1170 -> 3318 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 24), 7) => ('extract_u8', 'a', 4) */
   /* search1171_0_0 -> 21 in the cache */
   /* search1171_0_1 -> 1005 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 1005 },
      -1,
   } },
   /* search1171_1 -> 3166 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3355, 3166 },
      -1,
   } },

   /* replace1171_0 -> 21 in the cache */
   /* replace1171_1 -> 3312 in the cache */
   /* replace1171 -> 3313 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 32), 7) => ('extract_u8', 'a', 3) */
   /* search1172_0_0 -> 21 in the cache */
   /* search1172_0_1 -> 867 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 867 },
      -1,
   } },
   /* search1172_1 -> 3166 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3357, 3166 },
      -1,
   } },

   /* replace1172_0 -> 21 in the cache */
   /* replace1172_1 -> 3309 in the cache */
   /* replace1172 -> 3310 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 40), 7) => ('extract_u8', 'a', 2) */
   /* search1173_0_0 -> 21 in the cache */
   /* search1173_0_1 -> 3314 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 3314 },
      -1,
   } },
   /* search1173_1 -> 3166 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3359, 3166 },
      -1,
   } },

   /* replace1173_0 -> 21 in the cache */
   /* replace1173_1 -> 3305 in the cache */
   /* replace1173 -> 3306 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 48), 7) => ('extract_u8', 'a', 1) */
   /* search1174_0_0 -> 21 in the cache */
   /* search1174_0_1 -> 3319 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 3319 },
      -1,
   } },
   /* search1174_1 -> 3166 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3361, 3166 },
      -1,
   } },

   /* replace1174_0 -> 21 in the cache */
   /* replace1174_1 -> 1486 in the cache */
   /* replace1174 -> 3302 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 56), 7) => ('extract_u8', 'a', 0) */
   /* search1175_0_0 -> 21 in the cache */
   /* search1175_0_1 -> 3164 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 3164 },
      -1,
   } },
   /* search1175_1 -> 3166 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3363, 3166 },
      -1,
   } },

   /* replace1175_0 -> 21 in the cache */
   /* replace1175_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 890 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@16', 8), 1) => ('extract_i8', 'a', 0) */
   /* search1176_0_0 -> 11 in the cache */
   /* search1176_0_1 -> 824 in the cache */
   /* search1176_0 -> 3344 in the cache */
   /* search1176_1 -> 1444 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3344, 1444 },
      -1,
   } },

   /* replace1176_0 -> 11 in the cache */
   /* replace1176_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 849 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@32', 8), 3) => ('extract_i8', 'a', 2) */
   /* search1177_0_0 -> 16 in the cache */
   /* search1177_0_1 -> 824 in the cache */
   /* search1177_0 -> 3347 in the cache */
   /* search1177_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3347, 407 },
      -1,
   } },

   /* replace1177_0 -> 16 in the cache */
   /* replace1177_1 -> 403 in the cache */
   /* replace1177 -> 404 in the cache */

   /* ('extract_i8', ('ishl', 'a@32', 16), 3) => ('extract_i8', 'a', 1) */
   /* search1178_0_0 -> 16 in the cache */
   /* search1178_0_1 -> 846 in the cache */
   /* search1178_0 -> 998 in the cache */
   /* search1178_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 998, 407 },
      -1,
   } },

   /* replace1178_0 -> 16 in the cache */
   /* replace1178_1 -> 398 in the cache */
   /* replace1178 -> 399 in the cache */

   /* ('extract_i8', ('ishl', 'a@32', 24), 3) => ('extract_i8', 'a', 0) */
   /* search1179_0_0 -> 16 in the cache */
   /* search1179_0_1 -> 1005 in the cache */
   /* search1179_0 -> 1007 in the cache */
   /* search1179_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 1007, 407 },
      -1,
   } },

   /* replace1179_0 -> 16 in the cache */
   /* replace1179_1 -> 124 in the cache */
   /* replace1179 -> 395 in the cache */

   /* ('extract_i8', ('ishl', 'a@64', 8), 7) => ('extract_i8', 'a', 6) */
   /* search1180_0_0 -> 21 in the cache */
   /* search1180_0_1 -> 824 in the cache */
   /* search1180_0 -> 3351 in the cache */
   /* search1180_1 -> 3166 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3351, 3166 },
      -1,
   } },

   /* replace1180_0 -> 21 in the cache */
   /* replace1180_1 -> 3322 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3322 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 16), 7) => ('extract_i8', 'a', 5) */
   /* search1181_0_0 -> 21 in the cache */
   /* search1181_0_1 -> 846 in the cache */
   /* search1181_0 -> 3353 in the cache */
   /* search1181_1 -> 3166 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3353, 3166 },
      -1,
   } },

   /* replace1181_0 -> 21 in the cache */
   /* replace1181_1 -> 3317 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3317 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 24), 7) => ('extract_i8', 'a', 4) */
   /* search1182_0_0 -> 21 in the cache */
   /* search1182_0_1 -> 1005 in the cache */
   /* search1182_0 -> 3355 in the cache */
   /* search1182_1 -> 3166 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3355, 3166 },
      -1,
   } },

   /* replace1182_0 -> 21 in the cache */
   /* replace1182_1 -> 3312 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3312 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 32), 7) => ('extract_i8', 'a', 3) */
   /* search1183_0_0 -> 21 in the cache */
   /* search1183_0_1 -> 867 in the cache */
   /* search1183_0 -> 3357 in the cache */
   /* search1183_1 -> 3166 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3357, 3166 },
      -1,
   } },

   /* replace1183_0 -> 21 in the cache */
   /* replace1183_1 -> 3309 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3309 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 40), 7) => ('extract_i8', 'a', 2) */
   /* search1184_0_0 -> 21 in the cache */
   /* search1184_0_1 -> 3314 in the cache */
   /* search1184_0 -> 3359 in the cache */
   /* search1184_1 -> 3166 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3359, 3166 },
      -1,
   } },

   /* replace1184_0 -> 21 in the cache */
   /* replace1184_1 -> 3305 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3305 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 48), 7) => ('extract_i8', 'a', 1) */
   /* search1185_0_0 -> 21 in the cache */
   /* search1185_0_1 -> 3319 in the cache */
   /* search1185_0 -> 3361 in the cache */
   /* search1185_1 -> 3166 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3361, 3166 },
      -1,
   } },

   /* replace1185_0 -> 21 in the cache */
   /* replace1185_1 -> 1486 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 1486 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 56), 7) => ('extract_i8', 'a', 0) */
   /* search1186_0_0 -> 21 in the cache */
   /* search1186_0_1 -> 3164 in the cache */
   /* search1186_0 -> 3363 in the cache */
   /* search1186_1 -> 3166 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3363, 3166 },
      -1,
   } },

   /* replace1186_0 -> 21 in the cache */
   /* replace1186_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 890 },
      -1,
   } },

   /* ('ussub_4x8_vc4', 'a', 0) => a */
   /* search1187_0 -> 16 in the cache */
   /* search1187_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ussub_4x8_vc4,
      -1, 0,
      { 16, 124 },
      -1,
   } },

   /* replace1187 -> 16 in the cache */

   /* ('ussub_4x8_vc4', 'a', -1) => 0 */
   /* search1188_0 -> 16 in the cache */
   /* search1188_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ussub_4x8_vc4,
      -1, 0,
      { 16, 126 },
      -1,
   } },

   /* replace1188 -> 124 in the cache */

   /* ('fsub', 'a', 'b') => ('fadd', 'a', ('fneg', 'b')) */
   /* search1189_0 -> 0 in the cache */
   /* search1189_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1189_0 -> 0 in the cache */
   /* replace1189_1_0 -> 3 in the cache */
   /* replace1189_1 -> 1080 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1080 },
      -1,
   } },

   /* ('isub', 'a', 'b') => ('iadd', 'a', ('ineg', 'b')) */
   /* search1190_0 -> 0 in the cache */
   /* search1190_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1190_0 -> 0 in the cache */
   /* replace1190_1_0 -> 3 in the cache */
   /* replace1190_1 -> 93 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 93 },
      -1,
   } },

   /* ('uabs_usub', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b')) */
   /* search1191_0 -> 0 in the cache */
   /* search1191_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uabs_usub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1191_0_0 -> 0 in the cache */
   /* replace1191_0_1 -> 3 in the cache */
   /* replace1191_0 -> 1060 in the cache */
   /* replace1191_1_0_0 -> 0 in the cache */
   /* replace1191_1_0_1 -> 3 in the cache */
   /* replace1191_1_0 -> 3389 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3389 },
      -1,
   } },
   /* replace1191_2_0 -> 0 in the cache */
   /* replace1191_2_1 -> 3 in the cache */
   /* replace1191_2 -> 3389 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1060, 3392, 3389 },
      -1,
   } },

   /* ('uabs_isub', 'a', 'b') => ('bcsel', ('ilt', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b')) */
   /* search1192_0 -> 0 in the cache */
   /* search1192_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uabs_isub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1192_0_0 -> 0 in the cache */
   /* replace1192_0_1 -> 3 in the cache */
   /* replace1192_0 -> 1057 in the cache */
   /* replace1192_1_0_0 -> 0 in the cache */
   /* replace1192_1_0_1 -> 3 in the cache */
   /* replace1192_1_0 -> 3389 in the cache */
   /* replace1192_1 -> 3392 in the cache */
   /* replace1192_2_0 -> 0 in the cache */
   /* replace1192_2_1 -> 3 in the cache */
   /* replace1192_2 -> 3389 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1057, 3392, 3389 },
      -1,
   } },

   /* ('fmul(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmul', 'a', 'b')) */
   /* search1193_0_0 -> 0 in the cache */
   /* search1193_0 -> 214 in the cache */
   /* search1193_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 214, 3 },
      4,
   } },

   /* replace1193_0_0 -> 0 in the cache */
   /* replace1193_0_1 -> 3 in the cache */
   /* replace1193_0 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 266 },
      -1,
   } },

   /* ('fmulz(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmulz', 'a', 'b')) */
   /* search1194_0_0 -> 16 in the cache */
   /* search1194_0 -> 282 in the cache */
   /* search1194_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 282, 36 },
      4,
   } },

   /* replace1194_0_0 -> 16 in the cache */
   /* replace1194_0_1 -> 36 in the cache */
   /* replace1194_0 -> 271 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 271 },
      -1,
   } },

   /* ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   /* search1195_0_0 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 128 },
      -1,
   } },
   /* search1195_1_0 -> 129 in the cache */
   /* search1195_1 -> 1184 in the cache */
   /* search1195_2 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 3400, 1184, 131 },
      -1,
   } },

   /* replace1195_0 -> 128 in the cache */
   /* replace1195_1 -> 129 in the cache */
   /* replace1195_2 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 128, 129, 131 },
      -1,
   } },

   /* ('ffmaz', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search1196_0_0 -> 16 in the cache */
   /* search1196_0 -> 282 in the cache */
   /* search1196_1_0 -> 36 in the cache */
   /* search1196_1 -> 602 in the cache */
   /* search1196_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 282, 602, 137 },
      -1,
   } },

   /* replace1196_0 -> 16 in the cache */
   /* replace1196_1 -> 36 in the cache */
   /* replace1196_2 -> 137 in the cache */
   /* replace1196 -> 389 in the cache */

   /* ('imul', ('ineg', 'a'), 'b') => ('ineg', ('imul', 'a', 'b')) */
   /* search1197_0_0 -> 0 in the cache */
   /* search1197_0 -> 209 in the cache */
   /* search1197_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 209, 3 },
      -1,
   } },

   /* replace1197_0_0 -> 0 in the cache */
   /* replace1197_0_1 -> 3 in the cache */
   /* replace1197_0 -> 944 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 944 },
      -1,
   } },

   /* ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmul', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3406, 3407 },
      0,
   } },
   /* search1198_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3408, 807 },
      0,
   } },

   /* replace1198_0_0 -> 128 in the cache */
   /* replace1198_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 128, 131 },
      -1,
   } },
   /* replace1198_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3410, 129 },
      -1,
   } },

   /* ('~fmulz(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmulz', ('fmulz', 'a', 'c'), 'b') */
   /* search1199_0_0 -> 330 in the cache */
   /* search1199_0_1 -> 340 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 330, 340 },
      0,
   } },
   /* search1199_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 3412, 311 },
      0,
   } },

   /* replace1199_0_0 -> 16 in the cache */
   /* replace1199_0_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 137 },
      -1,
   } },
   /* replace1199_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 3414, 36 },
      -1,
   } },

   /* ('~fmul(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)') => ('fmulz', ('fmul', 'a', 'c'), 'b') */
   /* search1200_0_0 -> 330 in the cache */
   /* search1200_0_1 -> 340 in the cache */
   /* search1200_0 -> 3412 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3412, 3416 },
      0,
   } },

   /* replace1200_0_0 -> 16 in the cache */
   /* replace1200_0_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 16, 137 },
      -1,
   } },
   /* replace1200_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 3418, 36 },
      -1,
   } },

   /* ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1201_0_0 -> 3406 in the cache */
   /* search1201_0_1 -> 3407 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 3406, 3407 },
      0,
   } },
   /* search1201_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 3420, 807 },
      0,
   } },

   /* replace1201_0_0 -> 128 in the cache */
   /* replace1201_0_1 -> 131 in the cache */
   /* replace1201_0 -> 1018 in the cache */
   /* replace1201_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 1018, 129 },
      -1,
   } },

   /* ('~ffma', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3423, 3424 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1202_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3425, 3426, 155 },
      -1,
   } },

   /* replace1202_0_0 -> 151 in the cache */
   /* replace1202_0_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 151, 154 },
      -1,
   } },
   /* replace1202_1 -> 152 in the cache */
   /* replace1202_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3428, 152, 155 },
      -1,
   } },

   /* ('~ffmaz', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd') */
   /* search1203_0_0 -> 330 in the cache */
   /* search1203_0_1 -> 340 in the cache */
   /* search1203_0 -> 3412 in the cache */
   /* search1203_1 -> 311 in the cache */
   /* search1203_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3412, 311, 165 },
      -1,
   } },

   /* replace1203_0_0 -> 16 in the cache */
   /* replace1203_0_1 -> 137 in the cache */
   /* replace1203_0 -> 3414 in the cache */
   /* replace1203_1 -> 36 in the cache */
   /* replace1203_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3414, 36, 165 },
      -1,
   } },

   /* ('~ffma', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)', 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd') */
   /* search1204_0_0 -> 330 in the cache */
   /* search1204_0_1 -> 340 in the cache */
   /* search1204_0 -> 3412 in the cache */
   /* search1204_1 -> 3416 in the cache */
   /* search1204_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3412, 3416, 165 },
      -1,
   } },

   /* replace1204_0_0 -> 16 in the cache */
   /* replace1204_0_1 -> 137 in the cache */
   /* replace1204_0 -> 3418 in the cache */
   /* replace1204_1 -> 36 in the cache */
   /* replace1204_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3418, 36, 165 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_fmul)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1205_0_0 -> 3406 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      29,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3406, 3434 },
      0,
   } },
   /* search1205_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3435, 807 },
      0,
   } },

   /* replace1205_0_0 -> 128 in the cache */
   /* replace1205_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 128, 131 },
      -1,
   } },
   /* replace1205_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3437, 129 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1206_0_0 -> 3406 in the cache */
   /* search1206_0_1 -> 3407 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3406, 3407 },
      0,
   } },
   /* search1206_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3439, 807 },
      0,
   } },

   /* replace1206_0_0 -> 128 in the cache */
   /* replace1206_0_1 -> 131 in the cache */
   /* replace1206_0 -> 3437 in the cache */
   /* replace1206_1 -> 129 in the cache */
   /* replace1206 -> 3438 in the cache */

   /* ('~fadd(is_used_once)', ('ffma(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffma', 'a', 'b', 'd'), 'c') */
   /* search1207_0_0 -> 3423 in the cache */
   /* search1207_0_1 -> 152 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 3423, 152, 3441 },
      0,
   } },
   /* search1207_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3442, 1024 },
      0,
   } },

   /* replace1207_0_0 -> 151 in the cache */
   /* replace1207_0_1 -> 152 in the cache */
   /* replace1207_0_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 151, 152, 155 },
      -1,
   } },
   /* replace1207_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3444, 154 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('ffmaz(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffmaz', 'a', 'b', 'd'), 'c') */
   /* search1208_0_0 -> 330 in the cache */
   /* search1208_0_1 -> 36 in the cache */
   /* search1208_0_2 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 330, 36, 349 },
      0,
   } },
   /* search1208_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3446, 313 },
      0,
   } },

   /* replace1208_0_0 -> 16 in the cache */
   /* replace1208_0_1 -> 36 in the cache */
   /* replace1208_0_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 16, 36, 165 },
      -1,
   } },
   /* replace1208_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3448, 137 },
      -1,
   } },

   /* ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1209_0_0 -> 3406 in the cache */
   /* search1209_0_1 -> 3407 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 3406, 3407 },
      0,
   } },
   /* search1209_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 3450, 807 },
      0,
   } },

   /* replace1209_0_0 -> 128 in the cache */
   /* replace1209_0_1 -> 131 in the cache */
   /* replace1209_0 -> 1032 in the cache */
   /* replace1209_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1032, 129 },
      -1,
   } },

   /* ('~fmul', '#a', ('fmul', 'b(is_not_const)', '#c')) => ('fmul', ('fmul', 'a', 'c'), 'b') */
   /* search1210_0 -> 284 in the cache */
   /* search1210_1_0 -> 3407 in the cache */
   /* search1210_1_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3407, 807 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 284, 3453 },
      -1,
   } },

   /* replace1210_0_0 -> 128 in the cache */
   /* replace1210_0_1 -> 131 in the cache */
   /* replace1210_0 -> 3410 in the cache */
   /* replace1210_1 -> 129 in the cache */
   /* replace1210 -> 3411 in the cache */

   /* ('~fmulz', '#a', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmulz', 'a', 'c'), 'b') */
   /* search1211_0 -> 288 in the cache */
   /* search1211_1_0 -> 340 in the cache */
   /* search1211_1_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 340, 311 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 288, 3455 },
      -1,
   } },

   /* replace1211_0_0 -> 16 in the cache */
   /* replace1211_0_1 -> 137 in the cache */
   /* replace1211_0 -> 3414 in the cache */
   /* replace1211_1 -> 36 in the cache */
   /* replace1211 -> 3415 in the cache */

   /* ('~fmul', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1212_1_0 -> 340 in the cache */
   /* search1212_1_1 -> 311 in the cache */
   /* search1212_1 -> 3455 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3457, 3455 },
      -1,
   } },

   /* replace1212_0_0 -> 16 in the cache */
   /* replace1212_0_1 -> 137 in the cache */
   /* replace1212_0 -> 3418 in the cache */
   /* replace1212_1 -> 36 in the cache */
   /* replace1212 -> 3419 in the cache */

   /* ('~ffma', '#a', ('fmul', 'b(is_not_const)', '#c'), 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1213_1_0 -> 3424 in the cache */
   /* search1213_1_1 -> 3426 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3424, 3426 },
      -1,
   } },
   /* search1213_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3459, 3460, 155 },
      -1,
   } },

   /* replace1213_0_0 -> 151 in the cache */
   /* replace1213_0_1 -> 154 in the cache */
   /* replace1213_0 -> 3428 in the cache */
   /* replace1213_1 -> 152 in the cache */
   /* replace1213_2 -> 155 in the cache */
   /* replace1213 -> 3429 in the cache */

   /* ('~ffmaz', '#a', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd') */
   /* search1214_0 -> 288 in the cache */
   /* search1214_1_0 -> 340 in the cache */
   /* search1214_1_1 -> 311 in the cache */
   /* search1214_1 -> 3455 in the cache */
   /* search1214_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 288, 3455, 165 },
      -1,
   } },

   /* replace1214_0_0 -> 16 in the cache */
   /* replace1214_0_1 -> 137 in the cache */
   /* replace1214_0 -> 3414 in the cache */
   /* replace1214_1 -> 36 in the cache */
   /* replace1214_2 -> 165 in the cache */
   /* replace1214 -> 3431 in the cache */

   /* ('~ffmaz', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd') */
   /* search1215_0 -> 3457 in the cache */
   /* search1215_1_0 -> 340 in the cache */
   /* search1215_1_1 -> 311 in the cache */
   /* search1215_1 -> 3455 in the cache */
   /* search1215_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3457, 3455, 165 },
      -1,
   } },

   /* replace1215_0_0 -> 16 in the cache */
   /* replace1215_0_1 -> 137 in the cache */
   /* replace1215_0 -> 3418 in the cache */
   /* replace1215_1 -> 36 in the cache */
   /* replace1215_2 -> 165 in the cache */
   /* replace1215 -> 3433 in the cache */

   /* ('imul', '#a', ('imul', 'b(is_not_const)', '#c')) => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1216_0 -> 284 in the cache */
   /* search1216_1_0 -> 3407 in the cache */
   /* search1216_1_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 3407, 807 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 284, 3464 },
      -1,
   } },

   /* replace1216_0_0 -> 128 in the cache */
   /* replace1216_0_1 -> 131 in the cache */
   /* replace1216_0 -> 1018 in the cache */
   /* replace1216_1 -> 129 in the cache */
   /* replace1216 -> 3422 in the cache */

   /* ('~fadd', '#a', ('fadd', 'b(is_not_const)', '#c')) => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1217_0 -> 284 in the cache */
   /* search1217_1_0 -> 3407 in the cache */
   /* search1217_1_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3407, 807 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 284, 3466 },
      -1,
   } },

   /* replace1217_0_0 -> 128 in the cache */
   /* replace1217_0_1 -> 131 in the cache */
   /* replace1217_0 -> 3437 in the cache */
   /* replace1217_1 -> 129 in the cache */
   /* replace1217 -> 3438 in the cache */

   /* ('~fadd', '#a', ('fneg', ('fadd', 'b(is_not_const)', '#c'))) => ('fadd', ('fadd', 'a', ('fneg', 'c')), ('fneg', 'b')) */
   /* search1218_0 -> 284 in the cache */
   /* search1218_1_0_0 -> 3407 in the cache */
   /* search1218_1_0_1 -> 807 in the cache */
   /* search1218_1_0 -> 3466 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 3466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 284, 3468 },
      -1,
   } },

   /* replace1218_0_0 -> 128 in the cache */
   /* replace1218_0_1_0 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 128, 3470 },
      -1,
   } },
   /* replace1218_1_0 -> 129 in the cache */
   /* replace1218_1 -> 1184 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3471, 1184 },
      -1,
   } },

   /* ('~fadd', '#a', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffma', 'b', 'c', ('fadd', 'a', 'd')) */
   /* search1219_0 -> 3459 in the cache */
   /* search1219_1_0 -> 3424 in the cache */
   /* search1219_1_1 -> 3441 in the cache */
   /* search1219_1_2 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 3424, 3441, 1024 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3459, 3473 },
      -1,
   } },

   /* replace1219_0 -> 152 in the cache */
   /* replace1219_1 -> 154 in the cache */
   /* replace1219_2_0 -> 151 in the cache */
   /* replace1219_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 151, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 152, 154, 3475 },
      -1,
   } },

   /* ('~fadd', '#a', ('fneg', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffma', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd'))) */
   /* search1220_0 -> 3459 in the cache */
   /* search1220_1_0_0 -> 3424 in the cache */
   /* search1220_1_0_1 -> 3441 in the cache */
   /* search1220_1_0_2 -> 1024 in the cache */
   /* search1220_1_0 -> 3473 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 3473 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3459, 3477 },
      -1,
   } },

   /* replace1220_0_0 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 152 },
      -1,
   } },
   /* replace1220_1 -> 154 in the cache */
   /* replace1220_2_0 -> 151 in the cache */
   /* replace1220_2_1_0 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 151, 3480 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3479, 154, 3481 },
      -1,
   } },

   /* ('~fadd', '#a', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffmaz', 'b', 'c', ('fadd', 'a', 'd')) */
   /* search1221_0 -> 288 in the cache */
   /* search1221_1_0 -> 340 in the cache */
   /* search1221_1_1 -> 349 in the cache */
   /* search1221_1_2 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 340, 349, 313 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 288, 3483 },
      -1,
   } },

   /* replace1221_0 -> 36 in the cache */
   /* replace1221_1 -> 137 in the cache */
   /* replace1221_2_0 -> 16 in the cache */
   /* replace1221_2_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 16, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 36, 137, 3485 },
      -1,
   } },

   /* ('~fadd', '#a', ('fneg', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffmaz', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd'))) */
   /* search1222_0 -> 288 in the cache */
   /* search1222_1_0_0 -> 340 in the cache */
   /* search1222_1_0_1 -> 349 in the cache */
   /* search1222_1_0_2 -> 313 in the cache */
   /* search1222_1_0 -> 3483 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 3483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 288, 3487 },
      -1,
   } },

   /* replace1222_0_0 -> 36 in the cache */
   /* replace1222_0 -> 602 in the cache */
   /* replace1222_1 -> 137 in the cache */
   /* replace1222_2_0 -> 16 in the cache */
   /* replace1222_2_1_0 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 16, 3489 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 602, 137, 3490 },
      -1,
   } },

   /* ('iadd', '#a', ('iadd', 'b(is_not_const)', '#c')) => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1223_0 -> 284 in the cache */
   /* search1223_1_0 -> 3407 in the cache */
   /* search1223_1_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 3407, 807 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 284, 3492 },
      -1,
   } },

   /* replace1223_0_0 -> 128 in the cache */
   /* replace1223_0_1 -> 131 in the cache */
   /* replace1223_0 -> 1032 in the cache */
   /* replace1223_1 -> 129 in the cache */
   /* replace1223 -> 3452 in the cache */

   /* ('iand', '#a', ('iand', 'b(is_not_const)', '#c')) => ('iand', ('iand', 'a', 'c'), 'b') */
   /* search1224_0 -> 284 in the cache */
   /* search1224_1_0 -> 3407 in the cache */
   /* search1224_1_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 3407, 807 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 284, 3494 },
      -1,
   } },

   /* replace1224_0_0 -> 128 in the cache */
   /* replace1224_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 128, 131 },
      -1,
   } },
   /* replace1224_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3496, 129 },
      -1,
   } },

   /* ('ior', '#a', ('ior', 'b(is_not_const)', '#c')) => ('ior', ('ior', 'a', 'c'), 'b') */
   /* search1225_0 -> 284 in the cache */
   /* search1225_1_0 -> 3407 in the cache */
   /* search1225_1_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3407, 807 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 284, 3498 },
      -1,
   } },

   /* replace1225_0_0 -> 128 in the cache */
   /* replace1225_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 128, 131 },
      -1,
   } },
   /* replace1225_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 3500, 129 },
      -1,
   } },

   /* ('ixor', '#a', ('ixor', 'b(is_not_const)', '#c')) => ('ixor', ('ixor', 'a', 'c'), 'b') */
   /* search1226_0 -> 284 in the cache */
   /* search1226_1_0 -> 3407 in the cache */
   /* search1226_1_1 -> 807 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 3407, 807 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 2,
      { 284, 3502 },
      -1,
   } },

   /* replace1226_0_0 -> 128 in the cache */
   /* replace1226_0_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 128, 131 },
      -1,
   } },
   /* replace1226_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 2,
      { 3504, 129 },
      -1,
   } },

   /* ('~fadd', ('fadd(is_used_once)', 'a(is_fmul)', 'b(is_fmul)'), 'c(is_not_fmul)') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      29,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1227_0_1 -> 3434 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3506, 3434 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      8,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3507, 3508 },
      -1,
   } },

   /* replace1227_0_0 -> 128 in the cache */
   /* replace1227_0_1 -> 131 in the cache */
   /* replace1227_0 -> 3437 in the cache */
   /* replace1227_1 -> 129 in the cache */
   /* replace1227 -> 3438 in the cache */

   /* ('idiv', ('imul(no_signed_wrap)', 'a', 'b'), 'b') => a */
   /* search1228_0_0 -> 0 in the cache */
   /* search1228_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 3 },
      5,
   } },
   /* search1228_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 1,
      { 3510, 3 },
      -1,
   } },

   /* replace1228 -> 0 in the cache */

   /* ('bcsel', ('ige', ('find_lsb', 'a'), 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a') */
   /* search1229_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1229_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3512, 124 },
      -1,
   } },
   /* search1229_1_0 -> 32 in the cache */
   /* search1229_1 -> 3512 in the cache */
   /* search1229_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3513, 3512, 126 },
      -1,
   } },

   /* replace1229_0 -> 32 in the cache */
   /* replace1229 -> 3512 in the cache */

   /* ('bcsel', ('ige', ('ifind_msb', 'a'), 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1230_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search1230_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3515, 124 },
      -1,
   } },
   /* search1230_1_0 -> 16 in the cache */
   /* search1230_1 -> 3515 in the cache */
   /* search1230_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3516, 3515, 126 },
      -1,
   } },

   /* replace1230_0 -> 16 in the cache */
   /* replace1230 -> 3515 in the cache */

   /* ('bcsel', ('ige', ('ufind_msb', 'a'), 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a') */
   /* search1231_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1231_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3518, 124 },
      -1,
   } },
   /* search1231_1_0 -> 32 in the cache */
   /* search1231_1 -> 3518 in the cache */
   /* search1231_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3519, 3518, 126 },
      -1,
   } },

   /* replace1231_0 -> 32 in the cache */
   /* replace1231 -> 3518 in the cache */

   /* ('bcsel', ('ige', ('ifind_msb_rev', 'a'), 0), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a') */
   /* search1232_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb_rev,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1232_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3521, 124 },
      -1,
   } },
   /* search1232_1_0 -> 32 in the cache */
   /* search1232_1 -> 3521 in the cache */
   /* search1232_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3522, 3521, 126 },
      -1,
   } },

   /* replace1232_0 -> 32 in the cache */
   /* replace1232 -> 3521 in the cache */

   /* ('bcsel', ('ige', ('ufind_msb_rev', 'a'), 0), ('ufind_msb_rev', 'a'), -1) => ('ufind_msb_rev', 'a') */
   /* search1233_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1233_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3524, 124 },
      -1,
   } },
   /* search1233_1_0 -> 32 in the cache */
   /* search1233_1 -> 3524 in the cache */
   /* search1233_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3525, 3524, 126 },
      -1,
   } },

   /* replace1233_0 -> 32 in the cache */
   /* replace1233 -> 3524 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a') */
   /* search1234_0_0 -> 32 in the cache */
   /* search1234_0_1 -> 61 in the cache */
   /* search1234_0 -> 1220 in the cache */
   /* search1234_1_0 -> 32 in the cache */
   /* search1234_1 -> 3512 in the cache */
   /* search1234_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1220, 3512, 126 },
      -1,
   } },

   /* replace1234_0 -> 32 in the cache */
   /* replace1234 -> 3512 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1235_0_0 -> 16 in the cache */
   /* search1235_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 124 },
      -1,
   } },
   /* search1235_1_0 -> 16 in the cache */
   /* search1235_1 -> 3515 in the cache */
   /* search1235_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3528, 3515, 126 },
      -1,
   } },

   /* replace1235_0 -> 16 in the cache */
   /* replace1235 -> 3515 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a') */
   /* search1236_0_0 -> 32 in the cache */
   /* search1236_0_1 -> 61 in the cache */
   /* search1236_0 -> 1220 in the cache */
   /* search1236_1_0 -> 32 in the cache */
   /* search1236_1 -> 3518 in the cache */
   /* search1236_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1220, 3518, 126 },
      -1,
   } },

   /* replace1236_0 -> 32 in the cache */
   /* replace1236 -> 3518 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a') */
   /* search1237_0_0 -> 32 in the cache */
   /* search1237_0_1 -> 61 in the cache */
   /* search1237_0 -> 1220 in the cache */
   /* search1237_1_0 -> 32 in the cache */
   /* search1237_1 -> 3521 in the cache */
   /* search1237_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1220, 3521, 126 },
      -1,
   } },

   /* replace1237_0 -> 32 in the cache */
   /* replace1237 -> 3521 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ufind_msb_rev', 'a'), -1) => ('ufind_msb_rev', 'a') */
   /* search1238_0_0 -> 32 in the cache */
   /* search1238_0_1 -> 61 in the cache */
   /* search1238_0 -> 1220 in the cache */
   /* search1238_1_0 -> 32 in the cache */
   /* search1238_1 -> 3524 in the cache */
   /* search1238_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1220, 3524, 126 },
      -1,
   } },

   /* replace1238_0 -> 32 in the cache */
   /* replace1238 -> 3524 in the cache */

   /* ('bcsel', ('ine', 'a', -1), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1239_0_0 -> 16 in the cache */
   /* search1239_0_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 126 },
      -1,
   } },
   /* search1239_1_0 -> 16 in the cache */
   /* search1239_1 -> 3515 in the cache */
   /* search1239_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3533, 3515, 126 },
      -1,
   } },

   /* replace1239_0 -> 16 in the cache */
   /* replace1239 -> 3515 in the cache */

   /* ('bcsel', ('ine', 'a', -1), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a') */
   /* search1240_0_0 -> 32 in the cache */
   /* search1240_0_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 32, 63 },
      -1,
   } },
   /* search1240_1_0 -> 32 in the cache */
   /* search1240_1 -> 3521 in the cache */
   /* search1240_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3535, 3521, 126 },
      -1,
   } },

   /* replace1240_0 -> 32 in the cache */
   /* replace1240 -> 3521 in the cache */

   /* ('bcsel', ('ine', ('ifind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb', 'a'))), -1) => ('ifind_msb_rev', 'a') */
   /* search1241_0_0_0 -> 16 in the cache */
   /* search1241_0_0 -> 3515 in the cache */
   /* search1241_0_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3515, 126 },
      -1,
   } },
   /* search1241_1_0 -> 19 in the cache */
   /* search1241_1_1_0_0 -> 16 in the cache */
   /* search1241_1_1_0 -> 3515 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 19, 3538 },
      -1,
   } },
   /* search1241_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3537, 3539, 126 },
      -1,
   } },

   /* replace1241_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb_rev,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('bcsel', ('ine', ('ufind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), -1) => ('ufind_msb_rev', 'a') */
   /* search1242_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search1242_0_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3542, 126 },
      -1,
   } },
   /* search1242_1_0 -> 19 in the cache */
   /* search1242_1_1_0_0 -> 16 in the cache */
   /* search1242_1_1_0 -> 3542 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3542 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 19, 3544 },
      -1,
   } },
   /* search1242_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3543, 3545, 126 },
      -1,
   } },

   /* replace1242_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('bcsel', ('ieq', ('ifind_msb', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ifind_msb', 'a')))) => ('ifind_msb_rev', 'a') */
   /* search1243_0_0_0 -> 16 in the cache */
   /* search1243_0_0 -> 3515 in the cache */
   /* search1243_0_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3515, 126 },
      -1,
   } },
   /* search1243_1 -> 126 in the cache */
   /* search1243_2_0 -> 19 in the cache */
   /* search1243_2_1_0_0 -> 16 in the cache */
   /* search1243_2_1_0 -> 3515 in the cache */
   /* search1243_2_1 -> 3538 in the cache */
   /* search1243_2 -> 3539 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3548, 126, 3539 },
      -1,
   } },

   /* replace1243_0 -> 16 in the cache */
   /* replace1243 -> 3541 in the cache */

   /* ('bcsel', ('ieq', ('ufind_msb', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a') */
   /* search1244_0_0_0 -> 16 in the cache */
   /* search1244_0_0 -> 3542 in the cache */
   /* search1244_0_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3542, 126 },
      -1,
   } },
   /* search1244_1 -> 126 in the cache */
   /* search1244_2_0 -> 19 in the cache */
   /* search1244_2_1_0_0 -> 16 in the cache */
   /* search1244_2_1_0 -> 3542 in the cache */
   /* search1244_2_1 -> 3544 in the cache */
   /* search1244_2 -> 3545 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3550, 126, 3545 },
      -1,
   } },

   /* replace1244_0 -> 16 in the cache */
   /* replace1244 -> 3547 in the cache */

   /* ('bcsel', ('ine', ('ifind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb', 'a'))), ('ifind_msb', 'a')) => ('ifind_msb_rev', 'a') */
   /* search1245_0_0_0 -> 16 in the cache */
   /* search1245_0_0 -> 3515 in the cache */
   /* search1245_0_1 -> 126 in the cache */
   /* search1245_0 -> 3537 in the cache */
   /* search1245_1_0 -> 19 in the cache */
   /* search1245_1_1_0_0 -> 16 in the cache */
   /* search1245_1_1_0 -> 3515 in the cache */
   /* search1245_1_1 -> 3538 in the cache */
   /* search1245_1 -> 3539 in the cache */
   /* search1245_2_0 -> 16 in the cache */
   /* search1245_2 -> 3515 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3537, 3539, 3515 },
      -1,
   } },

   /* replace1245_0 -> 16 in the cache */
   /* replace1245 -> 3541 in the cache */

   /* ('bcsel', ('ine', ('ufind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), ('ufind_msb', 'a')) => ('ufind_msb_rev', 'a') */
   /* search1246_0_0_0 -> 16 in the cache */
   /* search1246_0_0 -> 3542 in the cache */
   /* search1246_0_1 -> 126 in the cache */
   /* search1246_0 -> 3543 in the cache */
   /* search1246_1_0 -> 19 in the cache */
   /* search1246_1_1_0_0 -> 16 in the cache */
   /* search1246_1_1_0 -> 3542 in the cache */
   /* search1246_1_1 -> 3544 in the cache */
   /* search1246_1 -> 3545 in the cache */
   /* search1246_2_0 -> 16 in the cache */
   /* search1246_2 -> 3542 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3543, 3545, 3542 },
      -1,
   } },

   /* replace1246_0 -> 16 in the cache */
   /* replace1246 -> 3547 in the cache */

   /* ('bcsel', ('ieq', ('ifind_msb', 'a@32'), -1), ('ifind_msb', 'a'), ('iadd', 31, ('ineg', ('ifind_msb', 'a')))) => ('ifind_msb_rev', 'a') */
   /* search1247_0_0_0 -> 16 in the cache */
   /* search1247_0_0 -> 3515 in the cache */
   /* search1247_0_1 -> 126 in the cache */
   /* search1247_0 -> 3548 in the cache */
   /* search1247_1_0 -> 16 in the cache */
   /* search1247_1 -> 3515 in the cache */
   /* search1247_2_0 -> 19 in the cache */
   /* search1247_2_1_0_0 -> 16 in the cache */
   /* search1247_2_1_0 -> 3515 in the cache */
   /* search1247_2_1 -> 3538 in the cache */
   /* search1247_2 -> 3539 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3548, 3515, 3539 },
      -1,
   } },

   /* replace1247_0 -> 16 in the cache */
   /* replace1247 -> 3541 in the cache */

   /* ('bcsel', ('ieq', ('ufind_msb', 'a@32'), -1), ('ufind_msb', 'a'), ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a') */
   /* search1248_0_0_0 -> 16 in the cache */
   /* search1248_0_0 -> 3542 in the cache */
   /* search1248_0_1 -> 126 in the cache */
   /* search1248_0 -> 3550 in the cache */
   /* search1248_1_0 -> 16 in the cache */
   /* search1248_1 -> 3542 in the cache */
   /* search1248_2_0 -> 19 in the cache */
   /* search1248_2_1_0_0 -> 16 in the cache */
   /* search1248_2_1_0 -> 3542 in the cache */
   /* search1248_2_1 -> 3544 in the cache */
   /* search1248_2 -> 3545 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3550, 3542, 3545 },
      -1,
   } },

   /* replace1248_0 -> 16 in the cache */
   /* replace1248 -> 3547 in the cache */

   /* ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), -1) => ('ufind_msb_rev', 'a') */
   /* search1249_0_0 -> 16 in the cache */
   /* search1249_0_1 -> 124 in the cache */
   /* search1249_0 -> 3528 in the cache */
   /* search1249_1_0 -> 19 in the cache */
   /* search1249_1_1_0_0 -> 16 in the cache */
   /* search1249_1_1_0 -> 3542 in the cache */
   /* search1249_1_1 -> 3544 in the cache */
   /* search1249_1 -> 3545 in the cache */
   /* search1249_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3528, 3545, 126 },
      -1,
   } },

   /* replace1249_0 -> 16 in the cache */
   /* replace1249 -> 3547 in the cache */

   /* ('bcsel', ('ieq', 'a@32', 0), -1, ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a') */
   /* search1250_0_0 -> 16 in the cache */
   /* search1250_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 124 },
      -1,
   } },
   /* search1250_1 -> 126 in the cache */
   /* search1250_2_0 -> 19 in the cache */
   /* search1250_2_1_0_0 -> 16 in the cache */
   /* search1250_2_1_0 -> 3542 in the cache */
   /* search1250_2_1 -> 3544 in the cache */
   /* search1250_2 -> 3545 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3557, 126, 3545 },
      -1,
   } },

   /* replace1250_0 -> 16 in the cache */
   /* replace1250 -> 3547 in the cache */

   /* ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), ('ufind_msb', 'a')) => ('ufind_msb_rev', 'a') */
   /* search1251_0_0 -> 16 in the cache */
   /* search1251_0_1 -> 124 in the cache */
   /* search1251_0 -> 3528 in the cache */
   /* search1251_1_0 -> 19 in the cache */
   /* search1251_1_1_0_0 -> 16 in the cache */
   /* search1251_1_1_0 -> 3542 in the cache */
   /* search1251_1_1 -> 3544 in the cache */
   /* search1251_1 -> 3545 in the cache */
   /* search1251_2_0 -> 16 in the cache */
   /* search1251_2 -> 3542 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3528, 3545, 3542 },
      -1,
   } },

   /* replace1251_0 -> 16 in the cache */
   /* replace1251 -> 3547 in the cache */

   /* ('bcsel', ('ieq', 'a@32', 0), ('ufind_msb', 'a'), ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a') */
   /* search1252_0_0 -> 16 in the cache */
   /* search1252_0_1 -> 124 in the cache */
   /* search1252_0 -> 3557 in the cache */
   /* search1252_1_0 -> 16 in the cache */
   /* search1252_1 -> 3542 in the cache */
   /* search1252_2_0 -> 19 in the cache */
   /* search1252_2_1_0_0 -> 16 in the cache */
   /* search1252_2_1_0 -> 3542 in the cache */
   /* search1252_2_1 -> 3544 in the cache */
   /* search1252_2 -> 3545 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3557, 3542, 3545 },
      -1,
   } },

   /* replace1252_0 -> 16 in the cache */
   /* replace1252 -> 3547 in the cache */

   /* ('bcsel', ('ine', ('ifind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a'))), -1) => ('ifind_msb', 'a') */
   /* search1253_0_0_0 -> 16 in the cache */
   /* search1253_0_0 -> 3541 in the cache */
   /* search1253_0_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3541, 126 },
      -1,
   } },
   /* search1253_1_0 -> 19 in the cache */
   /* search1253_1_1_0_0 -> 16 in the cache */
   /* search1253_1_1_0 -> 3541 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3541 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 19, 3562 },
      -1,
   } },
   /* search1253_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3561, 3563, 126 },
      -1,
   } },

   /* replace1253_0 -> 16 in the cache */
   /* replace1253 -> 3515 in the cache */

   /* ('bcsel', ('ine', ('ufind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), -1) => ('ufind_msb', 'a') */
   /* search1254_0_0_0 -> 16 in the cache */
   /* search1254_0_0 -> 3547 in the cache */
   /* search1254_0_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3547, 126 },
      -1,
   } },
   /* search1254_1_0 -> 19 in the cache */
   /* search1254_1_1_0_0 -> 16 in the cache */
   /* search1254_1_1_0 -> 3547 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3547 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 19, 3566 },
      -1,
   } },
   /* search1254_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3565, 3567, 126 },
      -1,
   } },

   /* replace1254_0 -> 16 in the cache */
   /* replace1254 -> 3542 in the cache */

   /* ('bcsel', ('ieq', ('ifind_msb_rev', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a')))) => ('ifind_msb', 'a') */
   /* search1255_0_0_0 -> 16 in the cache */
   /* search1255_0_0 -> 3541 in the cache */
   /* search1255_0_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3541, 126 },
      -1,
   } },
   /* search1255_1 -> 126 in the cache */
   /* search1255_2_0 -> 19 in the cache */
   /* search1255_2_1_0_0 -> 16 in the cache */
   /* search1255_2_1_0 -> 3541 in the cache */
   /* search1255_2_1 -> 3562 in the cache */
   /* search1255_2 -> 3563 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3569, 126, 3563 },
      -1,
   } },

   /* replace1255_0 -> 16 in the cache */
   /* replace1255 -> 3515 in the cache */

   /* ('bcsel', ('ieq', ('ufind_msb_rev', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a') */
   /* search1256_0_0_0 -> 16 in the cache */
   /* search1256_0_0 -> 3547 in the cache */
   /* search1256_0_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3547, 126 },
      -1,
   } },
   /* search1256_1 -> 126 in the cache */
   /* search1256_2_0 -> 19 in the cache */
   /* search1256_2_1_0_0 -> 16 in the cache */
   /* search1256_2_1_0 -> 3547 in the cache */
   /* search1256_2_1 -> 3566 in the cache */
   /* search1256_2 -> 3567 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3571, 126, 3567 },
      -1,
   } },

   /* replace1256_0 -> 16 in the cache */
   /* replace1256 -> 3542 in the cache */

   /* ('bcsel', ('ine', ('ifind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a'))), ('ifind_msb_rev', 'a')) => ('ifind_msb', 'a') */
   /* search1257_0_0_0 -> 16 in the cache */
   /* search1257_0_0 -> 3541 in the cache */
   /* search1257_0_1 -> 126 in the cache */
   /* search1257_0 -> 3561 in the cache */
   /* search1257_1_0 -> 19 in the cache */
   /* search1257_1_1_0_0 -> 16 in the cache */
   /* search1257_1_1_0 -> 3541 in the cache */
   /* search1257_1_1 -> 3562 in the cache */
   /* search1257_1 -> 3563 in the cache */
   /* search1257_2_0 -> 16 in the cache */
   /* search1257_2 -> 3541 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3561, 3563, 3541 },
      -1,
   } },

   /* replace1257_0 -> 16 in the cache */
   /* replace1257 -> 3515 in the cache */

   /* ('bcsel', ('ine', ('ufind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), ('ufind_msb_rev', 'a')) => ('ufind_msb', 'a') */
   /* search1258_0_0_0 -> 16 in the cache */
   /* search1258_0_0 -> 3547 in the cache */
   /* search1258_0_1 -> 126 in the cache */
   /* search1258_0 -> 3565 in the cache */
   /* search1258_1_0 -> 19 in the cache */
   /* search1258_1_1_0_0 -> 16 in the cache */
   /* search1258_1_1_0 -> 3547 in the cache */
   /* search1258_1_1 -> 3566 in the cache */
   /* search1258_1 -> 3567 in the cache */
   /* search1258_2_0 -> 16 in the cache */
   /* search1258_2 -> 3547 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3565, 3567, 3547 },
      -1,
   } },

   /* replace1258_0 -> 16 in the cache */
   /* replace1258 -> 3542 in the cache */

   /* ('bcsel', ('ieq', ('ifind_msb_rev', 'a@32'), -1), ('ifind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a')))) => ('ifind_msb', 'a') */
   /* search1259_0_0_0 -> 16 in the cache */
   /* search1259_0_0 -> 3541 in the cache */
   /* search1259_0_1 -> 126 in the cache */
   /* search1259_0 -> 3569 in the cache */
   /* search1259_1_0 -> 16 in the cache */
   /* search1259_1 -> 3541 in the cache */
   /* search1259_2_0 -> 19 in the cache */
   /* search1259_2_1_0_0 -> 16 in the cache */
   /* search1259_2_1_0 -> 3541 in the cache */
   /* search1259_2_1 -> 3562 in the cache */
   /* search1259_2 -> 3563 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3569, 3541, 3563 },
      -1,
   } },

   /* replace1259_0 -> 16 in the cache */
   /* replace1259 -> 3515 in the cache */

   /* ('bcsel', ('ieq', ('ufind_msb_rev', 'a@32'), -1), ('ufind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a') */
   /* search1260_0_0_0 -> 16 in the cache */
   /* search1260_0_0 -> 3547 in the cache */
   /* search1260_0_1 -> 126 in the cache */
   /* search1260_0 -> 3571 in the cache */
   /* search1260_1_0 -> 16 in the cache */
   /* search1260_1 -> 3547 in the cache */
   /* search1260_2_0 -> 19 in the cache */
   /* search1260_2_1_0_0 -> 16 in the cache */
   /* search1260_2_1_0 -> 3547 in the cache */
   /* search1260_2_1 -> 3566 in the cache */
   /* search1260_2 -> 3567 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3571, 3547, 3567 },
      -1,
   } },

   /* replace1260_0 -> 16 in the cache */
   /* replace1260 -> 3542 in the cache */

   /* ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), -1) => ('ufind_msb', 'a') */
   /* search1261_0_0 -> 16 in the cache */
   /* search1261_0_1 -> 124 in the cache */
   /* search1261_0 -> 3528 in the cache */
   /* search1261_1_0 -> 19 in the cache */
   /* search1261_1_1_0_0 -> 16 in the cache */
   /* search1261_1_1_0 -> 3547 in the cache */
   /* search1261_1_1 -> 3566 in the cache */
   /* search1261_1 -> 3567 in the cache */
   /* search1261_2 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3528, 3567, 126 },
      -1,
   } },

   /* replace1261_0 -> 16 in the cache */
   /* replace1261 -> 3542 in the cache */

   /* ('bcsel', ('ieq', 'a@32', 0), -1, ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a') */
   /* search1262_0_0 -> 16 in the cache */
   /* search1262_0_1 -> 124 in the cache */
   /* search1262_0 -> 3557 in the cache */
   /* search1262_1 -> 126 in the cache */
   /* search1262_2_0 -> 19 in the cache */
   /* search1262_2_1_0_0 -> 16 in the cache */
   /* search1262_2_1_0 -> 3547 in the cache */
   /* search1262_2_1 -> 3566 in the cache */
   /* search1262_2 -> 3567 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3557, 126, 3567 },
      -1,
   } },

   /* replace1262_0 -> 16 in the cache */
   /* replace1262 -> 3542 in the cache */

   /* ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), ('ufind_msb_rev', 'a')) => ('ufind_msb', 'a') */
   /* search1263_0_0 -> 16 in the cache */
   /* search1263_0_1 -> 124 in the cache */
   /* search1263_0 -> 3528 in the cache */
   /* search1263_1_0 -> 19 in the cache */
   /* search1263_1_1_0_0 -> 16 in the cache */
   /* search1263_1_1_0 -> 3547 in the cache */
   /* search1263_1_1 -> 3566 in the cache */
   /* search1263_1 -> 3567 in the cache */
   /* search1263_2_0 -> 16 in the cache */
   /* search1263_2 -> 3547 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3528, 3567, 3547 },
      -1,
   } },

   /* replace1263_0 -> 16 in the cache */
   /* replace1263 -> 3542 in the cache */

   /* ('bcsel', ('ieq', 'a@32', 0), ('ufind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a') */
   /* search1264_0_0 -> 16 in the cache */
   /* search1264_0_1 -> 124 in the cache */
   /* search1264_0 -> 3557 in the cache */
   /* search1264_1_0 -> 16 in the cache */
   /* search1264_1 -> 3547 in the cache */
   /* search1264_2_0 -> 19 in the cache */
   /* search1264_2_1_0_0 -> 16 in the cache */
   /* search1264_2_1_0 -> 3547 in the cache */
   /* search1264_2_1 -> 3566 in the cache */
   /* search1264_2 -> 3567 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3557, 3547, 3567 },
      -1,
   } },

   /* replace1264_0 -> 16 in the cache */
   /* replace1264 -> 3542 in the cache */

   /* ('find_lsb', ('bitfield_reverse', 'a')) => ('ufind_msb_rev', 'a') */
   /* search1265_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_reverse,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3581 },
      -1,
   } },

   /* replace1265_0 -> 16 in the cache */
   /* replace1265 -> 3547 in the cache */

   /* ('ufind_msb_rev', ('bitfield_reverse', 'a')) => ('find_lsb', 'a') */
   /* search1266_0_0 -> 16 in the cache */
   /* search1266_0 -> 3581 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 3581 },
      -1,
   } },

   /* replace1266_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('~fmul', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b') */
   /* search1267_0_0 -> 523 in the cache */
   /* search1267_0_1 -> 277 in the cache */
   /* search1267_0_2 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 277, 272 },
      0,
   } },
   /* search1267_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3585, 3 },
      -1,
   } },

   /* replace1267_0 -> 523 in the cache */
   /* replace1267_1_0 -> 3 in the cache */
   /* replace1267_1 -> 1080 in the cache */
   /* replace1267_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 1080, 3 },
      -1,
   } },

   /* ('~fmul', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b')) */
   /* search1268_0_0 -> 523 in the cache */
   /* search1268_0_1 -> 272 in the cache */
   /* search1268_0_2 -> 277 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 272, 277 },
      0,
   } },
   /* search1268_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3588, 3 },
      -1,
   } },

   /* replace1268_0 -> 523 in the cache */
   /* replace1268_1 -> 3 in the cache */
   /* replace1268_2_0 -> 3 in the cache */
   /* replace1268_2 -> 1080 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 3, 1080 },
      -1,
   } },

   /* ('~fmulz', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b') */
   /* search1269_0_0 -> 523 in the cache */
   /* search1269_0_1 -> 280 in the cache */
   /* search1269_0_2 -> 245 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 280, 245 },
      0,
   } },
   /* search1269_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 3591, 36 },
      -1,
   } },

   /* replace1269_0 -> 523 in the cache */
   /* replace1269_1_0 -> 36 in the cache */
   /* replace1269_1 -> 602 in the cache */
   /* replace1269_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 602, 36 },
      -1,
   } },

   /* ('~fmulz', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b')) */
   /* search1270_0_0 -> 523 in the cache */
   /* search1270_0_1 -> 245 in the cache */
   /* search1270_0_2 -> 280 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 245, 280 },
      0,
   } },
   /* search1270_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 3594, 36 },
      -1,
   } },

   /* replace1270_0 -> 523 in the cache */
   /* replace1270_1 -> 36 in the cache */
   /* replace1270_2_0 -> 36 in the cache */
   /* replace1270_2 -> 602 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 36, 602 },
      -1,
   } },

   /* ('fabs', ('bcsel(is_used_once)', 'b', ('fneg', 'a'), 'a')) => ('fabs', 'a') */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1271_0_1_0 -> 1101 in the cache */
   /* search1271_0_1 -> 1569 in the cache */
   /* search1271_0_2 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3597, 1569, 1101 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 3598 },
      -1,
   } },

   /* replace1271_0 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 1101 },
      -1,
   } },

   /* ('fabs', ('bcsel(is_used_once)', 'b', 'a', ('fneg', 'a'))) => ('fabs', 'a') */
   /* search1272_0_0 -> 3597 in the cache */
   /* search1272_0_1 -> 1101 in the cache */
   /* search1272_0_2_0 -> 1101 in the cache */
   /* search1272_0_2 -> 1569 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3597, 1101, 1569 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 3601 },
      -1,
   } },

   /* replace1272_0 -> 1101 in the cache */
   /* replace1272 -> 3600 in the cache */

   /* ('~bcsel', ('flt', 'a', 0.0), ('fneg', 'a'), 'a') => ('fabs', 'a') */
   /* search1273_0_0 -> 32 in the cache */
   /* search1273_0_1 -> 113 in the cache */
   /* search1273_0 -> 1159 in the cache */
   /* search1273_1_0 -> 32 in the cache */
   /* search1273_1 -> 98 in the cache */
   /* search1273_2 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1159, 98, 32 },
      -1,
   } },

   /* replace1273_0 -> 32 in the cache */
   /* replace1273 -> 103 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), 'd') => ('bcsel', ('iand', 'a', 'b'), 'c', 'd') */
   /* search1274_0 -> 753 in the cache */
   /* search1274_1_0 -> 1121 in the cache */
   /* search1274_1_1 -> 154 in the cache */
   /* search1274_1_2 -> 155 in the cache */
   /* search1274_1 -> 1314 in the cache */
   /* search1274_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1314, 155 },
      -1,
   } },

   /* replace1274_0_0 -> 753 in the cache */
   /* replace1274_0_1 -> 1121 in the cache */
   /* replace1274_0 -> 1133 in the cache */
   /* replace1274_1 -> 154 in the cache */
   /* replace1274_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1133, 154, 155 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', ('bcsel', 'c', 'b', 'd')) => ('bcsel', ('ior', 'a', 'c'), 'b', 'd') */
   /* search1275_0 -> 753 in the cache */
   /* search1275_1 -> 152 in the cache */
   /* search1275_2_0 -> 466 in the cache */
   /* search1275_2_1 -> 152 in the cache */
   /* search1275_2_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 466, 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 152, 3606 },
      -1,
   } },

   /* replace1275_0_0 -> 753 in the cache */
   /* replace1275_0_1 -> 466 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 753, 466 },
      -1,
   } },
   /* replace1275_1 -> 152 in the cache */
   /* replace1275_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3608, 152, 155 },
      -1,
   } },

   /* ('fmod', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ffloor', ('fdiv', 'a', 'b')))) */
   /* search1276_0 -> 0 in the cache */
   /* search1276_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1276_0 -> 0 in the cache */
   /* replace1276_1_0 -> 3 in the cache */
   /* replace1276_1_1_0_0 -> 0 in the cache */
   /* replace1276_1_1_0_1 -> 3 in the cache */
   /* replace1276_1_1_0 -> 2805 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 2805 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3, 3611 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 1,
      { 0, 3612 },
      -1,
   } },

   /* ('frem', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ftrunc', ('fdiv', 'a', 'b')))) */
   /* search1277_0 -> 0 in the cache */
   /* search1277_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1277_0 -> 0 in the cache */
   /* replace1277_1_0 -> 3 in the cache */
   /* replace1277_1_1_0_0 -> 0 in the cache */
   /* replace1277_1_1_0_1 -> 3 in the cache */
   /* replace1277_1_1_0 -> 2805 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 2805 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3, 3615 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 1,
      { 0, 3616 },
      -1,
   } },

   /* ('uadd_carry', 'a', 'b') => ('b2i', ('ult', ('iadd', 'a', 'b'), 'a')) */
   /* search1278_0 -> 0 in the cache */
   /* search1278_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uadd_carry,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1278_0_0_0 -> 0 in the cache */
   /* replace1278_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1278_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 3619, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 3620 },
      -1,
   } },

   /* ('usub_borrow', 'a', 'b') => ('b2i', ('ult', 'a', 'b')) */
   /* search1279_0 -> 0 in the cache */
   /* search1279_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_usub_borrow,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1279_0_0 -> 0 in the cache */
   /* replace1279_0_1 -> 3 in the cache */
   /* replace1279_0 -> 1060 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1060 },
      -1,
   } },

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bfi', ('bfm', 'bits', 'offset'), 'insert', 'base')) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* base */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* insert */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* offset */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_insert,
      -1, 0,
      { 3624, 3625, 3626, 3627 },
      -1,
   } },

   /* replace1280_0_0 -> 19 in the cache */
   /* replace1280_0_1 -> 3627 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 19, 3627 },
      -1,
   } },
   /* replace1280_1 -> 3625 in the cache */
   /* replace1280_2_0_0 -> 3627 in the cache */
   /* replace1280_2_0_1 -> 3626 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 3627, 3626 },
      -1,
   } },
   /* replace1280_2_1 -> 3625 in the cache */
   /* replace1280_2_2 -> 3624 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 3630, 3625, 3624 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3629, 3625, 3631 },
      -1,
   } },

   /* ('ihadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1281_0 -> 0 in the cache */
   /* search1281_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ihadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1281_0_0 -> 0 in the cache */
   /* replace1281_0_1 -> 3 in the cache */
   /* replace1281_0 -> 203 in the cache */
   /* replace1281_1_0_0 -> 0 in the cache */
   /* replace1281_1_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      2, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1281_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3634, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 203, 3635 },
      -1,
   } },

   /* ('uhadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1282_0 -> 0 in the cache */
   /* search1282_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1282_0_0 -> 0 in the cache */
   /* replace1282_0_1 -> 3 in the cache */
   /* replace1282_0 -> 203 in the cache */
   /* replace1282_1_0_0 -> 0 in the cache */
   /* replace1282_1_0_1 -> 3 in the cache */
   /* replace1282_1_0 -> 3634 in the cache */
   /* replace1282_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3634, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 203, 3638 },
      -1,
   } },

   /* ('irhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1283_0 -> 0 in the cache */
   /* search1283_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1283_0_0 -> 0 in the cache */
   /* replace1283_0_1 -> 3 in the cache */
   /* replace1283_0 -> 2301 in the cache */
   /* replace1283_1_0_0 -> 0 in the cache */
   /* replace1283_1_0_1 -> 3 in the cache */
   /* replace1283_1_0 -> 2674 in the cache */
   /* replace1283_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2674, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 2301, 3641 },
      -1,
   } },

   /* ('urhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1284_0 -> 0 in the cache */
   /* search1284_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_urhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1284_0_0 -> 0 in the cache */
   /* replace1284_0_1 -> 3 in the cache */
   /* replace1284_0 -> 2301 in the cache */
   /* replace1284_1_0_0 -> 0 in the cache */
   /* replace1284_1_0_1 -> 3 in the cache */
   /* replace1284_1_0 -> 2674 in the cache */
   /* replace1284_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2674, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 2301, 3644 },
      -1,
   } },

   /* ('ihadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1285_0 -> 21 in the cache */
   /* search1285_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ihadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1285_0_0 -> 21 in the cache */
   /* replace1285_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1285_1_0_0 -> 21 in the cache */
   /* replace1285_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ixor,
      2, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1285_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3648, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 3647, 3649 },
      -1,
   } },

   /* ('uhadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1286_0 -> 21 in the cache */
   /* search1286_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_uhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1286_0_0 -> 21 in the cache */
   /* replace1286_0_1 -> 41 in the cache */
   /* replace1286_0 -> 3647 in the cache */
   /* replace1286_1_0_0 -> 21 in the cache */
   /* replace1286_1_0_1 -> 41 in the cache */
   /* replace1286_1_0 -> 3648 in the cache */
   /* replace1286_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3648, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 3647, 3652 },
      -1,
   } },

   /* ('irhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1287_0 -> 21 in the cache */
   /* search1287_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_irhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1287_0_0 -> 21 in the cache */
   /* replace1287_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1287_1_0_0 -> 21 in the cache */
   /* replace1287_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1287_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3656, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 3655, 3657 },
      -1,
   } },

   /* ('urhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1288_0 -> 21 in the cache */
   /* search1288_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_urhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1288_0_0 -> 21 in the cache */
   /* replace1288_0_1 -> 41 in the cache */
   /* replace1288_0 -> 3655 in the cache */
   /* replace1288_1_0_0 -> 21 in the cache */
   /* replace1288_1_0_1 -> 41 in the cache */
   /* replace1288_1_0 -> 3656 in the cache */
   /* replace1288_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3656, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 3655, 3660 },
      -1,
   } },

   /* ('imul_32x16', 'a', 'b') => ('imul', 'a', ('extract_i16', 'b', 0)) */
   /* search1289_0 -> 16 in the cache */
   /* search1289_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul_32x16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1289_0 -> 16 in the cache */
   /* replace1289_1_0 -> 36 in the cache */
   /* replace1289_1_1 -> 124 in the cache */
   /* replace1289_1 -> 439 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 16, 439 },
      -1,
   } },

   /* ('umul_32x16', 'a', 'b') => ('imul', 'a', ('extract_u16', 'b', 0)) */
   /* search1290_0 -> 16 in the cache */
   /* search1290_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_32x16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1290_0 -> 16 in the cache */
   /* replace1290_1_0 -> 36 in the cache */
   /* replace1290_1_1 -> 124 in the cache */
   /* replace1290_1 -> 447 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 16, 447 },
      -1,
   } },

   /* ('uadd_sat@64', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b')) */
   /* search1291_0 -> 21 in the cache */
   /* search1291_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1291_0_0_0 -> 21 in the cache */
   /* replace1291_0_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1291_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 3667, 21 },
      -1,
   } },
   /* replace1291_1 -> 1491 in the cache */
   /* replace1291_2_0 -> 21 in the cache */
   /* replace1291_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3668, 1491, 3669 },
      -1,
   } },

   /* ('uadd_sat', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b')) */
   /* search1292_0 -> 0 in the cache */
   /* search1292_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1292_0_0_0 -> 0 in the cache */
   /* replace1292_0_0_1 -> 3 in the cache */
   /* replace1292_0_0 -> 3619 in the cache */
   /* replace1292_0_1 -> 0 in the cache */
   /* replace1292_0 -> 3620 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   /* replace1292_2_0 -> 0 in the cache */
   /* replace1292_2_1 -> 3 in the cache */
   /* replace1292_2 -> 210 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3620, 3672, 210 },
      -1,
   } },

   /* ('usub_sat', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b')) */
   /* search1293_0 -> 0 in the cache */
   /* search1293_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1293_0_0 -> 0 in the cache */
   /* replace1293_0_1 -> 3 in the cache */
   /* replace1293_0 -> 1060 in the cache */
   /* replace1293_1 -> 86 in the cache */
   /* replace1293_2_0 -> 0 in the cache */
   /* replace1293_2_1 -> 3 in the cache */
   /* replace1293_2 -> 3389 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1060, 86, 3389 },
      -1,
   } },

   /* ('usub_sat@64', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b')) */
   /* search1294_0 -> 21 in the cache */
   /* search1294_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 21, 41 },
      -1,
   } },

   /* replace1294_0_0 -> 21 in the cache */
   /* replace1294_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 41 },
      -1,
   } },
   /* replace1294_1 -> 890 in the cache */
   /* replace1294_2_0 -> 21 in the cache */
   /* replace1294_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3677, 890, 3678 },
      -1,
   } },

   /* ('iadd_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), ('iadd', 'a', 'b'), 9223372036854775807)) */
   /* search1295_0 -> 21 in the cache */
   /* search1295_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1295_0_0_0_0 -> 21 in the cache */
   /* replace1295_0_0_0_1 -> 890 in the cache */
   /* replace1295_0_0_0 -> 1481 in the cache */
   /* replace1295_0_0_1_0 -> 41 in the cache */
   /* replace1295_0_0_1_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 41, 890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1481, 3681 },
      -1,
   } },
   /* replace1295_0_1_0_0 -> 21 in the cache */
   /* replace1295_0_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1295_0_1_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3683, 890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3682, 3684 },
      -1,
   } },
   /* replace1295_1 -> 22 in the cache */
   /* replace1295_2_0_0_0_0 -> 21 in the cache */
   /* replace1295_2_0_0_0_1 -> 890 in the cache */
   /* replace1295_2_0_0_0 -> 1481 in the cache */
   /* replace1295_2_0_0_1_0 -> 41 in the cache */
   /* replace1295_2_0_0_1_1 -> 890 in the cache */
   /* replace1295_2_0_0_1 -> 3681 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      4, 1,
      { 1481, 3681 },
      -1,
   } },
   /* replace1295_2_0_1_0_0 -> 21 in the cache */
   /* replace1295_2_0_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1295_2_0_1_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3687, 890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      3, 3,
      { 3686, 3688 },
      -1,
   } },
   /* replace1295_2_1_0 -> 21 in the cache */
   /* replace1295_2_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      6, 1,
      { 21, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fffffffffffffff /* 9223372036854775807 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3689, 3690, 3691 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 7,
      { 3685, 22, 3692 },
      -1,
   } },

   /* ('isub_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), ('isub', 'a', 'b'), 9223372036854775807)) */
   /* search1296_0 -> 21 in the cache */
   /* search1296_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 21, 41 },
      -1,
   } },

   /* replace1296_0_0_0_0 -> 21 in the cache */
   /* replace1296_0_0_0_1 -> 890 in the cache */
   /* replace1296_0_0_0 -> 1481 in the cache */
   /* replace1296_0_0_1_0 -> 41 in the cache */
   /* replace1296_0_0_1_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 41, 890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1481, 3695 },
      -1,
   } },
   /* replace1296_0_1_0_0 -> 21 in the cache */
   /* replace1296_0_1_0_1 -> 41 in the cache */
   /* replace1296_0_1_0 -> 3678 in the cache */
   /* replace1296_0_1_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3678, 890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3696, 3697 },
      -1,
   } },
   /* replace1296_1 -> 22 in the cache */
   /* replace1296_2_0_0_0_0 -> 21 in the cache */
   /* replace1296_2_0_0_0_1 -> 890 in the cache */
   /* replace1296_2_0_0_0 -> 1481 in the cache */
   /* replace1296_2_0_0_1_0 -> 41 in the cache */
   /* replace1296_2_0_0_1_1 -> 890 in the cache */
   /* replace1296_2_0_0_1 -> 3695 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      3, 1,
      { 1481, 3695 },
      -1,
   } },
   /* replace1296_2_0_1_0_0 -> 21 in the cache */
   /* replace1296_2_0_1_0_1 -> 41 in the cache */
   /* replace1296_2_0_1_0 -> 3678 in the cache */
   /* replace1296_2_0_1_1 -> 890 in the cache */
   /* replace1296_2_0_1 -> 3697 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      2, 2,
      { 3699, 3697 },
      -1,
   } },
   /* replace1296_2_1_0 -> 21 in the cache */
   /* replace1296_2_1_1 -> 41 in the cache */
   /* replace1296_2_1 -> 3678 in the cache */
   /* replace1296_2_2 -> 3691 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3700, 3678, 3691 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3698, 22, 3701 },
      -1,
   } },

   /* ('ilt', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1297_0_0 -> 21 in the cache */
   /* search1297_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search1297_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3703, 890 },
      -1,
   } },

   /* replace1297_0_0_0 -> 21 in the cache */
   /* replace1297_0_0 -> 3146 in the cache */
   /* replace1297_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 3146, 3705 },
      -1,
   } },
   /* replace1297_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3706, 124 },
      -1,
   } },

   /* ('ilt', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1298_0_0 -> 21 in the cache */
   /* search1298_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search1298_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3708, 890 },
      -1,
   } },

   /* replace1298_0_0_0 -> 21 in the cache */
   /* replace1298_0_0 -> 3146 in the cache */
   /* replace1298_0_1_0 -> 41 in the cache */
   /* replace1298_0_1 -> 3705 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 3146, 3705 },
      -1,
   } },
   /* replace1298_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3710, 124 },
      -1,
   } },

   /* ('ige', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1299_0_0 -> 21 in the cache */
   /* search1299_0_1 -> 41 in the cache */
   /* search1299_0 -> 3703 in the cache */
   /* search1299_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3703, 890 },
      -1,
   } },

   /* replace1299_0_0_0 -> 21 in the cache */
   /* replace1299_0_0 -> 3146 in the cache */
   /* replace1299_0_1_0 -> 41 in the cache */
   /* replace1299_0_1 -> 3705 in the cache */
   /* replace1299_0 -> 3706 in the cache */
   /* replace1299_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3706, 124 },
      -1,
   } },

   /* ('ige', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1300_0_0 -> 21 in the cache */
   /* search1300_0_1 -> 41 in the cache */
   /* search1300_0 -> 3708 in the cache */
   /* search1300_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3708, 890 },
      -1,
   } },

   /* replace1300_0_0_0 -> 21 in the cache */
   /* replace1300_0_0 -> 3146 in the cache */
   /* replace1300_0_1_0 -> 41 in the cache */
   /* replace1300_0_1 -> 3705 in the cache */
   /* replace1300_0 -> 3710 in the cache */
   /* replace1300_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3710, 124 },
      -1,
   } },

   /* ('ilt', 'a@64', 0) => ('ilt', ('unpack_64_2x32_split_y', 'a'), 0) */
   /* search1301_0 -> 21 in the cache */
   /* search1301_1 -> 890 in the cache */
   /* search1301 -> 1481 in the cache */

   /* replace1301_0_0 -> 21 in the cache */
   /* replace1301_0 -> 3146 in the cache */
   /* replace1301_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3146, 124 },
      -1,
   } },

   /* ('ige', 'a@64', 0) => ('ige', ('unpack_64_2x32_split_y', 'a'), 0) */
   /* search1302_0 -> 21 in the cache */
   /* search1302_1 -> 890 in the cache */
   /* search1302 -> 1478 in the cache */

   /* replace1302_0_0 -> 21 in the cache */
   /* replace1302_0 -> 3146 in the cache */
   /* replace1302_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3146, 124 },
      -1,
   } },

   /* ('ine', 'a@64', 0) => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1303_0 -> 21 in the cache */
   /* search1303_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 21, 890 },
      -1,
   } },

   /* replace1303_0_0_0 -> 21 in the cache */
   /* replace1303_0_0 -> 3145 in the cache */
   /* replace1303_0_1_0 -> 21 in the cache */
   /* replace1303_0_1 -> 3146 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3145, 3146 },
      -1,
   } },
   /* replace1303_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 3719, 124 },
      -1,
   } },

   /* ('ieq', 'a@64', 0) => ('ieq', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1304_0 -> 21 in the cache */
   /* search1304_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 21, 890 },
      -1,
   } },

   /* replace1304_0_0_0 -> 21 in the cache */
   /* replace1304_0_0 -> 3145 in the cache */
   /* replace1304_0_1_0 -> 21 in the cache */
   /* replace1304_0_1 -> 3146 in the cache */
   /* replace1304_0 -> 3719 in the cache */
   /* replace1304_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 3719, 124 },
      -1,
   } },

   /* ('ult', 0, 'a@64') => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1305_0 -> 890 in the cache */
   /* search1305_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 890, 21 },
      -1,
   } },

   /* replace1305_0_0_0 -> 21 in the cache */
   /* replace1305_0_0 -> 3145 in the cache */
   /* replace1305_0_1_0 -> 21 in the cache */
   /* replace1305_0_1 -> 3146 in the cache */
   /* replace1305_0 -> 3719 in the cache */
   /* replace1305_1 -> 124 in the cache */
   /* replace1305 -> 3720 in the cache */

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('ior', ('iand', 'base', ('inot', ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))), ('iand', ('ishl', 'insert', 'offset'), ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset')))) */
   /* search1306_0 -> 3624 in the cache */
   /* search1306_1 -> 3625 in the cache */
   /* search1306_2 -> 3626 in the cache */
   /* search1306_3 -> 3627 in the cache */
   /* search1306 -> 3628 in the cache */

   /* replace1306_0_0 -> 19 in the cache */
   /* replace1306_0_1 -> 3627 in the cache */
   /* replace1306_0 -> 3629 in the cache */
   /* replace1306_1 -> 3625 in the cache */
   /* replace1306_2_0_0 -> 3624 in the cache */
   /* replace1306_2_0_1_0_0_0_0 -> 398 in the cache */
   /* replace1306_2_0_1_0_0_0_1 -> 3627 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 398, 3627 },
      -1,
   } },
   /* replace1306_2_0_1_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3724, 398 },
      -1,
   } },
   /* replace1306_2_0_1_0_1 -> 3626 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3725, 3626 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3726 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 3624, 3727 },
      -1,
   } },
   /* replace1306_2_1_0_0 -> 3625 in the cache */
   /* replace1306_2_1_0_1 -> 3626 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3625, 3626 },
      -1,
   } },
   /* replace1306_2_1_1_0_0_0 -> 398 in the cache */
   /* replace1306_2_1_1_0_0_1 -> 3627 in the cache */
   /* replace1306_2_1_1_0_0 -> 3724 in the cache */
   /* replace1306_2_1_1_0_1 -> 398 in the cache */
   /* replace1306_2_1_1_0 -> 3725 in the cache */
   /* replace1306_2_1_1_1 -> 3626 in the cache */
   /* replace1306_2_1_1 -> 3726 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 3729, 3726 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3728, 3730 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 3629, 3625, 3731 },
      -1,
   } },

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bitfield_select', ('bfm', 'bits', 'offset'), ('ishl', 'insert', 'offset'), 'base')) */
   /* search1307_0 -> 3624 in the cache */
   /* search1307_1 -> 3625 in the cache */
   /* search1307_2 -> 3626 in the cache */
   /* search1307_3 -> 3627 in the cache */
   /* search1307 -> 3628 in the cache */

   /* replace1307_0_0 -> 19 in the cache */
   /* replace1307_0_1 -> 3627 in the cache */
   /* replace1307_0 -> 3629 in the cache */
   /* replace1307_1 -> 3625 in the cache */
   /* replace1307_2_0_0 -> 3627 in the cache */
   /* replace1307_2_0_1 -> 3626 in the cache */
   /* replace1307_2_0 -> 3630 in the cache */
   /* replace1307_2_1_0 -> 3625 in the cache */
   /* replace1307_2_1_1 -> 3626 in the cache */
   /* replace1307_2_1 -> 3729 in the cache */
   /* replace1307_2_2 -> 3624 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 3630, 3729, 3624 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3629, 3625, 3733 },
      -1,
   } },

   /* ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ibfe', 'value', 'offset', 'bits')) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* value */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* offset */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibitfield_extract,
      -1, 0,
      { 3735, 3736, 3737 },
      -1,
   } },

   /* replace1308_0_0 -> 19 in the cache */
   /* replace1308_0_1 -> 3737 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 19, 3737 },
      -1,
   } },
   /* replace1308_1 -> 3735 in the cache */
   /* replace1308_2_0 -> 3735 in the cache */
   /* replace1308_2_1 -> 3736 in the cache */
   /* replace1308_2_2 -> 3737 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 3735, 3736, 3737 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3739, 3735, 3740 },
      -1,
   } },

   /* ('ubitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ubfe', 'value', 'offset', 'bits')) */
   /* search1309_0 -> 3735 in the cache */
   /* search1309_1 -> 3736 in the cache */
   /* search1309_2 -> 3737 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubitfield_extract,
      -1, 0,
      { 3735, 3736, 3737 },
      -1,
   } },

   /* replace1309_0_0 -> 19 in the cache */
   /* replace1309_0_1 -> 3737 in the cache */
   /* replace1309_0 -> 3739 in the cache */
   /* replace1309_1 -> 3735 in the cache */
   /* replace1309_2_0 -> 3735 in the cache */
   /* replace1309_2_1 -> 3736 in the cache */
   /* replace1309_2_2 -> 3737 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 3735, 3736, 3737 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3739, 3735, 3743 },
      -1,
   } },

   /* ('bitfield_select', 'a', 'b', 0) => ('iand', 'a', 'b') */
   /* search1310_0 -> 0 in the cache */
   /* search1310_1 -> 3 in the cache */
   /* search1310_2 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 0, 3, 86 },
      -1,
   } },

   /* replace1310_0 -> 0 in the cache */
   /* replace1310_1 -> 3 in the cache */
   /* replace1310 -> 2682 in the cache */

   /* ('bitfield_select', 'a', ('iand', 'a', 'b'), 'c') => ('bitfield_select', 'a', 'b', 'c') */
   /* search1311_0 -> 128 in the cache */
   /* search1311_1_0 -> 128 in the cache */
   /* search1311_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 128, 129 },
      -1,
   } },
   /* search1311_2 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 1,
      { 128, 3746, 131 },
      -1,
   } },

   /* replace1311_0 -> 128 in the cache */
   /* replace1311_1 -> 129 in the cache */
   /* replace1311_2 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 128, 129, 131 },
      -1,
   } },

   /* ('ubfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ubfe', 'value', 'offset', 'bits') */
   /* search1312_0 -> 3735 in the cache */
   /* search1312_1 -> 3736 in the cache */
   /* search1312_2_0 -> 19 in the cache */
   /* search1312_2_1 -> 3737 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 3737 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 1,
      { 3735, 3736, 3749 },
      -1,
   } },

   /* replace1312_0 -> 3735 in the cache */
   /* replace1312_1 -> 3736 in the cache */
   /* replace1312_2 -> 3737 in the cache */
   /* replace1312 -> 3743 in the cache */

   /* ('ubfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ubfe', 'value', 'offset', 'bits') */
   /* search1313_0 -> 3735 in the cache */
   /* search1313_1_0 -> 19 in the cache */
   /* search1313_1_1 -> 3736 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 3736 },
      -1,
   } },
   /* search1313_2 -> 3737 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 1,
      { 3735, 3751, 3737 },
      -1,
   } },

   /* replace1313_0 -> 3735 in the cache */
   /* replace1313_1 -> 3736 in the cache */
   /* replace1313_2 -> 3737 in the cache */
   /* replace1313 -> 3743 in the cache */

   /* ('ibfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ibfe', 'value', 'offset', 'bits') */
   /* search1314_0 -> 3735 in the cache */
   /* search1314_1 -> 3736 in the cache */
   /* search1314_2_0 -> 19 in the cache */
   /* search1314_2_1 -> 3737 in the cache */
   /* search1314_2 -> 3749 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 1,
      { 3735, 3736, 3749 },
      -1,
   } },

   /* replace1314_0 -> 3735 in the cache */
   /* replace1314_1 -> 3736 in the cache */
   /* replace1314_2 -> 3737 in the cache */
   /* replace1314 -> 3740 in the cache */

   /* ('ibfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ibfe', 'value', 'offset', 'bits') */
   /* search1315_0 -> 3735 in the cache */
   /* search1315_1_0 -> 19 in the cache */
   /* search1315_1_1 -> 3736 in the cache */
   /* search1315_1 -> 3751 in the cache */
   /* search1315_2 -> 3737 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 1,
      { 3735, 3751, 3737 },
      -1,
   } },

   /* replace1315_0 -> 3735 in the cache */
   /* replace1315_1 -> 3736 in the cache */
   /* replace1315_2 -> 3737 in the cache */
   /* replace1315 -> 3740 in the cache */

   /* ('bfm', 'bits', ('iand', 31, 'offset')) => ('bfm', 'bits', 'offset') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1316_1_0 -> 19 in the cache */
   /* search1316_1_1 -> 3736 in the cache */
   /* search1316_1 -> 3751 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 1,
      { 3755, 3751 },
      -1,
   } },

   /* replace1316_0 -> 3755 in the cache */
   /* replace1316_1 -> 3736 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 3755, 3736 },
      -1,
   } },

   /* ('bfm', ('iand', 31, 'bits'), 'offset') => ('bfm', 'bits', 'offset') */
   /* search1317_0_0 -> 19 in the cache */
   /* search1317_0_1 -> 3755 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 3755 },
      -1,
   } },
   /* search1317_1 -> 3736 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 1,
      { 3758, 3736 },
      -1,
   } },

   /* replace1317_0 -> 3755 in the cache */
   /* replace1317_1 -> 3736 in the cache */
   /* replace1317 -> 3757 in the cache */

   /* ('ult', 'a', ('umin', ('iand', 'a', 'b'), 'c')) => False */
   /* search1318_0 -> 128 in the cache */
   /* search1318_1_0_0 -> 128 in the cache */
   /* search1318_1_0_1 -> 129 in the cache */
   /* search1318_1_0 -> 196 in the cache */
   /* search1318_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 196, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 2,
      { 128, 3760 },
      -1,
   } },

   /* replace1318 -> 1070 in the cache */

   /* ('ult', 31, ('umin', '#bits(is_ult_32)', 'a')) => False */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x1f /* 31 */ },
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* bits */
      true,
      nir_type_invalid,
      30,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1319_1_1 -> 1101 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 3763, 1101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 3762, 3764 },
      -1,
   } },

   /* replace1319 -> 1070 in the cache */

   /* ('ubfe', 'value', 'offset', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset'))))) => ('ubfe', 'value', 'offset', 'width') */
   /* search1320_0 -> 3735 in the cache */
   /* search1320_1 -> 3736 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* width */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1320_2_1_0 -> 867 in the cache */
   /* search1320_2_1_1_0_0 -> 19 in the cache */
   /* search1320_2_1_1_0_1 -> 3736 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 19, 3736 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 3767 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 2,
      { 867, 3768 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      0, 3,
      { 3766, 3769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 3,
      { 3735, 3736, 3770 },
      -1,
   } },

   /* replace1320_0 -> 3735 in the cache */
   /* replace1320_1 -> 3736 in the cache */
   /* replace1320_2 -> 3766 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 3735, 3736, 3766 },
      -1,
   } },

   /* ('ibfe', 'value', 'offset', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset'))))) => ('ibfe', 'value', 'offset', 'width') */
   /* search1321_0 -> 3735 in the cache */
   /* search1321_1 -> 3736 in the cache */
   /* search1321_2_0 -> 3766 in the cache */
   /* search1321_2_1_0 -> 867 in the cache */
   /* search1321_2_1_1_0_0 -> 19 in the cache */
   /* search1321_2_1_1_0_1 -> 3736 in the cache */
   /* search1321_2_1_1_0 -> 3767 in the cache */
   /* search1321_2_1_1 -> 3768 in the cache */
   /* search1321_2_1 -> 3769 in the cache */
   /* search1321_2 -> 3770 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 3,
      { 3735, 3736, 3770 },
      -1,
   } },

   /* replace1321_0 -> 3735 in the cache */
   /* replace1321_1 -> 3736 in the cache */
   /* replace1321_2 -> 3766 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 3735, 3736, 3766 },
      -1,
   } },

   /* ('bfm', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset')))), 'offset') => ('bfm', 'width', 'offset') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* width */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1322_0_1_0 -> 867 in the cache */
   /* search1322_0_1_1_0_0 -> 19 in the cache */
   /* search1322_0_1_1_0_1 -> 3736 in the cache */
   /* search1322_0_1_1_0 -> 3767 in the cache */
   /* search1322_0_1_1 -> 3768 in the cache */
   /* search1322_0_1 -> 3769 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      0, 3,
      { 3775, 3769 },
      -1,
   } },
   /* search1322_1 -> 3736 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 3,
      { 3776, 3736 },
      -1,
   } },

   /* replace1322_0 -> 3775 in the cache */
   /* replace1322_1 -> 3736 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 3775, 3736 },
      -1,
   } },

   /* ('ubfe', 'a', 'b', 0) => 0 */
   /* search1323_0 -> 16 in the cache */
   /* search1323_1 -> 36 in the cache */
   /* search1323_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 36, 124 },
      -1,
   } },

   /* replace1323 -> 124 in the cache */

   /* ('ibfe', 'a', 'b', 0) => 0 */
   /* search1324_0 -> 16 in the cache */
   /* search1324_1 -> 36 in the cache */
   /* search1324_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 36, 124 },
      -1,
   } },

   /* replace1324 -> 124 in the cache */

   /* ('ubfe', 'a', 0, '#b') => ('iand', 'a', ('ushr', 4294967295, ('ineg', 'b'))) */
   /* search1325_0 -> 16 in the cache */
   /* search1325_1 -> 124 in the cache */
   /* search1325_2 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 124, 33 },
      -1,
   } },

   /* replace1325_0 -> 16 in the cache */
   /* replace1325_1_0 -> 920 in the cache */
   /* replace1325_1_1_0 -> 36 in the cache */
   /* replace1325_1_1 -> 2697 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 920, 2697 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 3782 },
      -1,
   } },

   /* ('b2i32', ('i2b', ('ubfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1) */
   /* search1326_0_0_0 -> 16 in the cache */
   /* search1326_0_0_1 -> 36 in the cache */
   /* search1326_0_0_2 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 36, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 3784 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 3785 },
      -1,
   } },

   /* replace1326_0 -> 16 in the cache */
   /* replace1326_1 -> 36 in the cache */
   /* replace1326_2 -> 398 in the cache */
   /* replace1326 -> 3784 in the cache */

   /* ('b2i32', ('i2b', ('ibfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1) */
   /* search1327_0_0_0 -> 16 in the cache */
   /* search1327_0_0_1 -> 36 in the cache */
   /* search1327_0_0_2 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 36, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 3787 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 3788 },
      -1,
   } },

   /* replace1327_0 -> 16 in the cache */
   /* replace1327_1 -> 36 in the cache */
   /* replace1327_2 -> 398 in the cache */
   /* replace1327 -> 3784 in the cache */

   /* ('ine', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1328_0_0 -> 16 in the cache */
   /* search1328_0_1 -> 33 in the cache */
   /* search1328_0_2 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 33, 311 },
      0,
   } },
   /* search1328_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3790, 124 },
      -1,
   } },

   /* replace1328_0_0 -> 16 in the cache */
   /* replace1328_0_1_0_0 -> 920 in the cache */
   /* replace1328_0_1_0_1_0 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 920, 3792 },
      -1,
   } },
   /* replace1328_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3793, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 3794 },
      -1,
   } },
   /* replace1328_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 3795, 124 },
      -1,
   } },

   /* ('ieq', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1329_0_0 -> 16 in the cache */
   /* search1329_0_1 -> 33 in the cache */
   /* search1329_0_2 -> 311 in the cache */
   /* search1329_0 -> 3790 in the cache */
   /* search1329_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3790, 124 },
      -1,
   } },

   /* replace1329_0_0 -> 16 in the cache */
   /* replace1329_0_1_0_0 -> 920 in the cache */
   /* replace1329_0_1_0_1_0 -> 137 in the cache */
   /* replace1329_0_1_0_1 -> 3792 in the cache */
   /* replace1329_0_1_0 -> 3793 in the cache */
   /* replace1329_0_1_1 -> 36 in the cache */
   /* replace1329_0_1 -> 3794 in the cache */
   /* replace1329_0 -> 3795 in the cache */
   /* replace1329_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 3795, 124 },
      -1,
   } },

   /* ('ine', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1330_0_0 -> 16 in the cache */
   /* search1330_0_1 -> 33 in the cache */
   /* search1330_0_2 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 33, 311 },
      0,
   } },
   /* search1330_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3799, 124 },
      -1,
   } },

   /* replace1330_0_0 -> 16 in the cache */
   /* replace1330_0_1_0_0 -> 920 in the cache */
   /* replace1330_0_1_0_1_0 -> 137 in the cache */
   /* replace1330_0_1_0_1 -> 3792 in the cache */
   /* replace1330_0_1_0 -> 3793 in the cache */
   /* replace1330_0_1_1 -> 36 in the cache */
   /* replace1330_0_1 -> 3794 in the cache */
   /* replace1330_0 -> 3795 in the cache */
   /* replace1330_1 -> 124 in the cache */
   /* replace1330 -> 3796 in the cache */

   /* ('ieq', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1331_0_0 -> 16 in the cache */
   /* search1331_0_1 -> 33 in the cache */
   /* search1331_0_2 -> 311 in the cache */
   /* search1331_0 -> 3799 in the cache */
   /* search1331_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3799, 124 },
      -1,
   } },

   /* replace1331_0_0 -> 16 in the cache */
   /* replace1331_0_1_0_0 -> 920 in the cache */
   /* replace1331_0_1_0_1_0 -> 137 in the cache */
   /* replace1331_0_1_0_1 -> 3792 in the cache */
   /* replace1331_0_1_0 -> 3793 in the cache */
   /* replace1331_0_1_1 -> 36 in the cache */
   /* replace1331_0_1 -> 3794 in the cache */
   /* replace1331_0 -> 3795 in the cache */
   /* replace1331_1 -> 124 in the cache */
   /* replace1331 -> 3798 in the cache */

   /* ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ieq', 0, 'bits'), 0, ('ishr', ('ishl', 'value', ('isub', ('isub', 32, 'bits'), 'offset')), ('isub', 32, 'bits'))) */
   /* search1332_0 -> 3735 in the cache */
   /* search1332_1 -> 3736 in the cache */
   /* search1332_2 -> 3737 in the cache */
   /* search1332 -> 3738 in the cache */

   /* replace1332_0_0 -> 124 in the cache */
   /* replace1332_0_1 -> 3737 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 124, 3737 },
      -1,
   } },
   /* replace1332_1 -> 124 in the cache */
   /* replace1332_2_0_0 -> 3735 in the cache */
   /* replace1332_2_0_1_0_0 -> 867 in the cache */
   /* replace1332_2_0_1_0_1 -> 3737 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 867, 3737 },
      -1,
   } },
   /* replace1332_2_0_1_1 -> 3736 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3803, 3736 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3735, 3804 },
      -1,
   } },
   /* replace1332_2_1_0 -> 867 in the cache */
   /* replace1332_2_1_1 -> 3737 in the cache */
   /* replace1332_2_1 -> 3803 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 3805, 3803 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3802, 124, 3806 },
      -1,
   } },

   /* ('ubitfield_extract', 'value', 'offset', 'bits') => ('iand', ('ushr', 'value', 'offset'), ('bcsel', ('ieq', 'bits', 32), 4294967295, ('isub', ('ishl', 1, 'bits'), 1))) */
   /* search1333_0 -> 3735 in the cache */
   /* search1333_1 -> 3736 in the cache */
   /* search1333_2 -> 3737 in the cache */
   /* search1333 -> 3742 in the cache */

   /* replace1333_0_0 -> 3735 in the cache */
   /* replace1333_0_1 -> 3736 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3735, 3736 },
      -1,
   } },
   /* replace1333_1_0_0 -> 3737 in the cache */
   /* replace1333_1_0_1 -> 867 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 3737, 867 },
      -1,
   } },
   /* replace1333_1_1 -> 920 in the cache */
   /* replace1333_1_2_0_0 -> 398 in the cache */
   /* replace1333_1_2_0_1 -> 3737 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 398, 3737 },
      -1,
   } },
   /* replace1333_1_2_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3810, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3809, 920, 3811 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3808, 3812 },
      -1,
   } },

   /* ('ifind_msb', 'value') => ('ufind_msb', ('bcsel', ('ilt', 'value', 0), ('inot', 'value'), 'value')) */
   /* search1334_0 -> 3735 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb,
      -1, 0,
      { 3735 },
      -1,
   } },

   /* replace1334_0_0_0 -> 3735 in the cache */
   /* replace1334_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3735, 124 },
      -1,
   } },
   /* replace1334_0_1_0 -> 3735 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3735 },
      -1,
   } },
   /* replace1334_0_2 -> 3735 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3815, 3816, 3735 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 3817 },
      -1,
   } },

   /* ('ifind_msb', 'value') => ('bcsel', ('ige', ('ifind_msb_rev', 'value'), 0), ('isub', 31, ('ifind_msb_rev', 'value')), ('ifind_msb_rev', 'value')) */
   /* search1335_0 -> 3735 in the cache */
   /* search1335 -> 3814 in the cache */

   /* replace1335_0_0_0 -> 3735 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb_rev,
      -1, 0,
      { 3735 },
      -1,
   } },
   /* replace1335_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3819, 124 },
      -1,
   } },
   /* replace1335_1_0 -> 19 in the cache */
   /* replace1335_1_1_0 -> 3735 in the cache */
   /* replace1335_1_1 -> 3819 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 19, 3819 },
      -1,
   } },
   /* replace1335_2_0 -> 3735 in the cache */
   /* replace1335_2 -> 3819 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3820, 3821, 3819 },
      -1,
   } },

   /* ('ufind_msb', 'value') => ('bcsel', ('ige', ('ufind_msb_rev', 'value'), 0), ('isub', 31, ('ufind_msb_rev', 'value')), ('ufind_msb_rev', 'value')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* value */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 3823 },
      -1,
   } },

   /* replace1336_0_0_0 -> 3823 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 3823 },
      -1,
   } },
   /* replace1336_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3825, 124 },
      -1,
   } },
   /* replace1336_1_0 -> 19 in the cache */
   /* replace1336_1_1_0 -> 3823 in the cache */
   /* replace1336_1_1 -> 3825 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 19, 3825 },
      -1,
   } },
   /* replace1336_2_0 -> 3823 in the cache */
   /* replace1336_2 -> 3825 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3826, 3827, 3825 },
      -1,
   } },

   /* ('uclz', 'a') => ('umin', 32, ('ufind_msb_rev', 'a')) */
   /* search1337_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uclz,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1337_0 -> 867 in the cache */
   /* replace1337_1_0 -> 16 in the cache */
   /* replace1337_1 -> 3547 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 867, 3547 },
      -1,
   } },

   /* ('find_lsb', 'value') => ('ufind_msb', ('iand', 'value', ('ineg', 'value'))) */
   /* search1338_0 -> 3823 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3823 },
      -1,
   } },

   /* replace1338_0_0 -> 3823 in the cache */
   /* replace1338_0_1_0 -> 3823 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3823 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3823, 3832 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 1,
      { 3833 },
      -1,
   } },

   /* ('extract_i8', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 3, 'b'), 8)), 24) */
   /* search1339_0 -> 16 in the cache */
   /* search1339_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1339_0_0 -> 16 in the cache */
   /* replace1339_0_1_0_0 -> 407 in the cache */
   /* replace1339_0_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 407, 36 },
      -1,
   } },
   /* replace1339_0_1_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3836, 824 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 3837 },
      -1,
   } },
   /* replace1339_1 -> 1005 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3838, 1005 },
      -1,
   } },

   /* ('extract_u8', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 8)), 255) */
   /* search1340_0 -> 16 in the cache */
   /* search1340_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1340_0_0 -> 16 in the cache */
   /* replace1340_0_1_0 -> 36 in the cache */
   /* replace1340_0_1_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 36, 824 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 3841 },
      -1,
   } },
   /* replace1340_1 -> 1003 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3842, 1003 },
      -1,
   } },

   /* ('extract_i16', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 1, 'b'), 16)), 16) */
   /* search1341_0 -> 16 in the cache */
   /* search1341_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1341_0_0 -> 16 in the cache */
   /* replace1341_0_1_0_0 -> 398 in the cache */
   /* replace1341_0_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 398, 36 },
      -1,
   } },
   /* replace1341_0_1_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3845, 846 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 3846 },
      -1,
   } },
   /* replace1341_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3847, 846 },
      -1,
   } },

   /* ('extract_u16', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 16)), 65535) */
   /* search1342_0 -> 16 in the cache */
   /* search1342_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1342_0_0 -> 16 in the cache */
   /* replace1342_0_1_0 -> 36 in the cache */
   /* replace1342_0_1_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 36, 846 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 3850 },
      -1,
   } },
   /* replace1342_1 -> 995 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3851, 995 },
      -1,
   } },

   /* ('pack_unorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 65535.0)))) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* v */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_unorm_2x16,
      -1, 0,
      { 3853 },
      -1,
   } },

   /* replace1343_0_0_0_0_0 -> 3853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 3853 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x40efffe000000000 /* 65535.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3855, 3856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 1,
      { 3857 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 1,
      { 3858 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec2_to_uint,
      -1, 1,
      { 3859 },
      -1,
   } },

   /* ('pack_unorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 255.0)))) */
   /* search1344_0 -> 3853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_unorm_4x8,
      -1, 0,
      { 3853 },
      -1,
   } },

   /* replace1344_0_0_0_0_0 -> 3853 in the cache */
   /* replace1344_0_0_0_0 -> 3855 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x406fe00000000000 /* 255.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3855, 3862 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 1,
      { 3863 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 1,
      { 3864 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec4_to_uint,
      -1, 1,
      { 3865 },
      -1,
   } },

   /* ('pack_snorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 32767.0)))) */
   /* search1345_0 -> 3853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_snorm_2x16,
      -1, 0,
      { 3853 },
      -1,
   } },

   /* replace1345_0_0_0_0_0 -> 245 in the cache */
   /* replace1345_0_0_0_0_1_0 -> 280 in the cache */
   /* replace1345_0_0_0_0_1_1 -> 3853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      2, 1,
      { 280, 3853 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 2,
      { 245, 3868 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x40dfffc000000000 /* 32767.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 3869, 3870 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 3,
      { 3871 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 3,
      { 3872 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec2_to_uint,
      -1, 3,
      { 3873 },
      -1,
   } },

   /* ('pack_snorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0)))) */
   /* search1346_0 -> 3853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_snorm_4x8,
      -1, 0,
      { 3853 },
      -1,
   } },

   /* replace1346_0_0_0_0_0 -> 245 in the cache */
   /* replace1346_0_0_0_0_1_0 -> 280 in the cache */
   /* replace1346_0_0_0_0_1_1 -> 3853 in the cache */
   /* replace1346_0_0_0_0_1 -> 3868 in the cache */
   /* replace1346_0_0_0_0 -> 3869 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x405fc00000000000 /* 127.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 3869, 3876 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 3,
      { 3877 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 3,
      { 3878 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec4_to_uint,
      -1, 3,
      { 3879 },
      -1,
   } },

   /* ('unpack_unorm_2x16', 'v') => ('fdiv', ('u2f32', ('vec2', ('extract_u16', 'v', 0), ('extract_u16', 'v', 1))), 65535.0) */
   /* search1347_0 -> 3853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_unorm_2x16,
      -1, 0,
      { 3853 },
      -1,
   } },

   /* replace1347_0_0_0_0 -> 3853 in the cache */
   /* replace1347_0_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3853, 124 },
      -1,
   } },
   /* replace1347_0_0_1_0 -> 3853 in the cache */
   /* replace1347_0_0_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3853, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3882, 3883 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 3884 },
      -1,
   } },
   /* replace1347_1 -> 3856 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3885, 3856 },
      -1,
   } },

   /* ('unpack_unorm_4x8', 'v') => ('fdiv', ('u2f32', ('vec4', ('extract_u8', 'v', 0), ('extract_u8', 'v', 1), ('extract_u8', 'v', 2), ('extract_u8', 'v', 3))), 255.0) */
   /* search1348_0 -> 3853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_unorm_4x8,
      -1, 0,
      { 3853 },
      -1,
   } },

   /* replace1348_0_0_0_0 -> 3853 in the cache */
   /* replace1348_0_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3853, 124 },
      -1,
   } },
   /* replace1348_0_0_1_0 -> 3853 in the cache */
   /* replace1348_0_0_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3853, 398 },
      -1,
   } },
   /* replace1348_0_0_2_0 -> 3853 in the cache */
   /* replace1348_0_0_2_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3853, 403 },
      -1,
   } },
   /* replace1348_0_0_3_0 -> 3853 in the cache */
   /* replace1348_0_0_3_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3853, 407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3888, 3889, 3890, 3891 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 3892 },
      -1,
   } },
   /* replace1348_1 -> 3862 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3893, 3862 },
      -1,
   } },

   /* ('unpack_snorm_2x16', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec2', ('extract_i16', 'v', 0), ('extract_i16', 'v', 1))), 32767.0))) */
   /* search1349_0 -> 3853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_snorm_2x16,
      -1, 0,
      { 3853 },
      -1,
   } },

   /* replace1349_0 -> 245 in the cache */
   /* replace1349_1_0 -> 280 in the cache */
   /* replace1349_1_1_0_0_0_0 -> 3853 in the cache */
   /* replace1349_1_1_0_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 3853, 124 },
      -1,
   } },
   /* replace1349_1_1_0_0_1_0 -> 3853 in the cache */
   /* replace1349_1_1_0_0_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 3853, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3896, 3897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 3898 },
      -1,
   } },
   /* replace1349_1_1_1 -> 3870 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3899, 3870 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 280, 3900 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 245, 3901 },
      -1,
   } },

   /* ('unpack_snorm_4x8', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec4', ('extract_i8', 'v', 0), ('extract_i8', 'v', 1), ('extract_i8', 'v', 2), ('extract_i8', 'v', 3))), 127.0))) */
   /* search1350_0 -> 3853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_snorm_4x8,
      -1, 0,
      { 3853 },
      -1,
   } },

   /* replace1350_0 -> 245 in the cache */
   /* replace1350_1_0 -> 280 in the cache */
   /* replace1350_1_1_0_0_0_0 -> 3853 in the cache */
   /* replace1350_1_1_0_0_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3853, 124 },
      -1,
   } },
   /* replace1350_1_1_0_0_1_0 -> 3853 in the cache */
   /* replace1350_1_1_0_0_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3853, 398 },
      -1,
   } },
   /* replace1350_1_1_0_0_2_0 -> 3853 in the cache */
   /* replace1350_1_1_0_0_2_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3853, 403 },
      -1,
   } },
   /* replace1350_1_1_0_0_3_0 -> 3853 in the cache */
   /* replace1350_1_1_0_0_3_1 -> 407 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3853, 407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3904, 3905, 3906, 3907 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 3908 },
      -1,
   } },
   /* replace1350_1_1_1 -> 3876 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3909, 3876 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 280, 3910 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 245, 3911 },
      -1,
   } },

   /* ('pack_half_2x16_split', 'a@32', 'b@32') => ('ior', ('ishl', ('u2u32', ('f2f16', 'b')), 16), ('u2u32', ('f2f16', 'a'))) */
   /* search1351_0 -> 16 in the cache */
   /* search1351_1 -> 36 in the cache */
   /* search1351 -> 3276 in the cache */

   /* replace1351_0_0_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3913 },
      -1,
   } },
   /* replace1351_0_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3914, 846 },
      -1,
   } },
   /* replace1351_1_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3916 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3915, 3917 },
      -1,
   } },

   /* ('unpack_half_2x16_split_x', 'a@32') => ('f2f32', ('u2u16', 'a')) */
   /* search1352_0 -> 16 in the cache */
   /* search1352 -> 3241 in the cache */

   /* replace1352_0_0 -> 16 in the cache */
   /* replace1352_0 -> 3238 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 3238 },
      -1,
   } },

   /* ('unpack_half_2x16_split_y', 'a@32') => ('f2f32', ('u2u16', ('ushr', 'a', 16))) */
   /* search1353_0 -> 16 in the cache */
   /* search1353 -> 3248 in the cache */

   /* replace1353_0_0_0 -> 16 in the cache */
   /* replace1353_0_0_1 -> 846 in the cache */
   /* replace1353_0_0 -> 1001 in the cache */
   /* replace1353_0 -> 3239 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 3239 },
      -1,
   } },

   /* ('pack_32_2x16_split', 'a@16', 'b@16') => ('ior', ('ishl', ('u2u32', 'b'), 16), ('u2u32', 'a')) */
   /* search1354_0 -> 11 in the cache */
   /* search1354_1 -> 260 in the cache */
   /* search1354 -> 3231 in the cache */

   /* replace1354_0_0_0 -> 260 in the cache */
   /* replace1354_0_0 -> 3232 in the cache */
   /* replace1354_0_1 -> 846 in the cache */
   /* replace1354_0 -> 3233 in the cache */
   /* replace1354_1_0 -> 11 in the cache */
   /* replace1354_1 -> 1795 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3233, 1795 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', 'a@32') => ('u2u16', 'a') */
   /* search1355_0 -> 16 in the cache */
   /* search1355 -> 3154 in the cache */

   /* replace1355_0 -> 16 in the cache */
   /* replace1355 -> 3238 in the cache */

   /* ('unpack_32_2x16_split_y', 'a@32') => ('u2u16', ('ushr', 'a', 16)) */
   /* search1356_0 -> 16 in the cache */
   /* search1356 -> 3156 in the cache */

   /* replace1356_0_0 -> 16 in the cache */
   /* replace1356_0_1 -> 846 in the cache */
   /* replace1356_0 -> 1001 in the cache */
   /* replace1356 -> 3239 in the cache */

   /* ('isign', 'a') => ('imin', ('imax', 'a', -1), 1) */
   /* search1357_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1357_0_0 -> 32 in the cache */
   /* replace1357_0_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 32, 63 },
      -1,
   } },
   /* replace1357_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 3923, 35 },
      -1,
   } },

   /* ('imin', ('imax', 'a', -1), 1) => ('isign', 'a') */
   /* search1358_0_0 -> 32 in the cache */
   /* search1358_0_1 -> 63 in the cache */
   /* search1358_0 -> 3923 in the cache */
   /* search1358_1 -> 35 in the cache */
   /* search1358 -> 3924 in the cache */

   /* replace1358_0 -> 32 in the cache */
   /* replace1358 -> 3922 in the cache */

   /* ('imax', ('imin', 'a', 1), -1) => ('isign', 'a') */
   /* search1359_0_0 -> 32 in the cache */
   /* search1359_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 32, 35 },
      -1,
   } },
   /* search1359_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 3925, 63 },
      -1,
   } },

   /* replace1359_0 -> 32 in the cache */
   /* replace1359 -> 3922 in the cache */

   /* ('fsign', 'a') => ('fsub', ('b2f', ('!flt', 0.0, 'a')), ('b2f', ('!flt', 'a', 0.0))) */
   /* search1360_0 -> 32 in the cache */
   /* search1360 -> 252 in the cache */

   /* replace1360_0_0_0 -> 113 in the cache */
   /* replace1360_0_0_1 -> 32 in the cache */
   /* replace1360_0_0 -> 1518 in the cache */
   /* replace1360_0 -> 1519 in the cache */
   /* replace1360_1_0_0 -> 32 in the cache */
   /* replace1360_1_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 3927 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 1519, 3928 },
      -1,
   } },

   /* ('amul', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1361_0 -> 0 in the cache */
   /* search1361_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_amul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1361_0 -> 0 in the cache */
   /* replace1361_1 -> 3 in the cache */
   /* replace1361 -> 944 in the cache */

   /* ('umul24', 'a', 'b') => ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)) */
   /* search1362_0 -> 16 in the cache */
   /* search1362_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul24,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1362_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffff /* 16777215 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 3932 },
      -1,
   } },
   /* replace1362_1_0 -> 36 in the cache */
   /* replace1362_1_1 -> 3932 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 3932 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 3,
      { 3933, 3934 },
      -1,
   } },

   /* ('umad24', 'a', 'b', 'c') => ('iadd', ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)), 'c') */
   /* search1363_0 -> 16 in the cache */
   /* search1363_1 -> 36 in the cache */
   /* search1363_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umad24,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* replace1363_0_0_0 -> 16 in the cache */
   /* replace1363_0_0_1 -> 3932 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 16, 3932 },
      -1,
   } },
   /* replace1363_0_1_0 -> 36 in the cache */
   /* replace1363_0_1_1 -> 3932 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 36, 3932 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 3,
      { 3937, 3938 },
      -1,
   } },
   /* replace1363_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 3939, 137 },
      -1,
   } },

   /* ('imul24_relaxed', 'a', 'b') => ('imul24', 'a', 'b') */
   /* search1364_0 -> 16 in the cache */
   /* search1364_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24_relaxed,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1364_0 -> 16 in the cache */
   /* replace1364_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('imul24_relaxed', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1365_0 -> 16 in the cache */
   /* search1365_1 -> 36 in the cache */
   /* search1365 -> 3941 in the cache */

   /* replace1365_0 -> 16 in the cache */
   /* replace1365_1 -> 36 in the cache */
   /* replace1365 -> 49 in the cache */

   /* ('umad24_relaxed', 'a', 'b', 'c') => ('umad24', 'a', 'b', 'c') */
   /* search1366_0 -> 16 in the cache */
   /* search1366_1 -> 36 in the cache */
   /* search1366_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umad24_relaxed,
      0, 1,
      { 16, 36, 137 },
      -1,
   } },

   /* replace1366_0 -> 16 in the cache */
   /* replace1366_1 -> 36 in the cache */
   /* replace1366_2 -> 137 in the cache */
   /* replace1366 -> 3936 in the cache */

   /* ('umad24_relaxed', 'a', 'b', 'c') => ('iadd', ('umul24_relaxed', 'a', 'b'), 'c') */
   /* search1367_0 -> 16 in the cache */
   /* search1367_1 -> 36 in the cache */
   /* search1367_2 -> 137 in the cache */
   /* search1367 -> 3943 in the cache */

   /* replace1367_0_0 -> 16 in the cache */
   /* replace1367_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul24_relaxed,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1367_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 3944, 137 },
      -1,
   } },

   /* ('umul24_relaxed', 'a', 'b') => ('umul24', 'a', 'b') */
   /* search1368_0 -> 16 in the cache */
   /* search1368_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul24_relaxed,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1368_0 -> 16 in the cache */
   /* replace1368_1 -> 36 in the cache */
   /* replace1368 -> 3931 in the cache */

   /* ('umul24_relaxed', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1369_0 -> 16 in the cache */
   /* search1369_1 -> 36 in the cache */
   /* search1369 -> 3946 in the cache */

   /* replace1369_0 -> 16 in the cache */
   /* replace1369_1 -> 36 in the cache */
   /* replace1369 -> 49 in the cache */

   /* ('imad24_ir3', 'a', 'b', 0) => ('imul24', 'a', 'b') */
   /* search1370_0 -> 16 in the cache */
   /* search1370_1 -> 36 in the cache */
   /* search1370_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 36, 124 },
      -1,
   } },

   /* replace1370_0 -> 16 in the cache */
   /* replace1370_1 -> 36 in the cache */
   /* replace1370 -> 3942 in the cache */

   /* ('imad24_ir3', 'a', 0, 'c') => c */
   /* search1371_0 -> 16 in the cache */
   /* search1371_1 -> 124 in the cache */
   /* search1371_2 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 124, 557 },
      -1,
   } },

   /* replace1371 -> 557 in the cache */

   /* ('imad24_ir3', 'a', 1, 'c') => ('iadd', 'a', 'c') */
   /* search1372_0 -> 16 in the cache */
   /* search1372_1 -> 398 in the cache */
   /* search1372_2 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 398, 557 },
      -1,
   } },

   /* replace1372_0 -> 16 in the cache */
   /* replace1372_1 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 16, 557 },
      -1,
   } },

   /* ('imad24_ir3', '#a', '#b', 'c') => ('iadd', ('imul', 'a', 'b'), 'c') */
   /* search1373_0 -> 288 in the cache */
   /* search1373_1 -> 33 in the cache */
   /* search1373_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 288, 33, 137 },
      -1,
   } },

   /* replace1373_0_0 -> 16 in the cache */
   /* replace1373_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1373_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 3952, 137 },
      -1,
   } },

   /* ('imul24', 'a', '#b@32(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b')) */
   /* search1374_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 3954 },
      -1,
   } },

   /* replace1374_0 -> 16 in the cache */
   /* replace1374_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 3956 },
      -1,
   } },

   /* ('imul24', 'a', '#b@32(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b')))) */
   /* search1375_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 3958 },
      -1,
   } },

   /* replace1375_0_0 -> 16 in the cache */
   /* replace1375_0_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3960 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 3961 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3962 },
      -1,
   } },

   /* ('imul24', 'a', 0) => 0 */
   /* search1376_0 -> 16 in the cache */
   /* search1376_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 124 },
      -1,
   } },

   /* replace1376 -> 124 in the cache */

   /* ('iadd_sat@8', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 127, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 128, ('iadd', 'a', 'b'))) */
   /* search1377_0 -> 6 in the cache */
   /* search1377_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 6, 2101 },
      -1,
   } },

   /* replace1377_0_0 -> 2101 in the cache */
   /* replace1377_0_1 -> 1422 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2101, 1422 },
      -1,
   } },
   /* replace1377_1_0_0_0 -> 6 in the cache */
   /* replace1377_1_0_0_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 6, 2101 },
      -1,
   } },
   /* replace1377_1_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3967, 6 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1377_1_2_0 -> 6 in the cache */
   /* replace1377_1_2_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 6, 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3968, 3969, 3970 },
      -1,
   } },
   /* replace1377_2_0_0 -> 6 in the cache */
   /* replace1377_2_0_1_0 -> 6 in the cache */
   /* replace1377_2_0_1_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 6, 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 6, 3972 },
      -1,
   } },
   /* replace1377_2_1 -> 7 in the cache */
   /* replace1377_2_2_0 -> 6 in the cache */
   /* replace1377_2_2_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 6, 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3973, 7, 3974 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3966, 3971, 3975 },
      -1,
   } },

   /* ('isub_sat@8', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 127, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 128, ('isub', 'a', 'b'))) */
   /* search1378_0 -> 6 in the cache */
   /* search1378_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 6, 2101 },
      -1,
   } },

   /* replace1378_0_0 -> 2101 in the cache */
   /* replace1378_0_1 -> 828 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2101, 828 },
      -1,
   } },
   /* replace1378_1_0_0_0 -> 6 in the cache */
   /* replace1378_1_0_0_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 6, 2101 },
      -1,
   } },
   /* replace1378_1_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3979, 6 },
      -1,
   } },
   /* replace1378_1_1 -> 3969 in the cache */
   /* replace1378_1_2_0 -> 6 in the cache */
   /* replace1378_1_2_1 -> 2101 in the cache */
   /* replace1378_1_2 -> 3979 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3980, 3969, 3979 },
      -1,
   } },
   /* replace1378_2_0_0 -> 6 in the cache */
   /* replace1378_2_0_1_0 -> 6 in the cache */
   /* replace1378_2_0_1_1 -> 2101 in the cache */
   /* replace1378_2_0_1 -> 3979 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 3979 },
      -1,
   } },
   /* replace1378_2_1 -> 7 in the cache */
   /* replace1378_2_2_0 -> 6 in the cache */
   /* replace1378_2_2_1 -> 2101 in the cache */
   /* replace1378_2_2 -> 3979 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3982, 7, 3979 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3978, 3981, 3983 },
      -1,
   } },

   /* ('iadd_sat@16', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 32767, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 32768, ('iadd', 'a', 'b'))) */
   /* search1379_0 -> 11 in the cache */
   /* search1379_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 11, 260 },
      -1,
   } },

   /* replace1379_0_0 -> 260 in the cache */
   /* replace1379_0_1 -> 1444 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 260, 1444 },
      -1,
   } },
   /* replace1379_1_0_0_0 -> 11 in the cache */
   /* replace1379_1_0_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 11, 260 },
      -1,
   } },
   /* replace1379_1_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3987, 11 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1379_1_2_0 -> 11 in the cache */
   /* replace1379_1_2_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 11, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3988, 3989, 3990 },
      -1,
   } },
   /* replace1379_2_0_0 -> 11 in the cache */
   /* replace1379_2_0_1_0 -> 11 in the cache */
   /* replace1379_2_0_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 11, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 11, 3992 },
      -1,
   } },
   /* replace1379_2_1 -> 12 in the cache */
   /* replace1379_2_2_0 -> 11 in the cache */
   /* replace1379_2_2_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 11, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3993, 12, 3994 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3986, 3991, 3995 },
      -1,
   } },

   /* ('isub_sat@16', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 32767, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 32768, ('isub', 'a', 'b'))) */
   /* search1380_0 -> 11 in the cache */
   /* search1380_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 11, 260 },
      -1,
   } },

   /* replace1380_0_0 -> 260 in the cache */
   /* replace1380_0_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 260, 849 },
      -1,
   } },
   /* replace1380_1_0_0_0 -> 11 in the cache */
   /* replace1380_1_0_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 11, 260 },
      -1,
   } },
   /* replace1380_1_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3999, 11 },
      -1,
   } },
   /* replace1380_1_1 -> 3989 in the cache */
   /* replace1380_1_2_0 -> 11 in the cache */
   /* replace1380_1_2_1 -> 260 in the cache */
   /* replace1380_1_2 -> 3999 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4000, 3989, 3999 },
      -1,
   } },
   /* replace1380_2_0_0 -> 11 in the cache */
   /* replace1380_2_0_1_0 -> 11 in the cache */
   /* replace1380_2_0_1_1 -> 260 in the cache */
   /* replace1380_2_0_1 -> 3999 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 3999 },
      -1,
   } },
   /* replace1380_2_1 -> 12 in the cache */
   /* replace1380_2_2_0 -> 11 in the cache */
   /* replace1380_2_2_1 -> 260 in the cache */
   /* replace1380_2_2 -> 3999 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4002, 12, 3999 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3998, 4001, 4003 },
      -1,
   } },

   /* ('iadd_sat@32', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 2147483647, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 2147483648, ('iadd', 'a', 'b'))) */
   /* search1381_0 -> 16 in the cache */
   /* search1381_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1381_0_0 -> 36 in the cache */
   /* replace1381_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 36, 398 },
      -1,
   } },
   /* replace1381_1_0_0_0 -> 16 in the cache */
   /* replace1381_1_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1381_1_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 4007, 16 },
      -1,
   } },
   /* replace1381_1_1 -> 981 in the cache */
   /* replace1381_1_2_0 -> 16 in the cache */
   /* replace1381_1_2_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4008, 981, 4009 },
      -1,
   } },
   /* replace1381_2_0_0 -> 16 in the cache */
   /* replace1381_2_0_1_0 -> 16 in the cache */
   /* replace1381_2_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 16, 4011 },
      -1,
   } },
   /* replace1381_2_1 -> 17 in the cache */
   /* replace1381_2_2_0 -> 16 in the cache */
   /* replace1381_2_2_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4012, 17, 4013 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 4006, 4010, 4014 },
      -1,
   } },

   /* ('isub_sat@32', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 2147483647, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 2147483648, ('isub', 'a', 'b'))) */
   /* search1382_0 -> 16 in the cache */
   /* search1382_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1382_0_0 -> 36 in the cache */
   /* replace1382_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 36, 124 },
      -1,
   } },
   /* replace1382_1_0_0_0 -> 16 in the cache */
   /* replace1382_1_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   /* replace1382_1_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4018, 16 },
      -1,
   } },
   /* replace1382_1_1 -> 981 in the cache */
   /* replace1382_1_2_0 -> 16 in the cache */
   /* replace1382_1_2_1 -> 36 in the cache */
   /* replace1382_1_2 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4019, 981, 4018 },
      -1,
   } },
   /* replace1382_2_0_0 -> 16 in the cache */
   /* replace1382_2_0_1_0 -> 16 in the cache */
   /* replace1382_2_0_1_1 -> 36 in the cache */
   /* replace1382_2_0_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4018 },
      -1,
   } },
   /* replace1382_2_1 -> 17 in the cache */
   /* replace1382_2_2_0 -> 16 in the cache */
   /* replace1382_2_2_1 -> 36 in the cache */
   /* replace1382_2_2 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4021, 17, 4018 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4017, 4020, 4022 },
      -1,
   } },

   /* ('iadd_sat@64', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 9223372036854775807, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 9223372036854775808, ('iadd', 'a', 'b'))) */
   /* search1383_0 -> 21 in the cache */
   /* search1383_1 -> 41 in the cache */
   /* search1383 -> 3680 in the cache */

   /* replace1383_0_0 -> 41 in the cache */
   /* replace1383_0_1 -> 1486 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 41, 1486 },
      -1,
   } },
   /* replace1383_1_0_0_0 -> 21 in the cache */
   /* replace1383_1_0_0_1 -> 41 in the cache */
   /* replace1383_1_0_0 -> 3667 in the cache */
   /* replace1383_1_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3667, 21 },
      -1,
   } },
   /* replace1383_1_1 -> 3691 in the cache */
   /* replace1383_1_2_0 -> 21 in the cache */
   /* replace1383_1_2_1 -> 41 in the cache */
   /* replace1383_1_2 -> 3669 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4025, 3691, 3669 },
      -1,
   } },
   /* replace1383_2_0_0 -> 21 in the cache */
   /* replace1383_2_0_1_0 -> 21 in the cache */
   /* replace1383_2_0_1_1 -> 41 in the cache */
   /* replace1383_2_0_1 -> 3683 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 21, 3683 },
      -1,
   } },
   /* replace1383_2_1 -> 22 in the cache */
   /* replace1383_2_2_0 -> 21 in the cache */
   /* replace1383_2_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4027, 22, 4028 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 4024, 4026, 4029 },
      -1,
   } },

   /* ('isub_sat@64', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 9223372036854775807, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 9223372036854775808, ('isub', 'a', 'b'))) */
   /* search1384_0 -> 21 in the cache */
   /* search1384_1 -> 41 in the cache */
   /* search1384 -> 3694 in the cache */

   /* replace1384_0_0 -> 41 in the cache */
   /* replace1384_0_1 -> 890 in the cache */
   /* replace1384_0 -> 3681 in the cache */
   /* replace1384_1_0_0_0 -> 21 in the cache */
   /* replace1384_1_0_0_1 -> 41 in the cache */
   /* replace1384_1_0_0 -> 3678 in the cache */
   /* replace1384_1_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3678, 21 },
      -1,
   } },
   /* replace1384_1_1 -> 3691 in the cache */
   /* replace1384_1_2_0 -> 21 in the cache */
   /* replace1384_1_2_1 -> 41 in the cache */
   /* replace1384_1_2 -> 3678 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4031, 3691, 3678 },
      -1,
   } },
   /* replace1384_2_0_0 -> 21 in the cache */
   /* replace1384_2_0_1_0 -> 21 in the cache */
   /* replace1384_2_0_1_1 -> 41 in the cache */
   /* replace1384_2_0_1 -> 3678 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 3678 },
      -1,
   } },
   /* replace1384_2_1 -> 22 in the cache */
   /* replace1384_2_2_0 -> 21 in the cache */
   /* replace1384_2_2_1 -> 41 in the cache */
   /* replace1384_2_2 -> 3678 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4033, 22, 3678 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3681, 4032, 4034 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('fneu', 'c', 'd')) */
   /* search1385_0_0_0 -> 0 in the cache */
   /* search1385_0_0_1 -> 3 in the cache */
   /* search1385_0_0 -> 1067 in the cache */
   /* search1385_0_1_0 -> 154 in the cache */
   /* search1385_0_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1067, 4036 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4037 },
      -1,
   } },

   /* replace1385_0_0 -> 0 in the cache */
   /* replace1385_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1385_1_0 -> 154 in the cache */
   /* replace1385_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4039, 4040 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('fneu', 'c', 'd')) */
   /* search1386_0_0_0 -> 0 in the cache */
   /* search1386_0_0_1 -> 3 in the cache */
   /* search1386_0_0 -> 1067 in the cache */
   /* search1386_0_1_0 -> 154 in the cache */
   /* search1386_0_1_1 -> 155 in the cache */
   /* search1386_0_1 -> 4036 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1067, 4036 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4042 },
      -1,
   } },

   /* replace1386_0_0 -> 0 in the cache */
   /* replace1386_0_1 -> 3 in the cache */
   /* replace1386_0 -> 4039 in the cache */
   /* replace1386_1_0 -> 154 in the cache */
   /* replace1386_1_1 -> 155 in the cache */
   /* replace1386_1 -> 4040 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4039, 4040 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1387_0_0_0 -> 0 in the cache */
   /* search1387_0_0_1 -> 3 in the cache */
   /* search1387_0_0 -> 1067 in the cache */
   /* search1387_0_1_0 -> 154 in the cache */
   /* search1387_0_1_1 -> 155 in the cache */
   /* search1387_0_1 -> 4040 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1067, 4040 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4045 },
      -1,
   } },

   /* replace1387_0_0 -> 0 in the cache */
   /* replace1387_0_1 -> 3 in the cache */
   /* replace1387_0 -> 4039 in the cache */
   /* replace1387_1_0 -> 154 in the cache */
   /* replace1387_1_1 -> 155 in the cache */
   /* replace1387_1 -> 4036 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4039, 4036 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1388_0_0_0 -> 0 in the cache */
   /* search1388_0_0_1 -> 3 in the cache */
   /* search1388_0_0 -> 1067 in the cache */
   /* search1388_0_1_0 -> 154 in the cache */
   /* search1388_0_1_1 -> 155 in the cache */
   /* search1388_0_1 -> 4040 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1067, 4040 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4048 },
      -1,
   } },

   /* replace1388_0_0 -> 0 in the cache */
   /* replace1388_0_1 -> 3 in the cache */
   /* replace1388_0 -> 4039 in the cache */
   /* replace1388_1_0 -> 154 in the cache */
   /* replace1388_1_1 -> 155 in the cache */
   /* replace1388_1 -> 4036 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4039, 4036 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1389_0_0_0 -> 0 in the cache */
   /* search1389_0_0_1 -> 3 in the cache */
   /* search1389_0_0 -> 4039 in the cache */
   /* search1389_0_1_0 -> 154 in the cache */
   /* search1389_0_1_1 -> 155 in the cache */
   /* search1389_0_1 -> 4040 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4039, 4040 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4051 },
      -1,
   } },

   /* replace1389_0_0 -> 0 in the cache */
   /* replace1389_0_1 -> 3 in the cache */
   /* replace1389_0 -> 1067 in the cache */
   /* replace1389_1_0 -> 154 in the cache */
   /* replace1389_1_1 -> 155 in the cache */
   /* replace1389_1 -> 4036 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1067, 4036 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1390_0_0_0 -> 0 in the cache */
   /* search1390_0_0_1 -> 3 in the cache */
   /* search1390_0_0 -> 4039 in the cache */
   /* search1390_0_1_0 -> 154 in the cache */
   /* search1390_0_1_1 -> 155 in the cache */
   /* search1390_0_1 -> 4040 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4039, 4040 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4054 },
      -1,
   } },

   /* replace1390_0_0 -> 0 in the cache */
   /* replace1390_0_1 -> 3 in the cache */
   /* replace1390_0 -> 1067 in the cache */
   /* replace1390_1_0 -> 154 in the cache */
   /* replace1390_1_1 -> 155 in the cache */
   /* replace1390_1 -> 4036 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1067, 4036 },
      -1,
   } },

   /* ('f2b1', ('b2f', 'a@1')) => a */
   /* search1391_0_0 -> 753 in the cache */
   /* search1391_0 -> 1116 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_f2b1,
      -1, 0,
      { 1116 },
      -1,
   } },

   /* replace1391 -> 753 in the cache */

   /* ('i2b1', ('b2i', 'a@1')) => a */
   /* search1392_0_0 -> 753 in the cache */
   /* search1392_0 -> 1215 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2b1,
      -1, 0,
      { 1215 },
      -1,
   } },

   /* replace1392 -> 753 in the cache */

   /* ('f2b8', ('b2f', 'a@8')) => a */
   /* search1393_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_f2b8,
      -1, 0,
      { 4059 },
      -1,
   } },

   /* replace1393 -> 6 in the cache */

   /* ('i2b8', ('b2i', 'a@8')) => a */
   /* search1394_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2b8,
      -1, 0,
      { 4061 },
      -1,
   } },

   /* replace1394 -> 6 in the cache */

   /* ('f2b16', ('b2f', 'a@16')) => a */
   /* search1395_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2b16,
      -1, 0,
      { 4063 },
      -1,
   } },

   /* replace1395 -> 11 in the cache */

   /* ('i2b16', ('b2i', 'a@16')) => a */
   /* search1396_0_0 -> 11 in the cache */
   /* search1396_0 -> 3035 in the cache */
   /* search1396 -> 3036 in the cache */

   /* replace1396 -> 11 in the cache */

   /* ('f2b32', ('b2f', 'a@32')) => a */
   /* search1397_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2b32,
      -1, 0,
      { 4065 },
      -1,
   } },

   /* replace1397 -> 16 in the cache */

   /* ('i2b32', ('b2i', 'a@32')) => a */
   /* search1398_0_0 -> 16 in the cache */
   /* search1398_0 -> 3037 in the cache */
   /* search1398 -> 3038 in the cache */

   /* replace1398 -> 16 in the cache */

   /* ('f2f', ('b2f', 'a')) => ('b2f', 'a') */
   /* search1399_0_0 -> 32 in the cache */
   /* search1399_0 -> 1520 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2f,
      -1, 0,
      { 1520 },
      -1,
   } },

   /* replace1399_0 -> 32 in the cache */
   /* replace1399 -> 1520 in the cache */

   /* ('f2u', ('b2f', 'a')) => ('b2i', 'a') */
   /* search1400_0_0 -> 32 in the cache */
   /* search1400_0 -> 1520 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 1520 },
      -1,
   } },

   /* replace1400_0 -> 32 in the cache */
   /* replace1400 -> 3027 in the cache */

   /* ('f2i', ('b2f', 'a')) => ('b2i', 'a') */
   /* search1401_0_0 -> 32 in the cache */
   /* search1401_0 -> 1520 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 1520 },
      -1,
   } },

   /* replace1401_0 -> 32 in the cache */
   /* replace1401 -> 3027 in the cache */

   /* ('u2f', ('b2i', 'a')) => ('b2f', 'a') */
   /* search1402_0_0 -> 32 in the cache */
   /* search1402_0 -> 3027 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 3027 },
      -1,
   } },

   /* replace1402_0 -> 32 in the cache */
   /* replace1402 -> 1520 in the cache */

   /* ('u2u', ('b2i', 'a')) => ('b2i', 'a') */
   /* search1403_0_0 -> 32 in the cache */
   /* search1403_0 -> 3027 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 3027 },
      -1,
   } },

   /* replace1403_0 -> 32 in the cache */
   /* replace1403 -> 3027 in the cache */

   /* ('i2f', ('b2i', 'a')) => ('b2f', 'a') */
   /* search1404_0_0 -> 32 in the cache */
   /* search1404_0 -> 3027 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 3027 },
      -1,
   } },

   /* replace1404_0 -> 32 in the cache */
   /* replace1404 -> 1520 in the cache */

   /* ('i2i', ('b2i', 'a')) => ('b2i', 'a') */
   /* search1405_0_0 -> 32 in the cache */
   /* search1405_0 -> 3027 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 3027 },
      -1,
   } },

   /* replace1405_0 -> 32 in the cache */
   /* replace1405 -> 3027 in the cache */

   /* ('i2i1', 'a@1') => a */
   /* search1406_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 753 },
      -1,
   } },

   /* replace1406 -> 753 in the cache */

   /* ('i2i8', 'a@8') => a */
   /* search1407_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1407 -> 6 in the cache */

   /* ('i2i16', 'a@16') => a */
   /* search1408_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1408 -> 11 in the cache */

   /* ('i2i32', 'a@32') => a */
   /* search1409_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1409 -> 16 in the cache */

   /* ('i2i64', 'a@64') => a */
   /* search1410_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1410 -> 21 in the cache */

   /* ('u2u1', 'a@1') => a */
   /* search1411_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 753 },
      -1,
   } },

   /* replace1411 -> 753 in the cache */

   /* ('u2u8', 'a@8') => a */
   /* search1412_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1412 -> 6 in the cache */

   /* ('u2u16', 'a@16') => a */
   /* search1413_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1413 -> 11 in the cache */

   /* ('u2u32', 'a@32') => a */
   /* search1414_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1414 -> 16 in the cache */

   /* ('u2u64', 'a@64') => a */
   /* search1415_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1415 -> 21 in the cache */

   /* ('f2f16', 'a@16') => a */
   /* search1416_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1416 -> 11 in the cache */

   /* ('f2f32', 'a@32') => a */
   /* search1417_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1417 -> 16 in the cache */

   /* ('f2f64', 'a@64') => a */
   /* search1418_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1418 -> 21 in the cache */

   /* ('b2b1', 'a@1') => a */
   /* search1419_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_b2b1,
      -1, 0,
      { 753 },
      -1,
   } },

   /* replace1419 -> 753 in the cache */

   /* ('b2b8', 'a@8') => a */
   /* search1420_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2b8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1420 -> 6 in the cache */

   /* ('b2b16', 'a@16') => a */
   /* search1421_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2b16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1421 -> 11 in the cache */

   /* ('b2b32', 'a@32') => a */
   /* search1422_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2b32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1422 -> 16 in the cache */

   /* ('i2i1', ('i2i8', 'a')) => ('i2i1', 'a') */
   /* search1423_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4091 },
      -1,
   } },

   /* replace1423_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2i1', ('u2u8', 'a')) => ('u2u1', 'a') */
   /* search1424_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4094 },
      -1,
   } },

   /* replace1424_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('u2u1', ('i2i8', 'a')) => ('i2i1', 'a') */
   /* search1425_0_0 -> 32 in the cache */
   /* search1425_0 -> 4091 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4091 },
      -1,
   } },

   /* replace1425_0 -> 32 in the cache */
   /* replace1425 -> 4093 in the cache */

   /* ('u2u1', ('u2u8', 'a')) => ('u2u1', 'a') */
   /* search1426_0_0 -> 32 in the cache */
   /* search1426_0 -> 4094 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4094 },
      -1,
   } },

   /* replace1426_0 -> 32 in the cache */
   /* replace1426 -> 4096 in the cache */

   /* ('i2i1', ('i2i16', 'a')) => ('i2i1', 'a') */
   /* search1427_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4099 },
      -1,
   } },

   /* replace1427_0 -> 32 in the cache */
   /* replace1427 -> 4093 in the cache */

   /* ('i2i1', ('u2u16', 'a')) => ('u2u1', 'a') */
   /* search1428_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4101 },
      -1,
   } },

   /* replace1428_0 -> 32 in the cache */
   /* replace1428 -> 4096 in the cache */

   /* ('u2u1', ('i2i16', 'a')) => ('i2i1', 'a') */
   /* search1429_0_0 -> 32 in the cache */
   /* search1429_0 -> 4099 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4099 },
      -1,
   } },

   /* replace1429_0 -> 32 in the cache */
   /* replace1429 -> 4093 in the cache */

   /* ('u2u1', ('u2u16', 'a')) => ('u2u1', 'a') */
   /* search1430_0_0 -> 32 in the cache */
   /* search1430_0 -> 4101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4101 },
      -1,
   } },

   /* replace1430_0 -> 32 in the cache */
   /* replace1430 -> 4096 in the cache */

   /* ('i2i1', ('i2i32', 'a')) => ('i2i1', 'a') */
   /* search1431_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4105 },
      -1,
   } },

   /* replace1431_0 -> 32 in the cache */
   /* replace1431 -> 4093 in the cache */

   /* ('i2i1', ('u2u32', 'a')) => ('u2u1', 'a') */
   /* search1432_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4107 },
      -1,
   } },

   /* replace1432_0 -> 32 in the cache */
   /* replace1432 -> 4096 in the cache */

   /* ('u2u1', ('i2i32', 'a')) => ('i2i1', 'a') */
   /* search1433_0_0 -> 32 in the cache */
   /* search1433_0 -> 4105 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4105 },
      -1,
   } },

   /* replace1433_0 -> 32 in the cache */
   /* replace1433 -> 4093 in the cache */

   /* ('u2u1', ('u2u32', 'a')) => ('u2u1', 'a') */
   /* search1434_0_0 -> 32 in the cache */
   /* search1434_0 -> 4107 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4107 },
      -1,
   } },

   /* replace1434_0 -> 32 in the cache */
   /* replace1434 -> 4096 in the cache */

   /* ('i2i1', ('i2i64', 'a')) => ('i2i1', 'a') */
   /* search1435_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4111 },
      -1,
   } },

   /* replace1435_0 -> 32 in the cache */
   /* replace1435 -> 4093 in the cache */

   /* ('i2i1', ('u2u64', 'a')) => ('u2u1', 'a') */
   /* search1436_0_0 -> 32 in the cache */
   /* search1436_0 -> 3135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3135 },
      -1,
   } },

   /* replace1436_0 -> 32 in the cache */
   /* replace1436 -> 4096 in the cache */

   /* ('u2u1', ('i2i64', 'a')) => ('i2i1', 'a') */
   /* search1437_0_0 -> 32 in the cache */
   /* search1437_0 -> 4111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4111 },
      -1,
   } },

   /* replace1437_0 -> 32 in the cache */
   /* replace1437 -> 4093 in the cache */

   /* ('u2u1', ('u2u64', 'a')) => ('u2u1', 'a') */
   /* search1438_0_0 -> 32 in the cache */
   /* search1438_0 -> 3135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3135 },
      -1,
   } },

   /* replace1438_0 -> 32 in the cache */
   /* replace1438 -> 4096 in the cache */

   /* ('i2i8', ('i2i1', 'a@1')) => ('i2i8', 'a') */
   /* search1439_0_0 -> 753 in the cache */
   /* search1439_0 -> 4074 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4074 },
      -1,
   } },

   /* replace1439_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 753 },
      -1,
   } },

   /* ('u2u8', ('u2u1', 'a@1')) => ('u2u8', 'a') */
   /* search1440_0_0 -> 753 in the cache */
   /* search1440_0 -> 4079 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4079 },
      -1,
   } },

   /* replace1440_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 753 },
      -1,
   } },

   /* ('i2i8', ('i2i16', 'a')) => ('i2i8', 'a') */
   /* search1441_0_0 -> 32 in the cache */
   /* search1441_0 -> 4099 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4099 },
      -1,
   } },

   /* replace1441_0 -> 32 in the cache */
   /* replace1441 -> 4091 in the cache */

   /* ('i2i8', ('u2u16', 'a')) => ('u2u8', 'a') */
   /* search1442_0_0 -> 32 in the cache */
   /* search1442_0 -> 4101 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4101 },
      -1,
   } },

   /* replace1442_0 -> 32 in the cache */
   /* replace1442 -> 4094 in the cache */

   /* ('u2u8', ('i2i16', 'a')) => ('i2i8', 'a') */
   /* search1443_0_0 -> 32 in the cache */
   /* search1443_0 -> 4099 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4099 },
      -1,
   } },

   /* replace1443_0 -> 32 in the cache */
   /* replace1443 -> 4091 in the cache */

   /* ('u2u8', ('u2u16', 'a')) => ('u2u8', 'a') */
   /* search1444_0_0 -> 32 in the cache */
   /* search1444_0 -> 4101 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4101 },
      -1,
   } },

   /* replace1444_0 -> 32 in the cache */
   /* replace1444 -> 4094 in the cache */

   /* ('i2i8', ('i2i32', 'a')) => ('i2i8', 'a') */
   /* search1445_0_0 -> 32 in the cache */
   /* search1445_0 -> 4105 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4105 },
      -1,
   } },

   /* replace1445_0 -> 32 in the cache */
   /* replace1445 -> 4091 in the cache */

   /* ('i2i8', ('u2u32', 'a')) => ('u2u8', 'a') */
   /* search1446_0_0 -> 32 in the cache */
   /* search1446_0 -> 4107 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4107 },
      -1,
   } },

   /* replace1446_0 -> 32 in the cache */
   /* replace1446 -> 4094 in the cache */

   /* ('u2u8', ('i2i32', 'a')) => ('i2i8', 'a') */
   /* search1447_0_0 -> 32 in the cache */
   /* search1447_0 -> 4105 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4105 },
      -1,
   } },

   /* replace1447_0 -> 32 in the cache */
   /* replace1447 -> 4091 in the cache */

   /* ('u2u8', ('u2u32', 'a')) => ('u2u8', 'a') */
   /* search1448_0_0 -> 32 in the cache */
   /* search1448_0 -> 4107 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4107 },
      -1,
   } },

   /* replace1448_0 -> 32 in the cache */
   /* replace1448 -> 4094 in the cache */

   /* ('i2i8', ('i2i64', 'a')) => ('i2i8', 'a') */
   /* search1449_0_0 -> 32 in the cache */
   /* search1449_0 -> 4111 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4111 },
      -1,
   } },

   /* replace1449_0 -> 32 in the cache */
   /* replace1449 -> 4091 in the cache */

   /* ('i2i8', ('u2u64', 'a')) => ('u2u8', 'a') */
   /* search1450_0_0 -> 32 in the cache */
   /* search1450_0 -> 3135 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3135 },
      -1,
   } },

   /* replace1450_0 -> 32 in the cache */
   /* replace1450 -> 4094 in the cache */

   /* ('u2u8', ('i2i64', 'a')) => ('i2i8', 'a') */
   /* search1451_0_0 -> 32 in the cache */
   /* search1451_0 -> 4111 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4111 },
      -1,
   } },

   /* replace1451_0 -> 32 in the cache */
   /* replace1451 -> 4091 in the cache */

   /* ('u2u8', ('u2u64', 'a')) => ('u2u8', 'a') */
   /* search1452_0_0 -> 32 in the cache */
   /* search1452_0 -> 3135 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3135 },
      -1,
   } },

   /* replace1452_0 -> 32 in the cache */
   /* replace1452 -> 4094 in the cache */

   /* ('i2i16', ('i2i1', 'a@1')) => ('i2i16', 'a') */
   /* search1453_0_0 -> 753 in the cache */
   /* search1453_0 -> 4074 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4074 },
      -1,
   } },

   /* replace1453_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 753 },
      -1,
   } },

   /* ('u2u16', ('u2u1', 'a@1')) => ('u2u16', 'a') */
   /* search1454_0_0 -> 753 in the cache */
   /* search1454_0 -> 4079 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4079 },
      -1,
   } },

   /* replace1454_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 753 },
      -1,
   } },

   /* ('i2i16', ('i2i8', 'a@1')) => ('i2i16', 'a') */
   /* search1455_0_0 -> 753 in the cache */
   /* search1455_0 -> 4117 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4117 },
      -1,
   } },

   /* replace1455_0 -> 753 in the cache */
   /* replace1455 -> 4133 in the cache */

   /* ('u2u16', ('u2u8', 'a@1')) => ('u2u16', 'a') */
   /* search1456_0_0 -> 753 in the cache */
   /* search1456_0 -> 4119 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4119 },
      -1,
   } },

   /* replace1456_0 -> 753 in the cache */
   /* replace1456 -> 4135 in the cache */

   /* ('i2i16', ('i2i8', 'a@8')) => ('i2i16', 'a') */
   /* search1457_0_0 -> 6 in the cache */
   /* search1457_0 -> 4075 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4075 },
      -1,
   } },

   /* replace1457_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u16', ('u2u8', 'a@8')) => ('u2u16', 'a') */
   /* search1458_0_0 -> 6 in the cache */
   /* search1458_0 -> 4080 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4080 },
      -1,
   } },

   /* replace1458_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('i2i16', ('i2i32', 'a')) => ('i2i16', 'a') */
   /* search1459_0_0 -> 32 in the cache */
   /* search1459_0 -> 4105 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4105 },
      -1,
   } },

   /* replace1459_0 -> 32 in the cache */
   /* replace1459 -> 4099 in the cache */

   /* ('i2i16', ('u2u32', 'a')) => ('u2u16', 'a') */
   /* search1460_0_0 -> 32 in the cache */
   /* search1460_0 -> 4107 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4107 },
      -1,
   } },

   /* replace1460_0 -> 32 in the cache */
   /* replace1460 -> 4101 in the cache */

   /* ('u2u16', ('i2i32', 'a')) => ('i2i16', 'a') */
   /* search1461_0_0 -> 32 in the cache */
   /* search1461_0 -> 4105 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4105 },
      -1,
   } },

   /* replace1461_0 -> 32 in the cache */
   /* replace1461 -> 4099 in the cache */

   /* ('u2u16', ('u2u32', 'a')) => ('u2u16', 'a') */
   /* search1462_0_0 -> 32 in the cache */
   /* search1462_0 -> 4107 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4107 },
      -1,
   } },

   /* replace1462_0 -> 32 in the cache */
   /* replace1462 -> 4101 in the cache */

   /* ('i2i16', ('i2i64', 'a')) => ('i2i16', 'a') */
   /* search1463_0_0 -> 32 in the cache */
   /* search1463_0 -> 4111 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4111 },
      -1,
   } },

   /* replace1463_0 -> 32 in the cache */
   /* replace1463 -> 4099 in the cache */

   /* ('i2i16', ('u2u64', 'a')) => ('u2u16', 'a') */
   /* search1464_0_0 -> 32 in the cache */
   /* search1464_0 -> 3135 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3135 },
      -1,
   } },

   /* replace1464_0 -> 32 in the cache */
   /* replace1464 -> 4101 in the cache */

   /* ('u2u16', ('i2i64', 'a')) => ('i2i16', 'a') */
   /* search1465_0_0 -> 32 in the cache */
   /* search1465_0 -> 4111 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4111 },
      -1,
   } },

   /* replace1465_0 -> 32 in the cache */
   /* replace1465 -> 4099 in the cache */

   /* ('u2u16', ('u2u64', 'a')) => ('u2u16', 'a') */
   /* search1466_0_0 -> 32 in the cache */
   /* search1466_0 -> 3135 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3135 },
      -1,
   } },

   /* replace1466_0 -> 32 in the cache */
   /* replace1466 -> 4101 in the cache */

   /* ('i2i32', ('i2i1', 'a@1')) => ('i2i32', 'a') */
   /* search1467_0_0 -> 753 in the cache */
   /* search1467_0 -> 4074 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4074 },
      -1,
   } },

   /* replace1467_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 753 },
      -1,
   } },

   /* ('u2u32', ('u2u1', 'a@1')) => ('u2u32', 'a') */
   /* search1468_0_0 -> 753 in the cache */
   /* search1468_0 -> 4079 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4079 },
      -1,
   } },

   /* replace1468_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 753 },
      -1,
   } },

   /* ('i2i32', ('i2i8', 'a@1')) => ('i2i32', 'a') */
   /* search1469_0_0 -> 753 in the cache */
   /* search1469_0 -> 4117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4117 },
      -1,
   } },

   /* replace1469_0 -> 753 in the cache */
   /* replace1469 -> 4151 in the cache */

   /* ('u2u32', ('u2u8', 'a@1')) => ('u2u32', 'a') */
   /* search1470_0_0 -> 753 in the cache */
   /* search1470_0 -> 4119 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4119 },
      -1,
   } },

   /* replace1470_0 -> 753 in the cache */
   /* replace1470 -> 4153 in the cache */

   /* ('i2i32', ('i2i8', 'a@8')) => ('i2i32', 'a') */
   /* search1471_0_0 -> 6 in the cache */
   /* search1471_0 -> 4075 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4075 },
      -1,
   } },

   /* replace1471_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u32', ('u2u8', 'a@8')) => ('u2u32', 'a') */
   /* search1472_0_0 -> 6 in the cache */
   /* search1472_0 -> 4080 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4080 },
      -1,
   } },

   /* replace1472_0 -> 6 in the cache */
   /* replace1472 -> 3210 in the cache */

   /* ('i2i32', ('i2i16', 'a@1')) => ('i2i32', 'a') */
   /* search1473_0_0 -> 753 in the cache */
   /* search1473_0 -> 4133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4133 },
      -1,
   } },

   /* replace1473_0 -> 753 in the cache */
   /* replace1473 -> 4151 in the cache */

   /* ('u2u32', ('u2u16', 'a@1')) => ('u2u32', 'a') */
   /* search1474_0_0 -> 753 in the cache */
   /* search1474_0 -> 4135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4135 },
      -1,
   } },

   /* replace1474_0 -> 753 in the cache */
   /* replace1474 -> 4153 in the cache */

   /* ('i2i32', ('i2i16', 'a@8')) => ('i2i32', 'a') */
   /* search1475_0_0 -> 6 in the cache */
   /* search1475_0 -> 4139 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4139 },
      -1,
   } },

   /* replace1475_0 -> 6 in the cache */
   /* replace1475 -> 4157 in the cache */

   /* ('u2u32', ('u2u16', 'a@8')) => ('u2u32', 'a') */
   /* search1476_0_0 -> 6 in the cache */
   /* search1476_0 -> 4141 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4141 },
      -1,
   } },

   /* replace1476_0 -> 6 in the cache */
   /* replace1476 -> 3210 in the cache */

   /* ('i2i32', ('i2i16', 'a@16')) => ('i2i32', 'a') */
   /* search1477_0_0 -> 11 in the cache */
   /* search1477_0 -> 4076 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4076 },
      -1,
   } },

   /* replace1477_0 -> 11 in the cache */
   /* replace1477 -> 1793 in the cache */

   /* ('u2u32', ('u2u16', 'a@16')) => ('u2u32', 'a') */
   /* search1478_0_0 -> 11 in the cache */
   /* search1478_0 -> 4081 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4081 },
      -1,
   } },

   /* replace1478_0 -> 11 in the cache */
   /* replace1478 -> 1795 in the cache */

   /* ('i2i32', ('i2i64', 'a')) => ('i2i32', 'a') */
   /* search1479_0_0 -> 32 in the cache */
   /* search1479_0 -> 4111 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4111 },
      -1,
   } },

   /* replace1479_0 -> 32 in the cache */
   /* replace1479 -> 4105 in the cache */

   /* ('i2i32', ('u2u64', 'a')) => ('u2u32', 'a') */
   /* search1480_0_0 -> 32 in the cache */
   /* search1480_0 -> 3135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3135 },
      -1,
   } },

   /* replace1480_0 -> 32 in the cache */
   /* replace1480 -> 4107 in the cache */

   /* ('u2u32', ('i2i64', 'a')) => ('i2i32', 'a') */
   /* search1481_0_0 -> 32 in the cache */
   /* search1481_0 -> 4111 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4111 },
      -1,
   } },

   /* replace1481_0 -> 32 in the cache */
   /* replace1481 -> 4105 in the cache */

   /* ('u2u32', ('u2u64', 'a')) => ('u2u32', 'a') */
   /* search1482_0_0 -> 32 in the cache */
   /* search1482_0 -> 3135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3135 },
      -1,
   } },

   /* replace1482_0 -> 32 in the cache */
   /* replace1482 -> 4107 in the cache */

   /* ('i2i64', ('i2i1', 'a@1')) => ('i2i64', 'a') */
   /* search1483_0_0 -> 753 in the cache */
   /* search1483_0 -> 4074 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4074 },
      -1,
   } },

   /* replace1483_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 753 },
      -1,
   } },

   /* ('u2u64', ('u2u1', 'a@1')) => ('u2u64', 'a') */
   /* search1484_0_0 -> 753 in the cache */
   /* search1484_0 -> 4079 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4079 },
      -1,
   } },

   /* replace1484_0 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 753 },
      -1,
   } },

   /* ('i2i64', ('i2i8', 'a@1')) => ('i2i64', 'a') */
   /* search1485_0_0 -> 753 in the cache */
   /* search1485_0 -> 4117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4117 },
      -1,
   } },

   /* replace1485_0 -> 753 in the cache */
   /* replace1485 -> 4170 in the cache */

   /* ('u2u64', ('u2u8', 'a@1')) => ('u2u64', 'a') */
   /* search1486_0_0 -> 753 in the cache */
   /* search1486_0 -> 4119 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4119 },
      -1,
   } },

   /* replace1486_0 -> 753 in the cache */
   /* replace1486 -> 4172 in the cache */

   /* ('i2i64', ('i2i8', 'a@8')) => ('i2i64', 'a') */
   /* search1487_0_0 -> 6 in the cache */
   /* search1487_0 -> 4075 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4075 },
      -1,
   } },

   /* replace1487_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u64', ('u2u8', 'a@8')) => ('u2u64', 'a') */
   /* search1488_0_0 -> 6 in the cache */
   /* search1488_0 -> 4080 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4080 },
      -1,
   } },

   /* replace1488_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('i2i64', ('i2i16', 'a@1')) => ('i2i64', 'a') */
   /* search1489_0_0 -> 753 in the cache */
   /* search1489_0 -> 4133 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4133 },
      -1,
   } },

   /* replace1489_0 -> 753 in the cache */
   /* replace1489 -> 4170 in the cache */

   /* ('u2u64', ('u2u16', 'a@1')) => ('u2u64', 'a') */
   /* search1490_0_0 -> 753 in the cache */
   /* search1490_0 -> 4135 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4135 },
      -1,
   } },

   /* replace1490_0 -> 753 in the cache */
   /* replace1490 -> 4172 in the cache */

   /* ('i2i64', ('i2i16', 'a@8')) => ('i2i64', 'a') */
   /* search1491_0_0 -> 6 in the cache */
   /* search1491_0 -> 4139 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4139 },
      -1,
   } },

   /* replace1491_0 -> 6 in the cache */
   /* replace1491 -> 4176 in the cache */

   /* ('u2u64', ('u2u16', 'a@8')) => ('u2u64', 'a') */
   /* search1492_0_0 -> 6 in the cache */
   /* search1492_0 -> 4141 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4141 },
      -1,
   } },

   /* replace1492_0 -> 6 in the cache */
   /* replace1492 -> 4178 in the cache */

   /* ('i2i64', ('i2i16', 'a@16')) => ('i2i64', 'a') */
   /* search1493_0_0 -> 11 in the cache */
   /* search1493_0 -> 4076 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4076 },
      -1,
   } },

   /* replace1493_0 -> 11 in the cache */
   /* replace1493 -> 1816 in the cache */

   /* ('u2u64', ('u2u16', 'a@16')) => ('u2u64', 'a') */
   /* search1494_0_0 -> 11 in the cache */
   /* search1494_0 -> 4081 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4081 },
      -1,
   } },

   /* replace1494_0 -> 11 in the cache */
   /* replace1494 -> 1818 in the cache */

   /* ('i2i64', ('i2i32', 'a@1')) => ('i2i64', 'a') */
   /* search1495_0_0 -> 753 in the cache */
   /* search1495_0 -> 4151 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4151 },
      -1,
   } },

   /* replace1495_0 -> 753 in the cache */
   /* replace1495 -> 4170 in the cache */

   /* ('u2u64', ('u2u32', 'a@1')) => ('u2u64', 'a') */
   /* search1496_0_0 -> 753 in the cache */
   /* search1496_0 -> 4153 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4153 },
      -1,
   } },

   /* replace1496_0 -> 753 in the cache */
   /* replace1496 -> 4172 in the cache */

   /* ('i2i64', ('i2i32', 'a@8')) => ('i2i64', 'a') */
   /* search1497_0_0 -> 6 in the cache */
   /* search1497_0 -> 4157 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4157 },
      -1,
   } },

   /* replace1497_0 -> 6 in the cache */
   /* replace1497 -> 4176 in the cache */

   /* ('u2u64', ('u2u32', 'a@8')) => ('u2u64', 'a') */
   /* search1498_0_0 -> 6 in the cache */
   /* search1498_0 -> 3210 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3210 },
      -1,
   } },

   /* replace1498_0 -> 6 in the cache */
   /* replace1498 -> 4178 in the cache */

   /* ('i2i64', ('i2i32', 'a@16')) => ('i2i64', 'a') */
   /* search1499_0_0 -> 11 in the cache */
   /* search1499_0 -> 1793 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 1793 },
      -1,
   } },

   /* replace1499_0 -> 11 in the cache */
   /* replace1499 -> 1816 in the cache */

   /* ('u2u64', ('u2u32', 'a@16')) => ('u2u64', 'a') */
   /* search1500_0_0 -> 11 in the cache */
   /* search1500_0 -> 1795 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 1795 },
      -1,
   } },

   /* replace1500_0 -> 11 in the cache */
   /* replace1500 -> 1818 in the cache */

   /* ('i2i64', ('i2i32', 'a@32')) => ('i2i64', 'a') */
   /* search1501_0_0 -> 16 in the cache */
   /* search1501_0 -> 4077 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4077 },
      -1,
   } },

   /* replace1501_0 -> 16 in the cache */
   /* replace1501 -> 1898 in the cache */

   /* ('u2u64', ('u2u32', 'a@32')) => ('u2u64', 'a') */
   /* search1502_0_0 -> 16 in the cache */
   /* search1502_0 -> 4082 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4082 },
      -1,
   } },

   /* replace1502_0 -> 16 in the cache */
   /* replace1502 -> 1900 in the cache */

   /* ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a') */
   /* search1503_0_0 -> 16 in the cache */
   /* search1503_0_1 -> 36 in the cache */
   /* search1503_0 -> 3128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3128 },
      -1,
   } },

   /* replace1503_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a') */
   /* search1504_0_0 -> 16 in the cache */
   /* search1504_0_1 -> 36 in the cache */
   /* search1504_0 -> 3128 in the cache */
   /* search1504 -> 4193 in the cache */

   /* replace1504_0 -> 16 in the cache */
   /* replace1504 -> 4194 in the cache */

   /* ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a') */
   /* search1505_0_0 -> 16 in the cache */
   /* search1505_0_1 -> 36 in the cache */
   /* search1505_0 -> 3128 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3128 },
      -1,
   } },

   /* replace1505_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a') */
   /* search1506_0_0 -> 16 in the cache */
   /* search1506_0_1 -> 36 in the cache */
   /* search1506_0 -> 3128 in the cache */
   /* search1506 -> 4195 in the cache */

   /* replace1506_0 -> 16 in the cache */
   /* replace1506 -> 4196 in the cache */

   /* ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a') */
   /* search1507_0_0 -> 16 in the cache */
   /* search1507_0_1 -> 36 in the cache */
   /* search1507_0 -> 3128 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3128 },
      -1,
   } },

   /* replace1507_0 -> 16 in the cache */
   /* replace1507 -> 4077 in the cache */

   /* ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a') */
   /* search1508_0_0 -> 16 in the cache */
   /* search1508_0_1 -> 36 in the cache */
   /* search1508_0 -> 3128 in the cache */
   /* search1508 -> 4197 in the cache */

   /* replace1508_0 -> 16 in the cache */
   /* replace1508 -> 4077 in the cache */

   /* ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a') */
   /* search1509_0_0 -> 16 in the cache */
   /* search1509_0_1 -> 36 in the cache */
   /* search1509_0 -> 3128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3128 },
      -1,
   } },

   /* replace1509_0 -> 16 in the cache */
   /* replace1509 -> 2014 in the cache */

   /* ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a') */
   /* search1510_0_0 -> 16 in the cache */
   /* search1510_0_1 -> 36 in the cache */
   /* search1510_0 -> 3128 in the cache */
   /* search1510 -> 4198 in the cache */

   /* replace1510_0 -> 16 in the cache */
   /* replace1510 -> 2014 in the cache */

   /* ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a') */
   /* search1511_0_0 -> 16 in the cache */
   /* search1511_0_1 -> 36 in the cache */
   /* search1511_0 -> 3128 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3128 },
      -1,
   } },

   /* replace1511_0 -> 16 in the cache */
   /* replace1511 -> 3238 in the cache */

   /* ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a') */
   /* search1512_0_0 -> 16 in the cache */
   /* search1512_0_1 -> 36 in the cache */
   /* search1512_0 -> 3128 in the cache */
   /* search1512 -> 4199 in the cache */

   /* replace1512_0 -> 16 in the cache */
   /* replace1512 -> 3238 in the cache */

   /* ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a') */
   /* search1513_0_0 -> 16 in the cache */
   /* search1513_0_1 -> 36 in the cache */
   /* search1513_0 -> 3128 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3128 },
      -1,
   } },

   /* replace1513_0 -> 16 in the cache */
   /* replace1513 -> 4082 in the cache */

   /* ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a') */
   /* search1514_0_0 -> 16 in the cache */
   /* search1514_0_1 -> 36 in the cache */
   /* search1514_0 -> 3128 in the cache */
   /* search1514 -> 4200 in the cache */

   /* replace1514_0 -> 16 in the cache */
   /* replace1514 -> 4082 in the cache */

   /* ('ieq', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1515_0_0 -> 6 in the cache */
   /* search1515_0 -> 4139 in the cache */
   /* search1515_1_0 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4139, 4201 },
      -1,
   } },

   /* replace1515_0 -> 6 in the cache */
   /* replace1515_1_0 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 6, 4203 },
      -1,
   } },

   /* ('ine', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1516_0_0 -> 6 in the cache */
   /* search1516_0 -> 4139 in the cache */
   /* search1516_1_0 -> 2101 in the cache */
   /* search1516_1 -> 4201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4139, 4201 },
      -1,
   } },

   /* replace1516_0 -> 6 in the cache */
   /* replace1516_1_0 -> 2101 in the cache */
   /* replace1516_1 -> 4203 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 6, 4203 },
      -1,
   } },

   /* ('ige', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1517_0_0 -> 6 in the cache */
   /* search1517_0 -> 4139 in the cache */
   /* search1517_1_0 -> 2101 in the cache */
   /* search1517_1 -> 4201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4139, 4201 },
      -1,
   } },

   /* replace1517_0 -> 6 in the cache */
   /* replace1517_1_0 -> 2101 in the cache */
   /* replace1517_1 -> 4203 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 4203 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1518_0_0 -> 6 in the cache */
   /* search1518_0 -> 4139 in the cache */
   /* search1518_1_0 -> 2101 in the cache */
   /* search1518_1 -> 4201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4139, 4201 },
      -1,
   } },

   /* replace1518_0 -> 6 in the cache */
   /* replace1518_1_0 -> 2101 in the cache */
   /* replace1518_1 -> 4203 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 4203 },
      -1,
   } },

   /* ('ige', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4211 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4213 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4212, 4214 },
      -1,
   } },

   /* replace1519_0_0 -> 4211 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4211 },
      -1,
   } },
   /* replace1519_1 -> 4213 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4216, 4213 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1520_0_0 -> 4211 in the cache */
   /* search1520_0 -> 4212 in the cache */
   /* search1520_1_0 -> 4213 in the cache */
   /* search1520_1 -> 4214 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4212, 4214 },
      -1,
   } },

   /* replace1520_0_0 -> 4211 in the cache */
   /* replace1520_0 -> 4216 in the cache */
   /* replace1520_1 -> 4213 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4216, 4213 },
      -1,
   } },

   /* ('ieq', ('i2i16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i16', ('i2i8', 'b')), 'b')) */
   /* search1521_0_0 -> 6 in the cache */
   /* search1521_0 -> 4139 in the cache */
   /* search1521_1 -> 2000 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4139, 2000 },
      -1,
   } },

   /* replace1521_0_0 -> 6 in the cache */
   /* replace1521_0_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 4221 },
      -1,
   } },
   /* replace1521_1_0_0_0 -> 260 in the cache */
   /* replace1521_1_0_0 -> 4221 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4221 },
      -1,
   } },
   /* replace1521_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4223, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4222, 4224 },
      -1,
   } },

   /* ('ine', ('i2i16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i16', ('i2i8', 'b')), 'b')) */
   /* search1522_0_0 -> 6 in the cache */
   /* search1522_0 -> 4139 in the cache */
   /* search1522_1 -> 2000 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4139, 2000 },
      -1,
   } },

   /* replace1522_0_0 -> 6 in the cache */
   /* replace1522_0_1_0 -> 260 in the cache */
   /* replace1522_0_1 -> 4221 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 4221 },
      -1,
   } },
   /* replace1522_1_0_0_0 -> 260 in the cache */
   /* replace1522_1_0_0 -> 4221 in the cache */
   /* replace1522_1_0 -> 4223 in the cache */
   /* replace1522_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4223, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4227, 4228 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1523_0_0 -> 6 in the cache */
   /* search1523_0 -> 4139 in the cache */
   /* search1523_1 -> 2000 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4139, 2000 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1523_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4231, 260 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1523_1_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4233, 260 },
      -1,
   } },
   /* replace1523_1_1_0 -> 6 in the cache */
   /* replace1523_1_1_1_0 -> 260 in the cache */
   /* replace1523_1_1_1 -> 4221 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 4221 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4234, 4235 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4232, 4236 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i16', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1524_1_0 -> 2101 in the cache */
   /* search1524_1 -> 4201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4238, 4201 },
      -1,
   } },

   /* replace1524_0_0 -> 11 in the cache */
   /* replace1524_0_1 -> 4233 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4233 },
      -1,
   } },
   /* replace1524_1_0_0 -> 11 in the cache */
   /* replace1524_1_0_1 -> 4231 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4231 },
      -1,
   } },
   /* replace1524_1_1_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 11 },
      -1,
   } },
   /* replace1524_1_1_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4242, 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4241, 4243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4240, 4244 },
      -1,
   } },

   /* ('ige', ('i2i16', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1525_0_0 -> 6 in the cache */
   /* search1525_0 -> 4139 in the cache */
   /* search1525_1 -> 2000 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4139, 2000 },
      -1,
   } },

   /* replace1525_0_0 -> 4233 in the cache */
   /* replace1525_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4233, 260 },
      -1,
   } },
   /* replace1525_1_0_0 -> 4231 in the cache */
   /* replace1525_1_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4231, 260 },
      -1,
   } },
   /* replace1525_1_1_0 -> 6 in the cache */
   /* replace1525_1_1_1_0 -> 260 in the cache */
   /* replace1525_1_1_1 -> 4221 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 4221 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4248, 4249 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4247, 4250 },
      -1,
   } },

   /* ('ige', '#a', ('i2i16', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1526_0 -> 4238 in the cache */
   /* search1526_1_0 -> 2101 in the cache */
   /* search1526_1 -> 4201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4238, 4201 },
      -1,
   } },

   /* replace1526_0_0 -> 11 in the cache */
   /* replace1526_0_1 -> 4231 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4231 },
      -1,
   } },
   /* replace1526_1_0_0 -> 11 in the cache */
   /* replace1526_1_0_1 -> 4233 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4233 },
      -1,
   } },
   /* replace1526_1_1_0_0 -> 11 in the cache */
   /* replace1526_1_1_0 -> 4242 in the cache */
   /* replace1526_1_1_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4242, 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4254, 4255 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4253, 4256 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1527_0_0 -> 6 in the cache */
   /* search1527_0 -> 4157 in the cache */
   /* search1527_1_0 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4157, 4258 },
      -1,
   } },

   /* replace1527_0 -> 6 in the cache */
   /* replace1527_1_0 -> 2101 in the cache */
   /* replace1527_1 -> 4203 in the cache */
   /* replace1527 -> 4204 in the cache */

   /* ('ine', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1528_0_0 -> 6 in the cache */
   /* search1528_0 -> 4157 in the cache */
   /* search1528_1_0 -> 2101 in the cache */
   /* search1528_1 -> 4258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4157, 4258 },
      -1,
   } },

   /* replace1528_0 -> 6 in the cache */
   /* replace1528_1_0 -> 2101 in the cache */
   /* replace1528_1 -> 4203 in the cache */
   /* replace1528 -> 4206 in the cache */

   /* ('ige', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1529_0_0 -> 6 in the cache */
   /* search1529_0 -> 4157 in the cache */
   /* search1529_1_0 -> 2101 in the cache */
   /* search1529_1 -> 4258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4157, 4258 },
      -1,
   } },

   /* replace1529_0 -> 6 in the cache */
   /* replace1529_1_0 -> 2101 in the cache */
   /* replace1529_1 -> 4203 in the cache */
   /* replace1529 -> 4208 in the cache */

   /* ('ilt', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1530_0_0 -> 6 in the cache */
   /* search1530_0 -> 4157 in the cache */
   /* search1530_1_0 -> 2101 in the cache */
   /* search1530_1 -> 4258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4157, 4258 },
      -1,
   } },

   /* replace1530_0 -> 6 in the cache */
   /* replace1530_1_0 -> 2101 in the cache */
   /* replace1530_1 -> 4203 in the cache */
   /* replace1530 -> 4210 in the cache */

   /* ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   /* search1531_0_0 -> 4211 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4211 },
      -1,
   } },
   /* search1531_1_0 -> 4213 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4213 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4263, 4264 },
      -1,
   } },

   /* replace1531_0_0 -> 4211 in the cache */
   /* replace1531_0 -> 4216 in the cache */
   /* replace1531_1 -> 4213 in the cache */
   /* replace1531 -> 4217 in the cache */

   /* ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1532_0_0 -> 4211 in the cache */
   /* search1532_0 -> 4263 in the cache */
   /* search1532_1_0 -> 4213 in the cache */
   /* search1532_1 -> 4264 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4263, 4264 },
      -1,
   } },

   /* replace1532_0_0 -> 4211 in the cache */
   /* replace1532_0 -> 4216 in the cache */
   /* replace1532_1 -> 4213 in the cache */
   /* replace1532 -> 4219 in the cache */

   /* ('ieq', ('i2i32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i32', ('i2i8', 'b')), 'b')) */
   /* search1533_0_0 -> 6 in the cache */
   /* search1533_0 -> 4157 in the cache */
   /* search1533_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4157, 33 },
      -1,
   } },

   /* replace1533_0_0 -> 6 in the cache */
   /* replace1533_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 4268 },
      -1,
   } },
   /* replace1533_1_0_0_0 -> 36 in the cache */
   /* replace1533_1_0_0 -> 4268 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4268 },
      -1,
   } },
   /* replace1533_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4270, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4269, 4271 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i32', ('i2i8', 'b')), 'b')) */
   /* search1534_0_0 -> 6 in the cache */
   /* search1534_0 -> 4157 in the cache */
   /* search1534_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4157, 33 },
      -1,
   } },

   /* replace1534_0_0 -> 6 in the cache */
   /* replace1534_0_1_0 -> 36 in the cache */
   /* replace1534_0_1 -> 4268 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 4268 },
      -1,
   } },
   /* replace1534_1_0_0_0 -> 36 in the cache */
   /* replace1534_1_0_0 -> 4268 in the cache */
   /* replace1534_1_0 -> 4270 in the cache */
   /* replace1534_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4270, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4274, 4275 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1535_0_0 -> 6 in the cache */
   /* search1535_0 -> 4157 in the cache */
   /* search1535_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4157, 33 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1535_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4278, 36 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1535_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4280, 36 },
      -1,
   } },
   /* replace1535_1_1_0 -> 6 in the cache */
   /* replace1535_1_1_1_0 -> 36 in the cache */
   /* replace1535_1_1_1 -> 4268 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 4268 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4281, 4282 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4279, 4283 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i32', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   /* search1536_0 -> 288 in the cache */
   /* search1536_1_0 -> 2101 in the cache */
   /* search1536_1 -> 4258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 288, 4258 },
      -1,
   } },

   /* replace1536_0_0 -> 16 in the cache */
   /* replace1536_0_1 -> 4280 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4280 },
      -1,
   } },
   /* replace1536_1_0_0 -> 16 in the cache */
   /* replace1536_1_0_1 -> 4278 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4278 },
      -1,
   } },
   /* replace1536_1_1_0_0 -> 16 in the cache */
   /* replace1536_1_1_0 -> 4194 in the cache */
   /* replace1536_1_1_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4194, 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4287, 4288 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4286, 4289 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1537_0_0 -> 6 in the cache */
   /* search1537_0 -> 4157 in the cache */
   /* search1537_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4157, 33 },
      -1,
   } },

   /* replace1537_0_0 -> 4280 in the cache */
   /* replace1537_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4280, 36 },
      -1,
   } },
   /* replace1537_1_0_0 -> 4278 in the cache */
   /* replace1537_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4278, 36 },
      -1,
   } },
   /* replace1537_1_1_0 -> 6 in the cache */
   /* replace1537_1_1_1_0 -> 36 in the cache */
   /* replace1537_1_1_1 -> 4268 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 4268 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4293, 4294 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4292, 4295 },
      -1,
   } },

   /* ('ige', '#a', ('i2i32', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1538_0 -> 288 in the cache */
   /* search1538_1_0 -> 2101 in the cache */
   /* search1538_1 -> 4258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 288, 4258 },
      -1,
   } },

   /* replace1538_0_0 -> 16 in the cache */
   /* replace1538_0_1 -> 4278 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4278 },
      -1,
   } },
   /* replace1538_1_0_0 -> 16 in the cache */
   /* replace1538_1_0_1 -> 4280 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4280 },
      -1,
   } },
   /* replace1538_1_1_0_0 -> 16 in the cache */
   /* replace1538_1_1_0 -> 4194 in the cache */
   /* replace1538_1_1_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4194, 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4299, 4300 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4298, 4301 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1539_0_0 -> 6 in the cache */
   /* search1539_0 -> 4176 in the cache */
   /* search1539_1_0 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4176, 4303 },
      -1,
   } },

   /* replace1539_0 -> 6 in the cache */
   /* replace1539_1_0 -> 2101 in the cache */
   /* replace1539_1 -> 4203 in the cache */
   /* replace1539 -> 4204 in the cache */

   /* ('ine', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1540_0_0 -> 6 in the cache */
   /* search1540_0 -> 4176 in the cache */
   /* search1540_1_0 -> 2101 in the cache */
   /* search1540_1 -> 4303 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4176, 4303 },
      -1,
   } },

   /* replace1540_0 -> 6 in the cache */
   /* replace1540_1_0 -> 2101 in the cache */
   /* replace1540_1 -> 4203 in the cache */
   /* replace1540 -> 4206 in the cache */

   /* ('ige', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1541_0_0 -> 6 in the cache */
   /* search1541_0 -> 4176 in the cache */
   /* search1541_1_0 -> 2101 in the cache */
   /* search1541_1 -> 4303 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4176, 4303 },
      -1,
   } },

   /* replace1541_0 -> 6 in the cache */
   /* replace1541_1_0 -> 2101 in the cache */
   /* replace1541_1 -> 4203 in the cache */
   /* replace1541 -> 4208 in the cache */

   /* ('ilt', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1542_0_0 -> 6 in the cache */
   /* search1542_0 -> 4176 in the cache */
   /* search1542_1_0 -> 2101 in the cache */
   /* search1542_1 -> 4303 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4176, 4303 },
      -1,
   } },

   /* replace1542_0 -> 6 in the cache */
   /* replace1542_1_0 -> 2101 in the cache */
   /* replace1542_1 -> 4203 in the cache */
   /* replace1542 -> 4210 in the cache */

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   /* search1543_0_0 -> 4211 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4211 },
      -1,
   } },
   /* search1543_1_0 -> 4213 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4213 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4308, 4309 },
      -1,
   } },

   /* replace1543_0_0 -> 4211 in the cache */
   /* replace1543_0 -> 4216 in the cache */
   /* replace1543_1 -> 4213 in the cache */
   /* replace1543 -> 4217 in the cache */

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1544_0_0 -> 4211 in the cache */
   /* search1544_0 -> 4308 in the cache */
   /* search1544_1_0 -> 4213 in the cache */
   /* search1544_1 -> 4309 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4308, 4309 },
      -1,
   } },

   /* replace1544_0_0 -> 4211 in the cache */
   /* replace1544_0 -> 4216 in the cache */
   /* replace1544_1 -> 4213 in the cache */
   /* replace1544 -> 4219 in the cache */

   /* ('ieq', ('i2i64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i64', ('i2i8', 'b')), 'b')) */
   /* search1545_0_0 -> 6 in the cache */
   /* search1545_0 -> 4176 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4176, 4312 },
      -1,
   } },

   /* replace1545_0_0 -> 6 in the cache */
   /* replace1545_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 4314 },
      -1,
   } },
   /* replace1545_1_0_0_0 -> 41 in the cache */
   /* replace1545_1_0_0 -> 4314 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4314 },
      -1,
   } },
   /* replace1545_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4316, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4315, 4317 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i64', ('i2i8', 'b')), 'b')) */
   /* search1546_0_0 -> 6 in the cache */
   /* search1546_0 -> 4176 in the cache */
   /* search1546_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4176, 4312 },
      -1,
   } },

   /* replace1546_0_0 -> 6 in the cache */
   /* replace1546_0_1_0 -> 41 in the cache */
   /* replace1546_0_1 -> 4314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 4314 },
      -1,
   } },
   /* replace1546_1_0_0_0 -> 41 in the cache */
   /* replace1546_1_0_0 -> 4314 in the cache */
   /* replace1546_1_0 -> 4316 in the cache */
   /* replace1546_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4316, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4320, 4321 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1547_0_0 -> 6 in the cache */
   /* search1547_0 -> 4176 in the cache */
   /* search1547_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4176, 4312 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1547_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4324, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1547_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4326, 41 },
      -1,
   } },
   /* replace1547_1_1_0 -> 6 in the cache */
   /* replace1547_1_1_1_0 -> 41 in the cache */
   /* replace1547_1_1_1 -> 4314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 4314 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4327, 4328 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4325, 4329 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1548_1_0 -> 2101 in the cache */
   /* search1548_1 -> 4303 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4331, 4303 },
      -1,
   } },

   /* replace1548_0_0 -> 21 in the cache */
   /* replace1548_0_1 -> 4326 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4326 },
      -1,
   } },
   /* replace1548_1_0_0 -> 21 in the cache */
   /* replace1548_1_0_1 -> 4324 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4324 },
      -1,
   } },
   /* replace1548_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1548_1_1_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4335, 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4334, 4336 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4333, 4337 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1549_0_0 -> 6 in the cache */
   /* search1549_0 -> 4176 in the cache */
   /* search1549_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4176, 4312 },
      -1,
   } },

   /* replace1549_0_0 -> 4326 in the cache */
   /* replace1549_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4326, 41 },
      -1,
   } },
   /* replace1549_1_0_0 -> 4324 in the cache */
   /* replace1549_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4324, 41 },
      -1,
   } },
   /* replace1549_1_1_0 -> 6 in the cache */
   /* replace1549_1_1_1_0 -> 41 in the cache */
   /* replace1549_1_1_1 -> 4314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 4314 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4341, 4342 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4340, 4343 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1550_0 -> 4331 in the cache */
   /* search1550_1_0 -> 2101 in the cache */
   /* search1550_1 -> 4303 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4331, 4303 },
      -1,
   } },

   /* replace1550_0_0 -> 21 in the cache */
   /* replace1550_0_1 -> 4324 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4324 },
      -1,
   } },
   /* replace1550_1_0_0 -> 21 in the cache */
   /* replace1550_1_0_1 -> 4326 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4326 },
      -1,
   } },
   /* replace1550_1_1_0_0 -> 21 in the cache */
   /* replace1550_1_1_0 -> 4335 in the cache */
   /* replace1550_1_1_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4335, 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4347, 4348 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4346, 4349 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1551_0_0 -> 11 in the cache */
   /* search1551_0 -> 1793 in the cache */
   /* search1551_1_0 -> 2101 in the cache */
   /* search1551_1 -> 4258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1793, 4258 },
      -1,
   } },

   /* replace1551_0 -> 11 in the cache */
   /* replace1551_1_0 -> 2101 in the cache */
   /* replace1551_1 -> 4201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4201 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1552_0_0 -> 11 in the cache */
   /* search1552_0 -> 1793 in the cache */
   /* search1552_1_0 -> 2101 in the cache */
   /* search1552_1 -> 4258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1793, 4258 },
      -1,
   } },

   /* replace1552_0 -> 11 in the cache */
   /* replace1552_1_0 -> 2101 in the cache */
   /* replace1552_1 -> 4201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4201 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1553_0_0 -> 11 in the cache */
   /* search1553_0 -> 1793 in the cache */
   /* search1553_1_0 -> 2101 in the cache */
   /* search1553_1 -> 4258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1793, 4258 },
      -1,
   } },

   /* replace1553_0 -> 11 in the cache */
   /* replace1553_1_0 -> 2101 in the cache */
   /* replace1553_1 -> 4201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4201 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1554_0_0 -> 11 in the cache */
   /* search1554_0 -> 1793 in the cache */
   /* search1554_1_0 -> 2101 in the cache */
   /* search1554_1 -> 4258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1793, 4258 },
      -1,
   } },

   /* replace1554_0 -> 11 in the cache */
   /* replace1554_1_0 -> 2101 in the cache */
   /* replace1554_1 -> 4201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4201 },
      -1,
   } },

   /* ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1555_0_0 -> 4211 in the cache */
   /* search1555_0 -> 4263 in the cache */
   /* search1555_1_0 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 528 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4263, 4359 },
      -1,
   } },

   /* replace1555_0_0 -> 4211 in the cache */
   /* replace1555_0 -> 4212 in the cache */
   /* replace1555_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4212, 528 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1556_0_0 -> 4211 in the cache */
   /* search1556_0 -> 4263 in the cache */
   /* search1556_1_0 -> 528 in the cache */
   /* search1556_1 -> 4359 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4263, 4359 },
      -1,
   } },

   /* replace1556_0_0 -> 4211 in the cache */
   /* replace1556_0 -> 4212 in the cache */
   /* replace1556_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4212, 528 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1557_0_0 -> 11 in the cache */
   /* search1557_0 -> 1793 in the cache */
   /* search1557_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1793, 4364 },
      -1,
   } },

   /* replace1557_0 -> 11 in the cache */
   /* replace1557_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4366 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1558_0_0 -> 11 in the cache */
   /* search1558_0 -> 1793 in the cache */
   /* search1558_1_0 -> 260 in the cache */
   /* search1558_1 -> 4364 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1793, 4364 },
      -1,
   } },

   /* replace1558_0 -> 11 in the cache */
   /* replace1558_1_0 -> 260 in the cache */
   /* replace1558_1 -> 4366 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4366 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1559_0_0 -> 11 in the cache */
   /* search1559_0 -> 1793 in the cache */
   /* search1559_1_0 -> 260 in the cache */
   /* search1559_1 -> 4364 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1793, 4364 },
      -1,
   } },

   /* replace1559_0 -> 11 in the cache */
   /* replace1559_1_0 -> 260 in the cache */
   /* replace1559_1 -> 4366 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4366 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1560_0_0 -> 11 in the cache */
   /* search1560_0 -> 1793 in the cache */
   /* search1560_1_0 -> 260 in the cache */
   /* search1560_1 -> 4364 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1793, 4364 },
      -1,
   } },

   /* replace1560_0 -> 11 in the cache */
   /* replace1560_1_0 -> 260 in the cache */
   /* replace1560_1 -> 4366 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4366 },
      -1,
   } },

   /* ('ige', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1561_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 517 },
      -1,
   } },
   /* search1561_1_0 -> 528 in the cache */
   /* search1561_1 -> 4359 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4374, 4359 },
      -1,
   } },

   /* replace1561_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 517 },
      -1,
   } },
   /* replace1561_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4376, 528 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1562_0_0 -> 517 in the cache */
   /* search1562_0 -> 4374 in the cache */
   /* search1562_1_0 -> 528 in the cache */
   /* search1562_1 -> 4359 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4374, 4359 },
      -1,
   } },

   /* replace1562_0_0 -> 517 in the cache */
   /* replace1562_0 -> 4376 in the cache */
   /* replace1562_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4376, 528 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i32', ('i2i16', 'b')), 'b')) */
   /* search1563_0_0 -> 11 in the cache */
   /* search1563_0 -> 1793 in the cache */
   /* search1563_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1793, 33 },
      -1,
   } },

   /* replace1563_0_0 -> 11 in the cache */
   /* replace1563_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4381 },
      -1,
   } },
   /* replace1563_1_0_0_0 -> 36 in the cache */
   /* replace1563_1_0_0 -> 4381 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4381 },
      -1,
   } },
   /* replace1563_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4383, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4382, 4384 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i32', ('i2i16', 'b')), 'b')) */
   /* search1564_0_0 -> 11 in the cache */
   /* search1564_0 -> 1793 in the cache */
   /* search1564_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1793, 33 },
      -1,
   } },

   /* replace1564_0_0 -> 11 in the cache */
   /* replace1564_0_1_0 -> 36 in the cache */
   /* replace1564_0_1 -> 4381 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4381 },
      -1,
   } },
   /* replace1564_1_0_0_0 -> 36 in the cache */
   /* replace1564_1_0_0 -> 4381 in the cache */
   /* replace1564_1_0 -> 4383 in the cache */
   /* replace1564_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4383, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4387, 4388 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b')))) */
   /* search1565_0_0 -> 11 in the cache */
   /* search1565_0 -> 1793 in the cache */
   /* search1565_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1793, 33 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x8000 /* -32768 */ },
   } },
   /* replace1565_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4391, 36 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1565_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4393, 36 },
      -1,
   } },
   /* replace1565_1_1_0 -> 11 in the cache */
   /* replace1565_1_1_1_0 -> 36 in the cache */
   /* replace1565_1_1_1 -> 4381 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4381 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4394, 4395 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4392, 4396 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i32', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b'))) */
   /* search1566_0 -> 288 in the cache */
   /* search1566_1_0 -> 260 in the cache */
   /* search1566_1 -> 4364 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 288, 4364 },
      -1,
   } },

   /* replace1566_0_0 -> 16 in the cache */
   /* replace1566_0_1 -> 4393 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4393 },
      -1,
   } },
   /* replace1566_1_0_0 -> 16 in the cache */
   /* replace1566_1_0_1 -> 4391 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4391 },
      -1,
   } },
   /* replace1566_1_1_0_0 -> 16 in the cache */
   /* replace1566_1_1_0 -> 4196 in the cache */
   /* replace1566_1_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4196, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4400, 4401 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4399, 4402 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b')))) */
   /* search1567_0_0 -> 11 in the cache */
   /* search1567_0 -> 1793 in the cache */
   /* search1567_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1793, 33 },
      -1,
   } },

   /* replace1567_0_0 -> 4393 in the cache */
   /* replace1567_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4393, 36 },
      -1,
   } },
   /* replace1567_1_0_0 -> 4391 in the cache */
   /* replace1567_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4391, 36 },
      -1,
   } },
   /* replace1567_1_1_0 -> 11 in the cache */
   /* replace1567_1_1_1_0 -> 36 in the cache */
   /* replace1567_1_1_1 -> 4381 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4381 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4406, 4407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4405, 4408 },
      -1,
   } },

   /* ('ige', '#a', ('i2i32', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b'))) */
   /* search1568_0 -> 288 in the cache */
   /* search1568_1_0 -> 260 in the cache */
   /* search1568_1 -> 4364 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 288, 4364 },
      -1,
   } },

   /* replace1568_0_0 -> 16 in the cache */
   /* replace1568_0_1 -> 4391 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4391 },
      -1,
   } },
   /* replace1568_1_0_0 -> 16 in the cache */
   /* replace1568_1_0_1 -> 4393 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4393 },
      -1,
   } },
   /* replace1568_1_1_0_0 -> 16 in the cache */
   /* replace1568_1_1_0 -> 4196 in the cache */
   /* replace1568_1_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4196, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4412, 4413 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4411, 4414 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1569_0_0 -> 11 in the cache */
   /* search1569_0 -> 1816 in the cache */
   /* search1569_1_0 -> 2101 in the cache */
   /* search1569_1 -> 4303 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1816, 4303 },
      -1,
   } },

   /* replace1569_0 -> 11 in the cache */
   /* replace1569_1_0 -> 2101 in the cache */
   /* replace1569_1 -> 4201 in the cache */
   /* replace1569 -> 4352 in the cache */

   /* ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1570_0_0 -> 11 in the cache */
   /* search1570_0 -> 1816 in the cache */
   /* search1570_1_0 -> 2101 in the cache */
   /* search1570_1 -> 4303 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1816, 4303 },
      -1,
   } },

   /* replace1570_0 -> 11 in the cache */
   /* replace1570_1_0 -> 2101 in the cache */
   /* replace1570_1 -> 4201 in the cache */
   /* replace1570 -> 4354 in the cache */

   /* ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1571_0_0 -> 11 in the cache */
   /* search1571_0 -> 1816 in the cache */
   /* search1571_1_0 -> 2101 in the cache */
   /* search1571_1 -> 4303 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1816, 4303 },
      -1,
   } },

   /* replace1571_0 -> 11 in the cache */
   /* replace1571_1_0 -> 2101 in the cache */
   /* replace1571_1 -> 4201 in the cache */
   /* replace1571 -> 4356 in the cache */

   /* ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1572_0_0 -> 11 in the cache */
   /* search1572_0 -> 1816 in the cache */
   /* search1572_1_0 -> 2101 in the cache */
   /* search1572_1 -> 4303 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1816, 4303 },
      -1,
   } },

   /* replace1572_0 -> 11 in the cache */
   /* replace1572_1_0 -> 2101 in the cache */
   /* replace1572_1 -> 4201 in the cache */
   /* replace1572 -> 4358 in the cache */

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1573_0_0 -> 4211 in the cache */
   /* search1573_0 -> 4308 in the cache */
   /* search1573_1_0 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 528 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4308, 4420 },
      -1,
   } },

   /* replace1573_0_0 -> 4211 in the cache */
   /* replace1573_0 -> 4212 in the cache */
   /* replace1573_1 -> 528 in the cache */
   /* replace1573 -> 4361 in the cache */

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1574_0_0 -> 4211 in the cache */
   /* search1574_0 -> 4308 in the cache */
   /* search1574_1_0 -> 528 in the cache */
   /* search1574_1 -> 4420 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4308, 4420 },
      -1,
   } },

   /* replace1574_0_0 -> 4211 in the cache */
   /* replace1574_0 -> 4212 in the cache */
   /* replace1574_1 -> 528 in the cache */
   /* replace1574 -> 4363 in the cache */

   /* ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1575_0_0 -> 11 in the cache */
   /* search1575_0 -> 1816 in the cache */
   /* search1575_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1816, 4423 },
      -1,
   } },

   /* replace1575_0 -> 11 in the cache */
   /* replace1575_1_0 -> 260 in the cache */
   /* replace1575_1 -> 4366 in the cache */
   /* replace1575 -> 4367 in the cache */

   /* ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1576_0_0 -> 11 in the cache */
   /* search1576_0 -> 1816 in the cache */
   /* search1576_1_0 -> 260 in the cache */
   /* search1576_1 -> 4423 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1816, 4423 },
      -1,
   } },

   /* replace1576_0 -> 11 in the cache */
   /* replace1576_1_0 -> 260 in the cache */
   /* replace1576_1 -> 4366 in the cache */
   /* replace1576 -> 4369 in the cache */

   /* ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1577_0_0 -> 11 in the cache */
   /* search1577_0 -> 1816 in the cache */
   /* search1577_1_0 -> 260 in the cache */
   /* search1577_1 -> 4423 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1816, 4423 },
      -1,
   } },

   /* replace1577_0 -> 11 in the cache */
   /* replace1577_1_0 -> 260 in the cache */
   /* replace1577_1 -> 4366 in the cache */
   /* replace1577 -> 4371 in the cache */

   /* ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1578_0_0 -> 11 in the cache */
   /* search1578_0 -> 1816 in the cache */
   /* search1578_1_0 -> 260 in the cache */
   /* search1578_1 -> 4423 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1816, 4423 },
      -1,
   } },

   /* replace1578_0 -> 11 in the cache */
   /* replace1578_1_0 -> 260 in the cache */
   /* replace1578_1 -> 4366 in the cache */
   /* replace1578 -> 4373 in the cache */

   /* ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1579_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 517 },
      -1,
   } },
   /* search1579_1_0 -> 528 in the cache */
   /* search1579_1 -> 4420 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4428, 4420 },
      -1,
   } },

   /* replace1579_0_0 -> 517 in the cache */
   /* replace1579_0 -> 4376 in the cache */
   /* replace1579_1 -> 528 in the cache */
   /* replace1579 -> 4377 in the cache */

   /* ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1580_0_0 -> 517 in the cache */
   /* search1580_0 -> 4428 in the cache */
   /* search1580_1_0 -> 528 in the cache */
   /* search1580_1 -> 4420 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4428, 4420 },
      -1,
   } },

   /* replace1580_0_0 -> 517 in the cache */
   /* replace1580_0 -> 4376 in the cache */
   /* replace1580_1 -> 528 in the cache */
   /* replace1580 -> 4379 in the cache */

   /* ('ieq', ('i2i64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i64', ('i2i16', 'b')), 'b')) */
   /* search1581_0_0 -> 11 in the cache */
   /* search1581_0 -> 1816 in the cache */
   /* search1581_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1816, 4312 },
      -1,
   } },

   /* replace1581_0_0 -> 11 in the cache */
   /* replace1581_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4432 },
      -1,
   } },
   /* replace1581_1_0_0_0 -> 41 in the cache */
   /* replace1581_1_0_0 -> 4432 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4432 },
      -1,
   } },
   /* replace1581_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4434, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4433, 4435 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i64', ('i2i16', 'b')), 'b')) */
   /* search1582_0_0 -> 11 in the cache */
   /* search1582_0 -> 1816 in the cache */
   /* search1582_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1816, 4312 },
      -1,
   } },

   /* replace1582_0_0 -> 11 in the cache */
   /* replace1582_0_1_0 -> 41 in the cache */
   /* replace1582_0_1 -> 4432 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4432 },
      -1,
   } },
   /* replace1582_1_0_0_0 -> 41 in the cache */
   /* replace1582_1_0_0 -> 4432 in the cache */
   /* replace1582_1_0 -> 4434 in the cache */
   /* replace1582_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4434, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4438, 4439 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b')))) */
   /* search1583_0_0 -> 11 in the cache */
   /* search1583_0 -> 1816 in the cache */
   /* search1583_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1816, 4312 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x8000 /* -32768 */ },
   } },
   /* replace1583_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4442, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1583_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4444, 41 },
      -1,
   } },
   /* replace1583_1_1_0 -> 11 in the cache */
   /* replace1583_1_1_1_0 -> 41 in the cache */
   /* replace1583_1_1_1 -> 4432 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4432 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4445, 4446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4443, 4447 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b'))) */
   /* search1584_0 -> 4331 in the cache */
   /* search1584_1_0 -> 260 in the cache */
   /* search1584_1 -> 4423 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4331, 4423 },
      -1,
   } },

   /* replace1584_0_0 -> 21 in the cache */
   /* replace1584_0_1 -> 4444 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4444 },
      -1,
   } },
   /* replace1584_1_0_0 -> 21 in the cache */
   /* replace1584_1_0_1 -> 4442 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4442 },
      -1,
   } },
   /* replace1584_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1584_1_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4452, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4451, 4453 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4450, 4454 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b')))) */
   /* search1585_0_0 -> 11 in the cache */
   /* search1585_0 -> 1816 in the cache */
   /* search1585_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1816, 4312 },
      -1,
   } },

   /* replace1585_0_0 -> 4444 in the cache */
   /* replace1585_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4444, 41 },
      -1,
   } },
   /* replace1585_1_0_0 -> 4442 in the cache */
   /* replace1585_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4442, 41 },
      -1,
   } },
   /* replace1585_1_1_0 -> 11 in the cache */
   /* replace1585_1_1_1_0 -> 41 in the cache */
   /* replace1585_1_1_1 -> 4432 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4432 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4458, 4459 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4457, 4460 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b'))) */
   /* search1586_0 -> 4331 in the cache */
   /* search1586_1_0 -> 260 in the cache */
   /* search1586_1 -> 4423 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4331, 4423 },
      -1,
   } },

   /* replace1586_0_0 -> 21 in the cache */
   /* replace1586_0_1 -> 4442 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4442 },
      -1,
   } },
   /* replace1586_1_0_0 -> 21 in the cache */
   /* replace1586_1_0_1 -> 4444 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4444 },
      -1,
   } },
   /* replace1586_1_1_0_0 -> 21 in the cache */
   /* replace1586_1_1_0 -> 4452 in the cache */
   /* replace1586_1_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4452, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4464, 4465 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4463, 4466 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1587_0_0 -> 16 in the cache */
   /* search1587_0 -> 1898 in the cache */
   /* search1587_1_0 -> 2101 in the cache */
   /* search1587_1 -> 4303 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1898, 4303 },
      -1,
   } },

   /* replace1587_0 -> 16 in the cache */
   /* replace1587_1_0 -> 2101 in the cache */
   /* replace1587_1 -> 4258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4258 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1588_0_0 -> 16 in the cache */
   /* search1588_0 -> 1898 in the cache */
   /* search1588_1_0 -> 2101 in the cache */
   /* search1588_1 -> 4303 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1898, 4303 },
      -1,
   } },

   /* replace1588_0 -> 16 in the cache */
   /* replace1588_1_0 -> 2101 in the cache */
   /* replace1588_1 -> 4258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4258 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1589_0_0 -> 16 in the cache */
   /* search1589_0 -> 1898 in the cache */
   /* search1589_1_0 -> 2101 in the cache */
   /* search1589_1 -> 4303 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1898, 4303 },
      -1,
   } },

   /* replace1589_0 -> 16 in the cache */
   /* replace1589_1_0 -> 2101 in the cache */
   /* replace1589_1 -> 4258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4258 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1590_0_0 -> 16 in the cache */
   /* search1590_0 -> 1898 in the cache */
   /* search1590_1_0 -> 2101 in the cache */
   /* search1590_1 -> 4303 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1898, 4303 },
      -1,
   } },

   /* replace1590_0 -> 16 in the cache */
   /* replace1590_1_0 -> 2101 in the cache */
   /* replace1590_1 -> 4258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4258 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1591_0_0 -> 4211 in the cache */
   /* search1591_0 -> 4308 in the cache */
   /* search1591_1_0 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 185 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4308, 4476 },
      -1,
   } },

   /* replace1591_0_0 -> 4211 in the cache */
   /* replace1591_0 -> 4263 in the cache */
   /* replace1591_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4263, 185 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1592_0_0 -> 4211 in the cache */
   /* search1592_0 -> 4308 in the cache */
   /* search1592_1_0 -> 185 in the cache */
   /* search1592_1 -> 4476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4308, 4476 },
      -1,
   } },

   /* replace1592_0_0 -> 4211 in the cache */
   /* replace1592_0 -> 4263 in the cache */
   /* replace1592_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4263, 185 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1593_0_0 -> 16 in the cache */
   /* search1593_0 -> 1898 in the cache */
   /* search1593_1_0 -> 260 in the cache */
   /* search1593_1 -> 4423 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1898, 4423 },
      -1,
   } },

   /* replace1593_0 -> 16 in the cache */
   /* replace1593_1_0 -> 260 in the cache */
   /* replace1593_1 -> 4364 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4364 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1594_0_0 -> 16 in the cache */
   /* search1594_0 -> 1898 in the cache */
   /* search1594_1_0 -> 260 in the cache */
   /* search1594_1 -> 4423 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1898, 4423 },
      -1,
   } },

   /* replace1594_0 -> 16 in the cache */
   /* replace1594_1_0 -> 260 in the cache */
   /* replace1594_1 -> 4364 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4364 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1595_0_0 -> 16 in the cache */
   /* search1595_0 -> 1898 in the cache */
   /* search1595_1_0 -> 260 in the cache */
   /* search1595_1 -> 4423 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1898, 4423 },
      -1,
   } },

   /* replace1595_0 -> 16 in the cache */
   /* replace1595_1_0 -> 260 in the cache */
   /* replace1595_1 -> 4364 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4364 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1596_0_0 -> 16 in the cache */
   /* search1596_0 -> 1898 in the cache */
   /* search1596_1_0 -> 260 in the cache */
   /* search1596_1 -> 4423 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1898, 4423 },
      -1,
   } },

   /* replace1596_0 -> 16 in the cache */
   /* replace1596_1_0 -> 260 in the cache */
   /* replace1596_1 -> 4364 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4364 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1597_0_0 -> 517 in the cache */
   /* search1597_0 -> 4428 in the cache */
   /* search1597_1_0 -> 185 in the cache */
   /* search1597_1 -> 4476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4428, 4476 },
      -1,
   } },

   /* replace1597_0_0 -> 517 in the cache */
   /* replace1597_0 -> 4374 in the cache */
   /* replace1597_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4374, 185 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1598_0_0 -> 517 in the cache */
   /* search1598_0 -> 4428 in the cache */
   /* search1598_1_0 -> 185 in the cache */
   /* search1598_1 -> 4476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4428, 4476 },
      -1,
   } },

   /* replace1598_0_0 -> 517 in the cache */
   /* replace1598_0 -> 4374 in the cache */
   /* replace1598_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4374, 185 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1599_0_0 -> 16 in the cache */
   /* search1599_0 -> 1898 in the cache */
   /* search1599_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1898, 4493 },
      -1,
   } },

   /* replace1599_0 -> 16 in the cache */
   /* replace1599_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4495 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1600_0_0 -> 16 in the cache */
   /* search1600_0 -> 1898 in the cache */
   /* search1600_1_0 -> 36 in the cache */
   /* search1600_1 -> 4493 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1898, 4493 },
      -1,
   } },

   /* replace1600_0 -> 16 in the cache */
   /* replace1600_1_0 -> 36 in the cache */
   /* replace1600_1 -> 4495 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4495 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1601_0_0 -> 16 in the cache */
   /* search1601_0 -> 1898 in the cache */
   /* search1601_1_0 -> 36 in the cache */
   /* search1601_1 -> 4493 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1898, 4493 },
      -1,
   } },

   /* replace1601_0 -> 16 in the cache */
   /* replace1601_1_0 -> 36 in the cache */
   /* replace1601_1 -> 4495 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4495 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1602_0_0 -> 16 in the cache */
   /* search1602_0 -> 1898 in the cache */
   /* search1602_1_0 -> 36 in the cache */
   /* search1602_1 -> 4493 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1898, 4493 },
      -1,
   } },

   /* replace1602_0 -> 16 in the cache */
   /* replace1602_1_0 -> 36 in the cache */
   /* replace1602_1 -> 4495 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4495 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1603_0_0 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 375 },
      -1,
   } },
   /* search1603_1_0 -> 185 in the cache */
   /* search1603_1 -> 4476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4503, 4476 },
      -1,
   } },

   /* replace1603_0_0 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 375 },
      -1,
   } },
   /* replace1603_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4505, 185 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1604_0_0 -> 375 in the cache */
   /* search1604_0 -> 4503 in the cache */
   /* search1604_1_0 -> 185 in the cache */
   /* search1604_1 -> 4476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4503, 4476 },
      -1,
   } },

   /* replace1604_0_0 -> 375 in the cache */
   /* replace1604_0 -> 4505 in the cache */
   /* replace1604_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4505, 185 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('i2i32', 'b')), ('ieq', ('i2i64', ('i2i32', 'b')), 'b')) */
   /* search1605_0_0 -> 16 in the cache */
   /* search1605_0 -> 1898 in the cache */
   /* search1605_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1898, 4312 },
      -1,
   } },

   /* replace1605_0_0 -> 16 in the cache */
   /* replace1605_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 16, 4510 },
      -1,
   } },
   /* replace1605_1_0_0_0 -> 41 in the cache */
   /* replace1605_1_0_0 -> 4510 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4510 },
      -1,
   } },
   /* replace1605_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4512, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4511, 4513 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('i2i32', 'b')), ('ine', ('i2i64', ('i2i32', 'b')), 'b')) */
   /* search1606_0_0 -> 16 in the cache */
   /* search1606_0 -> 1898 in the cache */
   /* search1606_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1898, 4312 },
      -1,
   } },

   /* replace1606_0_0 -> 16 in the cache */
   /* replace1606_0_1_0 -> 41 in the cache */
   /* replace1606_0_1 -> 4510 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 16, 4510 },
      -1,
   } },
   /* replace1606_1_0_0_0 -> 41 in the cache */
   /* replace1606_1_0_0 -> 4510 in the cache */
   /* replace1606_1_0 -> 4512 in the cache */
   /* replace1606_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4512, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4516, 4517 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), '#b') => ('iand', ('ilt', -2147483648, 'b'), ('ior', ('ilt', 2147483647, 'b'), ('ilt', 'a', ('i2i32', 'b')))) */
   /* search1607_0_0 -> 16 in the cache */
   /* search1607_0 -> 1898 in the cache */
   /* search1607_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1898, 4312 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x80000000 /* -2147483648 */ },
   } },
   /* replace1607_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4520, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fffffff /* 2147483647 */ },
   } },
   /* replace1607_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4522, 41 },
      -1,
   } },
   /* replace1607_1_1_0 -> 16 in the cache */
   /* replace1607_1_1_1_0 -> 41 in the cache */
   /* replace1607_1_1_1 -> 4510 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4510 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4523, 4524 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4521, 4525 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@32')) => ('iand', ('ilt', 'a', 2147483647), ('ior', ('ilt', 'a', -2147483648), ('ilt', ('i2i32', 'a'), 'b'))) */
   /* search1608_0 -> 4331 in the cache */
   /* search1608_1_0 -> 36 in the cache */
   /* search1608_1 -> 4493 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4331, 4493 },
      -1,
   } },

   /* replace1608_0_0 -> 21 in the cache */
   /* replace1608_0_1 -> 4522 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4522 },
      -1,
   } },
   /* replace1608_1_0_0 -> 21 in the cache */
   /* replace1608_1_0_1 -> 4520 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4520 },
      -1,
   } },
   /* replace1608_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1608_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4530, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4529, 4531 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4528, 4532 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), '#b') => ('iand', ('ige', 2147483647, 'b'), ('ior', ('ige', -2147483648, 'b'), ('ige', 'a', ('i2i32', 'b')))) */
   /* search1609_0_0 -> 16 in the cache */
   /* search1609_0 -> 1898 in the cache */
   /* search1609_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1898, 4312 },
      -1,
   } },

   /* replace1609_0_0 -> 4522 in the cache */
   /* replace1609_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4522, 41 },
      -1,
   } },
   /* replace1609_1_0_0 -> 4520 in the cache */
   /* replace1609_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4520, 41 },
      -1,
   } },
   /* replace1609_1_1_0 -> 16 in the cache */
   /* replace1609_1_1_1_0 -> 41 in the cache */
   /* replace1609_1_1_1 -> 4510 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4510 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4536, 4537 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4535, 4538 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@32')) => ('iand', ('ige', 'a', -2147483648), ('ior', ('ige', 'a', 2147483647), ('ige', ('i2i32', 'a'), 'b'))) */
   /* search1610_0 -> 4331 in the cache */
   /* search1610_1_0 -> 36 in the cache */
   /* search1610_1 -> 4493 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4331, 4493 },
      -1,
   } },

   /* replace1610_0_0 -> 21 in the cache */
   /* replace1610_0_1 -> 4520 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4520 },
      -1,
   } },
   /* replace1610_1_0_0 -> 21 in the cache */
   /* replace1610_1_0_1 -> 4522 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4522 },
      -1,
   } },
   /* replace1610_1_1_0_0 -> 21 in the cache */
   /* replace1610_1_1_0 -> 4530 in the cache */
   /* replace1610_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4530, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4542, 4543 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4541, 4544 },
      -1,
   } },

   /* ('ieq', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1611_0_0 -> 6 in the cache */
   /* search1611_0 -> 4141 in the cache */
   /* search1611_1_0 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4141, 4546 },
      -1,
   } },

   /* replace1611_0 -> 6 in the cache */
   /* replace1611_1_0 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 6, 4548 },
      -1,
   } },

   /* ('ine', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1612_0_0 -> 6 in the cache */
   /* search1612_0 -> 4141 in the cache */
   /* search1612_1_0 -> 2101 in the cache */
   /* search1612_1 -> 4546 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4141, 4546 },
      -1,
   } },

   /* replace1612_0 -> 6 in the cache */
   /* replace1612_1_0 -> 2101 in the cache */
   /* replace1612_1 -> 4548 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 6, 4548 },
      -1,
   } },

   /* ('uge', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1613_0_0 -> 6 in the cache */
   /* search1613_0 -> 4141 in the cache */
   /* search1613_1_0 -> 2101 in the cache */
   /* search1613_1 -> 4546 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4141, 4546 },
      -1,
   } },

   /* replace1613_0 -> 6 in the cache */
   /* replace1613_1_0 -> 2101 in the cache */
   /* replace1613_1 -> 4548 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 4548 },
      -1,
   } },

   /* ('ult', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1614_0_0 -> 6 in the cache */
   /* search1614_0 -> 4141 in the cache */
   /* search1614_1_0 -> 2101 in the cache */
   /* search1614_1 -> 4546 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4141, 4546 },
      -1,
   } },

   /* replace1614_0 -> 6 in the cache */
   /* replace1614_1_0 -> 2101 in the cache */
   /* replace1614_1 -> 4548 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 4548 },
      -1,
   } },

   /* ('uge', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1615_0_0 -> 4211 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4211 },
      -1,
   } },
   /* search1615_1_0 -> 4213 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4213 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4556, 4557 },
      -1,
   } },

   /* replace1615_0_0 -> 4211 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4211 },
      -1,
   } },
   /* replace1615_1 -> 4213 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4559, 4213 },
      -1,
   } },

   /* ('ult', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1616_0_0 -> 4211 in the cache */
   /* search1616_0 -> 4556 in the cache */
   /* search1616_1_0 -> 4213 in the cache */
   /* search1616_1 -> 4557 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4556, 4557 },
      -1,
   } },

   /* replace1616_0_0 -> 4211 in the cache */
   /* replace1616_0 -> 4559 in the cache */
   /* replace1616_1 -> 4213 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4559, 4213 },
      -1,
   } },

   /* ('ieq', ('u2u16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u16', ('u2u8', 'b')), 'b')) */
   /* search1617_0_0 -> 6 in the cache */
   /* search1617_0 -> 4141 in the cache */
   /* search1617_1 -> 2000 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4141, 2000 },
      -1,
   } },

   /* replace1617_0_0 -> 6 in the cache */
   /* replace1617_0_1_0 -> 260 in the cache */
   /* replace1617_0_1 -> 2008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 2008 },
      -1,
   } },
   /* replace1617_1_0_0_0 -> 260 in the cache */
   /* replace1617_1_0_0 -> 2008 in the cache */
   /* replace1617_1_0 -> 2009 in the cache */
   /* replace1617_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 2009, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4564, 4565 },
      -1,
   } },

   /* ('ine', ('u2u16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u16', ('u2u8', 'b')), 'b')) */
   /* search1618_0_0 -> 6 in the cache */
   /* search1618_0 -> 4141 in the cache */
   /* search1618_1 -> 2000 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4141, 2000 },
      -1,
   } },

   /* replace1618_0_0 -> 6 in the cache */
   /* replace1618_0_1_0 -> 260 in the cache */
   /* replace1618_0_1 -> 2008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 2008 },
      -1,
   } },
   /* replace1618_1_0_0_0 -> 260 in the cache */
   /* replace1618_1_0_0 -> 2008 in the cache */
   /* replace1618_1_0 -> 2009 in the cache */
   /* replace1618_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 2009, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4568, 4569 },
      -1,
   } },

   /* ('ult', ('u2u16', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1619_0_0 -> 6 in the cache */
   /* search1619_0 -> 4141 in the cache */
   /* search1619_1 -> 2000 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4141, 2000 },
      -1,
   } },

   /* replace1619_0_0 -> 849 in the cache */
   /* replace1619_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 849, 260 },
      -1,
   } },
   /* replace1619_1_0_0 -> 2002 in the cache */
   /* replace1619_1_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2002, 260 },
      -1,
   } },
   /* replace1619_1_1_0 -> 6 in the cache */
   /* replace1619_1_1_1_0 -> 260 in the cache */
   /* replace1619_1_1_1 -> 2008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 2008 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4573, 4574 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4572, 4575 },
      -1,
   } },

   /* ('ult', '#a', ('u2u16', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1620_0 -> 4238 in the cache */
   /* search1620_1_0 -> 2101 in the cache */
   /* search1620_1 -> 4546 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4238, 4546 },
      -1,
   } },

   /* replace1620_0_0 -> 11 in the cache */
   /* replace1620_0_1 -> 2002 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 2002 },
      -1,
   } },
   /* replace1620_1_0_0 -> 11 in the cache */
   /* replace1620_1_0_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 849 },
      -1,
   } },
   /* replace1620_1_1_0_0 -> 11 in the cache */
   /* replace1620_1_1_0 -> 1998 in the cache */
   /* replace1620_1_1_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1998, 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4579, 4580 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4578, 4581 },
      -1,
   } },

   /* ('uge', ('u2u16', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1621_0_0 -> 6 in the cache */
   /* search1621_0 -> 4141 in the cache */
   /* search1621_1 -> 2000 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4141, 2000 },
      -1,
   } },

   /* replace1621_0_0 -> 2002 in the cache */
   /* replace1621_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2002, 260 },
      -1,
   } },
   /* replace1621_1_0_0 -> 849 in the cache */
   /* replace1621_1_0_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 849, 260 },
      -1,
   } },
   /* replace1621_1_1_0 -> 6 in the cache */
   /* replace1621_1_1_1_0 -> 260 in the cache */
   /* replace1621_1_1_1 -> 2008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 2008 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4585, 4586 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4584, 4587 },
      -1,
   } },

   /* ('uge', '#a', ('u2u16', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1622_0 -> 4238 in the cache */
   /* search1622_1_0 -> 2101 in the cache */
   /* search1622_1 -> 4546 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4238, 4546 },
      -1,
   } },

   /* replace1622_0_0 -> 11 in the cache */
   /* replace1622_0_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 849 },
      -1,
   } },
   /* replace1622_1_0_0 -> 11 in the cache */
   /* replace1622_1_0_1 -> 2002 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 2002 },
      -1,
   } },
   /* replace1622_1_1_0_0 -> 11 in the cache */
   /* replace1622_1_1_0 -> 1998 in the cache */
   /* replace1622_1_1_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1998, 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4591, 4592 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4590, 4593 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1623_0_0 -> 6 in the cache */
   /* search1623_0 -> 3210 in the cache */
   /* search1623_1_0 -> 2101 in the cache */
   /* search1623_1 -> 3212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3210, 3212 },
      -1,
   } },

   /* replace1623_0 -> 6 in the cache */
   /* replace1623_1_0 -> 2101 in the cache */
   /* replace1623_1 -> 4548 in the cache */
   /* replace1623 -> 4549 in the cache */

   /* ('ine', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1624_0_0 -> 6 in the cache */
   /* search1624_0 -> 3210 in the cache */
   /* search1624_1_0 -> 2101 in the cache */
   /* search1624_1 -> 3212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3210, 3212 },
      -1,
   } },

   /* replace1624_0 -> 6 in the cache */
   /* replace1624_1_0 -> 2101 in the cache */
   /* replace1624_1 -> 4548 in the cache */
   /* replace1624 -> 4551 in the cache */

   /* ('uge', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1625_0_0 -> 6 in the cache */
   /* search1625_0 -> 3210 in the cache */
   /* search1625_1_0 -> 2101 in the cache */
   /* search1625_1 -> 3212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3210, 3212 },
      -1,
   } },

   /* replace1625_0 -> 6 in the cache */
   /* replace1625_1_0 -> 2101 in the cache */
   /* replace1625_1 -> 4548 in the cache */
   /* replace1625 -> 4553 in the cache */

   /* ('ult', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1626_0_0 -> 6 in the cache */
   /* search1626_0 -> 3210 in the cache */
   /* search1626_1_0 -> 2101 in the cache */
   /* search1626_1 -> 3212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3210, 3212 },
      -1,
   } },

   /* replace1626_0 -> 6 in the cache */
   /* replace1626_1_0 -> 2101 in the cache */
   /* replace1626_1 -> 4548 in the cache */
   /* replace1626 -> 4555 in the cache */

   /* ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1627_0_0 -> 4211 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4211 },
      -1,
   } },
   /* search1627_1_0 -> 4213 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4213 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4599, 4600 },
      -1,
   } },

   /* replace1627_0_0 -> 4211 in the cache */
   /* replace1627_0 -> 4559 in the cache */
   /* replace1627_1 -> 4213 in the cache */
   /* replace1627 -> 4560 in the cache */

   /* ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1628_0_0 -> 4211 in the cache */
   /* search1628_0 -> 4599 in the cache */
   /* search1628_1_0 -> 4213 in the cache */
   /* search1628_1 -> 4600 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4599, 4600 },
      -1,
   } },

   /* replace1628_0_0 -> 4211 in the cache */
   /* replace1628_0 -> 4559 in the cache */
   /* replace1628_1 -> 4213 in the cache */
   /* replace1628 -> 4562 in the cache */

   /* ('ieq', ('u2u32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u32', ('u2u8', 'b')), 'b')) */
   /* search1629_0_0 -> 6 in the cache */
   /* search1629_0 -> 3210 in the cache */
   /* search1629_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3210, 33 },
      -1,
   } },

   /* replace1629_0_0 -> 6 in the cache */
   /* replace1629_0_1_0 -> 36 in the cache */
   /* replace1629_0_1 -> 2016 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 2016 },
      -1,
   } },
   /* replace1629_1_0_0_0 -> 36 in the cache */
   /* replace1629_1_0_0 -> 2016 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2016 },
      -1,
   } },
   /* replace1629_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4605, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4604, 4606 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u32', ('u2u8', 'b')), 'b')) */
   /* search1630_0_0 -> 6 in the cache */
   /* search1630_0 -> 3210 in the cache */
   /* search1630_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3210, 33 },
      -1,
   } },

   /* replace1630_0_0 -> 6 in the cache */
   /* replace1630_0_1_0 -> 36 in the cache */
   /* replace1630_0_1 -> 2016 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 2016 },
      -1,
   } },
   /* replace1630_1_0_0_0 -> 36 in the cache */
   /* replace1630_1_0_0 -> 2016 in the cache */
   /* replace1630_1_0 -> 4605 in the cache */
   /* replace1630_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4605, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4609, 4610 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1631_0_0 -> 6 in the cache */
   /* search1631_0 -> 3210 in the cache */
   /* search1631_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3210, 33 },
      -1,
   } },

   /* replace1631_0_0 -> 124 in the cache */
   /* replace1631_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 124, 36 },
      -1,
   } },
   /* replace1631_1_0_0 -> 1003 in the cache */
   /* replace1631_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1003, 36 },
      -1,
   } },
   /* replace1631_1_1_0 -> 6 in the cache */
   /* replace1631_1_1_1_0 -> 36 in the cache */
   /* replace1631_1_1_1 -> 2016 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 2016 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4614, 4615 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4613, 4616 },
      -1,
   } },

   /* ('ult', '#a', ('u2u32', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1632_0 -> 288 in the cache */
   /* search1632_1_0 -> 2101 in the cache */
   /* search1632_1 -> 3212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 288, 3212 },
      -1,
   } },

   /* replace1632_0_0 -> 16 in the cache */
   /* replace1632_0_1 -> 1003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 1003 },
      -1,
   } },
   /* replace1632_1_0_0 -> 16 in the cache */
   /* replace1632_1_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 124 },
      -1,
   } },
   /* replace1632_1_1_0_0 -> 16 in the cache */
   /* replace1632_1_1_0 -> 2014 in the cache */
   /* replace1632_1_1_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2014, 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4620, 4621 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4619, 4622 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1633_0_0 -> 6 in the cache */
   /* search1633_0 -> 3210 in the cache */
   /* search1633_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3210, 33 },
      -1,
   } },

   /* replace1633_0_0 -> 1003 in the cache */
   /* replace1633_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1003, 36 },
      -1,
   } },
   /* replace1633_1_0_0 -> 124 in the cache */
   /* replace1633_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 124, 36 },
      -1,
   } },
   /* replace1633_1_1_0 -> 6 in the cache */
   /* replace1633_1_1_1_0 -> 36 in the cache */
   /* replace1633_1_1_1 -> 2016 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 2016 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4626, 4627 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4625, 4628 },
      -1,
   } },

   /* ('uge', '#a', ('u2u32', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1634_0 -> 288 in the cache */
   /* search1634_1_0 -> 2101 in the cache */
   /* search1634_1 -> 3212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 288, 3212 },
      -1,
   } },

   /* replace1634_0_0 -> 16 in the cache */
   /* replace1634_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 124 },
      -1,
   } },
   /* replace1634_1_0_0 -> 16 in the cache */
   /* replace1634_1_0_1 -> 1003 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 1003 },
      -1,
   } },
   /* replace1634_1_1_0_0 -> 16 in the cache */
   /* replace1634_1_1_0 -> 2014 in the cache */
   /* replace1634_1_1_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2014, 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4632, 4633 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4631, 4634 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1635_0_0 -> 6 in the cache */
   /* search1635_0 -> 4178 in the cache */
   /* search1635_1_0 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4178, 4636 },
      -1,
   } },

   /* replace1635_0 -> 6 in the cache */
   /* replace1635_1_0 -> 2101 in the cache */
   /* replace1635_1 -> 4548 in the cache */
   /* replace1635 -> 4549 in the cache */

   /* ('ine', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1636_0_0 -> 6 in the cache */
   /* search1636_0 -> 4178 in the cache */
   /* search1636_1_0 -> 2101 in the cache */
   /* search1636_1 -> 4636 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4178, 4636 },
      -1,
   } },

   /* replace1636_0 -> 6 in the cache */
   /* replace1636_1_0 -> 2101 in the cache */
   /* replace1636_1 -> 4548 in the cache */
   /* replace1636 -> 4551 in the cache */

   /* ('uge', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1637_0_0 -> 6 in the cache */
   /* search1637_0 -> 4178 in the cache */
   /* search1637_1_0 -> 2101 in the cache */
   /* search1637_1 -> 4636 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4178, 4636 },
      -1,
   } },

   /* replace1637_0 -> 6 in the cache */
   /* replace1637_1_0 -> 2101 in the cache */
   /* replace1637_1 -> 4548 in the cache */
   /* replace1637 -> 4553 in the cache */

   /* ('ult', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1638_0_0 -> 6 in the cache */
   /* search1638_0 -> 4178 in the cache */
   /* search1638_1_0 -> 2101 in the cache */
   /* search1638_1 -> 4636 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4178, 4636 },
      -1,
   } },

   /* replace1638_0 -> 6 in the cache */
   /* replace1638_1_0 -> 2101 in the cache */
   /* replace1638_1 -> 4548 in the cache */
   /* replace1638 -> 4555 in the cache */

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1639_0_0 -> 4211 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4211 },
      -1,
   } },
   /* search1639_1_0 -> 4213 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4213 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4641, 4642 },
      -1,
   } },

   /* replace1639_0_0 -> 4211 in the cache */
   /* replace1639_0 -> 4559 in the cache */
   /* replace1639_1 -> 4213 in the cache */
   /* replace1639 -> 4560 in the cache */

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1640_0_0 -> 4211 in the cache */
   /* search1640_0 -> 4641 in the cache */
   /* search1640_1_0 -> 4213 in the cache */
   /* search1640_1 -> 4642 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4641, 4642 },
      -1,
   } },

   /* replace1640_0_0 -> 4211 in the cache */
   /* replace1640_0 -> 4559 in the cache */
   /* replace1640_1 -> 4213 in the cache */
   /* replace1640 -> 4562 in the cache */

   /* ('ieq', ('u2u64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u64', ('u2u8', 'b')), 'b')) */
   /* search1641_0_0 -> 6 in the cache */
   /* search1641_0 -> 4178 in the cache */
   /* search1641_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4178, 4312 },
      -1,
   } },

   /* replace1641_0_0 -> 6 in the cache */
   /* replace1641_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 4646 },
      -1,
   } },
   /* replace1641_1_0_0_0 -> 41 in the cache */
   /* replace1641_1_0_0 -> 4646 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4646 },
      -1,
   } },
   /* replace1641_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4648, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4647, 4649 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u64', ('u2u8', 'b')), 'b')) */
   /* search1642_0_0 -> 6 in the cache */
   /* search1642_0 -> 4178 in the cache */
   /* search1642_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4178, 4312 },
      -1,
   } },

   /* replace1642_0_0 -> 6 in the cache */
   /* replace1642_0_1_0 -> 41 in the cache */
   /* replace1642_0_1 -> 4646 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 4646 },
      -1,
   } },
   /* replace1642_1_0_0_0 -> 41 in the cache */
   /* replace1642_1_0_0 -> 4646 in the cache */
   /* replace1642_1_0 -> 4648 in the cache */
   /* replace1642_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4648, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4652, 4653 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1643_0_0 -> 6 in the cache */
   /* search1643_0 -> 4178 in the cache */
   /* search1643_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4178, 4312 },
      -1,
   } },

   /* replace1643_0_0 -> 890 in the cache */
   /* replace1643_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 890, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   /* replace1643_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4657, 41 },
      -1,
   } },
   /* replace1643_1_1_0 -> 6 in the cache */
   /* replace1643_1_1_1_0 -> 41 in the cache */
   /* replace1643_1_1_1 -> 4646 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 4646 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4658, 4659 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4656, 4660 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1644_0 -> 4331 in the cache */
   /* search1644_1_0 -> 2101 in the cache */
   /* search1644_1 -> 4636 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4331, 4636 },
      -1,
   } },

   /* replace1644_0_0 -> 21 in the cache */
   /* replace1644_0_1 -> 4657 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 4657 },
      -1,
   } },
   /* replace1644_1_0_0 -> 21 in the cache */
   /* replace1644_1_0_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 890 },
      -1,
   } },
   /* replace1644_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1644_1_1_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4665, 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4664, 4666 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4663, 4667 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1645_0_0 -> 6 in the cache */
   /* search1645_0 -> 4178 in the cache */
   /* search1645_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4178, 4312 },
      -1,
   } },

   /* replace1645_0_0 -> 4657 in the cache */
   /* replace1645_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4657, 41 },
      -1,
   } },
   /* replace1645_1_0_0 -> 890 in the cache */
   /* replace1645_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 890, 41 },
      -1,
   } },
   /* replace1645_1_1_0 -> 6 in the cache */
   /* replace1645_1_1_1_0 -> 41 in the cache */
   /* replace1645_1_1_1 -> 4646 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 4646 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4671, 4672 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4670, 4673 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1646_0 -> 4331 in the cache */
   /* search1646_1_0 -> 2101 in the cache */
   /* search1646_1 -> 4636 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4331, 4636 },
      -1,
   } },

   /* replace1646_0_0 -> 21 in the cache */
   /* replace1646_0_1 -> 890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 890 },
      -1,
   } },
   /* replace1646_1_0_0 -> 21 in the cache */
   /* replace1646_1_0_1 -> 4657 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 4657 },
      -1,
   } },
   /* replace1646_1_1_0_0 -> 21 in the cache */
   /* replace1646_1_1_0 -> 4665 in the cache */
   /* replace1646_1_1_1 -> 2101 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4665, 2101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4677, 4678 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4676, 4679 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1647_0_0 -> 11 in the cache */
   /* search1647_0 -> 1795 in the cache */
   /* search1647_1_0 -> 2101 in the cache */
   /* search1647_1 -> 3212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1795, 3212 },
      -1,
   } },

   /* replace1647_0 -> 11 in the cache */
   /* replace1647_1_0 -> 2101 in the cache */
   /* replace1647_1 -> 4546 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4546 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1648_0_0 -> 11 in the cache */
   /* search1648_0 -> 1795 in the cache */
   /* search1648_1_0 -> 2101 in the cache */
   /* search1648_1 -> 3212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1795, 3212 },
      -1,
   } },

   /* replace1648_0 -> 11 in the cache */
   /* replace1648_1_0 -> 2101 in the cache */
   /* replace1648_1 -> 4546 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4546 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1649_0_0 -> 11 in the cache */
   /* search1649_0 -> 1795 in the cache */
   /* search1649_1_0 -> 2101 in the cache */
   /* search1649_1 -> 3212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1795, 3212 },
      -1,
   } },

   /* replace1649_0 -> 11 in the cache */
   /* replace1649_1_0 -> 2101 in the cache */
   /* replace1649_1 -> 4546 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4546 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1650_0_0 -> 11 in the cache */
   /* search1650_0 -> 1795 in the cache */
   /* search1650_1_0 -> 2101 in the cache */
   /* search1650_1 -> 3212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1795, 3212 },
      -1,
   } },

   /* replace1650_0 -> 11 in the cache */
   /* replace1650_1_0 -> 2101 in the cache */
   /* replace1650_1 -> 4546 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4546 },
      -1,
   } },

   /* ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1651_0_0 -> 4211 in the cache */
   /* search1651_0 -> 4599 in the cache */
   /* search1651_1_0 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 528 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4599, 4689 },
      -1,
   } },

   /* replace1651_0_0 -> 4211 in the cache */
   /* replace1651_0 -> 4556 in the cache */
   /* replace1651_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4556, 528 },
      -1,
   } },

   /* ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1652_0_0 -> 4211 in the cache */
   /* search1652_0 -> 4599 in the cache */
   /* search1652_1_0 -> 528 in the cache */
   /* search1652_1 -> 4689 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4599, 4689 },
      -1,
   } },

   /* replace1652_0_0 -> 4211 in the cache */
   /* replace1652_0 -> 4556 in the cache */
   /* replace1652_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4556, 528 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1653_0_0 -> 11 in the cache */
   /* search1653_0 -> 1795 in the cache */
   /* search1653_1_0 -> 260 in the cache */
   /* search1653_1 -> 3232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1795, 3232 },
      -1,
   } },

   /* replace1653_0 -> 11 in the cache */
   /* replace1653_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4695 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1654_0_0 -> 11 in the cache */
   /* search1654_0 -> 1795 in the cache */
   /* search1654_1_0 -> 260 in the cache */
   /* search1654_1 -> 3232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1795, 3232 },
      -1,
   } },

   /* replace1654_0 -> 11 in the cache */
   /* replace1654_1_0 -> 260 in the cache */
   /* replace1654_1 -> 4695 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4695 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1655_0_0 -> 11 in the cache */
   /* search1655_0 -> 1795 in the cache */
   /* search1655_1_0 -> 260 in the cache */
   /* search1655_1 -> 3232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1795, 3232 },
      -1,
   } },

   /* replace1655_0 -> 11 in the cache */
   /* replace1655_1_0 -> 260 in the cache */
   /* replace1655_1 -> 4695 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4695 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1656_0_0 -> 11 in the cache */
   /* search1656_0 -> 1795 in the cache */
   /* search1656_1_0 -> 260 in the cache */
   /* search1656_1 -> 3232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1795, 3232 },
      -1,
   } },

   /* replace1656_0 -> 11 in the cache */
   /* replace1656_1_0 -> 260 in the cache */
   /* replace1656_1 -> 4695 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4695 },
      -1,
   } },

   /* ('uge', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1657_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 517 },
      -1,
   } },
   /* search1657_1_0 -> 528 in the cache */
   /* search1657_1 -> 4689 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4703, 4689 },
      -1,
   } },

   /* replace1657_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 517 },
      -1,
   } },
   /* replace1657_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4705, 528 },
      -1,
   } },

   /* ('ult', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1658_0_0 -> 517 in the cache */
   /* search1658_0 -> 4703 in the cache */
   /* search1658_1_0 -> 528 in the cache */
   /* search1658_1 -> 4689 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4703, 4689 },
      -1,
   } },

   /* replace1658_0_0 -> 517 in the cache */
   /* replace1658_0 -> 4705 in the cache */
   /* replace1658_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4705, 528 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u32', ('u2u16', 'b')), 'b')) */
   /* search1659_0_0 -> 11 in the cache */
   /* search1659_0 -> 1795 in the cache */
   /* search1659_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1795, 33 },
      -1,
   } },

   /* replace1659_0_0 -> 11 in the cache */
   /* replace1659_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4710 },
      -1,
   } },
   /* replace1659_1_0_0_0 -> 36 in the cache */
   /* replace1659_1_0_0 -> 4710 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4710 },
      -1,
   } },
   /* replace1659_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4712, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4711, 4713 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u32', ('u2u16', 'b')), 'b')) */
   /* search1660_0_0 -> 11 in the cache */
   /* search1660_0 -> 1795 in the cache */
   /* search1660_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1795, 33 },
      -1,
   } },

   /* replace1660_0_0 -> 11 in the cache */
   /* replace1660_0_1_0 -> 36 in the cache */
   /* replace1660_0_1 -> 4710 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4710 },
      -1,
   } },
   /* replace1660_1_0_0_0 -> 36 in the cache */
   /* replace1660_1_0_0 -> 4710 in the cache */
   /* replace1660_1_0 -> 4712 in the cache */
   /* replace1660_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4712, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4716, 4717 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b')))) */
   /* search1661_0_0 -> 11 in the cache */
   /* search1661_0 -> 1795 in the cache */
   /* search1661_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1795, 33 },
      -1,
   } },

   /* replace1661_0_0 -> 124 in the cache */
   /* replace1661_0_1 -> 36 in the cache */
   /* replace1661_0 -> 4613 in the cache */
   /* replace1661_1_0_0 -> 995 in the cache */
   /* replace1661_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 995, 36 },
      -1,
   } },
   /* replace1661_1_1_0 -> 11 in the cache */
   /* replace1661_1_1_1_0 -> 36 in the cache */
   /* replace1661_1_1_1 -> 4710 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4710 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4720, 4721 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4613, 4722 },
      -1,
   } },

   /* ('ult', '#a', ('u2u32', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b'))) */
   /* search1662_0 -> 288 in the cache */
   /* search1662_1_0 -> 260 in the cache */
   /* search1662_1 -> 3232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 288, 3232 },
      -1,
   } },

   /* replace1662_0_0 -> 16 in the cache */
   /* replace1662_0_1 -> 995 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 995 },
      -1,
   } },
   /* replace1662_1_0_0 -> 16 in the cache */
   /* replace1662_1_0_1 -> 124 in the cache */
   /* replace1662_1_0 -> 4620 in the cache */
   /* replace1662_1_1_0_0 -> 16 in the cache */
   /* replace1662_1_1_0 -> 3238 in the cache */
   /* replace1662_1_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3238, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4620, 4726 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4725, 4727 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b')))) */
   /* search1663_0_0 -> 11 in the cache */
   /* search1663_0 -> 1795 in the cache */
   /* search1663_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1795, 33 },
      -1,
   } },

   /* replace1663_0_0 -> 995 in the cache */
   /* replace1663_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 995, 36 },
      -1,
   } },
   /* replace1663_1_0_0 -> 124 in the cache */
   /* replace1663_1_0_1 -> 36 in the cache */
   /* replace1663_1_0 -> 4626 in the cache */
   /* replace1663_1_1_0 -> 11 in the cache */
   /* replace1663_1_1_1_0 -> 36 in the cache */
   /* replace1663_1_1_1 -> 4710 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4710 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4626, 4731 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4730, 4732 },
      -1,
   } },

   /* ('uge', '#a', ('u2u32', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b'))) */
   /* search1664_0 -> 288 in the cache */
   /* search1664_1_0 -> 260 in the cache */
   /* search1664_1 -> 3232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 288, 3232 },
      -1,
   } },

   /* replace1664_0_0 -> 16 in the cache */
   /* replace1664_0_1 -> 124 in the cache */
   /* replace1664_0 -> 4631 in the cache */
   /* replace1664_1_0_0 -> 16 in the cache */
   /* replace1664_1_0_1 -> 995 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 995 },
      -1,
   } },
   /* replace1664_1_1_0_0 -> 16 in the cache */
   /* replace1664_1_1_0 -> 3238 in the cache */
   /* replace1664_1_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3238, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4735, 4736 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4631, 4737 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1665_0_0 -> 11 in the cache */
   /* search1665_0 -> 1818 in the cache */
   /* search1665_1_0 -> 2101 in the cache */
   /* search1665_1 -> 4636 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1818, 4636 },
      -1,
   } },

   /* replace1665_0 -> 11 in the cache */
   /* replace1665_1_0 -> 2101 in the cache */
   /* replace1665_1 -> 4546 in the cache */
   /* replace1665 -> 4682 in the cache */

   /* ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1666_0_0 -> 11 in the cache */
   /* search1666_0 -> 1818 in the cache */
   /* search1666_1_0 -> 2101 in the cache */
   /* search1666_1 -> 4636 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1818, 4636 },
      -1,
   } },

   /* replace1666_0 -> 11 in the cache */
   /* replace1666_1_0 -> 2101 in the cache */
   /* replace1666_1 -> 4546 in the cache */
   /* replace1666 -> 4684 in the cache */

   /* ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1667_0_0 -> 11 in the cache */
   /* search1667_0 -> 1818 in the cache */
   /* search1667_1_0 -> 2101 in the cache */
   /* search1667_1 -> 4636 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1818, 4636 },
      -1,
   } },

   /* replace1667_0 -> 11 in the cache */
   /* replace1667_1_0 -> 2101 in the cache */
   /* replace1667_1 -> 4546 in the cache */
   /* replace1667 -> 4686 in the cache */

   /* ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1668_0_0 -> 11 in the cache */
   /* search1668_0 -> 1818 in the cache */
   /* search1668_1_0 -> 2101 in the cache */
   /* search1668_1 -> 4636 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1818, 4636 },
      -1,
   } },

   /* replace1668_0 -> 11 in the cache */
   /* replace1668_1_0 -> 2101 in the cache */
   /* replace1668_1 -> 4546 in the cache */
   /* replace1668 -> 4688 in the cache */

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1669_0_0 -> 4211 in the cache */
   /* search1669_0 -> 4641 in the cache */
   /* search1669_1_0 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 528 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4641, 4743 },
      -1,
   } },

   /* replace1669_0_0 -> 4211 in the cache */
   /* replace1669_0 -> 4556 in the cache */
   /* replace1669_1 -> 528 in the cache */
   /* replace1669 -> 4691 in the cache */

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1670_0_0 -> 4211 in the cache */
   /* search1670_0 -> 4641 in the cache */
   /* search1670_1_0 -> 528 in the cache */
   /* search1670_1 -> 4743 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4641, 4743 },
      -1,
   } },

   /* replace1670_0_0 -> 4211 in the cache */
   /* replace1670_0 -> 4556 in the cache */
   /* replace1670_1 -> 528 in the cache */
   /* replace1670 -> 4693 in the cache */

   /* ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1671_0_0 -> 11 in the cache */
   /* search1671_0 -> 1818 in the cache */
   /* search1671_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1818, 4746 },
      -1,
   } },

   /* replace1671_0 -> 11 in the cache */
   /* replace1671_1_0 -> 260 in the cache */
   /* replace1671_1 -> 4695 in the cache */
   /* replace1671 -> 4696 in the cache */

   /* ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1672_0_0 -> 11 in the cache */
   /* search1672_0 -> 1818 in the cache */
   /* search1672_1_0 -> 260 in the cache */
   /* search1672_1 -> 4746 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1818, 4746 },
      -1,
   } },

   /* replace1672_0 -> 11 in the cache */
   /* replace1672_1_0 -> 260 in the cache */
   /* replace1672_1 -> 4695 in the cache */
   /* replace1672 -> 4698 in the cache */

   /* ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1673_0_0 -> 11 in the cache */
   /* search1673_0 -> 1818 in the cache */
   /* search1673_1_0 -> 260 in the cache */
   /* search1673_1 -> 4746 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1818, 4746 },
      -1,
   } },

   /* replace1673_0 -> 11 in the cache */
   /* replace1673_1_0 -> 260 in the cache */
   /* replace1673_1 -> 4695 in the cache */
   /* replace1673 -> 4700 in the cache */

   /* ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1674_0_0 -> 11 in the cache */
   /* search1674_0 -> 1818 in the cache */
   /* search1674_1_0 -> 260 in the cache */
   /* search1674_1 -> 4746 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1818, 4746 },
      -1,
   } },

   /* replace1674_0 -> 11 in the cache */
   /* replace1674_1_0 -> 260 in the cache */
   /* replace1674_1 -> 4695 in the cache */
   /* replace1674 -> 4702 in the cache */

   /* ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1675_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 517 },
      -1,
   } },
   /* search1675_1_0 -> 528 in the cache */
   /* search1675_1 -> 4743 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4751, 4743 },
      -1,
   } },

   /* replace1675_0_0 -> 517 in the cache */
   /* replace1675_0 -> 4705 in the cache */
   /* replace1675_1 -> 528 in the cache */
   /* replace1675 -> 4706 in the cache */

   /* ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1676_0_0 -> 517 in the cache */
   /* search1676_0 -> 4751 in the cache */
   /* search1676_1_0 -> 528 in the cache */
   /* search1676_1 -> 4743 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4751, 4743 },
      -1,
   } },

   /* replace1676_0_0 -> 517 in the cache */
   /* replace1676_0 -> 4705 in the cache */
   /* replace1676_1 -> 528 in the cache */
   /* replace1676 -> 4708 in the cache */

   /* ('ieq', ('u2u64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u64', ('u2u16', 'b')), 'b')) */
   /* search1677_0_0 -> 11 in the cache */
   /* search1677_0 -> 1818 in the cache */
   /* search1677_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1818, 4312 },
      -1,
   } },

   /* replace1677_0_0 -> 11 in the cache */
   /* replace1677_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4755 },
      -1,
   } },
   /* replace1677_1_0_0_0 -> 41 in the cache */
   /* replace1677_1_0_0 -> 4755 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4755 },
      -1,
   } },
   /* replace1677_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4757, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4756, 4758 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u64', ('u2u16', 'b')), 'b')) */
   /* search1678_0_0 -> 11 in the cache */
   /* search1678_0 -> 1818 in the cache */
   /* search1678_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1818, 4312 },
      -1,
   } },

   /* replace1678_0_0 -> 11 in the cache */
   /* replace1678_0_1_0 -> 41 in the cache */
   /* replace1678_0_1 -> 4755 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4755 },
      -1,
   } },
   /* replace1678_1_0_0_0 -> 41 in the cache */
   /* replace1678_1_0_0 -> 4755 in the cache */
   /* replace1678_1_0 -> 4757 in the cache */
   /* replace1678_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4757, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4761, 4762 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b')))) */
   /* search1679_0_0 -> 11 in the cache */
   /* search1679_0 -> 1818 in the cache */
   /* search1679_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1818, 4312 },
      -1,
   } },

   /* replace1679_0_0 -> 890 in the cache */
   /* replace1679_0_1 -> 41 in the cache */
   /* replace1679_0 -> 4656 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* replace1679_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4765, 41 },
      -1,
   } },
   /* replace1679_1_1_0 -> 11 in the cache */
   /* replace1679_1_1_1_0 -> 41 in the cache */
   /* replace1679_1_1_1 -> 4755 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4755 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4766, 4767 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4656, 4768 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b'))) */
   /* search1680_0 -> 4331 in the cache */
   /* search1680_1_0 -> 260 in the cache */
   /* search1680_1 -> 4746 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4331, 4746 },
      -1,
   } },

   /* replace1680_0_0 -> 21 in the cache */
   /* replace1680_0_1 -> 4765 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 4765 },
      -1,
   } },
   /* replace1680_1_0_0 -> 21 in the cache */
   /* replace1680_1_0_1 -> 890 in the cache */
   /* replace1680_1_0 -> 4664 in the cache */
   /* replace1680_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1680_1_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4772, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4664, 4773 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4771, 4774 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b')))) */
   /* search1681_0_0 -> 11 in the cache */
   /* search1681_0 -> 1818 in the cache */
   /* search1681_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1818, 4312 },
      -1,
   } },

   /* replace1681_0_0 -> 4765 in the cache */
   /* replace1681_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4765, 41 },
      -1,
   } },
   /* replace1681_1_0_0 -> 890 in the cache */
   /* replace1681_1_0_1 -> 41 in the cache */
   /* replace1681_1_0 -> 4671 in the cache */
   /* replace1681_1_1_0 -> 11 in the cache */
   /* replace1681_1_1_1_0 -> 41 in the cache */
   /* replace1681_1_1_1 -> 4755 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4755 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4671, 4778 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4777, 4779 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b'))) */
   /* search1682_0 -> 4331 in the cache */
   /* search1682_1_0 -> 260 in the cache */
   /* search1682_1 -> 4746 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4331, 4746 },
      -1,
   } },

   /* replace1682_0_0 -> 21 in the cache */
   /* replace1682_0_1 -> 890 in the cache */
   /* replace1682_0 -> 4676 in the cache */
   /* replace1682_1_0_0 -> 21 in the cache */
   /* replace1682_1_0_1 -> 4765 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 4765 },
      -1,
   } },
   /* replace1682_1_1_0_0 -> 21 in the cache */
   /* replace1682_1_1_0 -> 4772 in the cache */
   /* replace1682_1_1_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4772, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4782, 4783 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4676, 4784 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1683_0_0 -> 16 in the cache */
   /* search1683_0 -> 1900 in the cache */
   /* search1683_1_0 -> 2101 in the cache */
   /* search1683_1 -> 4636 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1900, 4636 },
      -1,
   } },

   /* replace1683_0 -> 16 in the cache */
   /* replace1683_1_0 -> 2101 in the cache */
   /* replace1683_1 -> 3212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 3212 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1684_0_0 -> 16 in the cache */
   /* search1684_0 -> 1900 in the cache */
   /* search1684_1_0 -> 2101 in the cache */
   /* search1684_1 -> 4636 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1900, 4636 },
      -1,
   } },

   /* replace1684_0 -> 16 in the cache */
   /* replace1684_1_0 -> 2101 in the cache */
   /* replace1684_1 -> 3212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 3212 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1685_0_0 -> 16 in the cache */
   /* search1685_0 -> 1900 in the cache */
   /* search1685_1_0 -> 2101 in the cache */
   /* search1685_1 -> 4636 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1900, 4636 },
      -1,
   } },

   /* replace1685_0 -> 16 in the cache */
   /* replace1685_1_0 -> 2101 in the cache */
   /* replace1685_1 -> 3212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 3212 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1686_0_0 -> 16 in the cache */
   /* search1686_0 -> 1900 in the cache */
   /* search1686_1_0 -> 2101 in the cache */
   /* search1686_1 -> 4636 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1900, 4636 },
      -1,
   } },

   /* replace1686_0 -> 16 in the cache */
   /* replace1686_1_0 -> 2101 in the cache */
   /* replace1686_1 -> 3212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 3212 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1687_0_0 -> 4211 in the cache */
   /* search1687_0 -> 4641 in the cache */
   /* search1687_1_0 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 185 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4641, 4794 },
      -1,
   } },

   /* replace1687_0_0 -> 4211 in the cache */
   /* replace1687_0 -> 4599 in the cache */
   /* replace1687_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4599, 185 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1688_0_0 -> 4211 in the cache */
   /* search1688_0 -> 4641 in the cache */
   /* search1688_1_0 -> 185 in the cache */
   /* search1688_1 -> 4794 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4641, 4794 },
      -1,
   } },

   /* replace1688_0_0 -> 4211 in the cache */
   /* replace1688_0 -> 4599 in the cache */
   /* replace1688_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4599, 185 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1689_0_0 -> 16 in the cache */
   /* search1689_0 -> 1900 in the cache */
   /* search1689_1_0 -> 260 in the cache */
   /* search1689_1 -> 4746 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1900, 4746 },
      -1,
   } },

   /* replace1689_0 -> 16 in the cache */
   /* replace1689_1_0 -> 260 in the cache */
   /* replace1689_1 -> 3232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 3232 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1690_0_0 -> 16 in the cache */
   /* search1690_0 -> 1900 in the cache */
   /* search1690_1_0 -> 260 in the cache */
   /* search1690_1 -> 4746 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1900, 4746 },
      -1,
   } },

   /* replace1690_0 -> 16 in the cache */
   /* replace1690_1_0 -> 260 in the cache */
   /* replace1690_1 -> 3232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 3232 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1691_0_0 -> 16 in the cache */
   /* search1691_0 -> 1900 in the cache */
   /* search1691_1_0 -> 260 in the cache */
   /* search1691_1 -> 4746 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1900, 4746 },
      -1,
   } },

   /* replace1691_0 -> 16 in the cache */
   /* replace1691_1_0 -> 260 in the cache */
   /* replace1691_1 -> 3232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 3232 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1692_0_0 -> 16 in the cache */
   /* search1692_0 -> 1900 in the cache */
   /* search1692_1_0 -> 260 in the cache */
   /* search1692_1 -> 4746 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1900, 4746 },
      -1,
   } },

   /* replace1692_0 -> 16 in the cache */
   /* replace1692_1_0 -> 260 in the cache */
   /* replace1692_1 -> 3232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 3232 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1693_0_0 -> 517 in the cache */
   /* search1693_0 -> 4751 in the cache */
   /* search1693_1_0 -> 185 in the cache */
   /* search1693_1 -> 4794 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4751, 4794 },
      -1,
   } },

   /* replace1693_0_0 -> 517 in the cache */
   /* replace1693_0 -> 4703 in the cache */
   /* replace1693_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4703, 185 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1694_0_0 -> 517 in the cache */
   /* search1694_0 -> 4751 in the cache */
   /* search1694_1_0 -> 185 in the cache */
   /* search1694_1 -> 4794 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4751, 4794 },
      -1,
   } },

   /* replace1694_0_0 -> 517 in the cache */
   /* replace1694_0 -> 4703 in the cache */
   /* replace1694_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4703, 185 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1695_0_0 -> 16 in the cache */
   /* search1695_0 -> 1900 in the cache */
   /* search1695_1_0 -> 36 in the cache */
   /* search1695_1 -> 3228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1900, 3228 },
      -1,
   } },

   /* replace1695_0 -> 16 in the cache */
   /* replace1695_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4812 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1696_0_0 -> 16 in the cache */
   /* search1696_0 -> 1900 in the cache */
   /* search1696_1_0 -> 36 in the cache */
   /* search1696_1 -> 3228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1900, 3228 },
      -1,
   } },

   /* replace1696_0 -> 16 in the cache */
   /* replace1696_1_0 -> 36 in the cache */
   /* replace1696_1 -> 4812 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4812 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1697_0_0 -> 16 in the cache */
   /* search1697_0 -> 1900 in the cache */
   /* search1697_1_0 -> 36 in the cache */
   /* search1697_1 -> 3228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1900, 3228 },
      -1,
   } },

   /* replace1697_0 -> 16 in the cache */
   /* replace1697_1_0 -> 36 in the cache */
   /* replace1697_1 -> 4812 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 4812 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1698_0_0 -> 16 in the cache */
   /* search1698_0 -> 1900 in the cache */
   /* search1698_1_0 -> 36 in the cache */
   /* search1698_1 -> 3228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1900, 3228 },
      -1,
   } },

   /* replace1698_0 -> 16 in the cache */
   /* replace1698_1_0 -> 36 in the cache */
   /* replace1698_1 -> 4812 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 4812 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1699_0_0 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 375 },
      -1,
   } },
   /* search1699_1_0 -> 185 in the cache */
   /* search1699_1 -> 4794 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4820, 4794 },
      -1,
   } },

   /* replace1699_0_0 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 375 },
      -1,
   } },
   /* replace1699_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4822, 185 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1700_0_0 -> 375 in the cache */
   /* search1700_0 -> 4820 in the cache */
   /* search1700_1_0 -> 185 in the cache */
   /* search1700_1 -> 4794 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4820, 4794 },
      -1,
   } },

   /* replace1700_0_0 -> 375 in the cache */
   /* replace1700_0 -> 4822 in the cache */
   /* replace1700_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4822, 185 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('u2u32', 'b')), ('ieq', ('u2u64', ('u2u32', 'b')), 'b')) */
   /* search1701_0_0 -> 16 in the cache */
   /* search1701_0 -> 1900 in the cache */
   /* search1701_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1900, 4312 },
      -1,
   } },

   /* replace1701_0_0 -> 16 in the cache */
   /* replace1701_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 16, 4827 },
      -1,
   } },
   /* replace1701_1_0_0_0 -> 41 in the cache */
   /* replace1701_1_0_0 -> 4827 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4827 },
      -1,
   } },
   /* replace1701_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4829, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4828, 4830 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('u2u32', 'b')), ('ine', ('u2u64', ('u2u32', 'b')), 'b')) */
   /* search1702_0_0 -> 16 in the cache */
   /* search1702_0 -> 1900 in the cache */
   /* search1702_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1900, 4312 },
      -1,
   } },

   /* replace1702_0_0 -> 16 in the cache */
   /* replace1702_0_1_0 -> 41 in the cache */
   /* replace1702_0_1 -> 4827 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 16, 4827 },
      -1,
   } },
   /* replace1702_1_0_0_0 -> 41 in the cache */
   /* replace1702_1_0_0 -> 4827 in the cache */
   /* replace1702_1_0 -> 4829 in the cache */
   /* replace1702_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4829, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4833, 4834 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 4294967295, 'b'), ('ult', 'a', ('u2u32', 'b')))) */
   /* search1703_0_0 -> 16 in the cache */
   /* search1703_0 -> 1900 in the cache */
   /* search1703_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1900, 4312 },
      -1,
   } },

   /* replace1703_0_0 -> 890 in the cache */
   /* replace1703_0_1 -> 41 in the cache */
   /* replace1703_0 -> 4656 in the cache */
   /* replace1703_1_0_0 -> 3243 in the cache */
   /* replace1703_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3243, 41 },
      -1,
   } },
   /* replace1703_1_1_0 -> 16 in the cache */
   /* replace1703_1_1_1_0 -> 41 in the cache */
   /* replace1703_1_1_1 -> 4827 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 4827 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4837, 4838 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4656, 4839 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@32')) => ('iand', ('ult', 'a', 4294967295), ('ior', ('ult', 'a', 0), ('ult', ('u2u32', 'a'), 'b'))) */
   /* search1704_0 -> 4331 in the cache */
   /* search1704_1_0 -> 36 in the cache */
   /* search1704_1 -> 3228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4331, 3228 },
      -1,
   } },

   /* replace1704_0_0 -> 21 in the cache */
   /* replace1704_0_1 -> 3243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 3243 },
      -1,
   } },
   /* replace1704_1_0_0 -> 21 in the cache */
   /* replace1704_1_0_1 -> 890 in the cache */
   /* replace1704_1_0 -> 4664 in the cache */
   /* replace1704_1_1_0_0 -> 21 in the cache */
   /* replace1704_1_1_0 -> 3235 in the cache */
   /* replace1704_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3235, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4664, 4843 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4842, 4844 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), '#b') => ('iand', ('uge', 4294967295, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u32', 'b')))) */
   /* search1705_0_0 -> 16 in the cache */
   /* search1705_0 -> 1900 in the cache */
   /* search1705_1 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1900, 4312 },
      -1,
   } },

   /* replace1705_0_0 -> 3243 in the cache */
   /* replace1705_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3243, 41 },
      -1,
   } },
   /* replace1705_1_0_0 -> 890 in the cache */
   /* replace1705_1_0_1 -> 41 in the cache */
   /* replace1705_1_0 -> 4671 in the cache */
   /* replace1705_1_1_0 -> 16 in the cache */
   /* replace1705_1_1_1_0 -> 41 in the cache */
   /* replace1705_1_1_1 -> 4827 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 4827 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4671, 4848 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4847, 4849 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@32')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 4294967295), ('uge', ('u2u32', 'a'), 'b'))) */
   /* search1706_0 -> 4331 in the cache */
   /* search1706_1_0 -> 36 in the cache */
   /* search1706_1 -> 3228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4331, 3228 },
      -1,
   } },

   /* replace1706_0_0 -> 21 in the cache */
   /* replace1706_0_1 -> 890 in the cache */
   /* replace1706_0 -> 4676 in the cache */
   /* replace1706_1_0_0 -> 21 in the cache */
   /* replace1706_1_0_1 -> 3243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 3243 },
      -1,
   } },
   /* replace1706_1_1_0_0 -> 21 in the cache */
   /* replace1706_1_1_0 -> 3235 in the cache */
   /* replace1706_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3235, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4852, 4853 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4676, 4854 },
      -1,
   } },

   /* ('feq', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('feq', 'a', ('f2f16', 'b')) */
   /* search1707_0_0 -> 11 in the cache */
   /* search1707_0 -> 1791 in the cache */
   /* search1707_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1791, 4856 },
      -1,
   } },

   /* replace1707_0 -> 11 in the cache */
   /* replace1707_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 11, 4858 },
      -1,
   } },

   /* ('fneu', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fneu', 'a', ('f2f16', 'b')) */
   /* search1708_0_0 -> 11 in the cache */
   /* search1708_0 -> 1791 in the cache */
   /* search1708_1_0 -> 260 in the cache */
   /* search1708_1 -> 4856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1791, 4856 },
      -1,
   } },

   /* replace1708_0 -> 11 in the cache */
   /* replace1708_1_0 -> 260 in the cache */
   /* replace1708_1 -> 4858 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 11, 4858 },
      -1,
   } },

   /* ('fge', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fge', 'a', ('f2f16', 'b')) */
   /* search1709_0_0 -> 11 in the cache */
   /* search1709_0 -> 1791 in the cache */
   /* search1709_1_0 -> 260 in the cache */
   /* search1709_1 -> 4856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1791, 4856 },
      -1,
   } },

   /* replace1709_0 -> 11 in the cache */
   /* replace1709_1_0 -> 260 in the cache */
   /* replace1709_1 -> 4858 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 11, 4858 },
      -1,
   } },

   /* ('flt', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('flt', 'a', ('f2f16', 'b')) */
   /* search1710_0_0 -> 11 in the cache */
   /* search1710_0 -> 1791 in the cache */
   /* search1710_1_0 -> 260 in the cache */
   /* search1710_1 -> 4856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1791, 4856 },
      -1,
   } },

   /* replace1710_0 -> 11 in the cache */
   /* replace1710_1_0 -> 260 in the cache */
   /* replace1710_1 -> 4858 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 4858 },
      -1,
   } },

   /* ('fge', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('fge', ('f2f16', 'b'), 'a') */
   /* search1711_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 517 },
      -1,
   } },
   /* search1711_1_0 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 528 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4866, 4867 },
      -1,
   } },

   /* replace1711_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 517 },
      -1,
   } },
   /* replace1711_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4869, 528 },
      -1,
   } },

   /* ('flt', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('flt', ('f2f16', 'b'), 'a') */
   /* search1712_0_0 -> 517 in the cache */
   /* search1712_0 -> 4866 in the cache */
   /* search1712_1_0 -> 528 in the cache */
   /* search1712_1 -> 4867 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4866, 4867 },
      -1,
   } },

   /* replace1712_0_0 -> 517 in the cache */
   /* replace1712_0 -> 4869 in the cache */
   /* replace1712_1 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4869, 528 },
      -1,
   } },

   /* ('feq', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f16', 'b')) */
   /* search1713_0_0 -> 11 in the cache */
   /* search1713_0 -> 1814 in the cache */
   /* search1713_1_0 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1814, 4873 },
      -1,
   } },

   /* replace1713_0 -> 11 in the cache */
   /* replace1713_1_0 -> 260 in the cache */
   /* replace1713_1 -> 4858 in the cache */
   /* replace1713 -> 4859 in the cache */

   /* ('fneu', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f16', 'b')) */
   /* search1714_0_0 -> 11 in the cache */
   /* search1714_0 -> 1814 in the cache */
   /* search1714_1_0 -> 260 in the cache */
   /* search1714_1 -> 4873 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1814, 4873 },
      -1,
   } },

   /* replace1714_0 -> 11 in the cache */
   /* replace1714_1_0 -> 260 in the cache */
   /* replace1714_1 -> 4858 in the cache */
   /* replace1714 -> 4861 in the cache */

   /* ('fge', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f16', 'b')) */
   /* search1715_0_0 -> 11 in the cache */
   /* search1715_0 -> 1814 in the cache */
   /* search1715_1_0 -> 260 in the cache */
   /* search1715_1 -> 4873 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1814, 4873 },
      -1,
   } },

   /* replace1715_0 -> 11 in the cache */
   /* replace1715_1_0 -> 260 in the cache */
   /* replace1715_1 -> 4858 in the cache */
   /* replace1715 -> 4863 in the cache */

   /* ('flt', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f16', 'b')) */
   /* search1716_0_0 -> 11 in the cache */
   /* search1716_0 -> 1814 in the cache */
   /* search1716_1_0 -> 260 in the cache */
   /* search1716_1 -> 4873 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1814, 4873 },
      -1,
   } },

   /* replace1716_0 -> 11 in the cache */
   /* replace1716_1_0 -> 260 in the cache */
   /* replace1716_1 -> 4858 in the cache */
   /* replace1716 -> 4865 in the cache */

   /* ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('fge', ('f2f16', 'b'), 'a') */
   /* search1717_0_0 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 517 },
      -1,
   } },
   /* search1717_1_0 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 528 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4878, 4879 },
      -1,
   } },

   /* replace1717_0_0 -> 517 in the cache */
   /* replace1717_0 -> 4869 in the cache */
   /* replace1717_1 -> 528 in the cache */
   /* replace1717 -> 4870 in the cache */

   /* ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('flt', ('f2f16', 'b'), 'a') */
   /* search1718_0_0 -> 517 in the cache */
   /* search1718_0 -> 4878 in the cache */
   /* search1718_1_0 -> 528 in the cache */
   /* search1718_1 -> 4879 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4878, 4879 },
      -1,
   } },

   /* replace1718_0_0 -> 517 in the cache */
   /* replace1718_0 -> 4869 in the cache */
   /* replace1718_1 -> 528 in the cache */
   /* replace1718 -> 4872 in the cache */

   /* ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f32', 'b')) */
   /* search1719_0_0 -> 16 in the cache */
   /* search1719_0 -> 1896 in the cache */
   /* search1719_1_0 -> 260 in the cache */
   /* search1719_1 -> 4873 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1896, 4873 },
      -1,
   } },

   /* replace1719_0 -> 16 in the cache */
   /* replace1719_1_0 -> 260 in the cache */
   /* replace1719_1 -> 4856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 16, 4856 },
      -1,
   } },

   /* ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f32', 'b')) */
   /* search1720_0_0 -> 16 in the cache */
   /* search1720_0 -> 1896 in the cache */
   /* search1720_1_0 -> 260 in the cache */
   /* search1720_1 -> 4873 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1896, 4873 },
      -1,
   } },

   /* replace1720_0 -> 16 in the cache */
   /* replace1720_1_0 -> 260 in the cache */
   /* replace1720_1 -> 4856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 16, 4856 },
      -1,
   } },

   /* ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f32', 'b')) */
   /* search1721_0_0 -> 16 in the cache */
   /* search1721_0 -> 1896 in the cache */
   /* search1721_1_0 -> 260 in the cache */
   /* search1721_1 -> 4873 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1896, 4873 },
      -1,
   } },

   /* replace1721_0 -> 16 in the cache */
   /* replace1721_1_0 -> 260 in the cache */
   /* replace1721_1 -> 4856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 4856 },
      -1,
   } },

   /* ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f32', 'b')) */
   /* search1722_0_0 -> 16 in the cache */
   /* search1722_0 -> 1896 in the cache */
   /* search1722_1_0 -> 260 in the cache */
   /* search1722_1 -> 4873 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1896, 4873 },
      -1,
   } },

   /* replace1722_0 -> 16 in the cache */
   /* replace1722_1_0 -> 260 in the cache */
   /* replace1722_1 -> 4856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 4856 },
      -1,
   } },

   /* ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a') */
   /* search1723_0_0 -> 517 in the cache */
   /* search1723_0 -> 4878 in the cache */
   /* search1723_1_0 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 185 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4878, 4890 },
      -1,
   } },

   /* replace1723_0_0 -> 517 in the cache */
   /* replace1723_0 -> 4866 in the cache */
   /* replace1723_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4866, 185 },
      -1,
   } },

   /* ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a') */
   /* search1724_0_0 -> 517 in the cache */
   /* search1724_0 -> 4878 in the cache */
   /* search1724_1_0 -> 185 in the cache */
   /* search1724_1 -> 4890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4878, 4890 },
      -1,
   } },

   /* replace1724_0_0 -> 517 in the cache */
   /* replace1724_0 -> 4866 in the cache */
   /* replace1724_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4866, 185 },
      -1,
   } },

   /* ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('feq', 'a', ('f2f32', 'b')) */
   /* search1725_0_0 -> 16 in the cache */
   /* search1725_0 -> 1896 in the cache */
   /* search1725_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1896, 4895 },
      -1,
   } },

   /* replace1725_0 -> 16 in the cache */
   /* replace1725_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 16, 4897 },
      -1,
   } },

   /* ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fneu', 'a', ('f2f32', 'b')) */
   /* search1726_0_0 -> 16 in the cache */
   /* search1726_0 -> 1896 in the cache */
   /* search1726_1_0 -> 36 in the cache */
   /* search1726_1 -> 4895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1896, 4895 },
      -1,
   } },

   /* replace1726_0 -> 16 in the cache */
   /* replace1726_1_0 -> 36 in the cache */
   /* replace1726_1 -> 4897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 16, 4897 },
      -1,
   } },

   /* ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fge', 'a', ('f2f32', 'b')) */
   /* search1727_0_0 -> 16 in the cache */
   /* search1727_0 -> 1896 in the cache */
   /* search1727_1_0 -> 36 in the cache */
   /* search1727_1 -> 4895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1896, 4895 },
      -1,
   } },

   /* replace1727_0 -> 16 in the cache */
   /* replace1727_1_0 -> 36 in the cache */
   /* replace1727_1 -> 4897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 4897 },
      -1,
   } },

   /* ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('flt', 'a', ('f2f32', 'b')) */
   /* search1728_0_0 -> 16 in the cache */
   /* search1728_0 -> 1896 in the cache */
   /* search1728_1_0 -> 36 in the cache */
   /* search1728_1 -> 4895 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1896, 4895 },
      -1,
   } },

   /* replace1728_0 -> 16 in the cache */
   /* replace1728_1_0 -> 36 in the cache */
   /* replace1728_1 -> 4897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 4897 },
      -1,
   } },

   /* ('fge', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a') */
   /* search1729_0_0 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 375 },
      -1,
   } },
   /* search1729_1_0 -> 185 in the cache */
   /* search1729_1 -> 4890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4905, 4890 },
      -1,
   } },

   /* replace1729_0_0 -> 375 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 375 },
      -1,
   } },
   /* replace1729_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4907, 185 },
      -1,
   } },

   /* ('flt', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a') */
   /* search1730_0_0 -> 375 in the cache */
   /* search1730_0 -> 4905 in the cache */
   /* search1730_1_0 -> 185 in the cache */
   /* search1730_1 -> 4890 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4905, 4890 },
      -1,
   } },

   /* replace1730_0_0 -> 375 in the cache */
   /* replace1730_0 -> 4907 in the cache */
   /* replace1730_1 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4907, 185 },
      -1,
   } },

   /* ('i2i32', ('iand', 'a@64', 4294967295)) => ('u2u32', 'a') */
   /* search1731_0_0 -> 21 in the cache */
   /* search1731_0_1 -> 3243 in the cache */
   /* search1731_0 -> 3244 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 1,
      { 3244 },
      -1,
   } },

   /* replace1731_0 -> 21 in the cache */
   /* replace1731 -> 3235 in the cache */

   /* ('i2i16', ('iand', 'a@32', 65535)) => ('u2u16', 'a') */
   /* search1732_0_0 -> 16 in the cache */
   /* search1732_0_1 -> 995 in the cache */
   /* search1732_0 -> 996 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 1,
      { 996 },
      -1,
   } },

   /* replace1732_0 -> 16 in the cache */
   /* replace1732 -> 3238 in the cache */

   /* ('i2i16', ('iand', 'a@64', 65535)) => ('u2u16', 'a') */
   /* search1733_0_0 -> 21 in the cache */
   /* search1733_0_1 -> 4765 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 4765 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 1,
      { 4913 },
      -1,
   } },

   /* replace1733_0 -> 21 in the cache */
   /* replace1733 -> 4772 in the cache */

   /* ('i2i8', ('iand', 'a@16', 255)) => ('u2u8', 'a') */
   /* search1734_0_0 -> 11 in the cache */
   /* search1734_0_1 -> 2002 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 2002 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 4915 },
      -1,
   } },

   /* replace1734_0 -> 11 in the cache */
   /* replace1734 -> 1998 in the cache */

   /* ('i2i8', ('iand', 'a@32', 255)) => ('u2u8', 'a') */
   /* search1735_0_0 -> 16 in the cache */
   /* search1735_0_1 -> 1003 in the cache */
   /* search1735_0 -> 1004 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 1004 },
      -1,
   } },

   /* replace1735_0 -> 16 in the cache */
   /* replace1735 -> 2014 in the cache */

   /* ('i2i8', ('iand', 'a@64', 255)) => ('u2u8', 'a') */
   /* search1736_0_0 -> 21 in the cache */
   /* search1736_0_1 -> 4657 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 4657 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 4918 },
      -1,
   } },

   /* replace1736_0 -> 21 in the cache */
   /* replace1736 -> 4665 in the cache */

   /* ('u2u16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a */
   /* search1737_0_0 -> 11 in the cache */
   /* search1737_0 -> 1998 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1998 },
      6,
   } },

   /* replace1737 -> 11 in the cache */

   /* ('extract_u8(only_lower_8_bits_used)', 'a@16', 0) => a */
   /* search1738_0 -> 11 in the cache */
   /* search1738_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 849 },
      6,
   } },

   /* replace1738 -> 11 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1739_0 -> 523 in the cache */
   /* search1739_1_0_0 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 528 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4922 },
      -1,
   } },
   /* search1739_2 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4923, 490 },
      6,
   } },

   /* replace1739_0 -> 523 in the cache */
   /* replace1739_1 -> 528 in the cache */
   /* replace1739_2 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 528, 490 },
      -1,
   } },

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1740_0 -> 523 in the cache */
   /* search1740_1_0_0 -> 528 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 528 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4926 },
      -1,
   } },
   /* search1740_2 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4927, 490 },
      6,
   } },

   /* replace1740_0 -> 523 in the cache */
   /* replace1740_1 -> 528 in the cache */
   /* replace1740_2 -> 490 in the cache */
   /* replace1740 -> 4925 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1741_0 -> 523 in the cache */
   /* search1741_1_0 -> 528 in the cache */
   /* search1741_1_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 528, 849 },
      -1,
   } },
   /* search1741_2 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4929, 490 },
      6,
   } },

   /* replace1741_0 -> 523 in the cache */
   /* replace1741_1 -> 528 in the cache */
   /* replace1741_2 -> 490 in the cache */
   /* replace1741 -> 4925 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1742_0_0_0 -> 11 in the cache */
   /* search1742_0_0 -> 1998 in the cache */
   /* search1742_0 -> 1999 in the cache */
   /* search1742_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1999, 260 },
      6,
   } },

   /* replace1742_0 -> 11 in the cache */
   /* replace1742_1 -> 260 in the cache */
   /* replace1742 -> 3987 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1743_0_0_0 -> 11 in the cache */
   /* search1743_0_0 -> 4242 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4242 },
      -1,
   } },
   /* search1743_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4932, 260 },
      6,
   } },

   /* replace1743_0 -> 11 in the cache */
   /* replace1743_1 -> 260 in the cache */
   /* replace1743 -> 3987 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1744_0_0 -> 11 in the cache */
   /* search1744_0_1 -> 849 in the cache */
   /* search1744_0 -> 3346 in the cache */
   /* search1744_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3346, 260 },
      6,
   } },

   /* replace1744_0 -> 11 in the cache */
   /* replace1744_1 -> 260 in the cache */
   /* replace1744 -> 3987 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1745_0_0_0 -> 11 in the cache */
   /* search1745_0_0 -> 1998 in the cache */
   /* search1745_0 -> 1999 in the cache */
   /* search1745_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 1999, 260 },
      6,
   } },

   /* replace1745_0 -> 11 in the cache */
   /* replace1745_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 11, 260 },
      -1,
   } },

   /* ('imul(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1746_0_0_0 -> 11 in the cache */
   /* search1746_0_0 -> 4242 in the cache */
   /* search1746_0 -> 4932 in the cache */
   /* search1746_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4932, 260 },
      6,
   } },

   /* replace1746_0 -> 11 in the cache */
   /* replace1746_1 -> 260 in the cache */
   /* replace1746 -> 4936 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('imul', 'a', 'b') */
   /* search1747_0_0 -> 11 in the cache */
   /* search1747_0_1 -> 849 in the cache */
   /* search1747_0 -> 3346 in the cache */
   /* search1747_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3346, 260 },
      6,
   } },

   /* replace1747_0 -> 11 in the cache */
   /* replace1747_1 -> 260 in the cache */
   /* replace1747 -> 4936 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1748_0_0_0 -> 11 in the cache */
   /* search1748_0_0 -> 1998 in the cache */
   /* search1748_0 -> 1999 in the cache */
   /* search1748_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1999, 260 },
      6,
   } },

   /* replace1748_0 -> 11 in the cache */
   /* replace1748_1 -> 260 in the cache */
   /* replace1748 -> 2012 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1749_0_0_0 -> 11 in the cache */
   /* search1749_0_0 -> 4242 in the cache */
   /* search1749_0 -> 4932 in the cache */
   /* search1749_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4932, 260 },
      6,
   } },

   /* replace1749_0 -> 11 in the cache */
   /* replace1749_1 -> 260 in the cache */
   /* replace1749 -> 2012 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iand', 'a', 'b') */
   /* search1750_0_0 -> 11 in the cache */
   /* search1750_0_1 -> 849 in the cache */
   /* search1750_0 -> 3346 in the cache */
   /* search1750_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3346, 260 },
      6,
   } },

   /* replace1750_0 -> 11 in the cache */
   /* replace1750_1 -> 260 in the cache */
   /* replace1750 -> 2012 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1751_0_0_0 -> 11 in the cache */
   /* search1751_0_0 -> 1998 in the cache */
   /* search1751_0 -> 1999 in the cache */
   /* search1751_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1999, 260 },
      6,
   } },

   /* replace1751_0 -> 11 in the cache */
   /* replace1751_1 -> 260 in the cache */
   /* replace1751 -> 2054 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1752_0_0_0 -> 11 in the cache */
   /* search1752_0_0 -> 4242 in the cache */
   /* search1752_0 -> 4932 in the cache */
   /* search1752_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4932, 260 },
      6,
   } },

   /* replace1752_0 -> 11 in the cache */
   /* replace1752_1 -> 260 in the cache */
   /* replace1752 -> 2054 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ior', 'a', 'b') */
   /* search1753_0_0 -> 11 in the cache */
   /* search1753_0_1 -> 849 in the cache */
   /* search1753_0 -> 3346 in the cache */
   /* search1753_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3346, 260 },
      6,
   } },

   /* replace1753_0 -> 11 in the cache */
   /* replace1753_1 -> 260 in the cache */
   /* replace1753 -> 2054 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1754_0_0_0 -> 11 in the cache */
   /* search1754_0_0 -> 1998 in the cache */
   /* search1754_0 -> 1999 in the cache */
   /* search1754_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1999, 260 },
      6,
   } },

   /* replace1754_0 -> 11 in the cache */
   /* replace1754_1 -> 260 in the cache */
   /* replace1754 -> 2078 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1755_0_0_0 -> 11 in the cache */
   /* search1755_0_0 -> 4242 in the cache */
   /* search1755_0 -> 4932 in the cache */
   /* search1755_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4932, 260 },
      6,
   } },

   /* replace1755_0 -> 11 in the cache */
   /* replace1755_1 -> 260 in the cache */
   /* replace1755 -> 2078 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1756_0_0 -> 11 in the cache */
   /* search1756_0_1 -> 849 in the cache */
   /* search1756_0 -> 3346 in the cache */
   /* search1756_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 3346, 260 },
      6,
   } },

   /* replace1756_0 -> 11 in the cache */
   /* replace1756_1 -> 260 in the cache */
   /* replace1756 -> 2078 in the cache */

   /* ('i2i16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a */
   /* search1757_0_0 -> 11 in the cache */
   /* search1757_0 -> 1998 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1998 },
      6,
   } },

   /* replace1757 -> 11 in the cache */

   /* ('extract_i8(only_lower_8_bits_used)', 'a@16', 0) => a */
   /* search1758_0 -> 11 in the cache */
   /* search1758_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 849 },
      6,
   } },

   /* replace1758 -> 11 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1759_0 -> 523 in the cache */
   /* search1759_1_0_0 -> 528 in the cache */
   /* search1759_1_0 -> 4922 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4922 },
      -1,
   } },
   /* search1759_2 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4950, 490 },
      6,
   } },

   /* replace1759_0 -> 523 in the cache */
   /* replace1759_1 -> 528 in the cache */
   /* replace1759_2 -> 490 in the cache */
   /* replace1759 -> 4925 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1760_0 -> 523 in the cache */
   /* search1760_1_0_0 -> 528 in the cache */
   /* search1760_1_0 -> 4926 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4926 },
      -1,
   } },
   /* search1760_2 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4952, 490 },
      6,
   } },

   /* replace1760_0 -> 523 in the cache */
   /* replace1760_1 -> 528 in the cache */
   /* replace1760_2 -> 490 in the cache */
   /* replace1760 -> 4925 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1761_0 -> 523 in the cache */
   /* search1761_1_0 -> 528 in the cache */
   /* search1761_1_1 -> 849 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 528, 849 },
      -1,
   } },
   /* search1761_2 -> 490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4954, 490 },
      6,
   } },

   /* replace1761_0 -> 523 in the cache */
   /* replace1761_1 -> 528 in the cache */
   /* replace1761_2 -> 490 in the cache */
   /* replace1761 -> 4925 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1762_0_0_0 -> 11 in the cache */
   /* search1762_0_0 -> 1998 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1998 },
      -1,
   } },
   /* search1762_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4956, 260 },
      6,
   } },

   /* replace1762_0 -> 11 in the cache */
   /* replace1762_1 -> 260 in the cache */
   /* replace1762 -> 3987 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1763_0_0_0 -> 11 in the cache */
   /* search1763_0_0 -> 4242 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4242 },
      -1,
   } },
   /* search1763_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4958, 260 },
      6,
   } },

   /* replace1763_0 -> 11 in the cache */
   /* replace1763_1 -> 260 in the cache */
   /* replace1763 -> 3987 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1764_0_0 -> 11 in the cache */
   /* search1764_0_1 -> 849 in the cache */
   /* search1764_0 -> 3367 in the cache */
   /* search1764_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3367, 260 },
      6,
   } },

   /* replace1764_0 -> 11 in the cache */
   /* replace1764_1 -> 260 in the cache */
   /* replace1764 -> 3987 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1765_0_0_0 -> 11 in the cache */
   /* search1765_0_0 -> 1998 in the cache */
   /* search1765_0 -> 4956 in the cache */
   /* search1765_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4956, 260 },
      6,
   } },

   /* replace1765_0 -> 11 in the cache */
   /* replace1765_1 -> 260 in the cache */
   /* replace1765 -> 4936 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1766_0_0_0 -> 11 in the cache */
   /* search1766_0_0 -> 4242 in the cache */
   /* search1766_0 -> 4958 in the cache */
   /* search1766_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4958, 260 },
      6,
   } },

   /* replace1766_0 -> 11 in the cache */
   /* replace1766_1 -> 260 in the cache */
   /* replace1766 -> 4936 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('imul', 'a', 'b') */
   /* search1767_0_0 -> 11 in the cache */
   /* search1767_0_1 -> 849 in the cache */
   /* search1767_0 -> 3367 in the cache */
   /* search1767_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3367, 260 },
      6,
   } },

   /* replace1767_0 -> 11 in the cache */
   /* replace1767_1 -> 260 in the cache */
   /* replace1767 -> 4936 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1768_0_0_0 -> 11 in the cache */
   /* search1768_0_0 -> 1998 in the cache */
   /* search1768_0 -> 4956 in the cache */
   /* search1768_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4956, 260 },
      6,
   } },

   /* replace1768_0 -> 11 in the cache */
   /* replace1768_1 -> 260 in the cache */
   /* replace1768 -> 2012 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1769_0_0_0 -> 11 in the cache */
   /* search1769_0_0 -> 4242 in the cache */
   /* search1769_0 -> 4958 in the cache */
   /* search1769_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4958, 260 },
      6,
   } },

   /* replace1769_0 -> 11 in the cache */
   /* replace1769_1 -> 260 in the cache */
   /* replace1769 -> 2012 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iand', 'a', 'b') */
   /* search1770_0_0 -> 11 in the cache */
   /* search1770_0_1 -> 849 in the cache */
   /* search1770_0 -> 3367 in the cache */
   /* search1770_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3367, 260 },
      6,
   } },

   /* replace1770_0 -> 11 in the cache */
   /* replace1770_1 -> 260 in the cache */
   /* replace1770 -> 2012 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1771_0_0_0 -> 11 in the cache */
   /* search1771_0_0 -> 1998 in the cache */
   /* search1771_0 -> 4956 in the cache */
   /* search1771_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4956, 260 },
      6,
   } },

   /* replace1771_0 -> 11 in the cache */
   /* replace1771_1 -> 260 in the cache */
   /* replace1771 -> 2054 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1772_0_0_0 -> 11 in the cache */
   /* search1772_0_0 -> 4242 in the cache */
   /* search1772_0 -> 4958 in the cache */
   /* search1772_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4958, 260 },
      6,
   } },

   /* replace1772_0 -> 11 in the cache */
   /* replace1772_1 -> 260 in the cache */
   /* replace1772 -> 2054 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ior', 'a', 'b') */
   /* search1773_0_0 -> 11 in the cache */
   /* search1773_0_1 -> 849 in the cache */
   /* search1773_0 -> 3367 in the cache */
   /* search1773_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3367, 260 },
      6,
   } },

   /* replace1773_0 -> 11 in the cache */
   /* replace1773_1 -> 260 in the cache */
   /* replace1773 -> 2054 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1774_0_0_0 -> 11 in the cache */
   /* search1774_0_0 -> 1998 in the cache */
   /* search1774_0 -> 4956 in the cache */
   /* search1774_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4956, 260 },
      6,
   } },

   /* replace1774_0 -> 11 in the cache */
   /* replace1774_1 -> 260 in the cache */
   /* replace1774 -> 2078 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1775_0_0_0 -> 11 in the cache */
   /* search1775_0_0 -> 4242 in the cache */
   /* search1775_0 -> 4958 in the cache */
   /* search1775_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4958, 260 },
      6,
   } },

   /* replace1775_0 -> 11 in the cache */
   /* replace1775_1 -> 260 in the cache */
   /* replace1775 -> 2078 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1776_0_0 -> 11 in the cache */
   /* search1776_0_1 -> 849 in the cache */
   /* search1776_0 -> 3367 in the cache */
   /* search1776_1 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 3367, 260 },
      6,
   } },

   /* replace1776_0 -> 11 in the cache */
   /* replace1776_1 -> 260 in the cache */
   /* replace1776 -> 2078 in the cache */

   /* ('u2u32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a */
   /* search1777_0_0 -> 16 in the cache */
   /* search1777_0 -> 2014 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2014 },
      6,
   } },

   /* replace1777 -> 16 in the cache */

   /* ('extract_u8(only_lower_8_bits_used)', 'a@32', 0) => a */
   /* search1778_0 -> 16 in the cache */
   /* search1778_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 124 },
      6,
   } },

   /* replace1778 -> 16 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1779_0 -> 523 in the cache */
   /* search1779_1_0_0 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 185 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4975 },
      -1,
   } },
   /* search1779_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4976, 561 },
      6,
   } },

   /* replace1779_0 -> 523 in the cache */
   /* replace1779_1 -> 185 in the cache */
   /* replace1779_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 185, 561 },
      -1,
   } },

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1780_0 -> 523 in the cache */
   /* search1780_1_0_0 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 185 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4979 },
      -1,
   } },
   /* search1780_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4980, 561 },
      6,
   } },

   /* replace1780_0 -> 523 in the cache */
   /* replace1780_1 -> 185 in the cache */
   /* replace1780_2 -> 561 in the cache */
   /* replace1780 -> 4978 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1781_0 -> 523 in the cache */
   /* search1781_1_0 -> 185 in the cache */
   /* search1781_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 185, 124 },
      -1,
   } },
   /* search1781_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 4982, 561 },
      6,
   } },

   /* replace1781_0 -> 523 in the cache */
   /* replace1781_1 -> 185 in the cache */
   /* replace1781_2 -> 561 in the cache */
   /* replace1781 -> 4978 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1782_0_0_0 -> 16 in the cache */
   /* search1782_0_0 -> 2014 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2014 },
      -1,
   } },
   /* search1782_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4984, 36 },
      6,
   } },

   /* replace1782_0 -> 16 in the cache */
   /* replace1782_1 -> 36 in the cache */
   /* replace1782 -> 4007 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1783_0_0_0 -> 16 in the cache */
   /* search1783_0_0 -> 4194 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4194 },
      -1,
   } },
   /* search1783_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4986, 36 },
      6,
   } },

   /* replace1783_0 -> 16 in the cache */
   /* replace1783_1 -> 36 in the cache */
   /* replace1783 -> 4007 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1784_0_0 -> 16 in the cache */
   /* search1784_0_1 -> 124 in the cache */
   /* search1784_0 -> 414 in the cache */
   /* search1784_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 414, 36 },
      6,
   } },

   /* replace1784_0 -> 16 in the cache */
   /* replace1784_1 -> 36 in the cache */
   /* replace1784 -> 4007 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1785_0_0_0 -> 16 in the cache */
   /* search1785_0_0 -> 2014 in the cache */
   /* search1785_0 -> 4984 in the cache */
   /* search1785_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4984, 36 },
      6,
   } },

   /* replace1785_0 -> 16 in the cache */
   /* replace1785_1 -> 36 in the cache */
   /* replace1785 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1786_0_0_0 -> 16 in the cache */
   /* search1786_0_0 -> 4194 in the cache */
   /* search1786_0 -> 4986 in the cache */
   /* search1786_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4986, 36 },
      6,
   } },

   /* replace1786_0 -> 16 in the cache */
   /* replace1786_1 -> 36 in the cache */
   /* replace1786 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1787_0_0 -> 16 in the cache */
   /* search1787_0_1 -> 124 in the cache */
   /* search1787_0 -> 414 in the cache */
   /* search1787_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 414, 36 },
      6,
   } },

   /* replace1787_0 -> 16 in the cache */
   /* replace1787_1 -> 36 in the cache */
   /* replace1787 -> 49 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1788_0_0_0 -> 16 in the cache */
   /* search1788_0_0 -> 2014 in the cache */
   /* search1788_0 -> 4984 in the cache */
   /* search1788_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4984, 36 },
      6,
   } },

   /* replace1788_0 -> 16 in the cache */
   /* replace1788_1 -> 36 in the cache */
   /* replace1788 -> 2020 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1789_0_0_0 -> 16 in the cache */
   /* search1789_0_0 -> 4194 in the cache */
   /* search1789_0 -> 4986 in the cache */
   /* search1789_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4986, 36 },
      6,
   } },

   /* replace1789_0 -> 16 in the cache */
   /* replace1789_1 -> 36 in the cache */
   /* replace1789 -> 2020 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1790_0_0 -> 16 in the cache */
   /* search1790_0_1 -> 124 in the cache */
   /* search1790_0 -> 414 in the cache */
   /* search1790_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 414, 36 },
      6,
   } },

   /* replace1790_0 -> 16 in the cache */
   /* replace1790_1 -> 36 in the cache */
   /* replace1790 -> 2020 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1791_0_0_0 -> 16 in the cache */
   /* search1791_0_0 -> 2014 in the cache */
   /* search1791_0 -> 4984 in the cache */
   /* search1791_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4984, 36 },
      6,
   } },

   /* replace1791_0 -> 16 in the cache */
   /* replace1791_1 -> 36 in the cache */
   /* replace1791 -> 2058 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1792_0_0_0 -> 16 in the cache */
   /* search1792_0_0 -> 4194 in the cache */
   /* search1792_0 -> 4986 in the cache */
   /* search1792_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4986, 36 },
      6,
   } },

   /* replace1792_0 -> 16 in the cache */
   /* replace1792_1 -> 36 in the cache */
   /* replace1792 -> 2058 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1793_0_0 -> 16 in the cache */
   /* search1793_0_1 -> 124 in the cache */
   /* search1793_0 -> 414 in the cache */
   /* search1793_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 414, 36 },
      6,
   } },

   /* replace1793_0 -> 16 in the cache */
   /* replace1793_1 -> 36 in the cache */
   /* replace1793 -> 2058 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1794_0_0_0 -> 16 in the cache */
   /* search1794_0_0 -> 2014 in the cache */
   /* search1794_0 -> 4984 in the cache */
   /* search1794_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4984, 36 },
      6,
   } },

   /* replace1794_0 -> 16 in the cache */
   /* replace1794_1 -> 36 in the cache */
   /* replace1794 -> 2082 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1795_0_0_0 -> 16 in the cache */
   /* search1795_0_0 -> 4194 in the cache */
   /* search1795_0 -> 4986 in the cache */
   /* search1795_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4986, 36 },
      6,
   } },

   /* replace1795_0 -> 16 in the cache */
   /* replace1795_1 -> 36 in the cache */
   /* replace1795 -> 2082 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1796_0_0 -> 16 in the cache */
   /* search1796_0_1 -> 124 in the cache */
   /* search1796_0 -> 414 in the cache */
   /* search1796_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 414, 36 },
      6,
   } },

   /* replace1796_0 -> 16 in the cache */
   /* replace1796_1 -> 36 in the cache */
   /* replace1796 -> 2082 in the cache */

   /* ('i2i32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a */
   /* search1797_0_0 -> 16 in the cache */
   /* search1797_0 -> 2014 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2014 },
      6,
   } },

   /* replace1797 -> 16 in the cache */

   /* ('extract_i8(only_lower_8_bits_used)', 'a@32', 0) => a */
   /* search1798_0 -> 16 in the cache */
   /* search1798_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 124 },
      6,
   } },

   /* replace1798 -> 16 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1799_0 -> 523 in the cache */
   /* search1799_1_0_0 -> 185 in the cache */
   /* search1799_1_0 -> 4975 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4975 },
      -1,
   } },
   /* search1799_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5003, 561 },
      6,
   } },

   /* replace1799_0 -> 523 in the cache */
   /* replace1799_1 -> 185 in the cache */
   /* replace1799_2 -> 561 in the cache */
   /* replace1799 -> 4978 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1800_0 -> 523 in the cache */
   /* search1800_1_0_0 -> 185 in the cache */
   /* search1800_1_0 -> 4979 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4979 },
      -1,
   } },
   /* search1800_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5005, 561 },
      6,
   } },

   /* replace1800_0 -> 523 in the cache */
   /* replace1800_1 -> 185 in the cache */
   /* replace1800_2 -> 561 in the cache */
   /* replace1800 -> 4978 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1801_0 -> 523 in the cache */
   /* search1801_1_0 -> 185 in the cache */
   /* search1801_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 185, 124 },
      -1,
   } },
   /* search1801_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5007, 561 },
      6,
   } },

   /* replace1801_0 -> 523 in the cache */
   /* replace1801_1 -> 185 in the cache */
   /* replace1801_2 -> 561 in the cache */
   /* replace1801 -> 4978 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1802_0_0_0 -> 16 in the cache */
   /* search1802_0_0 -> 2014 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2014 },
      -1,
   } },
   /* search1802_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5009, 36 },
      6,
   } },

   /* replace1802_0 -> 16 in the cache */
   /* replace1802_1 -> 36 in the cache */
   /* replace1802 -> 4007 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1803_0_0_0 -> 16 in the cache */
   /* search1803_0_0 -> 4194 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4194 },
      -1,
   } },
   /* search1803_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5011, 36 },
      6,
   } },

   /* replace1803_0 -> 16 in the cache */
   /* replace1803_1 -> 36 in the cache */
   /* replace1803 -> 4007 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1804_0_0 -> 16 in the cache */
   /* search1804_0_1 -> 124 in the cache */
   /* search1804_0 -> 395 in the cache */
   /* search1804_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 395, 36 },
      6,
   } },

   /* replace1804_0 -> 16 in the cache */
   /* replace1804_1 -> 36 in the cache */
   /* replace1804 -> 4007 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1805_0_0_0 -> 16 in the cache */
   /* search1805_0_0 -> 2014 in the cache */
   /* search1805_0 -> 5009 in the cache */
   /* search1805_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5009, 36 },
      6,
   } },

   /* replace1805_0 -> 16 in the cache */
   /* replace1805_1 -> 36 in the cache */
   /* replace1805 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1806_0_0_0 -> 16 in the cache */
   /* search1806_0_0 -> 4194 in the cache */
   /* search1806_0 -> 5011 in the cache */
   /* search1806_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5011, 36 },
      6,
   } },

   /* replace1806_0 -> 16 in the cache */
   /* replace1806_1 -> 36 in the cache */
   /* replace1806 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1807_0_0 -> 16 in the cache */
   /* search1807_0_1 -> 124 in the cache */
   /* search1807_0 -> 395 in the cache */
   /* search1807_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 395, 36 },
      6,
   } },

   /* replace1807_0 -> 16 in the cache */
   /* replace1807_1 -> 36 in the cache */
   /* replace1807 -> 49 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1808_0_0_0 -> 16 in the cache */
   /* search1808_0_0 -> 2014 in the cache */
   /* search1808_0 -> 5009 in the cache */
   /* search1808_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5009, 36 },
      6,
   } },

   /* replace1808_0 -> 16 in the cache */
   /* replace1808_1 -> 36 in the cache */
   /* replace1808 -> 2020 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1809_0_0_0 -> 16 in the cache */
   /* search1809_0_0 -> 4194 in the cache */
   /* search1809_0 -> 5011 in the cache */
   /* search1809_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5011, 36 },
      6,
   } },

   /* replace1809_0 -> 16 in the cache */
   /* replace1809_1 -> 36 in the cache */
   /* replace1809 -> 2020 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1810_0_0 -> 16 in the cache */
   /* search1810_0_1 -> 124 in the cache */
   /* search1810_0 -> 395 in the cache */
   /* search1810_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 395, 36 },
      6,
   } },

   /* replace1810_0 -> 16 in the cache */
   /* replace1810_1 -> 36 in the cache */
   /* replace1810 -> 2020 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1811_0_0_0 -> 16 in the cache */
   /* search1811_0_0 -> 2014 in the cache */
   /* search1811_0 -> 5009 in the cache */
   /* search1811_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5009, 36 },
      6,
   } },

   /* replace1811_0 -> 16 in the cache */
   /* replace1811_1 -> 36 in the cache */
   /* replace1811 -> 2058 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1812_0_0_0 -> 16 in the cache */
   /* search1812_0_0 -> 4194 in the cache */
   /* search1812_0 -> 5011 in the cache */
   /* search1812_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5011, 36 },
      6,
   } },

   /* replace1812_0 -> 16 in the cache */
   /* replace1812_1 -> 36 in the cache */
   /* replace1812 -> 2058 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1813_0_0 -> 16 in the cache */
   /* search1813_0_1 -> 124 in the cache */
   /* search1813_0 -> 395 in the cache */
   /* search1813_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 395, 36 },
      6,
   } },

   /* replace1813_0 -> 16 in the cache */
   /* replace1813_1 -> 36 in the cache */
   /* replace1813 -> 2058 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1814_0_0_0 -> 16 in the cache */
   /* search1814_0_0 -> 2014 in the cache */
   /* search1814_0 -> 5009 in the cache */
   /* search1814_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5009, 36 },
      6,
   } },

   /* replace1814_0 -> 16 in the cache */
   /* replace1814_1 -> 36 in the cache */
   /* replace1814 -> 2082 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1815_0_0_0 -> 16 in the cache */
   /* search1815_0_0 -> 4194 in the cache */
   /* search1815_0 -> 5011 in the cache */
   /* search1815_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5011, 36 },
      6,
   } },

   /* replace1815_0 -> 16 in the cache */
   /* replace1815_1 -> 36 in the cache */
   /* replace1815 -> 2082 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1816_0_0 -> 16 in the cache */
   /* search1816_0_1 -> 124 in the cache */
   /* search1816_0 -> 395 in the cache */
   /* search1816_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 395, 36 },
      6,
   } },

   /* replace1816_0 -> 16 in the cache */
   /* replace1816_1 -> 36 in the cache */
   /* replace1816 -> 2082 in the cache */

   /* ('u2u32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a */
   /* search1817_0_0 -> 16 in the cache */
   /* search1817_0 -> 3238 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3238 },
      7,
   } },

   /* replace1817 -> 16 in the cache */

   /* ('extract_u16(only_lower_16_bits_used)', 'a@32', 0) => a */
   /* search1818_0 -> 16 in the cache */
   /* search1818_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 124 },
      7,
   } },

   /* replace1818 -> 16 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1819_0 -> 523 in the cache */
   /* search1819_1_0_0 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 185 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 5028 },
      -1,
   } },
   /* search1819_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5029, 561 },
      7,
   } },

   /* replace1819_0 -> 523 in the cache */
   /* replace1819_1 -> 185 in the cache */
   /* replace1819_2 -> 561 in the cache */
   /* replace1819 -> 4978 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1820_0 -> 523 in the cache */
   /* search1820_1_0_0 -> 185 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 185 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 5031 },
      -1,
   } },
   /* search1820_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5032, 561 },
      7,
   } },

   /* replace1820_0 -> 523 in the cache */
   /* replace1820_1 -> 185 in the cache */
   /* replace1820_2 -> 561 in the cache */
   /* replace1820 -> 4978 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('extract_u16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1821_0 -> 523 in the cache */
   /* search1821_1_0 -> 185 in the cache */
   /* search1821_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 185, 124 },
      -1,
   } },
   /* search1821_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5034, 561 },
      7,
   } },

   /* replace1821_0 -> 523 in the cache */
   /* replace1821_1 -> 185 in the cache */
   /* replace1821_2 -> 561 in the cache */
   /* replace1821 -> 4978 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1822_0_0_0 -> 16 in the cache */
   /* search1822_0_0 -> 3238 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3238 },
      -1,
   } },
   /* search1822_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5036, 36 },
      7,
   } },

   /* replace1822_0 -> 16 in the cache */
   /* replace1822_1 -> 36 in the cache */
   /* replace1822 -> 4007 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1823_0_0_0 -> 16 in the cache */
   /* search1823_0_0 -> 4196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4196 },
      -1,
   } },
   /* search1823_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5038, 36 },
      7,
   } },

   /* replace1823_0 -> 16 in the cache */
   /* replace1823_1 -> 36 in the cache */
   /* replace1823 -> 4007 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1824_0_0 -> 16 in the cache */
   /* search1824_0_1 -> 124 in the cache */
   /* search1824_0 -> 446 in the cache */
   /* search1824_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 446, 36 },
      7,
   } },

   /* replace1824_0 -> 16 in the cache */
   /* replace1824_1 -> 36 in the cache */
   /* replace1824 -> 4007 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1825_0_0_0 -> 16 in the cache */
   /* search1825_0_0 -> 3238 in the cache */
   /* search1825_0 -> 5036 in the cache */
   /* search1825_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5036, 36 },
      7,
   } },

   /* replace1825_0 -> 16 in the cache */
   /* replace1825_1 -> 36 in the cache */
   /* replace1825 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1826_0_0_0 -> 16 in the cache */
   /* search1826_0_0 -> 4196 in the cache */
   /* search1826_0 -> 5038 in the cache */
   /* search1826_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5038, 36 },
      7,
   } },

   /* replace1826_0 -> 16 in the cache */
   /* replace1826_1 -> 36 in the cache */
   /* replace1826 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1827_0_0 -> 16 in the cache */
   /* search1827_0_1 -> 124 in the cache */
   /* search1827_0 -> 446 in the cache */
   /* search1827_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 446, 36 },
      7,
   } },

   /* replace1827_0 -> 16 in the cache */
   /* replace1827_1 -> 36 in the cache */
   /* replace1827 -> 49 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1828_0_0_0 -> 16 in the cache */
   /* search1828_0_0 -> 3238 in the cache */
   /* search1828_0 -> 5036 in the cache */
   /* search1828_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5036, 36 },
      7,
   } },

   /* replace1828_0 -> 16 in the cache */
   /* replace1828_1 -> 36 in the cache */
   /* replace1828 -> 2020 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1829_0_0_0 -> 16 in the cache */
   /* search1829_0_0 -> 4196 in the cache */
   /* search1829_0 -> 5038 in the cache */
   /* search1829_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5038, 36 },
      7,
   } },

   /* replace1829_0 -> 16 in the cache */
   /* replace1829_1 -> 36 in the cache */
   /* replace1829 -> 2020 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1830_0_0 -> 16 in the cache */
   /* search1830_0_1 -> 124 in the cache */
   /* search1830_0 -> 446 in the cache */
   /* search1830_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 446, 36 },
      7,
   } },

   /* replace1830_0 -> 16 in the cache */
   /* replace1830_1 -> 36 in the cache */
   /* replace1830 -> 2020 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1831_0_0_0 -> 16 in the cache */
   /* search1831_0_0 -> 3238 in the cache */
   /* search1831_0 -> 5036 in the cache */
   /* search1831_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5036, 36 },
      7,
   } },

   /* replace1831_0 -> 16 in the cache */
   /* replace1831_1 -> 36 in the cache */
   /* replace1831 -> 2058 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1832_0_0_0 -> 16 in the cache */
   /* search1832_0_0 -> 4196 in the cache */
   /* search1832_0 -> 5038 in the cache */
   /* search1832_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5038, 36 },
      7,
   } },

   /* replace1832_0 -> 16 in the cache */
   /* replace1832_1 -> 36 in the cache */
   /* replace1832 -> 2058 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1833_0_0 -> 16 in the cache */
   /* search1833_0_1 -> 124 in the cache */
   /* search1833_0 -> 446 in the cache */
   /* search1833_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 446, 36 },
      7,
   } },

   /* replace1833_0 -> 16 in the cache */
   /* replace1833_1 -> 36 in the cache */
   /* replace1833 -> 2058 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1834_0_0_0 -> 16 in the cache */
   /* search1834_0_0 -> 3238 in the cache */
   /* search1834_0 -> 5036 in the cache */
   /* search1834_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5036, 36 },
      7,
   } },

   /* replace1834_0 -> 16 in the cache */
   /* replace1834_1 -> 36 in the cache */
   /* replace1834 -> 2082 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1835_0_0_0 -> 16 in the cache */
   /* search1835_0_0 -> 4196 in the cache */
   /* search1835_0 -> 5038 in the cache */
   /* search1835_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5038, 36 },
      7,
   } },

   /* replace1835_0 -> 16 in the cache */
   /* replace1835_1 -> 36 in the cache */
   /* replace1835 -> 2082 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1836_0_0 -> 16 in the cache */
   /* search1836_0_1 -> 124 in the cache */
   /* search1836_0 -> 446 in the cache */
   /* search1836_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 446, 36 },
      7,
   } },

   /* replace1836_0 -> 16 in the cache */
   /* replace1836_1 -> 36 in the cache */
   /* replace1836 -> 2082 in the cache */

   /* ('i2i32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a */
   /* search1837_0_0 -> 16 in the cache */
   /* search1837_0 -> 3238 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3238 },
      7,
   } },

   /* replace1837 -> 16 in the cache */

   /* ('extract_i16(only_lower_16_bits_used)', 'a@32', 0) => a */
   /* search1838_0 -> 16 in the cache */
   /* search1838_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 124 },
      7,
   } },

   /* replace1838 -> 16 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1839_0 -> 523 in the cache */
   /* search1839_1_0_0 -> 185 in the cache */
   /* search1839_1_0 -> 5028 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 5028 },
      -1,
   } },
   /* search1839_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5055, 561 },
      7,
   } },

   /* replace1839_0 -> 523 in the cache */
   /* replace1839_1 -> 185 in the cache */
   /* replace1839_2 -> 561 in the cache */
   /* replace1839 -> 4978 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1840_0 -> 523 in the cache */
   /* search1840_1_0_0 -> 185 in the cache */
   /* search1840_1_0 -> 5031 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 5031 },
      -1,
   } },
   /* search1840_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5057, 561 },
      7,
   } },

   /* replace1840_0 -> 523 in the cache */
   /* replace1840_1 -> 185 in the cache */
   /* replace1840_2 -> 561 in the cache */
   /* replace1840 -> 4978 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('extract_i16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1841_0 -> 523 in the cache */
   /* search1841_1_0 -> 185 in the cache */
   /* search1841_1_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 185, 124 },
      -1,
   } },
   /* search1841_2 -> 561 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5059, 561 },
      7,
   } },

   /* replace1841_0 -> 523 in the cache */
   /* replace1841_1 -> 185 in the cache */
   /* replace1841_2 -> 561 in the cache */
   /* replace1841 -> 4978 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1842_0_0_0 -> 16 in the cache */
   /* search1842_0_0 -> 3238 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3238 },
      -1,
   } },
   /* search1842_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5061, 36 },
      7,
   } },

   /* replace1842_0 -> 16 in the cache */
   /* replace1842_1 -> 36 in the cache */
   /* replace1842 -> 4007 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1843_0_0_0 -> 16 in the cache */
   /* search1843_0_0 -> 4196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4196 },
      -1,
   } },
   /* search1843_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5063, 36 },
      7,
   } },

   /* replace1843_0 -> 16 in the cache */
   /* replace1843_1 -> 36 in the cache */
   /* replace1843 -> 4007 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1844_0_0 -> 16 in the cache */
   /* search1844_0_1 -> 124 in the cache */
   /* search1844_0 -> 438 in the cache */
   /* search1844_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 438, 36 },
      7,
   } },

   /* replace1844_0 -> 16 in the cache */
   /* replace1844_1 -> 36 in the cache */
   /* replace1844 -> 4007 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1845_0_0_0 -> 16 in the cache */
   /* search1845_0_0 -> 3238 in the cache */
   /* search1845_0 -> 5061 in the cache */
   /* search1845_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5061, 36 },
      7,
   } },

   /* replace1845_0 -> 16 in the cache */
   /* replace1845_1 -> 36 in the cache */
   /* replace1845 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1846_0_0_0 -> 16 in the cache */
   /* search1846_0_0 -> 4196 in the cache */
   /* search1846_0 -> 5063 in the cache */
   /* search1846_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5063, 36 },
      7,
   } },

   /* replace1846_0 -> 16 in the cache */
   /* replace1846_1 -> 36 in the cache */
   /* replace1846 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1847_0_0 -> 16 in the cache */
   /* search1847_0_1 -> 124 in the cache */
   /* search1847_0 -> 438 in the cache */
   /* search1847_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 438, 36 },
      7,
   } },

   /* replace1847_0 -> 16 in the cache */
   /* replace1847_1 -> 36 in the cache */
   /* replace1847 -> 49 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1848_0_0_0 -> 16 in the cache */
   /* search1848_0_0 -> 3238 in the cache */
   /* search1848_0 -> 5061 in the cache */
   /* search1848_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5061, 36 },
      7,
   } },

   /* replace1848_0 -> 16 in the cache */
   /* replace1848_1 -> 36 in the cache */
   /* replace1848 -> 2020 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1849_0_0_0 -> 16 in the cache */
   /* search1849_0_0 -> 4196 in the cache */
   /* search1849_0 -> 5063 in the cache */
   /* search1849_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5063, 36 },
      7,
   } },

   /* replace1849_0 -> 16 in the cache */
   /* replace1849_1 -> 36 in the cache */
   /* replace1849 -> 2020 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1850_0_0 -> 16 in the cache */
   /* search1850_0_1 -> 124 in the cache */
   /* search1850_0 -> 438 in the cache */
   /* search1850_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 438, 36 },
      7,
   } },

   /* replace1850_0 -> 16 in the cache */
   /* replace1850_1 -> 36 in the cache */
   /* replace1850 -> 2020 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1851_0_0_0 -> 16 in the cache */
   /* search1851_0_0 -> 3238 in the cache */
   /* search1851_0 -> 5061 in the cache */
   /* search1851_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5061, 36 },
      7,
   } },

   /* replace1851_0 -> 16 in the cache */
   /* replace1851_1 -> 36 in the cache */
   /* replace1851 -> 2058 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1852_0_0_0 -> 16 in the cache */
   /* search1852_0_0 -> 4196 in the cache */
   /* search1852_0 -> 5063 in the cache */
   /* search1852_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5063, 36 },
      7,
   } },

   /* replace1852_0 -> 16 in the cache */
   /* replace1852_1 -> 36 in the cache */
   /* replace1852 -> 2058 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1853_0_0 -> 16 in the cache */
   /* search1853_0_1 -> 124 in the cache */
   /* search1853_0 -> 438 in the cache */
   /* search1853_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 438, 36 },
      7,
   } },

   /* replace1853_0 -> 16 in the cache */
   /* replace1853_1 -> 36 in the cache */
   /* replace1853 -> 2058 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1854_0_0_0 -> 16 in the cache */
   /* search1854_0_0 -> 3238 in the cache */
   /* search1854_0 -> 5061 in the cache */
   /* search1854_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5061, 36 },
      7,
   } },

   /* replace1854_0 -> 16 in the cache */
   /* replace1854_1 -> 36 in the cache */
   /* replace1854 -> 2082 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1855_0_0_0 -> 16 in the cache */
   /* search1855_0_0 -> 4196 in the cache */
   /* search1855_0 -> 5063 in the cache */
   /* search1855_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5063, 36 },
      7,
   } },

   /* replace1855_0 -> 16 in the cache */
   /* replace1855_1 -> 36 in the cache */
   /* replace1855 -> 2082 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1856_0_0 -> 16 in the cache */
   /* search1856_0_1 -> 124 in the cache */
   /* search1856_0 -> 438 in the cache */
   /* search1856_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 438, 36 },
      7,
   } },

   /* replace1856_0 -> 16 in the cache */
   /* replace1856_1 -> 36 in the cache */
   /* replace1856 -> 2082 in the cache */

   /* ('ldexp@16', 'x', 'exp') => ('fmul', ('fmul', 'x', ('i2i16', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -30), 30), 1), 15), 10))), ('i2i16', ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -30), 30), ('ishr', ('imin', ('imax', 'exp', -30), 30), 1)), 15), 10))) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* exp */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 5078, 5079 },
      -1,
   } },

   /* replace1857_0_0 -> 5078 in the cache */
   /* replace1857_0_1_0_0_0_0_0_0 -> 5079 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x1e /* -30 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 5079, 5081 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1e /* 30 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 5082, 5083 },
      -1,
   } },
   /* replace1857_0_1_0_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5084, 398 },
      -1,
   } },
   /* replace1857_0_1_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 5085, 14 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xa /* 10 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 5086, 5087 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 3,
      { 5088 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 5078, 5089 },
      -1,
   } },
   /* replace1857_1_0_0_0_0_0_0 -> 5079 in the cache */
   /* replace1857_1_0_0_0_0_0_1 -> 5081 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 5079, 5081 },
      -1,
   } },
   /* replace1857_1_0_0_0_0_1 -> 5083 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 5091, 5083 },
      -1,
   } },
   /* replace1857_1_0_0_0_1_0_0_0 -> 5079 in the cache */
   /* replace1857_1_0_0_0_1_0_0_1 -> 5081 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 5079, 5081 },
      -1,
   } },
   /* replace1857_1_0_0_0_1_0_1 -> 5083 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 5093, 5083 },
      -1,
   } },
   /* replace1857_1_0_0_0_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5094, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 5092, 5095 },
      -1,
   } },
   /* replace1857_1_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 5096, 14 },
      -1,
   } },
   /* replace1857_1_0_1 -> 5087 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5097, 5087 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 5,
      { 5098 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 5090, 5099 },
      -1,
   } },

   /* ('ldexp@32', 'x', 'exp') => ('fmul', ('fmul', 'x', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -254), 254), 1), 127), 23)), ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -254), 254), ('ishr', ('imin', ('imax', 'exp', -254), 254), 1)), 127), 23)) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1858_1 -> 5079 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 5101, 5079 },
      -1,
   } },

   /* replace1858_0_0 -> 5101 in the cache */
   /* replace1858_0_1_0_0_0_0_0 -> 5079 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0xfe /* -254 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 5079, 5103 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfe /* 254 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 5104, 5105 },
      -1,
   } },
   /* replace1858_0_1_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5106, 398 },
      -1,
   } },
   /* replace1858_0_1_0_1 -> 4280 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 5107, 4280 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x17 /* 23 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 5108, 5109 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 5101, 5110 },
      -1,
   } },
   /* replace1858_1_0_0_0_0_0 -> 5079 in the cache */
   /* replace1858_1_0_0_0_0_1 -> 5103 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 5079, 5103 },
      -1,
   } },
   /* replace1858_1_0_0_0_1 -> 5105 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 5112, 5105 },
      -1,
   } },
   /* replace1858_1_0_0_1_0_0_0 -> 5079 in the cache */
   /* replace1858_1_0_0_1_0_0_1 -> 5103 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 5079, 5103 },
      -1,
   } },
   /* replace1858_1_0_0_1_0_1 -> 5105 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 5114, 5105 },
      -1,
   } },
   /* replace1858_1_0_0_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5115, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 5113, 5116 },
      -1,
   } },
   /* replace1858_1_0_1 -> 4280 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 5117, 4280 },
      -1,
   } },
   /* replace1858_1_1 -> 5109 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5118, 5109 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 5111, 5119 },
      -1,
   } },

   /* ('ldexp@64', 'x', 'exp') => ('fmul', ('fmul', 'x', ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1), 1023), 20))), ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -2046), 2046), ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1)), 1023), 20))) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1859_1 -> 5079 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 5121, 5079 },
      -1,
   } },

   /* replace1859_0_0 -> 5121 in the cache */
   /* replace1859_0_1_0 -> 124 in the cache */
   /* replace1859_0_1_1_0_0_0_0_0 -> 5079 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x7fe /* -2046 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 5079, 5123 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fe /* 2046 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 5124, 5125 },
      -1,
   } },
   /* replace1859_0_1_1_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5126, 398 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3ff /* 1023 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 5127, 5128 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x14 /* 20 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 5129, 5130 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 3,
      { 124, 5131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 5121, 5132 },
      -1,
   } },
   /* replace1859_1_0 -> 124 in the cache */
   /* replace1859_1_1_0_0_0_0_0 -> 5079 in the cache */
   /* replace1859_1_1_0_0_0_0_1 -> 5123 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 5079, 5123 },
      -1,
   } },
   /* replace1859_1_1_0_0_0_1 -> 5125 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 5134, 5125 },
      -1,
   } },
   /* replace1859_1_1_0_0_1_0_0_0 -> 5079 in the cache */
   /* replace1859_1_1_0_0_1_0_0_1 -> 5123 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 5079, 5123 },
      -1,
   } },
   /* replace1859_1_1_0_0_1_0_1 -> 5125 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 5136, 5125 },
      -1,
   } },
   /* replace1859_1_1_0_0_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5137, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 5135, 5138 },
      -1,
   } },
   /* replace1859_1_1_0_1 -> 5128 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 5139, 5128 },
      -1,
   } },
   /* replace1859_1_1_1 -> 5130 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5140, 5130 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 5,
      { 124, 5141 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 5133, 5142 },
      -1,
   } },

   /* ('ior(many-comm-expr)', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 1431655765), 1), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 2863311530), 1)) => ('bitfield_reverse', 'x') */
   /* search1860_0_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5101 in the cache */
   /* search1860_0_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 5101, 846 },
      -1,
   } },
   /* search1860_0_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 5101 in the cache */
   /* search1860_0_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 846 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 5101, 846 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      8, 1,
      { 5144, 5145 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00ff /* 16711935 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      7, 2,
      { 5146, 5147 },
      -1,
   } },
   /* search1860_0_0_0_0_0_0_0_0_0_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5148, 824 },
      -1,
   } },
   /* search1860_0_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 5101 in the cache */
   /* search1860_0_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 846 in the cache */
   /* search1860_0_0_0_0_0_0_0_0_0_1_0_0_0 -> 5144 in the cache */
   /* search1860_0_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 5101 in the cache */
   /* search1860_0_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 846 in the cache */
   /* search1860_0_0_0_0_0_0_0_0_0_1_0_0_1 -> 5145 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      10, 1,
      { 5144, 5145 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00ff00 /* 4278255360 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      9, 2,
      { 5150, 5151 },
      -1,
   } },
   /* search1860_0_0_0_0_0_0_0_0_0_1_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5152, 824 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      6, 5,
      { 5149, 5153 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf0f0f0f /* 252645135 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      5, 6,
      { 5154, 5155 },
      -1,
   } },
   /* search1860_0_0_0_0_0_0_0_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 5156, 2187 },
      -1,
   } },
   /* search1860_0_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 5101 in the cache */
   /* search1860_0_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 846 in the cache */
   /* search1860_0_0_0_0_0_0_1_0_0_0_0_0_0 -> 5144 in the cache */
   /* search1860_0_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 5101 in the cache */
   /* search1860_0_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 846 in the cache */
   /* search1860_0_0_0_0_0_0_1_0_0_0_0_0_1 -> 5145 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      14, 1,
      { 5144, 5145 },
      -1,
   } },
   /* search1860_0_0_0_0_0_0_1_0_0_0_0_1 -> 5147 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      13, 2,
      { 5158, 5147 },
      -1,
   } },
   /* search1860_0_0_0_0_0_0_1_0_0_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5159, 824 },
      -1,
   } },
   /* search1860_0_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 5101 in the cache */
   /* search1860_0_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 846 in the cache */
   /* search1860_0_0_0_0_0_0_1_0_0_1_0_0_0 -> 5144 in the cache */
   /* search1860_0_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 5101 in the cache */
   /* search1860_0_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 846 in the cache */
   /* search1860_0_0_0_0_0_0_1_0_0_1_0_0_1 -> 5145 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      16, 1,
      { 5144, 5145 },
      -1,
   } },
   /* search1860_0_0_0_0_0_0_1_0_0_1_0_1 -> 5151 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      15, 2,
      { 5161, 5151 },
      -1,
   } },
   /* search1860_0_0_0_0_0_0_1_0_0_1_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5162, 824 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      12, 5,
      { 5160, 5163 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf0f0f0f0 /* 4042322160 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      11, 6,
      { 5164, 5165 },
      -1,
   } },
   /* search1860_0_0_0_0_0_0_1_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 5166, 2187 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      4, 13,
      { 5157, 5167 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x33333333 /* 858993459 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 14,
      { 5168, 5169 },
      -1,
   } },
   /* search1860_0_0_0_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 14,
      { 5170, 403 },
      -1,
   } },
   /* search1860_0_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 5101 in the cache */
   /* search1860_0_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 846 in the cache */
   /* search1860_0_0_0_1_0_0_0_0_0_0_0_0_0 -> 5144 in the cache */
   /* search1860_0_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 5101 in the cache */
   /* search1860_0_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 846 in the cache */
   /* search1860_0_0_0_1_0_0_0_0_0_0_0_0_1 -> 5145 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      22, 1,
      { 5144, 5145 },
      -1,
   } },
   /* search1860_0_0_0_1_0_0_0_0_0_0_0_1 -> 5147 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      21, 2,
      { 5172, 5147 },
      -1,
   } },
   /* search1860_0_0_0_1_0_0_0_0_0_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5173, 824 },
      -1,
   } },
   /* search1860_0_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 5101 in the cache */
   /* search1860_0_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 846 in the cache */
   /* search1860_0_0_0_1_0_0_0_0_0_1_0_0_0 -> 5144 in the cache */
   /* search1860_0_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 5101 in the cache */
   /* search1860_0_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 846 in the cache */
   /* search1860_0_0_0_1_0_0_0_0_0_1_0_0_1 -> 5145 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      24, 1,
      { 5144, 5145 },
      -1,
   } },
   /* search1860_0_0_0_1_0_0_0_0_0_1_0_1 -> 5151 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      23, 2,
      { 5175, 5151 },
      -1,
   } },
   /* search1860_0_0_0_1_0_0_0_0_0_1_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5176, 824 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      20, 5,
      { 5174, 5177 },
      -1,
   } },
   /* search1860_0_0_0_1_0_0_0_0_1 -> 5155 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      19, 6,
      { 5178, 5155 },
      -1,
   } },
   /* search1860_0_0_0_1_0_0_0_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 5179, 2187 },
      -1,
   } },
   /* search1860_0_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 5101 in the cache */
   /* search1860_0_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 846 in the cache */
   /* search1860_0_0_0_1_0_0_1_0_0_0_0_0_0 -> 5144 in the cache */
   /* search1860_0_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 5101 in the cache */
   /* search1860_0_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 846 in the cache */
   /* search1860_0_0_0_1_0_0_1_0_0_0_0_0_1 -> 5145 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      28, 1,
      { 5144, 5145 },
      -1,
   } },
   /* search1860_0_0_0_1_0_0_1_0_0_0_0_1 -> 5147 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      27, 2,
      { 5181, 5147 },
      -1,
   } },
   /* search1860_0_0_0_1_0_0_1_0_0_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5182, 824 },
      -1,
   } },
   /* search1860_0_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 5101 in the cache */
   /* search1860_0_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 846 in the cache */
   /* search1860_0_0_0_1_0_0_1_0_0_1_0_0_0 -> 5144 in the cache */
   /* search1860_0_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 5101 in the cache */
   /* search1860_0_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 846 in the cache */
   /* search1860_0_0_0_1_0_0_1_0_0_1_0_0_1 -> 5145 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      30, 1,
      { 5144, 5145 },
      -1,
   } },
   /* search1860_0_0_0_1_0_0_1_0_0_1_0_1 -> 5151 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      29, 2,
      { 5184, 5151 },
      -1,
   } },
   /* search1860_0_0_0_1_0_0_1_0_0_1_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5185, 824 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      26, 5,
      { 5183, 5186 },
      -1,
   } },
   /* search1860_0_0_0_1_0_0_1_0_1 -> 5165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      25, 6,
      { 5187, 5165 },
      -1,
   } },
   /* search1860_0_0_0_1_0_0_1_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 5188, 2187 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      18, 13,
      { 5180, 5189 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xcccccccc /* 3435973836 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      17, 14,
      { 5190, 5191 },
      -1,
   } },
   /* search1860_0_0_0_1_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 14,
      { 5192, 403 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      2, 29,
      { 5171, 5193 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x55555555 /* 1431655765 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 30,
      { 5194, 5195 },
      -1,
   } },
   /* search1860_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 30,
      { 5196, 398 },
      -1,
   } },
   /* search1860_1_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5101 in the cache */
   /* search1860_1_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 846 in the cache */
   /* search1860_1_0_0_0_0_0_0_0_0_0_0_0_0 -> 5144 in the cache */
   /* search1860_1_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 5101 in the cache */
   /* search1860_1_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 846 in the cache */
   /* search1860_1_0_0_0_0_0_0_0_0_0_0_0_1 -> 5145 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      38, 1,
      { 5144, 5145 },
      -1,
   } },
   /* search1860_1_0_0_0_0_0_0_0_0_0_0_1 -> 5147 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      37, 2,
      { 5198, 5147 },
      -1,
   } },
   /* search1860_1_0_0_0_0_0_0_0_0_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5199, 824 },
      -1,
   } },
   /* search1860_1_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 5101 in the cache */
   /* search1860_1_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 846 in the cache */
   /* search1860_1_0_0_0_0_0_0_0_0_1_0_0_0 -> 5144 in the cache */
   /* search1860_1_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 5101 in the cache */
   /* search1860_1_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 846 in the cache */
   /* search1860_1_0_0_0_0_0_0_0_0_1_0_0_1 -> 5145 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      40, 1,
      { 5144, 5145 },
      -1,
   } },
   /* search1860_1_0_0_0_0_0_0_0_0_1_0_1 -> 5151 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      39, 2,
      { 5201, 5151 },
      -1,
   } },
   /* search1860_1_0_0_0_0_0_0_0_0_1_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5202, 824 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      36, 5,
      { 5200, 5203 },
      -1,
   } },
   /* search1860_1_0_0_0_0_0_0_0_1 -> 5155 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      35, 6,
      { 5204, 5155 },
      -1,
   } },
   /* search1860_1_0_0_0_0_0_0_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 5205, 2187 },
      -1,
   } },
   /* search1860_1_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 5101 in the cache */
   /* search1860_1_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 846 in the cache */
   /* search1860_1_0_0_0_0_0_1_0_0_0_0_0_0 -> 5144 in the cache */
   /* search1860_1_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 5101 in the cache */
   /* search1860_1_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 846 in the cache */
   /* search1860_1_0_0_0_0_0_1_0_0_0_0_0_1 -> 5145 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      44, 1,
      { 5144, 5145 },
      -1,
   } },
   /* search1860_1_0_0_0_0_0_1_0_0_0_0_1 -> 5147 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      43, 2,
      { 5207, 5147 },
      -1,
   } },
   /* search1860_1_0_0_0_0_0_1_0_0_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5208, 824 },
      -1,
   } },
   /* search1860_1_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 5101 in the cache */
   /* search1860_1_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 846 in the cache */
   /* search1860_1_0_0_0_0_0_1_0_0_1_0_0_0 -> 5144 in the cache */
   /* search1860_1_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 5101 in the cache */
   /* search1860_1_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 846 in the cache */
   /* search1860_1_0_0_0_0_0_1_0_0_1_0_0_1 -> 5145 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      46, 1,
      { 5144, 5145 },
      -1,
   } },
   /* search1860_1_0_0_0_0_0_1_0_0_1_0_1 -> 5151 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      45, 2,
      { 5210, 5151 },
      -1,
   } },
   /* search1860_1_0_0_0_0_0_1_0_0_1_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5211, 824 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      42, 5,
      { 5209, 5212 },
      -1,
   } },
   /* search1860_1_0_0_0_0_0_1_0_1 -> 5165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      41, 6,
      { 5213, 5165 },
      -1,
   } },
   /* search1860_1_0_0_0_0_0_1_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 5214, 2187 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      34, 13,
      { 5206, 5215 },
      -1,
   } },
   /* search1860_1_0_0_0_0_1 -> 5169 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      33, 14,
      { 5216, 5169 },
      -1,
   } },
   /* search1860_1_0_0_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 14,
      { 5217, 403 },
      -1,
   } },
   /* search1860_1_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 5101 in the cache */
   /* search1860_1_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 846 in the cache */
   /* search1860_1_0_0_1_0_0_0_0_0_0_0_0_0 -> 5144 in the cache */
   /* search1860_1_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 5101 in the cache */
   /* search1860_1_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 846 in the cache */
   /* search1860_1_0_0_1_0_0_0_0_0_0_0_0_1 -> 5145 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      52, 1,
      { 5144, 5145 },
      -1,
   } },
   /* search1860_1_0_0_1_0_0_0_0_0_0_0_1 -> 5147 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      51, 2,
      { 5219, 5147 },
      -1,
   } },
   /* search1860_1_0_0_1_0_0_0_0_0_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5220, 824 },
      -1,
   } },
   /* search1860_1_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 5101 in the cache */
   /* search1860_1_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 846 in the cache */
   /* search1860_1_0_0_1_0_0_0_0_0_1_0_0_0 -> 5144 in the cache */
   /* search1860_1_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 5101 in the cache */
   /* search1860_1_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 846 in the cache */
   /* search1860_1_0_0_1_0_0_0_0_0_1_0_0_1 -> 5145 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      54, 1,
      { 5144, 5145 },
      -1,
   } },
   /* search1860_1_0_0_1_0_0_0_0_0_1_0_1 -> 5151 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      53, 2,
      { 5222, 5151 },
      -1,
   } },
   /* search1860_1_0_0_1_0_0_0_0_0_1_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5223, 824 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      50, 5,
      { 5221, 5224 },
      -1,
   } },
   /* search1860_1_0_0_1_0_0_0_0_1 -> 5155 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      49, 6,
      { 5225, 5155 },
      -1,
   } },
   /* search1860_1_0_0_1_0_0_0_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 5226, 2187 },
      -1,
   } },
   /* search1860_1_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 5101 in the cache */
   /* search1860_1_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 846 in the cache */
   /* search1860_1_0_0_1_0_0_1_0_0_0_0_0_0 -> 5144 in the cache */
   /* search1860_1_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 5101 in the cache */
   /* search1860_1_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 846 in the cache */
   /* search1860_1_0_0_1_0_0_1_0_0_0_0_0_1 -> 5145 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      58, 1,
      { 5144, 5145 },
      -1,
   } },
   /* search1860_1_0_0_1_0_0_1_0_0_0_0_1 -> 5147 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      57, 2,
      { 5228, 5147 },
      -1,
   } },
   /* search1860_1_0_0_1_0_0_1_0_0_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5229, 824 },
      -1,
   } },
   /* search1860_1_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 5101 in the cache */
   /* search1860_1_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 846 in the cache */
   /* search1860_1_0_0_1_0_0_1_0_0_1_0_0_0 -> 5144 in the cache */
   /* search1860_1_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 5101 in the cache */
   /* search1860_1_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 846 in the cache */
   /* search1860_1_0_0_1_0_0_1_0_0_1_0_0_1 -> 5145 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      60, 1,
      { 5144, 5145 },
      -1,
   } },
   /* search1860_1_0_0_1_0_0_1_0_0_1_0_1 -> 5151 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      59, 2,
      { 5231, 5151 },
      -1,
   } },
   /* search1860_1_0_0_1_0_0_1_0_0_1_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5232, 824 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      56, 5,
      { 5230, 5233 },
      -1,
   } },
   /* search1860_1_0_0_1_0_0_1_0_1 -> 5165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      55, 6,
      { 5234, 5165 },
      -1,
   } },
   /* search1860_1_0_0_1_0_0_1_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 5235, 2187 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      48, 13,
      { 5227, 5236 },
      -1,
   } },
   /* search1860_1_0_0_1_0_1 -> 5191 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      47, 14,
      { 5237, 5191 },
      -1,
   } },
   /* search1860_1_0_0_1_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 14,
      { 5238, 403 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      32, 29,
      { 5218, 5239 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xaaaaaaaa /* 2863311530 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      31, 30,
      { 5240, 5241 },
      -1,
   } },
   /* search1860_1_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 30,
      { 5242, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 61,
      { 5197, 5243 },
      -1,
   } },

   /* replace1860_0 -> 5101 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_reverse,
      -1, 0,
      { 5101 },
      -1,
   } },

   /* ('ior(many-comm-expr)', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 4278255360), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 16711935)) => ('bitfield_reverse', 'x') */
   /* search1861_0_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5101 in the cache */
   /* search1861_0_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 846 in the cache */
   /* search1861_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5144 in the cache */
   /* search1861_0_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 5101 in the cache */
   /* search1861_0_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 846 in the cache */
   /* search1861_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 5145 in the cache */
   /* search1861_0_0_0_0_0_0_0_0_0_0_0_0 -> 5146 in the cache */
   /* search1861_0_0_0_0_0_0_0_0_0_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5146, 398 },
      -1,
   } },
   /* search1861_0_0_0_0_0_0_0_0_0_0_1 -> 5241 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      7, 2,
      { 5246, 5241 },
      -1,
   } },
   /* search1861_0_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 5101 in the cache */
   /* search1861_0_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 846 in the cache */
   /* search1861_0_0_0_0_0_0_0_0_0_1_0_0_0 -> 5144 in the cache */
   /* search1861_0_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 5101 in the cache */
   /* search1861_0_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 846 in the cache */
   /* search1861_0_0_0_0_0_0_0_0_0_1_0_0_1 -> 5145 in the cache */
   /* search1861_0_0_0_0_0_0_0_0_0_1_0_0 -> 5150 in the cache */
   /* search1861_0_0_0_0_0_0_0_0_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5150, 398 },
      -1,
   } },
   /* search1861_0_0_0_0_0_0_0_0_0_1_1 -> 5195 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      9, 2,
      { 5248, 5195 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      6, 5,
      { 5247, 5249 },
      -1,
   } },
   /* search1861_0_0_0_0_0_0_0_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5250, 403 },
      -1,
   } },
   /* search1861_0_0_0_0_0_0_0_1 -> 5191 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      5, 6,
      { 5251, 5191 },
      -1,
   } },
   /* search1861_0_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 5101 in the cache */
   /* search1861_0_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 846 in the cache */
   /* search1861_0_0_0_0_0_0_1_0_0_0_0_0_0 -> 5144 in the cache */
   /* search1861_0_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 5101 in the cache */
   /* search1861_0_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 846 in the cache */
   /* search1861_0_0_0_0_0_0_1_0_0_0_0_0_1 -> 5145 in the cache */
   /* search1861_0_0_0_0_0_0_1_0_0_0_0_0 -> 5158 in the cache */
   /* search1861_0_0_0_0_0_0_1_0_0_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5158, 398 },
      -1,
   } },
   /* search1861_0_0_0_0_0_0_1_0_0_0_1 -> 5241 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      13, 2,
      { 5253, 5241 },
      -1,
   } },
   /* search1861_0_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 5101 in the cache */
   /* search1861_0_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 846 in the cache */
   /* search1861_0_0_0_0_0_0_1_0_0_1_0_0_0 -> 5144 in the cache */
   /* search1861_0_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 5101 in the cache */
   /* search1861_0_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 846 in the cache */
   /* search1861_0_0_0_0_0_0_1_0_0_1_0_0_1 -> 5145 in the cache */
   /* search1861_0_0_0_0_0_0_1_0_0_1_0_0 -> 5161 in the cache */
   /* search1861_0_0_0_0_0_0_1_0_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5161, 398 },
      -1,
   } },
   /* search1861_0_0_0_0_0_0_1_0_0_1_1 -> 5195 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      15, 2,
      { 5255, 5195 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      12, 5,
      { 5254, 5256 },
      -1,
   } },
   /* search1861_0_0_0_0_0_0_1_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 5257, 403 },
      -1,
   } },
   /* search1861_0_0_0_0_0_0_1_1 -> 5169 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      11, 6,
      { 5258, 5169 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      4, 13,
      { 5252, 5259 },
      -1,
   } },
   /* search1861_0_0_0_0_0_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 13,
      { 5260, 2187 },
      -1,
   } },
   /* search1861_0_0_0_0_1 -> 5165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 14,
      { 5261, 5165 },
      -1,
   } },
   /* search1861_0_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 5101 in the cache */
   /* search1861_0_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 846 in the cache */
   /* search1861_0_0_0_1_0_0_0_0_0_0_0_0_0 -> 5144 in the cache */
   /* search1861_0_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 5101 in the cache */
   /* search1861_0_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 846 in the cache */
   /* search1861_0_0_0_1_0_0_0_0_0_0_0_0_1 -> 5145 in the cache */
   /* search1861_0_0_0_1_0_0_0_0_0_0_0_0 -> 5172 in the cache */
   /* search1861_0_0_0_1_0_0_0_0_0_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5172, 398 },
      -1,
   } },
   /* search1861_0_0_0_1_0_0_0_0_0_0_1 -> 5241 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      21, 2,
      { 5263, 5241 },
      -1,
   } },
   /* search1861_0_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 5101 in the cache */
   /* search1861_0_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 846 in the cache */
   /* search1861_0_0_0_1_0_0_0_0_0_1_0_0_0 -> 5144 in the cache */
   /* search1861_0_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 5101 in the cache */
   /* search1861_0_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 846 in the cache */
   /* search1861_0_0_0_1_0_0_0_0_0_1_0_0_1 -> 5145 in the cache */
   /* search1861_0_0_0_1_0_0_0_0_0_1_0_0 -> 5175 in the cache */
   /* search1861_0_0_0_1_0_0_0_0_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5175, 398 },
      -1,
   } },
   /* search1861_0_0_0_1_0_0_0_0_0_1_1 -> 5195 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      23, 2,
      { 5265, 5195 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      20, 5,
      { 5264, 5266 },
      -1,
   } },
   /* search1861_0_0_0_1_0_0_0_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5267, 403 },
      -1,
   } },
   /* search1861_0_0_0_1_0_0_0_1 -> 5191 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      19, 6,
      { 5268, 5191 },
      -1,
   } },
   /* search1861_0_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 5101 in the cache */
   /* search1861_0_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 846 in the cache */
   /* search1861_0_0_0_1_0_0_1_0_0_0_0_0_0 -> 5144 in the cache */
   /* search1861_0_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 5101 in the cache */
   /* search1861_0_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 846 in the cache */
   /* search1861_0_0_0_1_0_0_1_0_0_0_0_0_1 -> 5145 in the cache */
   /* search1861_0_0_0_1_0_0_1_0_0_0_0_0 -> 5181 in the cache */
   /* search1861_0_0_0_1_0_0_1_0_0_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5181, 398 },
      -1,
   } },
   /* search1861_0_0_0_1_0_0_1_0_0_0_1 -> 5241 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      27, 2,
      { 5270, 5241 },
      -1,
   } },
   /* search1861_0_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 5101 in the cache */
   /* search1861_0_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 846 in the cache */
   /* search1861_0_0_0_1_0_0_1_0_0_1_0_0_0 -> 5144 in the cache */
   /* search1861_0_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 5101 in the cache */
   /* search1861_0_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 846 in the cache */
   /* search1861_0_0_0_1_0_0_1_0_0_1_0_0_1 -> 5145 in the cache */
   /* search1861_0_0_0_1_0_0_1_0_0_1_0_0 -> 5184 in the cache */
   /* search1861_0_0_0_1_0_0_1_0_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5184, 398 },
      -1,
   } },
   /* search1861_0_0_0_1_0_0_1_0_0_1_1 -> 5195 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      29, 2,
      { 5272, 5195 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      26, 5,
      { 5271, 5273 },
      -1,
   } },
   /* search1861_0_0_0_1_0_0_1_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 5274, 403 },
      -1,
   } },
   /* search1861_0_0_0_1_0_0_1_1 -> 5169 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      25, 6,
      { 5275, 5169 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      18, 13,
      { 5269, 5276 },
      -1,
   } },
   /* search1861_0_0_0_1_0_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 13,
      { 5277, 2187 },
      -1,
   } },
   /* search1861_0_0_0_1_1 -> 5155 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      17, 14,
      { 5278, 5155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      2, 29,
      { 5262, 5279 },
      -1,
   } },
   /* search1861_0_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 29,
      { 5280, 824 },
      -1,
   } },
   /* search1861_0_1 -> 5151 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 30,
      { 5281, 5151 },
      -1,
   } },
   /* search1861_1_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5101 in the cache */
   /* search1861_1_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 846 in the cache */
   /* search1861_1_0_0_0_0_0_0_0_0_0_0_0_0 -> 5144 in the cache */
   /* search1861_1_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 5101 in the cache */
   /* search1861_1_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 846 in the cache */
   /* search1861_1_0_0_0_0_0_0_0_0_0_0_0_1 -> 5145 in the cache */
   /* search1861_1_0_0_0_0_0_0_0_0_0_0_0 -> 5198 in the cache */
   /* search1861_1_0_0_0_0_0_0_0_0_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5198, 398 },
      -1,
   } },
   /* search1861_1_0_0_0_0_0_0_0_0_0_1 -> 5241 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      37, 2,
      { 5283, 5241 },
      -1,
   } },
   /* search1861_1_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 5101 in the cache */
   /* search1861_1_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 846 in the cache */
   /* search1861_1_0_0_0_0_0_0_0_0_1_0_0_0 -> 5144 in the cache */
   /* search1861_1_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 5101 in the cache */
   /* search1861_1_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 846 in the cache */
   /* search1861_1_0_0_0_0_0_0_0_0_1_0_0_1 -> 5145 in the cache */
   /* search1861_1_0_0_0_0_0_0_0_0_1_0_0 -> 5201 in the cache */
   /* search1861_1_0_0_0_0_0_0_0_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5201, 398 },
      -1,
   } },
   /* search1861_1_0_0_0_0_0_0_0_0_1_1 -> 5195 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      39, 2,
      { 5285, 5195 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      36, 5,
      { 5284, 5286 },
      -1,
   } },
   /* search1861_1_0_0_0_0_0_0_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5287, 403 },
      -1,
   } },
   /* search1861_1_0_0_0_0_0_0_1 -> 5191 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      35, 6,
      { 5288, 5191 },
      -1,
   } },
   /* search1861_1_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 5101 in the cache */
   /* search1861_1_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 846 in the cache */
   /* search1861_1_0_0_0_0_0_1_0_0_0_0_0_0 -> 5144 in the cache */
   /* search1861_1_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 5101 in the cache */
   /* search1861_1_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 846 in the cache */
   /* search1861_1_0_0_0_0_0_1_0_0_0_0_0_1 -> 5145 in the cache */
   /* search1861_1_0_0_0_0_0_1_0_0_0_0_0 -> 5207 in the cache */
   /* search1861_1_0_0_0_0_0_1_0_0_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5207, 398 },
      -1,
   } },
   /* search1861_1_0_0_0_0_0_1_0_0_0_1 -> 5241 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      43, 2,
      { 5290, 5241 },
      -1,
   } },
   /* search1861_1_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 5101 in the cache */
   /* search1861_1_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 846 in the cache */
   /* search1861_1_0_0_0_0_0_1_0_0_1_0_0_0 -> 5144 in the cache */
   /* search1861_1_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 5101 in the cache */
   /* search1861_1_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 846 in the cache */
   /* search1861_1_0_0_0_0_0_1_0_0_1_0_0_1 -> 5145 in the cache */
   /* search1861_1_0_0_0_0_0_1_0_0_1_0_0 -> 5210 in the cache */
   /* search1861_1_0_0_0_0_0_1_0_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5210, 398 },
      -1,
   } },
   /* search1861_1_0_0_0_0_0_1_0_0_1_1 -> 5195 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      45, 2,
      { 5292, 5195 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      42, 5,
      { 5291, 5293 },
      -1,
   } },
   /* search1861_1_0_0_0_0_0_1_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 5294, 403 },
      -1,
   } },
   /* search1861_1_0_0_0_0_0_1_1 -> 5169 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      41, 6,
      { 5295, 5169 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      34, 13,
      { 5289, 5296 },
      -1,
   } },
   /* search1861_1_0_0_0_0_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 13,
      { 5297, 2187 },
      -1,
   } },
   /* search1861_1_0_0_0_1 -> 5165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      33, 14,
      { 5298, 5165 },
      -1,
   } },
   /* search1861_1_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 5101 in the cache */
   /* search1861_1_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 846 in the cache */
   /* search1861_1_0_0_1_0_0_0_0_0_0_0_0_0 -> 5144 in the cache */
   /* search1861_1_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 5101 in the cache */
   /* search1861_1_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 846 in the cache */
   /* search1861_1_0_0_1_0_0_0_0_0_0_0_0_1 -> 5145 in the cache */
   /* search1861_1_0_0_1_0_0_0_0_0_0_0_0 -> 5219 in the cache */
   /* search1861_1_0_0_1_0_0_0_0_0_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5219, 398 },
      -1,
   } },
   /* search1861_1_0_0_1_0_0_0_0_0_0_1 -> 5241 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      51, 2,
      { 5300, 5241 },
      -1,
   } },
   /* search1861_1_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 5101 in the cache */
   /* search1861_1_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 846 in the cache */
   /* search1861_1_0_0_1_0_0_0_0_0_1_0_0_0 -> 5144 in the cache */
   /* search1861_1_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 5101 in the cache */
   /* search1861_1_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 846 in the cache */
   /* search1861_1_0_0_1_0_0_0_0_0_1_0_0_1 -> 5145 in the cache */
   /* search1861_1_0_0_1_0_0_0_0_0_1_0_0 -> 5222 in the cache */
   /* search1861_1_0_0_1_0_0_0_0_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5222, 398 },
      -1,
   } },
   /* search1861_1_0_0_1_0_0_0_0_0_1_1 -> 5195 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      53, 2,
      { 5302, 5195 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      50, 5,
      { 5301, 5303 },
      -1,
   } },
   /* search1861_1_0_0_1_0_0_0_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5304, 403 },
      -1,
   } },
   /* search1861_1_0_0_1_0_0_0_1 -> 5191 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      49, 6,
      { 5305, 5191 },
      -1,
   } },
   /* search1861_1_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 5101 in the cache */
   /* search1861_1_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 846 in the cache */
   /* search1861_1_0_0_1_0_0_1_0_0_0_0_0_0 -> 5144 in the cache */
   /* search1861_1_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 5101 in the cache */
   /* search1861_1_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 846 in the cache */
   /* search1861_1_0_0_1_0_0_1_0_0_0_0_0_1 -> 5145 in the cache */
   /* search1861_1_0_0_1_0_0_1_0_0_0_0_0 -> 5228 in the cache */
   /* search1861_1_0_0_1_0_0_1_0_0_0_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5228, 398 },
      -1,
   } },
   /* search1861_1_0_0_1_0_0_1_0_0_0_1 -> 5241 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      57, 2,
      { 5307, 5241 },
      -1,
   } },
   /* search1861_1_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 5101 in the cache */
   /* search1861_1_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 846 in the cache */
   /* search1861_1_0_0_1_0_0_1_0_0_1_0_0_0 -> 5144 in the cache */
   /* search1861_1_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 5101 in the cache */
   /* search1861_1_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 846 in the cache */
   /* search1861_1_0_0_1_0_0_1_0_0_1_0_0_1 -> 5145 in the cache */
   /* search1861_1_0_0_1_0_0_1_0_0_1_0_0 -> 5231 in the cache */
   /* search1861_1_0_0_1_0_0_1_0_0_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5231, 398 },
      -1,
   } },
   /* search1861_1_0_0_1_0_0_1_0_0_1_1 -> 5195 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      59, 2,
      { 5309, 5195 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      56, 5,
      { 5308, 5310 },
      -1,
   } },
   /* search1861_1_0_0_1_0_0_1_0_1 -> 403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 5311, 403 },
      -1,
   } },
   /* search1861_1_0_0_1_0_0_1_1 -> 5169 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      55, 6,
      { 5312, 5169 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      48, 13,
      { 5306, 5313 },
      -1,
   } },
   /* search1861_1_0_0_1_0_1 -> 2187 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 13,
      { 5314, 2187 },
      -1,
   } },
   /* search1861_1_0_0_1_1 -> 5155 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      47, 14,
      { 5315, 5155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      32, 29,
      { 5299, 5316 },
      -1,
   } },
   /* search1861_1_0_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 29,
      { 5317, 824 },
      -1,
   } },
   /* search1861_1_1 -> 5147 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      31, 30,
      { 5318, 5147 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 61,
      { 5282, 5319 },
      -1,
   } },

   /* replace1861_0 -> 5101 in the cache */
   /* replace1861 -> 5245 in the cache */

   /* ('ball_iequal2', ('ieq', 'a', 'b'), -1) => ('ball_iequal2', 'a', 'b') */
   /* search1862_0_0 -> 0 in the cache */
   /* search1862_0_1 -> 3 in the cache */
   /* search1862_0 -> 1073 in the cache */
   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 2,
      { 1073, 5321 },
      -1,
   } },

   /* replace1862_0 -> 0 in the cache */
   /* replace1862_1 -> 3 in the cache */
   /* replace1862 -> 2427 in the cache */

   /* ('ball_iequal2', ('feq', 'a', 'b'), -1) => ('ball_fequal2', 'a', 'b') */
   /* search1863_0_0 -> 0 in the cache */
   /* search1863_0_1 -> 3 in the cache */
   /* search1863_0 -> 1067 in the cache */
   /* search1863_1 -> 5321 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 2,
      { 1067, 5321 },
      -1,
   } },

   /* replace1863_0 -> 0 in the cache */
   /* replace1863_1 -> 3 in the cache */
   /* replace1863 -> 2497 in the cache */

   /* ('bany_inequal2', ('ine', 'a', 'b'), 0) => ('bany_inequal2', 'a', 'b') */
   /* search1864_0_0 -> 0 in the cache */
   /* search1864_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 2,
      { 5324, 5325 },
      -1,
   } },

   /* replace1864_0 -> 0 in the cache */
   /* replace1864_1 -> 3 in the cache */
   /* replace1864 -> 2538 in the cache */

   /* ('bany_inequal2', ('fneu', 'a', 'b'), 0) => ('bany_fnequal2', 'a', 'b') */
   /* search1865_0_0 -> 0 in the cache */
   /* search1865_0_1 -> 3 in the cache */
   /* search1865_0 -> 4039 in the cache */
   /* search1865_1 -> 5325 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 2,
      { 4039, 5325 },
      -1,
   } },

   /* replace1865_0 -> 0 in the cache */
   /* replace1865_1 -> 3 in the cache */
   /* replace1865 -> 2579 in the cache */

   /* ('ball_iequal3', ('ieq', 'a', 'b'), -1) => ('ball_iequal3', 'a', 'b') */
   /* search1866_0_0 -> 0 in the cache */
   /* search1866_0_1 -> 3 in the cache */
   /* search1866_0 -> 1073 in the cache */
   /* search1866_1 -> 5321 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 2,
      { 1073, 5321 },
      -1,
   } },

   /* replace1866_0 -> 0 in the cache */
   /* replace1866_1 -> 3 in the cache */
   /* replace1866 -> 2433 in the cache */

   /* ('ball_iequal3', ('feq', 'a', 'b'), -1) => ('ball_fequal3', 'a', 'b') */
   /* search1867_0_0 -> 0 in the cache */
   /* search1867_0_1 -> 3 in the cache */
   /* search1867_0 -> 1067 in the cache */
   /* search1867_1 -> 5321 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 2,
      { 1067, 5321 },
      -1,
   } },

   /* replace1867_0 -> 0 in the cache */
   /* replace1867_1 -> 3 in the cache */
   /* replace1867 -> 2501 in the cache */

   /* ('bany_inequal3', ('ine', 'a', 'b'), 0) => ('bany_inequal3', 'a', 'b') */
   /* search1868_0_0 -> 0 in the cache */
   /* search1868_0_1 -> 3 in the cache */
   /* search1868_0 -> 5324 in the cache */
   /* search1868_1 -> 5325 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 2,
      { 5324, 5325 },
      -1,
   } },

   /* replace1868_0 -> 0 in the cache */
   /* replace1868_1 -> 3 in the cache */
   /* replace1868 -> 2542 in the cache */

   /* ('bany_inequal3', ('fneu', 'a', 'b'), 0) => ('bany_fnequal3', 'a', 'b') */
   /* search1869_0_0 -> 0 in the cache */
   /* search1869_0_1 -> 3 in the cache */
   /* search1869_0 -> 4039 in the cache */
   /* search1869_1 -> 5325 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 2,
      { 4039, 5325 },
      -1,
   } },

   /* replace1869_0 -> 0 in the cache */
   /* replace1869_1 -> 3 in the cache */
   /* replace1869 -> 2583 in the cache */

   /* ('ball_iequal4', ('ieq', 'a', 'b'), -1) => ('ball_iequal4', 'a', 'b') */
   /* search1870_0_0 -> 0 in the cache */
   /* search1870_0_1 -> 3 in the cache */
   /* search1870_0 -> 1073 in the cache */
   /* search1870_1 -> 5321 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 2,
      { 1073, 5321 },
      -1,
   } },

   /* replace1870_0 -> 0 in the cache */
   /* replace1870_1 -> 3 in the cache */
   /* replace1870 -> 2440 in the cache */

   /* ('ball_iequal4', ('feq', 'a', 'b'), -1) => ('ball_fequal4', 'a', 'b') */
   /* search1871_0_0 -> 0 in the cache */
   /* search1871_0_1 -> 3 in the cache */
   /* search1871_0 -> 1067 in the cache */
   /* search1871_1 -> 5321 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 2,
      { 1067, 5321 },
      -1,
   } },

   /* replace1871_0 -> 0 in the cache */
   /* replace1871_1 -> 3 in the cache */
   /* replace1871 -> 2507 in the cache */

   /* ('bany_inequal4', ('ine', 'a', 'b'), 0) => ('bany_inequal4', 'a', 'b') */
   /* search1872_0_0 -> 0 in the cache */
   /* search1872_0_1 -> 3 in the cache */
   /* search1872_0 -> 5324 in the cache */
   /* search1872_1 -> 5325 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 2,
      { 5324, 5325 },
      -1,
   } },

   /* replace1872_0 -> 0 in the cache */
   /* replace1872_1 -> 3 in the cache */
   /* replace1872 -> 2548 in the cache */

   /* ('bany_inequal4', ('fneu', 'a', 'b'), 0) => ('bany_fnequal4', 'a', 'b') */
   /* search1873_0_0 -> 0 in the cache */
   /* search1873_0_1 -> 3 in the cache */
   /* search1873_0 -> 4039 in the cache */
   /* search1873_1 -> 5325 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 2,
      { 4039, 5325 },
      -1,
   } },

   /* replace1873_0 -> 0 in the cache */
   /* replace1873_1 -> 3 in the cache */
   /* replace1873 -> 2589 in the cache */

   /* ('ball_iequal8', ('ieq', 'a', 'b'), -1) => ('ball_iequal8', 'a', 'b') */
   /* search1874_0_0 -> 0 in the cache */
   /* search1874_0_1 -> 3 in the cache */
   /* search1874_0 -> 1073 in the cache */
   /* search1874_1 -> 5321 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 2,
      { 1073, 5321 },
      -1,
   } },

   /* replace1874_0 -> 0 in the cache */
   /* replace1874_1 -> 3 in the cache */
   /* replace1874 -> 2447 in the cache */

   /* ('ball_iequal8', ('feq', 'a', 'b'), -1) => ('ball_fequal8', 'a', 'b') */
   /* search1875_0_0 -> 0 in the cache */
   /* search1875_0_1 -> 3 in the cache */
   /* search1875_0 -> 1067 in the cache */
   /* search1875_1 -> 5321 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 2,
      { 1067, 5321 },
      -1,
   } },

   /* replace1875_0 -> 0 in the cache */
   /* replace1875_1 -> 3 in the cache */
   /* replace1875 -> 2512 in the cache */

   /* ('bany_inequal8', ('ine', 'a', 'b'), 0) => ('bany_inequal8', 'a', 'b') */
   /* search1876_0_0 -> 0 in the cache */
   /* search1876_0_1 -> 3 in the cache */
   /* search1876_0 -> 5324 in the cache */
   /* search1876_1 -> 5325 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 2,
      { 5324, 5325 },
      -1,
   } },

   /* replace1876_0 -> 0 in the cache */
   /* replace1876_1 -> 3 in the cache */
   /* replace1876 -> 2553 in the cache */

   /* ('bany_inequal8', ('fneu', 'a', 'b'), 0) => ('bany_fnequal8', 'a', 'b') */
   /* search1877_0_0 -> 0 in the cache */
   /* search1877_0_1 -> 3 in the cache */
   /* search1877_0 -> 4039 in the cache */
   /* search1877_1 -> 5325 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 2,
      { 4039, 5325 },
      -1,
   } },

   /* replace1877_0 -> 0 in the cache */
   /* replace1877_1 -> 3 in the cache */
   /* replace1877 -> 2594 in the cache */

   /* ('ball_iequal16', ('ieq', 'a', 'b'), -1) => ('ball_iequal16', 'a', 'b') */
   /* search1878_0_0 -> 0 in the cache */
   /* search1878_0_1 -> 3 in the cache */
   /* search1878_0 -> 1073 in the cache */
   /* search1878_1 -> 5321 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 2,
      { 1073, 5321 },
      -1,
   } },

   /* replace1878_0 -> 0 in the cache */
   /* replace1878_1 -> 3 in the cache */
   /* replace1878 -> 2464 in the cache */

   /* ('ball_iequal16', ('feq', 'a', 'b'), -1) => ('ball_fequal16', 'a', 'b') */
   /* search1879_0_0 -> 0 in the cache */
   /* search1879_0_1 -> 3 in the cache */
   /* search1879_0 -> 1067 in the cache */
   /* search1879_1 -> 5321 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 2,
      { 1067, 5321 },
      -1,
   } },

   /* replace1879_0 -> 0 in the cache */
   /* replace1879_1 -> 3 in the cache */
   /* replace1879 -> 2521 in the cache */

   /* ('bany_inequal16', ('ine', 'a', 'b'), 0) => ('bany_inequal16', 'a', 'b') */
   /* search1880_0_0 -> 0 in the cache */
   /* search1880_0_1 -> 3 in the cache */
   /* search1880_0 -> 5324 in the cache */
   /* search1880_1 -> 5325 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 2,
      { 5324, 5325 },
      -1,
   } },

   /* replace1880_0 -> 0 in the cache */
   /* replace1880_1 -> 3 in the cache */
   /* replace1880 -> 2562 in the cache */

   /* ('bany_inequal16', ('fneu', 'a', 'b'), 0) => ('bany_fnequal16', 'a', 'b') */
   /* search1881_0_0 -> 0 in the cache */
   /* search1881_0_1 -> 3 in the cache */
   /* search1881_0 -> 4039 in the cache */
   /* search1881_1 -> 5325 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 2,
      { 4039, 5325 },
      -1,
   } },

   /* replace1881_0 -> 0 in the cache */
   /* replace1881_1 -> 3 in the cache */
   /* replace1881 -> 2603 in the cache */

   /* ('iand', ('feq', 'a', 'a'), ('flt', 'a', 'b')) => ('!flt', 'a', 'b') */
   /* search1882_0_0 -> 0 in the cache */
   /* search1882_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search1882_1_0 -> 0 in the cache */
   /* search1882_1_1 -> 3 in the cache */
   /* search1882_1 -> 1042 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5344, 1042 },
      -1,
   } },

   /* replace1882_0 -> 0 in the cache */
   /* replace1882_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('flt', 'b', 'a')) => ('!flt', 'b', 'a') */
   /* search1883_0_0 -> 32 in the cache */
   /* search1883_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 32, 32 },
      -1,
   } },
   /* search1883_1_0 -> 2260 in the cache */
   /* search1883_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 2260, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5347, 5348 },
      -1,
   } },

   /* replace1883_0 -> 2260 in the cache */
   /* replace1883_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 2260, 32 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('fge', 'a', 'b')) => ('!fge', 'a', 'b') */
   /* search1884_0_0 -> 0 in the cache */
   /* search1884_0_1 -> 0 in the cache */
   /* search1884_0 -> 5344 in the cache */
   /* search1884_1_0 -> 0 in the cache */
   /* search1884_1_1 -> 3 in the cache */
   /* search1884_1 -> 1039 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5344, 1039 },
      -1,
   } },

   /* replace1884_0 -> 0 in the cache */
   /* replace1884_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('fge', 'b', 'a')) => ('!fge', 'b', 'a') */
   /* search1885_0_0 -> 32 in the cache */
   /* search1885_0_1 -> 32 in the cache */
   /* search1885_0 -> 5347 in the cache */
   /* search1885_1_0 -> 2260 in the cache */
   /* search1885_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2260, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5347, 5353 },
      -1,
   } },

   /* replace1885_0 -> 2260 in the cache */
   /* replace1885_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 2260, 32 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('feq', 'a', 'b')) => ('!feq', 'a', 'b') */
   /* search1886_0_0 -> 0 in the cache */
   /* search1886_0_1 -> 0 in the cache */
   /* search1886_0 -> 5344 in the cache */
   /* search1886_1_0 -> 0 in the cache */
   /* search1886_1_1 -> 3 in the cache */
   /* search1886_1 -> 1067 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5344, 1067 },
      -1,
   } },

   /* replace1886_0 -> 0 in the cache */
   /* replace1886_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'a')) => ('!feq', 'b', 'a') */
   /* search1887_0_0 -> 32 in the cache */
   /* search1887_0_1 -> 32 in the cache */
   /* search1887_0 -> 5347 in the cache */
   /* search1887_1_0 -> 2260 in the cache */
   /* search1887_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 2260, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5347, 5358 },
      -1,
   } },

   /* replace1887_0 -> 2260 in the cache */
   /* replace1887_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_feq,
      0, 1,
      { 2260, 32 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('feq', 'b', 'd'), ('feq', 'c', 'd')) */
   /* search1888_0_0 -> 753 in the cache */
   /* search1888_0_1 -> 1021 in the cache */
   /* search1888_0_2 -> 3426 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1021, 3426 },
      -1,
   } },
   /* search1888_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 5361, 1024 },
      -1,
   } },

   /* replace1888_0 -> 753 in the cache */
   /* replace1888_1_0 -> 152 in the cache */
   /* replace1888_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 152, 155 },
      -1,
   } },
   /* replace1888_2_0 -> 154 in the cache */
   /* replace1888_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5363, 5364 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fneu', 'b', 'd'), ('fneu', 'c', 'd')) */
   /* search1889_0_0 -> 753 in the cache */
   /* search1889_0_1 -> 1021 in the cache */
   /* search1889_0_2 -> 3426 in the cache */
   /* search1889_0 -> 5361 in the cache */
   /* search1889_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 5361, 1024 },
      -1,
   } },

   /* replace1889_0 -> 753 in the cache */
   /* replace1889_1_0 -> 152 in the cache */
   /* replace1889_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 152, 155 },
      -1,
   } },
   /* replace1889_2_0 -> 154 in the cache */
   /* replace1889_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5367, 5368 },
      -1,
   } },

   /* ('ieq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ieq', 'b', 'd'), ('ieq', 'c', 'd')) */
   /* search1890_0_0 -> 753 in the cache */
   /* search1890_0_1 -> 1021 in the cache */
   /* search1890_0_2 -> 3426 in the cache */
   /* search1890_0 -> 5361 in the cache */
   /* search1890_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 5361, 1024 },
      -1,
   } },

   /* replace1890_0 -> 753 in the cache */
   /* replace1890_1_0 -> 152 in the cache */
   /* replace1890_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 152, 155 },
      -1,
   } },
   /* replace1890_2_0 -> 154 in the cache */
   /* replace1890_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5371, 5372 },
      -1,
   } },

   /* ('ine', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ine', 'b', 'd'), ('ine', 'c', 'd')) */
   /* search1891_0_0 -> 753 in the cache */
   /* search1891_0_1 -> 1021 in the cache */
   /* search1891_0_2 -> 3426 in the cache */
   /* search1891_0 -> 5361 in the cache */
   /* search1891_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 5361, 1024 },
      -1,
   } },

   /* replace1891_0 -> 753 in the cache */
   /* replace1891_1_0 -> 152 in the cache */
   /* replace1891_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 152, 155 },
      -1,
   } },
   /* replace1891_2_0 -> 154 in the cache */
   /* replace1891_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5375, 5376 },
      -1,
   } },

   /* ('flt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('flt', 'b', 'd'), ('flt', 'c', 'd')) */
   /* search1892_0_0 -> 753 in the cache */
   /* search1892_0_1 -> 1021 in the cache */
   /* search1892_0_2 -> 3426 in the cache */
   /* search1892_0 -> 5361 in the cache */
   /* search1892_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5361, 1024 },
      -1,
   } },

   /* replace1892_0 -> 753 in the cache */
   /* replace1892_1_0 -> 152 in the cache */
   /* replace1892_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 152, 155 },
      -1,
   } },
   /* replace1892_2_0 -> 154 in the cache */
   /* replace1892_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 5379, 5380 },
      -1,
   } },

   /* ('flt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('flt', 'd', 'b'), ('flt', 'd', 'c')) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1893_1_0 -> 1163 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1163, 5383, 5384 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5382, 5385 },
      -1,
   } },

   /* replace1893_0 -> 1163 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5387, 5388 },
      -1,
   } },
   /* replace1893_2_0 -> 5387 in the cache */
   /* replace1893_2_1 -> 1718 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5387, 1718 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1163, 5389, 5390 },
      -1,
   } },

   /* ('fge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fge', 'b', 'd'), ('fge', 'c', 'd')) */
   /* search1894_0_0 -> 753 in the cache */
   /* search1894_0_1 -> 1021 in the cache */
   /* search1894_0_2 -> 3426 in the cache */
   /* search1894_0 -> 5361 in the cache */
   /* search1894_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5361, 1024 },
      -1,
   } },

   /* replace1894_0 -> 753 in the cache */
   /* replace1894_1_0 -> 152 in the cache */
   /* replace1894_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 152, 155 },
      -1,
   } },
   /* replace1894_2_0 -> 154 in the cache */
   /* replace1894_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 5393, 5394 },
      -1,
   } },

   /* ('fge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('fge', 'd', 'b'), ('fge', 'd', 'c')) */
   /* search1895_0 -> 5382 in the cache */
   /* search1895_1_0 -> 1163 in the cache */
   /* search1895_1_1 -> 5383 in the cache */
   /* search1895_1_2 -> 5384 in the cache */
   /* search1895_1 -> 5385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5382, 5385 },
      -1,
   } },

   /* replace1895_0 -> 1163 in the cache */
   /* replace1895_1_0 -> 5387 in the cache */
   /* replace1895_1_1 -> 5388 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5387, 5388 },
      -1,
   } },
   /* replace1895_2_0 -> 5387 in the cache */
   /* replace1895_2_1 -> 1718 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5387, 1718 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1163, 5397, 5398 },
      -1,
   } },

   /* ('ilt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ilt', 'b', 'd'), ('ilt', 'c', 'd')) */
   /* search1896_0_0 -> 753 in the cache */
   /* search1896_0_1 -> 1021 in the cache */
   /* search1896_0_2 -> 3426 in the cache */
   /* search1896_0 -> 5361 in the cache */
   /* search1896_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5361, 1024 },
      -1,
   } },

   /* replace1896_0 -> 753 in the cache */
   /* replace1896_1_0 -> 152 in the cache */
   /* replace1896_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 152, 155 },
      -1,
   } },
   /* replace1896_2_0 -> 154 in the cache */
   /* replace1896_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 5401, 5402 },
      -1,
   } },

   /* ('ilt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ilt', 'd', 'b'), ('ilt', 'd', 'c')) */
   /* search1897_0 -> 5382 in the cache */
   /* search1897_1_0 -> 1163 in the cache */
   /* search1897_1_1 -> 5383 in the cache */
   /* search1897_1_2 -> 5384 in the cache */
   /* search1897_1 -> 5385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5382, 5385 },
      -1,
   } },

   /* replace1897_0 -> 1163 in the cache */
   /* replace1897_1_0 -> 5387 in the cache */
   /* replace1897_1_1 -> 5388 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5387, 5388 },
      -1,
   } },
   /* replace1897_2_0 -> 5387 in the cache */
   /* replace1897_2_1 -> 1718 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5387, 1718 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1163, 5405, 5406 },
      -1,
   } },

   /* ('ige', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ige', 'b', 'd'), ('ige', 'c', 'd')) */
   /* search1898_0_0 -> 753 in the cache */
   /* search1898_0_1 -> 1021 in the cache */
   /* search1898_0_2 -> 3426 in the cache */
   /* search1898_0 -> 5361 in the cache */
   /* search1898_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5361, 1024 },
      -1,
   } },

   /* replace1898_0 -> 753 in the cache */
   /* replace1898_1_0 -> 152 in the cache */
   /* replace1898_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 152, 155 },
      -1,
   } },
   /* replace1898_2_0 -> 154 in the cache */
   /* replace1898_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 5409, 5410 },
      -1,
   } },

   /* ('ige', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ige', 'd', 'b'), ('ige', 'd', 'c')) */
   /* search1899_0 -> 5382 in the cache */
   /* search1899_1_0 -> 1163 in the cache */
   /* search1899_1_1 -> 5383 in the cache */
   /* search1899_1_2 -> 5384 in the cache */
   /* search1899_1 -> 5385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5382, 5385 },
      -1,
   } },

   /* replace1899_0 -> 1163 in the cache */
   /* replace1899_1_0 -> 5387 in the cache */
   /* replace1899_1_1 -> 5388 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5387, 5388 },
      -1,
   } },
   /* replace1899_2_0 -> 5387 in the cache */
   /* replace1899_2_1 -> 1718 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5387, 1718 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1163, 5413, 5414 },
      -1,
   } },

   /* ('ult', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ult', 'b', 'd'), ('ult', 'c', 'd')) */
   /* search1900_0_0 -> 753 in the cache */
   /* search1900_0_1 -> 1021 in the cache */
   /* search1900_0_2 -> 3426 in the cache */
   /* search1900_0 -> 5361 in the cache */
   /* search1900_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5361, 1024 },
      -1,
   } },

   /* replace1900_0 -> 753 in the cache */
   /* replace1900_1_0 -> 152 in the cache */
   /* replace1900_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 152, 155 },
      -1,
   } },
   /* replace1900_2_0 -> 154 in the cache */
   /* replace1900_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 5417, 5418 },
      -1,
   } },

   /* ('ult', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ult', 'd', 'b'), ('ult', 'd', 'c')) */
   /* search1901_0 -> 5382 in the cache */
   /* search1901_1_0 -> 1163 in the cache */
   /* search1901_1_1 -> 5383 in the cache */
   /* search1901_1_2 -> 5384 in the cache */
   /* search1901_1 -> 5385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5382, 5385 },
      -1,
   } },

   /* replace1901_0 -> 1163 in the cache */
   /* replace1901_1_0 -> 5387 in the cache */
   /* replace1901_1_1 -> 5388 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5387, 5388 },
      -1,
   } },
   /* replace1901_2_0 -> 5387 in the cache */
   /* replace1901_2_1 -> 1718 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5387, 1718 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1163, 5421, 5422 },
      -1,
   } },

   /* ('uge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('uge', 'b', 'd'), ('uge', 'c', 'd')) */
   /* search1902_0_0 -> 753 in the cache */
   /* search1902_0_1 -> 1021 in the cache */
   /* search1902_0_2 -> 3426 in the cache */
   /* search1902_0 -> 5361 in the cache */
   /* search1902_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5361, 1024 },
      -1,
   } },

   /* replace1902_0 -> 753 in the cache */
   /* replace1902_1_0 -> 152 in the cache */
   /* replace1902_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 152, 155 },
      -1,
   } },
   /* replace1902_2_0 -> 154 in the cache */
   /* replace1902_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 5425, 5426 },
      -1,
   } },

   /* ('uge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('uge', 'd', 'b'), ('uge', 'd', 'c')) */
   /* search1903_0 -> 5382 in the cache */
   /* search1903_1_0 -> 1163 in the cache */
   /* search1903_1_1 -> 5383 in the cache */
   /* search1903_1_2 -> 5384 in the cache */
   /* search1903_1 -> 5385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5382, 5385 },
      -1,
   } },

   /* replace1903_0 -> 1163 in the cache */
   /* replace1903_1_0 -> 5387 in the cache */
   /* replace1903_1_1 -> 5388 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5387, 5388 },
      -1,
   } },
   /* replace1903_2_0 -> 5387 in the cache */
   /* replace1903_2_1 -> 1718 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5387, 1718 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1163, 5429, 5430 },
      -1,
   } },

   /* ('fadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fadd', 'b', 'd'), ('fadd', 'c', 'd')) */
   /* search1904_0_0 -> 753 in the cache */
   /* search1904_0_1 -> 1021 in the cache */
   /* search1904_0_2 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 1021, 154 },
      0,
   } },
   /* search1904_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 5432, 1024 },
      -1,
   } },

   /* replace1904_0 -> 753 in the cache */
   /* replace1904_1_0 -> 152 in the cache */
   /* replace1904_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 152, 155 },
      -1,
   } },
   /* replace1904_2_0 -> 154 in the cache */
   /* replace1904_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5434, 5435 },
      -1,
   } },

   /* ('fmul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmul', 'b', 'd'), ('fmul', 'c', 'd')) */
   /* search1905_0_0 -> 753 in the cache */
   /* search1905_0_1 -> 1021 in the cache */
   /* search1905_0_2 -> 154 in the cache */
   /* search1905_0 -> 5432 in the cache */
   /* search1905_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 5432, 1024 },
      -1,
   } },

   /* replace1905_0 -> 753 in the cache */
   /* replace1905_1_0 -> 152 in the cache */
   /* replace1905_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 152, 155 },
      -1,
   } },
   /* replace1905_2_0 -> 154 in the cache */
   /* replace1905_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5438, 5439 },
      -1,
   } },

   /* ('fmulz', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmulz', 'b', 'd'), ('fmulz', 'c', 'd')) */
   /* search1906_0_0 -> 753 in the cache */
   /* search1906_0_1 -> 33 in the cache */
   /* search1906_0_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 33, 137 },
      0,
   } },
   /* search1906_1 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 5441, 313 },
      -1,
   } },

   /* replace1906_0 -> 753 in the cache */
   /* replace1906_1_0 -> 36 in the cache */
   /* replace1906_1_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 165 },
      -1,
   } },
   /* replace1906_2_0 -> 137 in the cache */
   /* replace1906_2_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 137, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5443, 5444 },
      -1,
   } },

   /* ('iadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('iadd', 'b', 'd'), ('iadd', 'c', 'd')) */
   /* search1907_0_0 -> 753 in the cache */
   /* search1907_0_1 -> 1021 in the cache */
   /* search1907_0_2 -> 154 in the cache */
   /* search1907_0 -> 5432 in the cache */
   /* search1907_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5432, 1024 },
      -1,
   } },

   /* replace1907_0 -> 753 in the cache */
   /* replace1907_1_0 -> 152 in the cache */
   /* replace1907_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 152, 155 },
      -1,
   } },
   /* replace1907_2_0 -> 154 in the cache */
   /* replace1907_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5447, 5448 },
      -1,
   } },

   /* ('imul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('imul', 'b', 'd'), ('imul', 'c', 'd')) */
   /* search1908_0_0 -> 753 in the cache */
   /* search1908_0_1 -> 1021 in the cache */
   /* search1908_0_2 -> 154 in the cache */
   /* search1908_0 -> 5432 in the cache */
   /* search1908_1 -> 1024 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5432, 1024 },
      -1,
   } },

   /* replace1908_0 -> 753 in the cache */
   /* replace1908_1_0 -> 152 in the cache */
   /* replace1908_1_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 152, 155 },
      -1,
   } },
   /* replace1908_2_0 -> 154 in the cache */
   /* replace1908_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5451, 5452 },
      -1,
   } },

   /* ('fddx', 'a') => 0.0 */
   /* search1909_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1909 -> 113 in the cache */

   /* ('fddx_fine', 'a') => 0.0 */
   /* search1910_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1910 -> 113 in the cache */

   /* ('fddx_coarse', 'a') => 0.0 */
   /* search1911_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1911 -> 113 in the cache */

   /* ('fddy', 'a') => 0.0 */
   /* search1912_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1912 -> 113 in the cache */

   /* ('fddy_fine', 'a') => 0.0 */
   /* search1913_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1913 -> 113 in the cache */

   /* ('fddy_coarse', 'a') => 0.0 */
   /* search1914_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1914 -> 113 in the cache */

   /* ('umul_low', '#a(is_lower_half_zero)', 'b') => 0 */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      31,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1915_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_low,
      0, 1,
      { 5460, 36 },
      -1,
   } },

   /* replace1915 -> 124 in the cache */

   /* ('imadsh_mix16', '#a@32(is_lower_half_zero)', 'b@32', 'c@32') => c */
   /* search1916_0 -> 5460 in the cache */
   /* search1916_1 -> 36 in the cache */
   /* search1916_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imadsh_mix16,
      -1, 0,
      { 5460, 36, 137 },
      -1,
   } },

   /* replace1916 -> 137 in the cache */

   /* ('imadsh_mix16', 'a@32', '#b@32(is_upper_half_zero)', 'c@32') => c */
   /* search1917_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      32,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1917_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imadsh_mix16,
      -1, 0,
      { 16, 5463, 137 },
      -1,
   } },

   /* replace1917 -> 137 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search1918_0 -> 753 in the cache */
   /* search1918_1_0 -> 745 in the cache */
   /* search1918_1_1 -> 746 in the cache */
   /* search1918_1_2 -> 755 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 745, 746, 755 },
      0,
   } },
   /* search1918_2_0 -> 745 in the cache */
   /* search1918_2_1 -> 746 in the cache */
   /* search1918_2_2 -> 757 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 745, 746, 757 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 5465, 5466 },
      -1,
   } },

   /* replace1918_0 -> 745 in the cache */
   /* replace1918_1 -> 746 in the cache */
   /* replace1918_2_0 -> 753 in the cache */
   /* replace1918_2_1 -> 755 in the cache */
   /* replace1918_2_2 -> 757 in the cache */
   /* replace1918_2 -> 1309 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 745, 746, 1309 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search1919_0 -> 753 in the cache */
   /* search1919_1_0 -> 745 in the cache */
   /* search1919_1_1 -> 746 in the cache */
   /* search1919_1_2 -> 755 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 745, 746, 755 },
      -1,
   } },
   /* search1919_2_0 -> 745 in the cache */
   /* search1919_2_1 -> 746 in the cache */
   /* search1919_2_2 -> 757 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 745, 746, 757 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 5469, 5470 },
      -1,
   } },

   /* replace1919_0 -> 745 in the cache */
   /* replace1919_1 -> 746 in the cache */
   /* replace1919_2_0 -> 753 in the cache */
   /* replace1919_2_1 -> 755 in the cache */
   /* replace1919_2_2 -> 757 in the cache */
   /* replace1919_2 -> 1309 in the cache */
   /* replace1919 -> 5468 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search1920_0 -> 753 in the cache */
   /* search1920_1_0 -> 745 in the cache */
   /* search1920_1_1 -> 746 in the cache */
   /* search1920_1_2 -> 755 in the cache */
   /* search1920_1 -> 5465 in the cache */
   /* search1920_2_0 -> 745 in the cache */
   /* search1920_2_1 -> 757 in the cache */
   /* search1920_2_2 -> 755 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 745, 757, 755 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 5465, 5472 },
      -1,
   } },

   /* replace1920_0 -> 745 in the cache */
   /* replace1920_1_0 -> 753 in the cache */
   /* replace1920_1_1 -> 746 in the cache */
   /* replace1920_1_2 -> 757 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 746, 757 },
      -1,
   } },
   /* replace1920_2 -> 755 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 745, 5474, 755 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search1921_0 -> 753 in the cache */
   /* search1921_1_0 -> 745 in the cache */
   /* search1921_1_1 -> 746 in the cache */
   /* search1921_1_2 -> 755 in the cache */
   /* search1921_1 -> 5469 in the cache */
   /* search1921_2_0 -> 745 in the cache */
   /* search1921_2_1 -> 757 in the cache */
   /* search1921_2_2 -> 755 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 745, 757, 755 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 5469, 5476 },
      -1,
   } },

   /* replace1921_0 -> 745 in the cache */
   /* replace1921_1_0 -> 753 in the cache */
   /* replace1921_1_1 -> 746 in the cache */
   /* replace1921_1_2 -> 757 in the cache */
   /* replace1921_1 -> 5474 in the cache */
   /* replace1921_2 -> 755 in the cache */
   /* replace1921 -> 5475 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd') */
   /* search1922_0 -> 753 in the cache */
   /* search1922_1_0 -> 152 in the cache */
   /* search1922_1_1 -> 154 in the cache */
   /* search1922_1_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 152, 154, 155 },
      0,
   } },
   /* search1922_2_0 -> 1315 in the cache */
   /* search1922_2_1 -> 154 in the cache */
   /* search1922_2_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 1315, 154, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 5478, 5479 },
      -1,
   } },

   /* replace1922_0_0 -> 753 in the cache */
   /* replace1922_0_1 -> 152 in the cache */
   /* replace1922_0_2 -> 1315 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 152, 1315 },
      -1,
   } },
   /* replace1922_1 -> 154 in the cache */
   /* replace1922_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 5481, 154, 155 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd') */
   /* search1923_0 -> 753 in the cache */
   /* search1923_1_0 -> 152 in the cache */
   /* search1923_1_1 -> 154 in the cache */
   /* search1923_1_2 -> 155 in the cache */
   /* search1923_1 -> 684 in the cache */
   /* search1923_2_0 -> 1315 in the cache */
   /* search1923_2_1 -> 154 in the cache */
   /* search1923_2_2 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 1315, 154, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 684, 5483 },
      -1,
   } },

   /* replace1923_0_0 -> 753 in the cache */
   /* replace1923_0_1 -> 152 in the cache */
   /* replace1923_0_2 -> 1315 in the cache */
   /* replace1923_0 -> 5481 in the cache */
   /* replace1923_1 -> 154 in the cache */
   /* replace1923_2 -> 155 in the cache */
   /* replace1923 -> 5482 in the cache */

   /* ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1924_0 -> 753 in the cache */
   /* search1924_1_0 -> 36 in the cache */
   /* search1924_1_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 137 },
      0,
   } },
   /* search1924_2_0 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 5486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5485, 5487 },
      -1,
   } },

   /* replace1924_0 -> 36 in the cache */
   /* replace1924_1_0 -> 753 in the cache */
   /* replace1924_1_1 -> 137 in the cache */
   /* replace1924_1_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 137, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 5489 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c(is_not_const)'), ('fmulz', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1925_0 -> 753 in the cache */
   /* search1925_1_0 -> 36 in the cache */
   /* search1925_1_1 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 349 },
      0,
   } },
   /* search1925_2_0 -> 36 in the cache */
   /* search1925_2_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5491, 5492 },
      -1,
   } },

   /* replace1925_0 -> 36 in the cache */
   /* replace1925_1_0 -> 753 in the cache */
   /* replace1925_1_1 -> 137 in the cache */
   /* replace1925_1_2 -> 165 in the cache */
   /* replace1925_1 -> 5489 in the cache */
   /* replace1925 -> 5490 in the cache */

   /* ('bcsel', 'a', ('fmulz', 'b', 'c(is_not_const)'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1926_0 -> 753 in the cache */
   /* search1926_1_0 -> 36 in the cache */
   /* search1926_1_1 -> 349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 349 },
      -1,
   } },
   /* search1926_2_0 -> 36 in the cache */
   /* search1926_2_1 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 165 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5494, 5495 },
      -1,
   } },

   /* replace1926_0 -> 36 in the cache */
   /* replace1926_1_0 -> 753 in the cache */
   /* replace1926_1_1 -> 137 in the cache */
   /* replace1926_1_2 -> 165 in the cache */
   /* replace1926_1 -> 5489 in the cache */
   /* replace1926 -> 5490 in the cache */

   /* ('bcsel', 'a', ('fmulz', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1927_0 -> 753 in the cache */
   /* search1927_1_0 -> 36 in the cache */
   /* search1927_1_1 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 137 },
      -1,
   } },
   /* search1927_2_0 -> 36 in the cache */
   /* search1927_2_1 -> 5486 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 5486 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5497, 5498 },
      -1,
   } },

   /* replace1927_0 -> 36 in the cache */
   /* replace1927_1_0 -> 753 in the cache */
   /* replace1927_1_1 -> 137 in the cache */
   /* replace1927_1_2 -> 165 in the cache */
   /* replace1927_1 -> 5489 in the cache */
   /* replace1927 -> 5490 in the cache */

   /* ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1928_0 -> 753 in the cache */
   /* search1928_1_0 -> 152 in the cache */
   /* search1928_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1928_2_0 -> 152 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 152, 5501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5500, 5502 },
      -1,
   } },

   /* replace1928_0 -> 152 in the cache */
   /* replace1928_1_0 -> 753 in the cache */
   /* replace1928_1_1 -> 154 in the cache */
   /* replace1928_1_2 -> 155 in the cache */
   /* replace1928_1 -> 1304 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 152, 1304 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c(is_not_const)'), ('fmul', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1929_0 -> 753 in the cache */
   /* search1929_1_0 -> 152 in the cache */
   /* search1929_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 152, 3441 },
      0,
   } },
   /* search1929_2_0 -> 152 in the cache */
   /* search1929_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5505, 5506 },
      -1,
   } },

   /* replace1929_0 -> 152 in the cache */
   /* replace1929_1_0 -> 753 in the cache */
   /* replace1929_1_1 -> 154 in the cache */
   /* replace1929_1_2 -> 155 in the cache */
   /* replace1929_1 -> 1304 in the cache */
   /* replace1929 -> 5504 in the cache */

   /* ('bcsel', 'a', ('fmul', 'b', 'c(is_not_const)'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1930_0 -> 753 in the cache */
   /* search1930_1_0 -> 152 in the cache */
   /* search1930_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 152, 3441 },
      -1,
   } },
   /* search1930_2_0 -> 152 in the cache */
   /* search1930_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5508, 5509 },
      -1,
   } },

   /* replace1930_0 -> 152 in the cache */
   /* replace1930_1_0 -> 753 in the cache */
   /* replace1930_1_1 -> 154 in the cache */
   /* replace1930_1_2 -> 155 in the cache */
   /* replace1930_1 -> 1304 in the cache */
   /* replace1930 -> 5504 in the cache */

   /* ('bcsel', 'a', ('fmul', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1931_0 -> 753 in the cache */
   /* search1931_1_0 -> 152 in the cache */
   /* search1931_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1931_2_0 -> 152 in the cache */
   /* search1931_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 152, 5501 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5511, 5512 },
      -1,
   } },

   /* replace1931_0 -> 152 in the cache */
   /* replace1931_1_0 -> 753 in the cache */
   /* replace1931_1_1 -> 154 in the cache */
   /* replace1931_1_2 -> 155 in the cache */
   /* replace1931_1 -> 1304 in the cache */
   /* replace1931 -> 5504 in the cache */

   /* ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c'), ('iadd', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1932_0 -> 753 in the cache */
   /* search1932_1_0 -> 152 in the cache */
   /* search1932_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1932_2_0 -> 152 in the cache */
   /* search1932_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 152, 5501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5514, 5515 },
      -1,
   } },

   /* replace1932_0 -> 152 in the cache */
   /* replace1932_1_0 -> 753 in the cache */
   /* replace1932_1_1 -> 154 in the cache */
   /* replace1932_1_2 -> 155 in the cache */
   /* replace1932_1 -> 1304 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 152, 1304 },
      -1,
   } },

   /* ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c(is_not_const)'), ('iadd', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1933_0 -> 753 in the cache */
   /* search1933_1_0 -> 152 in the cache */
   /* search1933_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 152, 3441 },
      0,
   } },
   /* search1933_2_0 -> 152 in the cache */
   /* search1933_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5518, 5519 },
      -1,
   } },

   /* replace1933_0 -> 152 in the cache */
   /* replace1933_1_0 -> 753 in the cache */
   /* replace1933_1_1 -> 154 in the cache */
   /* replace1933_1_2 -> 155 in the cache */
   /* replace1933_1 -> 1304 in the cache */
   /* replace1933 -> 5517 in the cache */

   /* ('bcsel', 'a', ('iadd', 'b', 'c(is_not_const)'), ('iadd(is_used_once)', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1934_0 -> 753 in the cache */
   /* search1934_1_0 -> 152 in the cache */
   /* search1934_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 152, 3441 },
      -1,
   } },
   /* search1934_2_0 -> 152 in the cache */
   /* search1934_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5521, 5522 },
      -1,
   } },

   /* replace1934_0 -> 152 in the cache */
   /* replace1934_1_0 -> 753 in the cache */
   /* replace1934_1_1 -> 154 in the cache */
   /* replace1934_1_2 -> 155 in the cache */
   /* replace1934_1 -> 1304 in the cache */
   /* replace1934 -> 5517 in the cache */

   /* ('bcsel', 'a', ('iadd', 'b', 'c'), ('iadd(is_used_once)', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1935_0 -> 753 in the cache */
   /* search1935_1_0 -> 152 in the cache */
   /* search1935_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1935_2_0 -> 152 in the cache */
   /* search1935_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 152, 5501 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5524, 5525 },
      -1,
   } },

   /* replace1935_0 -> 152 in the cache */
   /* replace1935_1_0 -> 753 in the cache */
   /* replace1935_1_1 -> 154 in the cache */
   /* replace1935_1_2 -> 155 in the cache */
   /* replace1935_1 -> 1304 in the cache */
   /* replace1935 -> 5517 in the cache */

   /* ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c'), ('imul', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1936_0 -> 753 in the cache */
   /* search1936_1_0 -> 152 in the cache */
   /* search1936_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1936_2_0 -> 152 in the cache */
   /* search1936_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 152, 5501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5527, 5528 },
      -1,
   } },

   /* replace1936_0 -> 152 in the cache */
   /* replace1936_1_0 -> 753 in the cache */
   /* replace1936_1_1 -> 154 in the cache */
   /* replace1936_1_2 -> 155 in the cache */
   /* replace1936_1 -> 1304 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 152, 1304 },
      -1,
   } },

   /* ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c(is_not_const)'), ('imul', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1937_0 -> 753 in the cache */
   /* search1937_1_0 -> 152 in the cache */
   /* search1937_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 152, 3441 },
      0,
   } },
   /* search1937_2_0 -> 152 in the cache */
   /* search1937_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5531, 5532 },
      -1,
   } },

   /* replace1937_0 -> 152 in the cache */
   /* replace1937_1_0 -> 753 in the cache */
   /* replace1937_1_1 -> 154 in the cache */
   /* replace1937_1_2 -> 155 in the cache */
   /* replace1937_1 -> 1304 in the cache */
   /* replace1937 -> 5530 in the cache */

   /* ('bcsel', 'a', ('imul', 'b', 'c(is_not_const)'), ('imul(is_used_once)', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1938_0 -> 753 in the cache */
   /* search1938_1_0 -> 152 in the cache */
   /* search1938_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 152, 3441 },
      -1,
   } },
   /* search1938_2_0 -> 152 in the cache */
   /* search1938_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5534, 5535 },
      -1,
   } },

   /* replace1938_0 -> 152 in the cache */
   /* replace1938_1_0 -> 753 in the cache */
   /* replace1938_1_1 -> 154 in the cache */
   /* replace1938_1_2 -> 155 in the cache */
   /* replace1938_1 -> 1304 in the cache */
   /* replace1938 -> 5530 in the cache */

   /* ('bcsel', 'a', ('imul', 'b', 'c'), ('imul(is_used_once)', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1939_0 -> 753 in the cache */
   /* search1939_1_0 -> 152 in the cache */
   /* search1939_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1939_2_0 -> 152 in the cache */
   /* search1939_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 152, 5501 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5537, 5538 },
      -1,
   } },

   /* replace1939_0 -> 152 in the cache */
   /* replace1939_1_0 -> 753 in the cache */
   /* replace1939_1_1 -> 154 in the cache */
   /* replace1939_1_2 -> 155 in the cache */
   /* replace1939_1 -> 1304 in the cache */
   /* replace1939 -> 5530 in the cache */

   /* ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c'), ('iand', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1940_0 -> 753 in the cache */
   /* search1940_1_0 -> 152 in the cache */
   /* search1940_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1940_2_0 -> 152 in the cache */
   /* search1940_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 152, 5501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5540, 5541 },
      -1,
   } },

   /* replace1940_0 -> 152 in the cache */
   /* replace1940_1_0 -> 753 in the cache */
   /* replace1940_1_1 -> 154 in the cache */
   /* replace1940_1_2 -> 155 in the cache */
   /* replace1940_1 -> 1304 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 152, 1304 },
      -1,
   } },

   /* ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c(is_not_const)'), ('iand', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1941_0 -> 753 in the cache */
   /* search1941_1_0 -> 152 in the cache */
   /* search1941_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 152, 3441 },
      0,
   } },
   /* search1941_2_0 -> 152 in the cache */
   /* search1941_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5544, 5545 },
      -1,
   } },

   /* replace1941_0 -> 152 in the cache */
   /* replace1941_1_0 -> 753 in the cache */
   /* replace1941_1_1 -> 154 in the cache */
   /* replace1941_1_2 -> 155 in the cache */
   /* replace1941_1 -> 1304 in the cache */
   /* replace1941 -> 5543 in the cache */

   /* ('bcsel', 'a', ('iand', 'b', 'c(is_not_const)'), ('iand(is_used_once)', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1942_0 -> 753 in the cache */
   /* search1942_1_0 -> 152 in the cache */
   /* search1942_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 152, 3441 },
      -1,
   } },
   /* search1942_2_0 -> 152 in the cache */
   /* search1942_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5547, 5548 },
      -1,
   } },

   /* replace1942_0 -> 152 in the cache */
   /* replace1942_1_0 -> 753 in the cache */
   /* replace1942_1_1 -> 154 in the cache */
   /* replace1942_1_2 -> 155 in the cache */
   /* replace1942_1 -> 1304 in the cache */
   /* replace1942 -> 5543 in the cache */

   /* ('bcsel', 'a', ('iand', 'b', 'c'), ('iand(is_used_once)', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1943_0 -> 753 in the cache */
   /* search1943_1_0 -> 152 in the cache */
   /* search1943_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1943_2_0 -> 152 in the cache */
   /* search1943_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 152, 5501 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5550, 5551 },
      -1,
   } },

   /* replace1943_0 -> 152 in the cache */
   /* replace1943_1_0 -> 753 in the cache */
   /* replace1943_1_1 -> 154 in the cache */
   /* replace1943_1_2 -> 155 in the cache */
   /* replace1943_1 -> 1304 in the cache */
   /* replace1943 -> 5543 in the cache */

   /* ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c'), ('ior', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1944_0 -> 753 in the cache */
   /* search1944_1_0 -> 152 in the cache */
   /* search1944_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1944_2_0 -> 152 in the cache */
   /* search1944_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 152, 5501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5553, 5554 },
      -1,
   } },

   /* replace1944_0 -> 152 in the cache */
   /* replace1944_1_0 -> 753 in the cache */
   /* replace1944_1_1 -> 154 in the cache */
   /* replace1944_1_2 -> 155 in the cache */
   /* replace1944_1 -> 1304 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 152, 1304 },
      -1,
   } },

   /* ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c(is_not_const)'), ('ior', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1945_0 -> 753 in the cache */
   /* search1945_1_0 -> 152 in the cache */
   /* search1945_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 152, 3441 },
      0,
   } },
   /* search1945_2_0 -> 152 in the cache */
   /* search1945_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5557, 5558 },
      -1,
   } },

   /* replace1945_0 -> 152 in the cache */
   /* replace1945_1_0 -> 753 in the cache */
   /* replace1945_1_1 -> 154 in the cache */
   /* replace1945_1_2 -> 155 in the cache */
   /* replace1945_1 -> 1304 in the cache */
   /* replace1945 -> 5556 in the cache */

   /* ('bcsel', 'a', ('ior', 'b', 'c(is_not_const)'), ('ior(is_used_once)', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1946_0 -> 753 in the cache */
   /* search1946_1_0 -> 152 in the cache */
   /* search1946_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 152, 3441 },
      -1,
   } },
   /* search1946_2_0 -> 152 in the cache */
   /* search1946_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5560, 5561 },
      -1,
   } },

   /* replace1946_0 -> 152 in the cache */
   /* replace1946_1_0 -> 753 in the cache */
   /* replace1946_1_1 -> 154 in the cache */
   /* replace1946_1_2 -> 155 in the cache */
   /* replace1946_1 -> 1304 in the cache */
   /* replace1946 -> 5556 in the cache */

   /* ('bcsel', 'a', ('ior', 'b', 'c'), ('ior(is_used_once)', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1947_0 -> 753 in the cache */
   /* search1947_1_0 -> 152 in the cache */
   /* search1947_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1947_2_0 -> 152 in the cache */
   /* search1947_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 152, 5501 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5563, 5564 },
      -1,
   } },

   /* replace1947_0 -> 152 in the cache */
   /* replace1947_1_0 -> 753 in the cache */
   /* replace1947_1_1 -> 154 in the cache */
   /* replace1947_1_2 -> 155 in the cache */
   /* replace1947_1 -> 1304 in the cache */
   /* replace1947 -> 5556 in the cache */

   /* ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c'), ('ixor', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1948_0 -> 753 in the cache */
   /* search1948_1_0 -> 152 in the cache */
   /* search1948_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1948_2_0 -> 152 in the cache */
   /* search1948_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 152, 5501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5566, 5567 },
      -1,
   } },

   /* replace1948_0 -> 152 in the cache */
   /* replace1948_1_0 -> 753 in the cache */
   /* replace1948_1_1 -> 154 in the cache */
   /* replace1948_1_2 -> 155 in the cache */
   /* replace1948_1 -> 1304 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 152, 1304 },
      -1,
   } },

   /* ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c(is_not_const)'), ('ixor', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1949_0 -> 753 in the cache */
   /* search1949_1_0 -> 152 in the cache */
   /* search1949_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 152, 3441 },
      0,
   } },
   /* search1949_2_0 -> 152 in the cache */
   /* search1949_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5570, 5571 },
      -1,
   } },

   /* replace1949_0 -> 152 in the cache */
   /* replace1949_1_0 -> 753 in the cache */
   /* replace1949_1_1 -> 154 in the cache */
   /* replace1949_1_2 -> 155 in the cache */
   /* replace1949_1 -> 1304 in the cache */
   /* replace1949 -> 5569 in the cache */

   /* ('bcsel', 'a', ('ixor', 'b', 'c(is_not_const)'), ('ixor(is_used_once)', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1950_0 -> 753 in the cache */
   /* search1950_1_0 -> 152 in the cache */
   /* search1950_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 152, 3441 },
      -1,
   } },
   /* search1950_2_0 -> 152 in the cache */
   /* search1950_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5573, 5574 },
      -1,
   } },

   /* replace1950_0 -> 152 in the cache */
   /* replace1950_1_0 -> 753 in the cache */
   /* replace1950_1_1 -> 154 in the cache */
   /* replace1950_1_2 -> 155 in the cache */
   /* replace1950_1 -> 1304 in the cache */
   /* replace1950 -> 5569 in the cache */

   /* ('bcsel', 'a', ('ixor', 'b', 'c'), ('ixor(is_used_once)', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1951_0 -> 753 in the cache */
   /* search1951_1_0 -> 152 in the cache */
   /* search1951_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1951_2_0 -> 152 in the cache */
   /* search1951_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 152, 5501 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5576, 5577 },
      -1,
   } },

   /* replace1951_0 -> 152 in the cache */
   /* replace1951_1_0 -> 753 in the cache */
   /* replace1951_1_1 -> 154 in the cache */
   /* replace1951_1_2 -> 155 in the cache */
   /* replace1951_1 -> 1304 in the cache */
   /* replace1951 -> 5569 in the cache */

   /* ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c'), ('fmin', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1952_0 -> 753 in the cache */
   /* search1952_1_0 -> 152 in the cache */
   /* search1952_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1952_2_0 -> 152 in the cache */
   /* search1952_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 152, 5501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5579, 5580 },
      -1,
   } },

   /* replace1952_0 -> 152 in the cache */
   /* replace1952_1_0 -> 753 in the cache */
   /* replace1952_1_1 -> 154 in the cache */
   /* replace1952_1_2 -> 155 in the cache */
   /* replace1952_1 -> 1304 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 152, 1304 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c(is_not_const)'), ('fmin', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1953_0 -> 753 in the cache */
   /* search1953_1_0 -> 152 in the cache */
   /* search1953_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 152, 3441 },
      0,
   } },
   /* search1953_2_0 -> 152 in the cache */
   /* search1953_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5583, 5584 },
      -1,
   } },

   /* replace1953_0 -> 152 in the cache */
   /* replace1953_1_0 -> 753 in the cache */
   /* replace1953_1_1 -> 154 in the cache */
   /* replace1953_1_2 -> 155 in the cache */
   /* replace1953_1 -> 1304 in the cache */
   /* replace1953 -> 5582 in the cache */

   /* ('bcsel', 'a', ('fmin', 'b', 'c(is_not_const)'), ('fmin(is_used_once)', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1954_0 -> 753 in the cache */
   /* search1954_1_0 -> 152 in the cache */
   /* search1954_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 152, 3441 },
      -1,
   } },
   /* search1954_2_0 -> 152 in the cache */
   /* search1954_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5586, 5587 },
      -1,
   } },

   /* replace1954_0 -> 152 in the cache */
   /* replace1954_1_0 -> 753 in the cache */
   /* replace1954_1_1 -> 154 in the cache */
   /* replace1954_1_2 -> 155 in the cache */
   /* replace1954_1 -> 1304 in the cache */
   /* replace1954 -> 5582 in the cache */

   /* ('bcsel', 'a', ('fmin', 'b', 'c'), ('fmin(is_used_once)', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1955_0 -> 753 in the cache */
   /* search1955_1_0 -> 152 in the cache */
   /* search1955_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1955_2_0 -> 152 in the cache */
   /* search1955_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 152, 5501 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5589, 5590 },
      -1,
   } },

   /* replace1955_0 -> 152 in the cache */
   /* replace1955_1_0 -> 753 in the cache */
   /* replace1955_1_1 -> 154 in the cache */
   /* replace1955_1_2 -> 155 in the cache */
   /* replace1955_1 -> 1304 in the cache */
   /* replace1955 -> 5582 in the cache */

   /* ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c'), ('fmax', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1956_0 -> 753 in the cache */
   /* search1956_1_0 -> 152 in the cache */
   /* search1956_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1956_2_0 -> 152 in the cache */
   /* search1956_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 152, 5501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5592, 5593 },
      -1,
   } },

   /* replace1956_0 -> 152 in the cache */
   /* replace1956_1_0 -> 753 in the cache */
   /* replace1956_1_1 -> 154 in the cache */
   /* replace1956_1_2 -> 155 in the cache */
   /* replace1956_1 -> 1304 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 152, 1304 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c(is_not_const)'), ('fmax', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1957_0 -> 753 in the cache */
   /* search1957_1_0 -> 152 in the cache */
   /* search1957_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 152, 3441 },
      0,
   } },
   /* search1957_2_0 -> 152 in the cache */
   /* search1957_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5596, 5597 },
      -1,
   } },

   /* replace1957_0 -> 152 in the cache */
   /* replace1957_1_0 -> 753 in the cache */
   /* replace1957_1_1 -> 154 in the cache */
   /* replace1957_1_2 -> 155 in the cache */
   /* replace1957_1 -> 1304 in the cache */
   /* replace1957 -> 5595 in the cache */

   /* ('bcsel', 'a', ('fmax', 'b', 'c(is_not_const)'), ('fmax(is_used_once)', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1958_0 -> 753 in the cache */
   /* search1958_1_0 -> 152 in the cache */
   /* search1958_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 152, 3441 },
      -1,
   } },
   /* search1958_2_0 -> 152 in the cache */
   /* search1958_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5599, 5600 },
      -1,
   } },

   /* replace1958_0 -> 152 in the cache */
   /* replace1958_1_0 -> 753 in the cache */
   /* replace1958_1_1 -> 154 in the cache */
   /* replace1958_1_2 -> 155 in the cache */
   /* replace1958_1 -> 1304 in the cache */
   /* replace1958 -> 5595 in the cache */

   /* ('bcsel', 'a', ('fmax', 'b', 'c'), ('fmax(is_used_once)', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1959_0 -> 753 in the cache */
   /* search1959_1_0 -> 152 in the cache */
   /* search1959_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1959_2_0 -> 152 in the cache */
   /* search1959_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 152, 5501 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5602, 5603 },
      -1,
   } },

   /* replace1959_0 -> 152 in the cache */
   /* replace1959_1_0 -> 753 in the cache */
   /* replace1959_1_1 -> 154 in the cache */
   /* replace1959_1_2 -> 155 in the cache */
   /* replace1959_1 -> 1304 in the cache */
   /* replace1959 -> 5595 in the cache */

   /* ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c'), ('imin', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1960_0 -> 753 in the cache */
   /* search1960_1_0 -> 152 in the cache */
   /* search1960_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1960_2_0 -> 152 in the cache */
   /* search1960_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 152, 5501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5605, 5606 },
      -1,
   } },

   /* replace1960_0 -> 152 in the cache */
   /* replace1960_1_0 -> 753 in the cache */
   /* replace1960_1_1 -> 154 in the cache */
   /* replace1960_1_2 -> 155 in the cache */
   /* replace1960_1 -> 1304 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 152, 1304 },
      -1,
   } },

   /* ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c(is_not_const)'), ('imin', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1961_0 -> 753 in the cache */
   /* search1961_1_0 -> 152 in the cache */
   /* search1961_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 152, 3441 },
      0,
   } },
   /* search1961_2_0 -> 152 in the cache */
   /* search1961_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5609, 5610 },
      -1,
   } },

   /* replace1961_0 -> 152 in the cache */
   /* replace1961_1_0 -> 753 in the cache */
   /* replace1961_1_1 -> 154 in the cache */
   /* replace1961_1_2 -> 155 in the cache */
   /* replace1961_1 -> 1304 in the cache */
   /* replace1961 -> 5608 in the cache */

   /* ('bcsel', 'a', ('imin', 'b', 'c(is_not_const)'), ('imin(is_used_once)', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1962_0 -> 753 in the cache */
   /* search1962_1_0 -> 152 in the cache */
   /* search1962_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 152, 3441 },
      -1,
   } },
   /* search1962_2_0 -> 152 in the cache */
   /* search1962_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5612, 5613 },
      -1,
   } },

   /* replace1962_0 -> 152 in the cache */
   /* replace1962_1_0 -> 753 in the cache */
   /* replace1962_1_1 -> 154 in the cache */
   /* replace1962_1_2 -> 155 in the cache */
   /* replace1962_1 -> 1304 in the cache */
   /* replace1962 -> 5608 in the cache */

   /* ('bcsel', 'a', ('imin', 'b', 'c'), ('imin(is_used_once)', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1963_0 -> 753 in the cache */
   /* search1963_1_0 -> 152 in the cache */
   /* search1963_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1963_2_0 -> 152 in the cache */
   /* search1963_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 152, 5501 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5615, 5616 },
      -1,
   } },

   /* replace1963_0 -> 152 in the cache */
   /* replace1963_1_0 -> 753 in the cache */
   /* replace1963_1_1 -> 154 in the cache */
   /* replace1963_1_2 -> 155 in the cache */
   /* replace1963_1 -> 1304 in the cache */
   /* replace1963 -> 5608 in the cache */

   /* ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c'), ('imax', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1964_0 -> 753 in the cache */
   /* search1964_1_0 -> 152 in the cache */
   /* search1964_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1964_2_0 -> 152 in the cache */
   /* search1964_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 152, 5501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5618, 5619 },
      -1,
   } },

   /* replace1964_0 -> 152 in the cache */
   /* replace1964_1_0 -> 753 in the cache */
   /* replace1964_1_1 -> 154 in the cache */
   /* replace1964_1_2 -> 155 in the cache */
   /* replace1964_1 -> 1304 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 152, 1304 },
      -1,
   } },

   /* ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c(is_not_const)'), ('imax', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1965_0 -> 753 in the cache */
   /* search1965_1_0 -> 152 in the cache */
   /* search1965_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 152, 3441 },
      0,
   } },
   /* search1965_2_0 -> 152 in the cache */
   /* search1965_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5622, 5623 },
      -1,
   } },

   /* replace1965_0 -> 152 in the cache */
   /* replace1965_1_0 -> 753 in the cache */
   /* replace1965_1_1 -> 154 in the cache */
   /* replace1965_1_2 -> 155 in the cache */
   /* replace1965_1 -> 1304 in the cache */
   /* replace1965 -> 5621 in the cache */

   /* ('bcsel', 'a', ('imax', 'b', 'c(is_not_const)'), ('imax(is_used_once)', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1966_0 -> 753 in the cache */
   /* search1966_1_0 -> 152 in the cache */
   /* search1966_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 152, 3441 },
      -1,
   } },
   /* search1966_2_0 -> 152 in the cache */
   /* search1966_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5625, 5626 },
      -1,
   } },

   /* replace1966_0 -> 152 in the cache */
   /* replace1966_1_0 -> 753 in the cache */
   /* replace1966_1_1 -> 154 in the cache */
   /* replace1966_1_2 -> 155 in the cache */
   /* replace1966_1 -> 1304 in the cache */
   /* replace1966 -> 5621 in the cache */

   /* ('bcsel', 'a', ('imax', 'b', 'c'), ('imax(is_used_once)', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1967_0 -> 753 in the cache */
   /* search1967_1_0 -> 152 in the cache */
   /* search1967_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1967_2_0 -> 152 in the cache */
   /* search1967_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 152, 5501 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5628, 5629 },
      -1,
   } },

   /* replace1967_0 -> 152 in the cache */
   /* replace1967_1_0 -> 753 in the cache */
   /* replace1967_1_1 -> 154 in the cache */
   /* replace1967_1_2 -> 155 in the cache */
   /* replace1967_1 -> 1304 in the cache */
   /* replace1967 -> 5621 in the cache */

   /* ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c'), ('umin', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1968_0 -> 753 in the cache */
   /* search1968_1_0 -> 152 in the cache */
   /* search1968_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1968_2_0 -> 152 in the cache */
   /* search1968_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 152, 5501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5631, 5632 },
      -1,
   } },

   /* replace1968_0 -> 152 in the cache */
   /* replace1968_1_0 -> 753 in the cache */
   /* replace1968_1_1 -> 154 in the cache */
   /* replace1968_1_2 -> 155 in the cache */
   /* replace1968_1 -> 1304 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 152, 1304 },
      -1,
   } },

   /* ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c(is_not_const)'), ('umin', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1969_0 -> 753 in the cache */
   /* search1969_1_0 -> 152 in the cache */
   /* search1969_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 152, 3441 },
      0,
   } },
   /* search1969_2_0 -> 152 in the cache */
   /* search1969_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5635, 5636 },
      -1,
   } },

   /* replace1969_0 -> 152 in the cache */
   /* replace1969_1_0 -> 753 in the cache */
   /* replace1969_1_1 -> 154 in the cache */
   /* replace1969_1_2 -> 155 in the cache */
   /* replace1969_1 -> 1304 in the cache */
   /* replace1969 -> 5634 in the cache */

   /* ('bcsel', 'a', ('umin', 'b', 'c(is_not_const)'), ('umin(is_used_once)', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1970_0 -> 753 in the cache */
   /* search1970_1_0 -> 152 in the cache */
   /* search1970_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 152, 3441 },
      -1,
   } },
   /* search1970_2_0 -> 152 in the cache */
   /* search1970_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5638, 5639 },
      -1,
   } },

   /* replace1970_0 -> 152 in the cache */
   /* replace1970_1_0 -> 753 in the cache */
   /* replace1970_1_1 -> 154 in the cache */
   /* replace1970_1_2 -> 155 in the cache */
   /* replace1970_1 -> 1304 in the cache */
   /* replace1970 -> 5634 in the cache */

   /* ('bcsel', 'a', ('umin', 'b', 'c'), ('umin(is_used_once)', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1971_0 -> 753 in the cache */
   /* search1971_1_0 -> 152 in the cache */
   /* search1971_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1971_2_0 -> 152 in the cache */
   /* search1971_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 152, 5501 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5641, 5642 },
      -1,
   } },

   /* replace1971_0 -> 152 in the cache */
   /* replace1971_1_0 -> 753 in the cache */
   /* replace1971_1_1 -> 154 in the cache */
   /* replace1971_1_2 -> 155 in the cache */
   /* replace1971_1 -> 1304 in the cache */
   /* replace1971 -> 5634 in the cache */

   /* ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c'), ('umax', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1972_0 -> 753 in the cache */
   /* search1972_1_0 -> 152 in the cache */
   /* search1972_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 152, 154 },
      0,
   } },
   /* search1972_2_0 -> 152 in the cache */
   /* search1972_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 152, 5501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5644, 5645 },
      -1,
   } },

   /* replace1972_0 -> 152 in the cache */
   /* replace1972_1_0 -> 753 in the cache */
   /* replace1972_1_1 -> 154 in the cache */
   /* replace1972_1_2 -> 155 in the cache */
   /* replace1972_1 -> 1304 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 152, 1304 },
      -1,
   } },

   /* ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c(is_not_const)'), ('umax', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1973_0 -> 753 in the cache */
   /* search1973_1_0 -> 152 in the cache */
   /* search1973_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 152, 3441 },
      0,
   } },
   /* search1973_2_0 -> 152 in the cache */
   /* search1973_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5648, 5649 },
      -1,
   } },

   /* replace1973_0 -> 152 in the cache */
   /* replace1973_1_0 -> 753 in the cache */
   /* replace1973_1_1 -> 154 in the cache */
   /* replace1973_1_2 -> 155 in the cache */
   /* replace1973_1 -> 1304 in the cache */
   /* replace1973 -> 5647 in the cache */

   /* ('bcsel', 'a', ('umax', 'b', 'c(is_not_const)'), ('umax(is_used_once)', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1974_0 -> 753 in the cache */
   /* search1974_1_0 -> 152 in the cache */
   /* search1974_1_1 -> 3441 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 152, 3441 },
      -1,
   } },
   /* search1974_2_0 -> 152 in the cache */
   /* search1974_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5651, 5652 },
      -1,
   } },

   /* replace1974_0 -> 152 in the cache */
   /* replace1974_1_0 -> 753 in the cache */
   /* replace1974_1_1 -> 154 in the cache */
   /* replace1974_1_2 -> 155 in the cache */
   /* replace1974_1 -> 1304 in the cache */
   /* replace1974 -> 5647 in the cache */

   /* ('bcsel', 'a', ('umax', 'b', 'c'), ('umax(is_used_once)', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1975_0 -> 753 in the cache */
   /* search1975_1_0 -> 152 in the cache */
   /* search1975_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 152, 154 },
      -1,
   } },
   /* search1975_2_0 -> 152 in the cache */
   /* search1975_2_1 -> 5501 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 152, 5501 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 753, 5654, 5655 },
      -1,
   } },

   /* replace1975_0 -> 152 in the cache */
   /* replace1975_1_0 -> 753 in the cache */
   /* replace1975_1_1 -> 154 in the cache */
   /* replace1975_1_2 -> 155 in the cache */
   /* replace1975_1 -> 1304 in the cache */
   /* replace1975 -> 5647 in the cache */

   /* ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1976_0 -> 753 in the cache */
   /* search1976_1_0 -> 152 in the cache */
   /* search1976_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 152, 154 },
      0,
   } },
   /* search1976_2_0 -> 152 in the cache */
   /* search1976_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 152, 155 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 5657, 5658 },
      -1,
   } },

   /* replace1976_0 -> 152 in the cache */
   /* replace1976_1_0 -> 753 in the cache */
   /* replace1976_1_1 -> 154 in the cache */
   /* replace1976_1_2 -> 155 in the cache */
   /* replace1976_1 -> 1304 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 152, 1304 },
      -1,
   } },

   /* ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1977_0 -> 753 in the cache */
   /* search1977_1_0 -> 152 in the cache */
   /* search1977_1_1 -> 154 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 152, 154 },
      -1,
   } },
   /* search1977_2_0 -> 152 in the cache */
   /* search1977_2_1 -> 155 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 152, 155 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 5661, 5662 },
      -1,
   } },

   /* replace1977_0 -> 152 in the cache */
   /* replace1977_1_0 -> 753 in the cache */
   /* replace1977_1_1 -> 154 in the cache */
   /* replace1977_1_2 -> 155 in the cache */
   /* replace1977_1 -> 1304 in the cache */
   /* replace1977 -> 5660 in the cache */

   /* ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c') */
   /* search1978_0 -> 753 in the cache */
   /* search1978_1_0 -> 129 in the cache */
   /* search1978_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 129, 131 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1978_2_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 5665, 131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 5664, 5666 },
      -1,
   } },

   /* replace1978_0_0 -> 753 in the cache */
   /* replace1978_0_1 -> 129 in the cache */
   /* replace1978_0_2 -> 5665 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 129, 5665 },
      -1,
   } },
   /* replace1978_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 5668, 131 },
      -1,
   } },

   /* ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c') */
   /* search1979_0 -> 753 in the cache */
   /* search1979_1_0 -> 129 in the cache */
   /* search1979_1_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 129, 131 },
      -1,
   } },
   /* search1979_2_0 -> 5665 in the cache */
   /* search1979_2_1 -> 131 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 5665, 131 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 753, 5670, 5671 },
      -1,
   } },

   /* replace1979_0_0 -> 753 in the cache */
   /* replace1979_0_1 -> 129 in the cache */
   /* replace1979_0_2 -> 5665 in the cache */
   /* replace1979_0 -> 5668 in the cache */
   /* replace1979_1 -> 131 in the cache */
   /* replace1979 -> 5669 in the cache */

   /* ('bcsel', 'c', ('frcp(is_used_once)', 'a'), ('frcp(is_used_once)', 'b')) => ('frcp', ('bcsel', 'c', 'a', 'b')) */
   /* search1980_0 -> 523 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 5673 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 5675 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5674, 5676 },
      -1,
   } },

   /* replace1980_0_0 -> 523 in the cache */
   /* replace1980_0_1 -> 5673 in the cache */
   /* replace1980_0_2 -> 5675 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5673, 5675 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 5678 },
      -1,
   } },

   /* ('bcsel', 'c', ('frsq(is_used_once)', 'a'), ('frsq(is_used_once)', 'b')) => ('frsq', ('bcsel', 'c', 'a', 'b')) */
   /* search1981_0 -> 523 in the cache */
   /* search1981_1_0 -> 5673 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 5673 },
      0,
   } },
   /* search1981_2_0 -> 5675 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 5675 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5680, 5681 },
      -1,
   } },

   /* replace1981_0_0 -> 523 in the cache */
   /* replace1981_0_1 -> 5673 in the cache */
   /* replace1981_0_2 -> 5675 in the cache */
   /* replace1981_0 -> 5678 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 5678 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsqrt(is_used_once)', 'a'), ('fsqrt(is_used_once)', 'b')) => ('fsqrt', ('bcsel', 'c', 'a', 'b')) */
   /* search1982_0 -> 523 in the cache */
   /* search1982_1_0 -> 5673 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 5673 },
      0,
   } },
   /* search1982_2_0 -> 5675 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 5675 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5684, 5685 },
      -1,
   } },

   /* replace1982_0_0 -> 523 in the cache */
   /* replace1982_0_1 -> 5673 in the cache */
   /* replace1982_0_2 -> 5675 in the cache */
   /* replace1982_0 -> 5678 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 5678 },
      -1,
   } },

   /* ('bcsel', 'c', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('bcsel', 'c', 'a', 'b')) */
   /* search1983_0 -> 523 in the cache */
   /* search1983_1_0 -> 5673 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 5673 },
      0,
   } },
   /* search1983_2_0 -> 5675 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 5675 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5688, 5689 },
      -1,
   } },

   /* replace1983_0_0 -> 523 in the cache */
   /* replace1983_0_1 -> 5673 in the cache */
   /* replace1983_0_2 -> 5675 in the cache */
   /* replace1983_0 -> 5678 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 5678 },
      -1,
   } },

   /* ('bcsel', 'c', ('flog2(is_used_once)', 'a'), ('flog2(is_used_once)', 'b')) => ('flog2', ('bcsel', 'c', 'a', 'b')) */
   /* search1984_0 -> 523 in the cache */
   /* search1984_1_0 -> 5673 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 5673 },
      0,
   } },
   /* search1984_2_0 -> 5675 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 5675 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5692, 5693 },
      -1,
   } },

   /* replace1984_0_0 -> 523 in the cache */
   /* replace1984_0_1 -> 5673 in the cache */
   /* replace1984_0_2 -> 5675 in the cache */
   /* replace1984_0 -> 5678 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 5678 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b')) */
   /* search1985_0 -> 523 in the cache */
   /* search1985_1_0 -> 5673 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 5673 },
      0,
   } },
   /* search1985_2_0 -> 5675 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 5675 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5696, 5697 },
      -1,
   } },

   /* replace1985_0_0 -> 523 in the cache */
   /* replace1985_0_1 -> 5673 in the cache */
   /* replace1985_0_2 -> 5675 in the cache */
   /* replace1985_0 -> 5678 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 5678 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsin(is_used_once)', 'a'), ('fsin(is_used_once)', 'b')) => ('fsin', ('bcsel', 'c', 'a', 'b')) */
   /* search1986_0 -> 523 in the cache */
   /* search1986_1_0 -> 5673 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 5673 },
      0,
   } },
   /* search1986_2_0 -> 5675 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 5675 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5700, 5701 },
      -1,
   } },

   /* replace1986_0_0 -> 523 in the cache */
   /* replace1986_0_1 -> 5673 in the cache */
   /* replace1986_0_2 -> 5675 in the cache */
   /* replace1986_0 -> 5678 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 5678 },
      -1,
   } },

   /* ('bcsel', 'c', ('fcos(is_used_once)', 'a'), ('fcos(is_used_once)', 'b')) => ('fcos', ('bcsel', 'c', 'a', 'b')) */
   /* search1987_0 -> 523 in the cache */
   /* search1987_1_0 -> 5673 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 5673 },
      0,
   } },
   /* search1987_2_0 -> 5675 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 5675 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5704, 5705 },
      -1,
   } },

   /* replace1987_0_0 -> 523 in the cache */
   /* replace1987_0_1 -> 5673 in the cache */
   /* replace1987_0_2 -> 5675 in the cache */
   /* replace1987_0 -> 5678 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 5678 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsin_amd(is_used_once)', 'a'), ('fsin_amd(is_used_once)', 'b')) => ('fsin_amd', ('bcsel', 'c', 'a', 'b')) */
   /* search1988_0 -> 523 in the cache */
   /* search1988_1_0 -> 5673 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin_amd,
      -1, 0,
      { 5673 },
      0,
   } },
   /* search1988_2_0 -> 5675 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin_amd,
      -1, 0,
      { 5675 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5708, 5709 },
      -1,
   } },

   /* replace1988_0_0 -> 523 in the cache */
   /* replace1988_0_1 -> 5673 in the cache */
   /* replace1988_0_2 -> 5675 in the cache */
   /* replace1988_0 -> 5678 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin_amd,
      -1, 0,
      { 5678 },
      -1,
   } },

   /* ('bcsel', 'c', ('fcos_amd(is_used_once)', 'a'), ('fcos_amd(is_used_once)', 'b')) => ('fcos_amd', ('bcsel', 'c', 'a', 'b')) */
   /* search1989_0 -> 523 in the cache */
   /* search1989_1_0 -> 5673 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos_amd,
      -1, 0,
      { 5673 },
      0,
   } },
   /* search1989_2_0 -> 5675 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos_amd,
      -1, 0,
      { 5675 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5712, 5713 },
      -1,
   } },

   /* replace1989_0_0 -> 523 in the cache */
   /* replace1989_0_1 -> 5673 in the cache */
   /* replace1989_0_2 -> 5675 in the cache */
   /* replace1989_0 -> 5678 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos_amd,
      -1, 0,
      { 5678 },
      -1,
   } },

   /* ('bcsel', 'c', ('fneg(is_used_once)', 'a'), ('fneg(is_used_once)', 'b')) => ('fneg', ('bcsel', 'c', 'a', 'b')) */
   /* search1990_0 -> 523 in the cache */
   /* search1990_1_0 -> 5673 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5673 },
      0,
   } },
   /* search1990_2_0 -> 5675 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5675 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5716, 5717 },
      -1,
   } },

   /* replace1990_0_0 -> 523 in the cache */
   /* replace1990_0_1 -> 5673 in the cache */
   /* replace1990_0_2 -> 5675 in the cache */
   /* replace1990_0 -> 5678 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5678 },
      -1,
   } },

   /* ('bcsel', 'c', ('fabs(is_used_once)', 'a'), ('fabs(is_used_once)', 'b')) => ('fabs', ('bcsel', 'c', 'a', 'b')) */
   /* search1991_0 -> 523 in the cache */
   /* search1991_1_0 -> 5673 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5673 },
      0,
   } },
   /* search1991_2_0 -> 5675 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5675 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5720, 5721 },
      -1,
   } },

   /* replace1991_0_0 -> 523 in the cache */
   /* replace1991_0_1 -> 5673 in the cache */
   /* replace1991_0_2 -> 5675 in the cache */
   /* replace1991_0 -> 5678 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5678 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b')) */
   /* search1992_0 -> 523 in the cache */
   /* search1992_1_0 -> 5673 in the cache */
   /* search1992_1 -> 5696 in the cache */
   /* search1992_2_0 -> 5675 in the cache */
   /* search1992_2 -> 5697 in the cache */
   /* search1992 -> 5698 in the cache */

   /* replace1992_0_0 -> 523 in the cache */
   /* replace1992_0_1 -> 5673 in the cache */
   /* replace1992_0_2 -> 5675 in the cache */
   /* replace1992_0 -> 5678 in the cache */
   /* replace1992 -> 5699 in the cache */

   /* ('ineg', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('ineg', 'a'), ('ineg', 'b')) */
   /* search1993_0_0 -> 523 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5724, 5725 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 5726 },
      -1,
   } },

   /* replace1993_0 -> 523 in the cache */
   /* replace1993_1_0 -> 5673 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 5673 },
      -1,
   } },
   /* replace1993_2_0 -> 5675 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 5675 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5728, 5729 },
      -1,
   } },

   /* ('iabs', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('iabs', 'a'), ('iabs', 'b')) */
   /* search1994_0_0 -> 523 in the cache */
   /* search1994_0_1 -> 5724 in the cache */
   /* search1994_0_2 -> 5725 in the cache */
   /* search1994_0 -> 5726 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 5726 },
      -1,
   } },

   /* replace1994_0 -> 523 in the cache */
   /* replace1994_1_0 -> 5673 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 5673 },
      -1,
   } },
   /* replace1994_2_0 -> 5675 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 5675 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5732, 5733 },
      -1,
   } },

   /* ('inot', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('inot', 'a'), ('inot', 'b')) */
   /* search1995_0_0 -> 523 in the cache */
   /* search1995_0_1 -> 5724 in the cache */
   /* search1995_0_2 -> 5725 in the cache */
   /* search1995_0 -> 5726 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 5726 },
      -1,
   } },

   /* replace1995_0 -> 523 in the cache */
   /* replace1995_1_0 -> 5673 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 5673 },
      -1,
   } },
   /* replace1995_2_0 -> 5675 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 5675 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5736, 5737 },
      -1,
   } },

   /* ('isign', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('isign', 'a'), ('isign', 'b')) */
   /* search1996_0_0 -> 523 in the cache */
   /* search1996_0_1 -> 5724 in the cache */
   /* search1996_0_2 -> 5725 in the cache */
   /* search1996_0 -> 5726 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 5726 },
      -1,
   } },

   /* replace1996_0 -> 523 in the cache */
   /* replace1996_1_0 -> 5673 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 5673 },
      -1,
   } },
   /* replace1996_2_0 -> 5675 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 5675 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 523, 5740, 5741 },
      -1,
   } },

   /* ('fisnormal', 'a@16') => ('ult', 4095, ('iadd', ('ishl', 'a', 1), 2048)) */
   /* search1997_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fisnormal,
      -1, 0,
      { 11 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xfff /* 4095 */ },
   } },
   /* replace1997_1_0_0 -> 11 in the cache */
   /* replace1997_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 398 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x800 /* 2048 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5745, 5746 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 5744, 5747 },
      -1,
   } },

   /* ('fisnormal', 'a@32') => ('ult', 33554431, ('iadd', ('ishl', 'a', 1), 16777216)) */
   /* search1998_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fisnormal,
      -1, 0,
      { 16 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1ffffff /* 33554431 */ },
   } },
   /* replace1998_1_0_0 -> 16 in the cache */
   /* replace1998_1_0_1 -> 398 in the cache */
   /* replace1998_1_0 -> 984 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1000000 /* 16777216 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 984, 5751 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 5750, 5752 },
      -1,
   } },

   /* ('fisnormal', 'a@64') => ('ult', 18014398509481983, ('iadd', ('ishl', 'a', 1), 9007199254740992)) */
   /* search1999_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fisnormal,
      -1, 0,
      { 21 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x3fffffffffffff /* 18014398509481983 */ },
   } },
   /* replace1999_1_0_0 -> 21 in the cache */
   /* replace1999_1_0_1 -> 398 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 398 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x20000000000000 /* 9007199254740992 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5756, 5757 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 5755, 5758 },
      -1,
   } },

   /* ('f2f16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2f16', 'a'), ('f2f16', 'b')) */
   /* search2000_0_0 -> 16 in the cache */
   /* search2000_0_1 -> 36 in the cache */
   /* search2000_0 -> 3141 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 3141 },
      -1,
   } },

   /* replace2000_0_0 -> 16 in the cache */
   /* replace2000_0 -> 3916 in the cache */
   /* replace2000_1_0 -> 36 in the cache */
   /* replace2000_1 -> 3913 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3916, 3913 },
      -1,
   } },

   /* ('f2fmp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2fmp', 'a'), ('f2fmp', 'b')) */
   /* search2001_0_0 -> 16 in the cache */
   /* search2001_0_1 -> 36 in the cache */
   /* search2001_0 -> 3141 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 3141 },
      -1,
   } },

   /* replace2001_0_0 -> 16 in the cache */
   /* replace2001_0 -> 1982 in the cache */
   /* replace2001_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 1982, 5763 },
      -1,
   } },

   /* ('u2u16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('u2u16', 'a'), ('u2u16', 'b')) */
   /* search2002_0_0 -> 16 in the cache */
   /* search2002_0_1 -> 36 in the cache */
   /* search2002_0 -> 3141 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3141 },
      -1,
   } },

   /* replace2002_0_0 -> 16 in the cache */
   /* replace2002_0 -> 3238 in the cache */
   /* replace2002_1_0 -> 36 in the cache */
   /* replace2002_1 -> 4710 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3238, 4710 },
      -1,
   } },

   /* ('i2i16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2i16', 'a'), ('i2i16', 'b')) */
   /* search2003_0_0 -> 16 in the cache */
   /* search2003_0_1 -> 36 in the cache */
   /* search2003_0 -> 3141 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3141 },
      -1,
   } },

   /* replace2003_0_0 -> 16 in the cache */
   /* replace2003_0 -> 4196 in the cache */
   /* replace2003_1_0 -> 36 in the cache */
   /* replace2003_1 -> 4381 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 4196, 4381 },
      -1,
   } },

   /* ('i2imp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2imp', 'a'), ('i2imp', 'b')) */
   /* search2004_0_0 -> 16 in the cache */
   /* search2004_0_1 -> 36 in the cache */
   /* search2004_0 -> 3141 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 3141 },
      -1,
   } },

   /* replace2004_0_0 -> 16 in the cache */
   /* replace2004_0 -> 1993 in the cache */
   /* replace2004_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 1993, 5770 },
      -1,
   } },

   /* ('f2f16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c')) */
   /* search2005_0_0 -> 16 in the cache */
   /* search2005_0_1 -> 36 in the cache */
   /* search2005_0_2 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 16, 36, 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 5772 },
      -1,
   } },

   /* replace2005_0_0 -> 16 in the cache */
   /* replace2005_0 -> 3916 in the cache */
   /* replace2005_1_0 -> 36 in the cache */
   /* replace2005_1 -> 3913 in the cache */
   /* replace2005_2_0 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 3916, 3913, 5774 },
      -1,
   } },

   /* ('f2fmp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c')) */
   /* search2006_0_0 -> 16 in the cache */
   /* search2006_0_1 -> 36 in the cache */
   /* search2006_0_2 -> 137 in the cache */
   /* search2006_0 -> 5772 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 5772 },
      -1,
   } },

   /* replace2006_0_0 -> 16 in the cache */
   /* replace2006_0 -> 1982 in the cache */
   /* replace2006_1_0 -> 36 in the cache */
   /* replace2006_1 -> 5763 in the cache */
   /* replace2006_2_0 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 1982, 5763, 5777 },
      -1,
   } },

   /* ('u2u16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c')) */
   /* search2007_0_0 -> 16 in the cache */
   /* search2007_0_1 -> 36 in the cache */
   /* search2007_0_2 -> 137 in the cache */
   /* search2007_0 -> 5772 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 5772 },
      -1,
   } },

   /* replace2007_0_0 -> 16 in the cache */
   /* replace2007_0 -> 3238 in the cache */
   /* replace2007_1_0 -> 36 in the cache */
   /* replace2007_1 -> 4710 in the cache */
   /* replace2007_2_0 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 3238, 4710, 5780 },
      -1,
   } },

   /* ('i2i16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c')) */
   /* search2008_0_0 -> 16 in the cache */
   /* search2008_0_1 -> 36 in the cache */
   /* search2008_0_2 -> 137 in the cache */
   /* search2008_0 -> 5772 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 5772 },
      -1,
   } },

   /* replace2008_0_0 -> 16 in the cache */
   /* replace2008_0 -> 4196 in the cache */
   /* replace2008_1_0 -> 36 in the cache */
   /* replace2008_1 -> 4381 in the cache */
   /* replace2008_2_0 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 4196, 4381, 5783 },
      -1,
   } },

   /* ('i2imp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c')) */
   /* search2009_0_0 -> 16 in the cache */
   /* search2009_0_1 -> 36 in the cache */
   /* search2009_0_2 -> 137 in the cache */
   /* search2009_0 -> 5772 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 5772 },
      -1,
   } },

   /* replace2009_0_0 -> 16 in the cache */
   /* replace2009_0 -> 1993 in the cache */
   /* replace2009_1_0 -> 36 in the cache */
   /* replace2009_1 -> 5770 in the cache */
   /* replace2009_2_0 -> 137 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 137 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 1993, 5770, 5786 },
      -1,
   } },

   /* ('f2f16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'), ('f2f16', 'd')) */
   /* search2010_0_0 -> 16 in the cache */
   /* search2010_0_1 -> 36 in the cache */
   /* search2010_0_2 -> 137 in the cache */
   /* search2010_0_3 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 16, 36, 137, 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 5788 },
      -1,
   } },

   /* replace2010_0_0 -> 16 in the cache */
   /* replace2010_0 -> 3916 in the cache */
   /* replace2010_1_0 -> 36 in the cache */
   /* replace2010_1 -> 3913 in the cache */
   /* replace2010_2_0 -> 137 in the cache */
   /* replace2010_2 -> 5774 in the cache */
   /* replace2010_3_0 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3916, 3913, 5774, 5790 },
      -1,
   } },

   /* ('f2fmp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'), ('f2fmp', 'd')) */
   /* search2011_0_0 -> 16 in the cache */
   /* search2011_0_1 -> 36 in the cache */
   /* search2011_0_2 -> 137 in the cache */
   /* search2011_0_3 -> 165 in the cache */
   /* search2011_0 -> 5788 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 5788 },
      -1,
   } },

   /* replace2011_0_0 -> 16 in the cache */
   /* replace2011_0 -> 1982 in the cache */
   /* replace2011_1_0 -> 36 in the cache */
   /* replace2011_1 -> 5763 in the cache */
   /* replace2011_2_0 -> 137 in the cache */
   /* replace2011_2 -> 5777 in the cache */
   /* replace2011_3_0 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 1982, 5763, 5777, 5793 },
      -1,
   } },

   /* ('u2u16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'), ('u2u16', 'd')) */
   /* search2012_0_0 -> 16 in the cache */
   /* search2012_0_1 -> 36 in the cache */
   /* search2012_0_2 -> 137 in the cache */
   /* search2012_0_3 -> 165 in the cache */
   /* search2012_0 -> 5788 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 5788 },
      -1,
   } },

   /* replace2012_0_0 -> 16 in the cache */
   /* replace2012_0 -> 3238 in the cache */
   /* replace2012_1_0 -> 36 in the cache */
   /* replace2012_1 -> 4710 in the cache */
   /* replace2012_2_0 -> 137 in the cache */
   /* replace2012_2 -> 5780 in the cache */
   /* replace2012_3_0 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3238, 4710, 5780, 5796 },
      -1,
   } },

   /* ('i2i16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'), ('i2i16', 'd')) */
   /* search2013_0_0 -> 16 in the cache */
   /* search2013_0_1 -> 36 in the cache */
   /* search2013_0_2 -> 137 in the cache */
   /* search2013_0_3 -> 165 in the cache */
   /* search2013_0 -> 5788 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 5788 },
      -1,
   } },

   /* replace2013_0_0 -> 16 in the cache */
   /* replace2013_0 -> 4196 in the cache */
   /* replace2013_1_0 -> 36 in the cache */
   /* replace2013_1 -> 4381 in the cache */
   /* replace2013_2_0 -> 137 in the cache */
   /* replace2013_2 -> 5783 in the cache */
   /* replace2013_3_0 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 4196, 4381, 5783, 5799 },
      -1,
   } },

   /* ('i2imp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'), ('i2imp', 'd')) */
   /* search2014_0_0 -> 16 in the cache */
   /* search2014_0_1 -> 36 in the cache */
   /* search2014_0_2 -> 137 in the cache */
   /* search2014_0_3 -> 165 in the cache */
   /* search2014_0 -> 5788 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 5788 },
      -1,
   } },

   /* replace2014_0_0 -> 16 in the cache */
   /* replace2014_0 -> 1993 in the cache */
   /* replace2014_1_0 -> 36 in the cache */
   /* replace2014_1 -> 5770 in the cache */
   /* replace2014_2_0 -> 137 in the cache */
   /* replace2014_2 -> 5786 in the cache */
   /* replace2014_3_0 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 1993, 5770, 5786, 5802 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_expression_cond[] = {
   (is_used_once),
   (is_only_used_as_float),
   (is_used_by_if),
   (is_not_used_by_if),
   (is_used_by_non_fsat),
   (no_signed_wrap),
   (only_lower_8_bits_used),
   (only_lower_16_bits_used),
};

static const nir_search_variable_cond nir_opt_algebraic_variable_cond[] = {
   (is_pos_power_of_two),
   (is_neg_power_of_two),
   (is_bitcount2),
   (is_finite_not_zero),
   (is_finite),
   (is_not_const),
   (is_not_const_zero),
   (is_ult_0xfffc07fc),
   (is_not_fmul),
   (is_first_5_bits_uge_2),
   (is_unsigned_multiple_of_4),
   (is_unsigned_multiple_of_2),
   (is_unsigned_multiple_of_8),
   (is_unsigned_multiple_of_16),
   (is_unsigned_multiple_of_32),
   (is_unsigned_multiple_of_64),
   (is_a_number),
   (is_gt_0_and_lt_1),
   (is_zero_to_one),
   (is_not_negative),
   (is_integral),
   (is_not_positive),
   (is_not_zero),
   (is_a_number_not_negative),
   (is_a_number_not_positive),
   (is_gt_zero),
   (is_lt_zero),
   (is_a_number_gt_zero),
   (is_a_number_lt_zero),
   (is_fmul),
   (is_ult_32),
   (is_lower_half_zero),
   (is_upper_half_zero),
};

static const struct transform nir_opt_algebraic_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2689, 1216, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2689, 1216, 0 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3145, 3235, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 52, 54, 4 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 55, 57, 4 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 58, 32, 0 },
   { 67, 68, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 32, 0 },
   { 69, 73, 1 },
   { 74, 77, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 61, 0 },
   { 78, 81, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 62, 61, 0 },
   { 64, 61, 0 },
   { 82, 81, 1 },
   { 83, 88, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 61, 0 },
   { 66, 61, 0 },
   { 89, 95, 1 },
   { 96, 97, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3079, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3080, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2965, 2966, 0 },
   { 2967, 2968, 0 },
   { 2969, 1220, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3680, 3693, 79 },
   { 3965, 3976, 110 },
   { 3985, 3996, 110 },
   { 4005, 4015, 110 },
   { 3680, 4030, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 120, 32, 0 },
   { 3680, 3693, 79 },
   { 3965, 3976, 110 },
   { 3985, 3996, 110 },
   { 4005, 4015, 110 },
   { 3680, 4030, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3694, 3702, 79 },
   { 3977, 3984, 110 },
   { 3997, 4004, 110 },
   { 4016, 4023, 110 },
   { 3694, 4035, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 121, 32, 0 },
   { 3694, 3702, 79 },
   { 3977, 3984, 110 },
   { 3997, 4004, 110 },
   { 4016, 4023, 110 },
   { 3694, 4035, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3666, 3670, 75 },
   { 3671, 3673, 76 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 122, 32, 0 },
   { 3666, 3670, 75 },
   { 3671, 3673, 76 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3674, 3675, 77 },
   { 3676, 3679, 78 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 123, 32, 0 },
   { 3674, 3675, 77 },
   { 3676, 3679, 78 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 125, 16, 0 },
   { 127, 126, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 117, 0 },
   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 246, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 286, 287, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 286, 287, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 270, 271, 6 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 270, 271, 6 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 289, 290, 0 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 270, 271, 6 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 289, 290, 0 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2669, 32, 0 },
   { 2670, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 1070, 0 },
   { 2971, 1118, 0 },
   { 2972, 753, 0 },
   { 3117, 1224, 0 },
   { 3718, 3720, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 1509, 40 },
   { 3082, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 241, 124, 0 },
   { 242, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 252, 3929, 103 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 687, 689, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { 687, 689, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 294, 266, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { 294, 266, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 294, 266, 0 },
   { 687, 689, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { 294, 266, 0 },
   { 687, 689, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 413, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 413, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 299, 36, 0 },
   { 333, 413, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 299, 36, 0 },
   { 333, 413, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 299, 36, 0 },
   { 350, 352, 0 },
   { 333, 413, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 299, 36, 0 },
   { 350, 352, 0 },
   { 333, 413, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 336, 429, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 336, 429, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 300, 36, 0 },
   { 336, 429, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 300, 36, 0 },
   { 336, 429, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 300, 36, 0 },
   { 353, 355, 0 },
   { 336, 429, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 300, 36, 0 },
   { 353, 355, 0 },
   { 336, 429, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 458, 459, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 301, 36, 0 },
   { 458, 459, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 301, 36, 0 },
   { 365, 366, 7 },
   { 458, 459, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 456, 457, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 455, 336, 0 },
   { 456, 457, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 36, 0 },
   { 456, 457, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 36, 0 },
   { 455, 336, 0 },
   { 456, 457, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 36, 0 },
   { 367, 368, 8 },
   { 456, 457, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 36, 0 },
   { 367, 368, 8 },
   { 455, 336, 0 },
   { 456, 457, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 345, 445, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 345, 445, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 303, 36, 0 },
   { 345, 445, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 303, 36, 0 },
   { 345, 445, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 303, 36, 0 },
   { 359, 361, 0 },
   { 345, 445, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 303, 36, 0 },
   { 359, 361, 0 },
   { 345, 445, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 348, 453, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 348, 453, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 36, 0 },
   { 348, 453, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 36, 0 },
   { 348, 453, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 36, 0 },
   { 362, 364, 0 },
   { 348, 453, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 36, 0 },
   { 362, 364, 0 },
   { 348, 453, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 464, 465, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 305, 36, 0 },
   { 464, 465, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 305, 36, 0 },
   { 371, 372, 7 },
   { 464, 465, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 462, 463, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 306, 36, 0 },
   { 462, 463, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 306, 36, 0 },
   { 373, 374, 8 },
   { 462, 463, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 339, 437, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 339, 437, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 307, 36, 0 },
   { 339, 437, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 307, 36, 0 },
   { 339, 437, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 308, 36, 0 },
   { 339, 437, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 308, 36, 0 },
   { 339, 437, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 307, 36, 0 },
   { 308, 36, 0 },
   { 356, 358, 0 },
   { 339, 437, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 307, 36, 0 },
   { 308, 36, 0 },
   { 356, 358, 0 },
   { 339, 437, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 460, 461, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 309, 36, 0 },
   { 460, 461, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 310, 36, 0 },
   { 460, 461, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 309, 36, 0 },
   { 310, 36, 0 },
   { 369, 370, 7 },
   { 460, 461, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2974, 753, 0 },
   { 2975, 1118, 0 },
   { 2978, 2979, 0 },
   { 2980, 2981, 0 },
   { 2984, 2985, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 0 },
   { 2993, 2994, 0 },
   { 2995, 2996, 0 },
   { 2997, 2998, 57 },
   { 2999, 3000, 57 },
   { 3003, 3004, 57 },
   { 3005, 3006, 57 },
   { 3007, 3, 0 },
   { 3009, 2237, 0 },
   { 3010, 3012, 0 },
   { 3014, 1215, 0 },
   { 3015, 3011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2974, 753, 0 },
   { 2975, 1118, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 2978, 2979, 0 },
   { 2980, 2981, 0 },
   { 2984, 2985, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 0 },
   { 2993, 2994, 0 },
   { 2995, 2996, 0 },
   { 2997, 2998, 57 },
   { 2999, 3000, 57 },
   { 3003, 3004, 57 },
   { 3005, 3006, 57 },
   { 3007, 3, 0 },
   { 3009, 2237, 0 },
   { 3010, 3012, 0 },
   { 3014, 1215, 0 },
   { 3015, 3011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2661, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 690, 695, 20 },
   { 696, 701, 20 },
   { 702, 708, 21 },
   { 3075, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 709, 711, 22 },
   { 712, 714, 22 },
   { 715, 717, 23 },
   { 3073, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 710, 724, 26 },
   { 713, 725, 26 },
   { 716, 726, 27 },
   { 3077, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 727, 729, 28 },
   { 3074, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 761, 766, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 797, 798, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 795, 796, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 793, 794, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 789, 792, 0 },
   { 793, 794, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 799, 792, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2696, 32, 0 },
   { 3162, 3163, 58 },
   { 1010, 424, 58 },
   { 3165, 3167, 58 },
   { 1001, 449, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2695, 1216, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2695, 1216, 0 },
   { 2696, 32, 0 },
   { 3162, 3163, 58 },
   { 1010, 424, 58 },
   { 3165, 3167, 58 },
   { 1001, 449, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2694, 32, 0 },
   { 3168, 3169, 58 },
   { 3170, 408, 58 },
   { 3171, 3172, 58 },
   { 3202, 441, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2691, 1216, 0 },
   { 2693, 2692, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2691, 1216, 0 },
   { 2693, 2692, 0 },
   { 2694, 32, 0 },
   { 3168, 3169, 58 },
   { 3170, 408, 58 },
   { 3171, 3172, 58 },
   { 3202, 441, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2662, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { 1481, 3716, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2656, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2656, 1070, 0 },
   { 3127, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2656, 1070, 0 },
   { 3126, 1224, 0 },
   { 3723, 3720, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2656, 1070, 0 },
   { 3126, 1224, 0 },
   { 3127, 1070, 0 },
   { 3723, 3720, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { 1478, 3717, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 3083, 219, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1332, 61, 0 },
   { 1333, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1334, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1334, 32, 0 },
   { 1335, 32, 0 },
   { 1336, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3840, 3843, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3840, 3843, 90 },
   { 4921, 11, 0 },
   { 4974, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4084, 11, 0 },
   { 4085, 16, 0 },
   { 4086, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4074, 753, 0 },
   { 4075, 6, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3835, 3839, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3835, 3839, 90 },
   { 4949, 11, 0 },
   { 5002, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3844, 3848, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3844, 3848, 91 },
   { 5054, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3849, 3852, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3849, 3852, 91 },
   { 5027, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2673, 32, 0 },
   { 2676, 2666, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2359, 2367, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2361, 2368, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2363, 2369, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 2370, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2389, 2396, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2397, 2399, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2400, 2402, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2403, 2405, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2406, 2408, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2409, 2412, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2413, 2417, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2418, 2420, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2421, 2423, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2424, 2426, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2427, 2432, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 2439, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 2446, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2447, 2463, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 2496, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2497, 2500, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2501, 2506, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2507, 2511, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2512, 2520, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2521, 2537, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2538, 2541, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2542, 2547, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2548, 2552, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2553, 2561, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2562, 2578, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2579, 2582, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2583, 2588, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2589, 2593, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2594, 2602, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2603, 2619, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3389, 3390, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3389, 3390, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2722, 2725, 50 },
   { 2701, 2704, 50 },
   { 2708, 2711, 50 },
   { 2726, 2729, 50 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2730, 2732, 50 },
   { 2714, 2716, 50 },
   { 2719, 2721, 50 },
   { 2733, 2735, 50 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2740, 2743, 51 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2740, 2743, 51 },
   { 2765, 32, 0 },
   { 2766, 253, 0 },
   { 2767, 2764, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2740, 2743, 51 },
   { 2768, 2738, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2740, 2743, 51 },
   { 2765, 32, 0 },
   { 2766, 253, 0 },
   { 2767, 2764, 0 },
   { 2768, 2738, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2757, 2810, 54 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2805, 2807, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2804, 2786, 0 },
   { 2805, 2807, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2812, 2894, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2895, 2964, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3008, 36, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3076, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3128, 3230, 61 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3237, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3154, 3238, 64 },
   { 3154, 3238, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3156, 3239, 64 },
   { 3156, 3239, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3779, 124, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3190, 414, 58 },
   { 3191, 417, 58 },
   { 3192, 421, 58 },
   { 3193, 424, 58 },
   { 3206, 446, 59 },
   { 3207, 449, 59 },
   { 3779, 124, 0 },
   { 3781, 3783, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3780, 124, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3194, 395, 58 },
   { 3195, 399, 58 },
   { 3196, 404, 58 },
   { 3197, 408, 58 },
   { 3208, 438, 59 },
   { 3209, 441, 59 },
   { 3780, 124, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3231, 3234, 62 },
   { 3231, 3921, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3241, 3919, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3248, 3920, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3276, 3918, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3276, 3918, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3276, 3918, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3276, 3918, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3385, 16, 0 },
   { 3386, 124, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3387, 3388, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3391, 3393, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3394, 3395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3831, 3834, 89 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3814, 3818, 86 },
   { 3814, 3822, 87 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3824, 3828, 87 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3610, 3613, 68 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3614, 3617, 68 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3618, 3621, 69 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3622, 3623, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3628, 3632, 71 },
   { 3628, 3732, 82 },
   { 3628, 3734, 83 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3633, 3636, 72 },
   { 3646, 3650, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3637, 3639, 72 },
   { 3651, 3653, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3640, 3642, 72 },
   { 3654, 3658, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3643, 3645, 72 },
   { 3659, 3661, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3662, 3663, 74 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3664, 3665, 74 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3738, 3741, 84 },
   { 3738, 3807, 85 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3742, 3744, 84 },
   { 3742, 3813, 85 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3745, 2682, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3829, 3830, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3854, 3860, 92 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3861, 3866, 93 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3867, 3874, 94 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3875, 3880, 95 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3881, 3886, 96 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3887, 3894, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3895, 3902, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3903, 3912, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3922, 3924, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3930, 944, 104 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3931, 3935, 105 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3936, 3940, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3941, 3942, 107 },
   { 3941, 49, 104 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3943, 3936, 108 },
   { 3943, 3945, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3946, 3931, 109 },
   { 3946, 49, 105 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3947, 3942, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3948, 557, 0 },
   { 3949, 3950, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3947, 3942, 0 },
   { 3948, 557, 0 },
   { 3949, 3950, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3948, 557, 0 },
   { 3949, 3950, 0 },
   { 3951, 3953, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3947, 3942, 0 },
   { 3948, 557, 0 },
   { 3949, 3950, 0 },
   { 3951, 3953, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3955, 3957, 1 },
   { 3959, 3963, 1 },
   { 3964, 124, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4087, 753, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4088, 6, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4089, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4090, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5080, 5100, 113 },
   { 5102, 5120, 113 },
   { 5122, 5143, 113 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5454, 113, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5455, 113, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5456, 113, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5457, 113, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5458, 113, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5459, 113, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5461, 124, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5464, 137, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5462, 137, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5462, 137, 0 },
   { 5464, 137, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5743, 5748, 116 },
   { 5749, 5753, 116 },
   { 5754, 5759, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3404, 3405, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4938, 4936, 0 },
   { 4991, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4963, 4936, 0 },
   { 5016, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5068, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5043, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 3421, 3422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 3421, 3422, 0 },
   { 3465, 3422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 3404, 3405, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 1017, 1020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 5450, 5453, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 4938, 4936, 0 },
   { 4991, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 4963, 4936, 0 },
   { 5016, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 5068, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 5043, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3404, 3405, 0 },
   { 4938, 4936, 0 },
   { 4991, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3404, 3405, 0 },
   { 4963, 4936, 0 },
   { 5016, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3404, 3405, 0 },
   { 5068, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3404, 3405, 0 },
   { 5043, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2638, 2639, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4938, 4936, 0 },
   { 4963, 4936, 0 },
   { 4991, 49, 0 },
   { 5016, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4938, 4936, 0 },
   { 4991, 49, 0 },
   { 5068, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4938, 4936, 0 },
   { 4991, 49, 0 },
   { 5043, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4963, 4936, 0 },
   { 5016, 49, 0 },
   { 5068, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4963, 4936, 0 },
   { 5016, 49, 0 },
   { 5043, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5043, 49, 0 },
   { 5068, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3511, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 32, 0 },
   { 69, 73, 1 },
   { 74, 77, 1 },
   { 3511, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4934, 3987, 0 },
   { 4988, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4960, 3987, 0 },
   { 5013, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5065, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5040, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 208, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 3451, 3452, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 3451, 3452, 0 },
   { 3493, 3452, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 314, 316, 0 },
   { 332, 333, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 318, 319, 0 },
   { 335, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 325, 326, 0 },
   { 344, 345, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 328, 329, 0 },
   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 321, 323, 0 },
   { 338, 339, 0 },
   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 5446, 5449, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4934, 3987, 0 },
   { 4988, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4960, 3987, 0 },
   { 5013, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 5065, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 5040, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 181, 183, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 188, 190, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 211, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 211, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 332, 333, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 335, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 344, 345, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 338, 339, 0 },
   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 4934, 3987, 0 },
   { 4988, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 4960, 3987, 0 },
   { 5013, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 5065, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 5040, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4934, 3987, 0 },
   { 4988, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4960, 3987, 0 },
   { 5013, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5065, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5040, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 335, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 344, 345, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 338, 339, 0 },
   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 4934, 3987, 0 },
   { 4988, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 4960, 3987, 0 },
   { 5013, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 5065, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 5040, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 344, 345, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 338, 339, 0 },
   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 4934, 3987, 0 },
   { 4988, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 4960, 3987, 0 },
   { 5013, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 5065, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 5040, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 344, 345, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { 4934, 3987, 0 },
   { 4988, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { 4960, 3987, 0 },
   { 5013, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { 5065, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { 5040, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { 4934, 3987, 0 },
   { 4988, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { 4960, 3987, 0 },
   { 5013, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { 5065, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { 5040, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 4934, 3987, 0 },
   { 4988, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 4960, 3987, 0 },
   { 5013, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 5065, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 5040, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4934, 3987, 0 },
   { 4960, 3987, 0 },
   { 4988, 4007, 0 },
   { 5013, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4934, 3987, 0 },
   { 4988, 4007, 0 },
   { 5065, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4934, 3987, 0 },
   { 4988, 4007, 0 },
   { 5040, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4960, 3987, 0 },
   { 5013, 4007, 0 },
   { 5065, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4960, 3987, 0 },
   { 5013, 4007, 0 },
   { 5040, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5040, 4007, 0 },
   { 5065, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3275, 3276, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5529, 5530, 0 },
   { 5533, 5530, 0 },
   { 5536, 5530, 0 },
   { 5539, 5530, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5718, 5719, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5722, 5723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5516, 5517, 0 },
   { 5520, 5517, 0 },
   { 5523, 5517, 0 },
   { 5526, 5517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5503, 5504, 0 },
   { 5507, 5504, 0 },
   { 5510, 5504, 0 },
   { 5513, 5504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5488, 5490, 0 },
   { 5493, 5490, 0 },
   { 5496, 5490, 0 },
   { 5499, 5490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5542, 5543, 0 },
   { 5546, 5543, 0 },
   { 5549, 5543, 0 },
   { 5552, 5543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5555, 5556, 0 },
   { 5559, 5556, 0 },
   { 5562, 5556, 0 },
   { 5565, 5556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5698, 5699, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5467, 5468, 0 },
   { 5471, 5468, 0 },
   { 5473, 5475, 0 },
   { 5477, 5475, 0 },
   { 5480, 5482, 0 },
   { 5484, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1303, 0 },
   { 1308, 1310, 0 },
   { 1313, 1310, 0 },
   { 1317, 1319, 0 },
   { 1322, 1319, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 1768, 1770, 0 },
   { 1873, 1875, 0 },
   { 1953, 1955, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5581, 5582, 0 },
   { 5585, 5582, 0 },
   { 5588, 5582, 0 },
   { 5591, 5582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5594, 5595, 0 },
   { 5598, 5595, 0 },
   { 5601, 5595, 0 },
   { 5604, 5595, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5607, 5608, 0 },
   { 5611, 5608, 0 },
   { 5614, 5608, 0 },
   { 5617, 5608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5620, 5621, 0 },
   { 5624, 5621, 0 },
   { 5627, 5621, 0 },
   { 5630, 5621, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5633, 5634, 0 },
   { 5637, 5634, 0 },
   { 5640, 5634, 0 },
   { 5643, 5634, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5646, 5647, 0 },
   { 5650, 5647, 0 },
   { 5653, 5647, 0 },
   { 5656, 5647, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5568, 5569, 0 },
   { 5572, 5569, 0 },
   { 5575, 5569, 0 },
   { 5578, 5569, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5659, 5660, 0 },
   { 5663, 5660, 0 },
   { 5667, 5669, 0 },
   { 5672, 5669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5677, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5529, 5530, 0 },
   { 5533, 5530, 0 },
   { 5536, 5530, 0 },
   { 5539, 5530, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5718, 5719, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5722, 5723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5516, 5517, 0 },
   { 5520, 5517, 0 },
   { 5523, 5517, 0 },
   { 5526, 5517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5503, 5504, 0 },
   { 5507, 5504, 0 },
   { 5510, 5504, 0 },
   { 5513, 5504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5488, 5490, 0 },
   { 5493, 5490, 0 },
   { 5496, 5490, 0 },
   { 5499, 5490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5542, 5543, 0 },
   { 5546, 5543, 0 },
   { 5549, 5543, 0 },
   { 5552, 5543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5555, 5556, 0 },
   { 5559, 5556, 0 },
   { 5562, 5556, 0 },
   { 5565, 5556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5698, 5699, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5467, 5468, 0 },
   { 5471, 5468, 0 },
   { 5473, 5475, 0 },
   { 5477, 5475, 0 },
   { 5480, 5482, 0 },
   { 5484, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1303, 0 },
   { 1308, 1310, 0 },
   { 1313, 1310, 0 },
   { 1317, 1319, 0 },
   { 1322, 1319, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 1768, 1770, 0 },
   { 1873, 1875, 0 },
   { 1953, 1955, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5581, 5582, 0 },
   { 5585, 5582, 0 },
   { 5588, 5582, 0 },
   { 5591, 5582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5594, 5595, 0 },
   { 5598, 5595, 0 },
   { 5601, 5595, 0 },
   { 5604, 5595, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5607, 5608, 0 },
   { 5611, 5608, 0 },
   { 5614, 5608, 0 },
   { 5617, 5608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5620, 5621, 0 },
   { 5624, 5621, 0 },
   { 5627, 5621, 0 },
   { 5630, 5621, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5633, 5634, 0 },
   { 5637, 5634, 0 },
   { 5640, 5634, 0 },
   { 5643, 5634, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5646, 5647, 0 },
   { 5650, 5647, 0 },
   { 5653, 5647, 0 },
   { 5656, 5647, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5568, 5569, 0 },
   { 5572, 5569, 0 },
   { 5575, 5569, 0 },
   { 5578, 5569, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5659, 5660, 0 },
   { 5663, 5660, 0 },
   { 5667, 5669, 0 },
   { 5672, 5669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5677, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2974, 753, 0 },
   { 2975, 1118, 0 },
   { 2978, 2979, 0 },
   { 2980, 2981, 0 },
   { 2984, 2985, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 0 },
   { 2993, 2994, 0 },
   { 2995, 2996, 0 },
   { 2997, 2998, 57 },
   { 2999, 3000, 57 },
   { 3003, 3004, 57 },
   { 3005, 3006, 57 },
   { 3007, 3, 0 },
   { 3009, 2237, 0 },
   { 3010, 3012, 0 },
   { 3014, 1215, 0 },
   { 3015, 3011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1305, 1303, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5529, 5530, 0 },
   { 5533, 5530, 0 },
   { 5536, 5530, 0 },
   { 5539, 5530, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5718, 5719, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5722, 5723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5516, 5517, 0 },
   { 5520, 5517, 0 },
   { 5523, 5517, 0 },
   { 5526, 5517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5503, 5504, 0 },
   { 5507, 5504, 0 },
   { 5510, 5504, 0 },
   { 5513, 5504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5488, 5490, 0 },
   { 5493, 5490, 0 },
   { 5496, 5490, 0 },
   { 5499, 5490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5542, 5543, 0 },
   { 5546, 5543, 0 },
   { 5549, 5543, 0 },
   { 5552, 5543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5555, 5556, 0 },
   { 5559, 5556, 0 },
   { 5562, 5556, 0 },
   { 5565, 5556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5698, 5699, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5467, 5468, 0 },
   { 5471, 5468, 0 },
   { 5473, 5475, 0 },
   { 5477, 5475, 0 },
   { 5480, 5482, 0 },
   { 5484, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1302, 1303, 0 },
   { 1305, 1303, 0 },
   { 1308, 1310, 0 },
   { 1313, 1310, 0 },
   { 1317, 1319, 0 },
   { 1322, 1319, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 1768, 1770, 0 },
   { 1873, 1875, 0 },
   { 1953, 1955, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5581, 5582, 0 },
   { 5585, 5582, 0 },
   { 5588, 5582, 0 },
   { 5591, 5582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5594, 5595, 0 },
   { 5598, 5595, 0 },
   { 5601, 5595, 0 },
   { 5604, 5595, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5607, 5608, 0 },
   { 5611, 5608, 0 },
   { 5614, 5608, 0 },
   { 5617, 5608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5620, 5621, 0 },
   { 5624, 5621, 0 },
   { 5627, 5621, 0 },
   { 5630, 5621, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5633, 5634, 0 },
   { 5637, 5634, 0 },
   { 5640, 5634, 0 },
   { 5643, 5634, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5646, 5647, 0 },
   { 5650, 5647, 0 },
   { 5653, 5647, 0 },
   { 5656, 5647, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5568, 5569, 0 },
   { 5572, 5569, 0 },
   { 5575, 5569, 0 },
   { 5578, 5569, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5659, 5660, 0 },
   { 5663, 5660, 0 },
   { 5667, 5669, 0 },
   { 5672, 5669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5677, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3527, 3512, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3529, 3515, 0 },
   { 3534, 3515, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3530, 3518, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3531, 3521, 0 },
   { 3536, 3521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3532, 3524, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2974, 753, 0 },
   { 2975, 1118, 0 },
   { 2978, 2979, 0 },
   { 2980, 2981, 0 },
   { 2984, 2985, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 0 },
   { 2993, 2994, 0 },
   { 2995, 2996, 0 },
   { 2997, 2998, 57 },
   { 2999, 3000, 57 },
   { 3003, 3004, 57 },
   { 3005, 3006, 57 },
   { 3007, 3, 0 },
   { 3009, 2237, 0 },
   { 3010, 3012, 0 },
   { 3014, 1215, 0 },
   { 3015, 3011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2974, 753, 0 },
   { 2975, 1118, 0 },
   { 2978, 2979, 0 },
   { 2980, 2981, 0 },
   { 2984, 2985, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 0 },
   { 2993, 2994, 0 },
   { 2995, 2996, 0 },
   { 2997, 2998, 57 },
   { 2999, 3000, 57 },
   { 3003, 3004, 57 },
   { 3005, 3006, 57 },
   { 3007, 3, 0 },
   { 3009, 2237, 0 },
   { 3010, 3012, 0 },
   { 3014, 1215, 0 },
   { 3015, 3011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1305, 1303, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5529, 5530, 0 },
   { 5533, 5530, 0 },
   { 5536, 5530, 0 },
   { 5539, 5530, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5718, 5719, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5722, 5723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5516, 5517, 0 },
   { 5520, 5517, 0 },
   { 5523, 5517, 0 },
   { 5526, 5517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5503, 5504, 0 },
   { 5507, 5504, 0 },
   { 5510, 5504, 0 },
   { 5513, 5504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5488, 5490, 0 },
   { 5493, 5490, 0 },
   { 5496, 5490, 0 },
   { 5499, 5490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5542, 5543, 0 },
   { 5546, 5543, 0 },
   { 5549, 5543, 0 },
   { 5552, 5543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5555, 5556, 0 },
   { 5559, 5556, 0 },
   { 5562, 5556, 0 },
   { 5565, 5556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5698, 5699, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5467, 5468, 0 },
   { 5471, 5468, 0 },
   { 5473, 5475, 0 },
   { 5477, 5475, 0 },
   { 5480, 5482, 0 },
   { 5484, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1302, 1303, 0 },
   { 1305, 1303, 0 },
   { 1308, 1310, 0 },
   { 1313, 1310, 0 },
   { 1317, 1319, 0 },
   { 1322, 1319, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 1768, 1770, 0 },
   { 1873, 1875, 0 },
   { 1953, 1955, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5581, 5582, 0 },
   { 5585, 5582, 0 },
   { 5588, 5582, 0 },
   { 5591, 5582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5594, 5595, 0 },
   { 5598, 5595, 0 },
   { 5601, 5595, 0 },
   { 5604, 5595, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5607, 5608, 0 },
   { 5611, 5608, 0 },
   { 5614, 5608, 0 },
   { 5617, 5608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5620, 5621, 0 },
   { 5624, 5621, 0 },
   { 5627, 5621, 0 },
   { 5630, 5621, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5633, 5634, 0 },
   { 5637, 5634, 0 },
   { 5640, 5634, 0 },
   { 5643, 5634, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5646, 5647, 0 },
   { 5650, 5647, 0 },
   { 5653, 5647, 0 },
   { 5656, 5647, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5568, 5569, 0 },
   { 5572, 5569, 0 },
   { 5575, 5569, 0 },
   { 5578, 5569, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5659, 5660, 0 },
   { 5663, 5660, 0 },
   { 5667, 5669, 0 },
   { 5672, 5669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5677, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2974, 753, 0 },
   { 2975, 1118, 0 },
   { 2978, 2979, 0 },
   { 2980, 2981, 0 },
   { 2984, 2985, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 0 },
   { 2993, 2994, 0 },
   { 2995, 2996, 0 },
   { 2997, 2998, 57 },
   { 2999, 3000, 57 },
   { 3003, 3004, 57 },
   { 3005, 3006, 57 },
   { 3007, 3, 0 },
   { 3009, 2237, 0 },
   { 3010, 3012, 0 },
   { 3014, 1215, 0 },
   { 3015, 3011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1305, 1303, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5529, 5530, 0 },
   { 5533, 5530, 0 },
   { 5536, 5530, 0 },
   { 5539, 5530, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5718, 5719, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5722, 5723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5516, 5517, 0 },
   { 5520, 5517, 0 },
   { 5523, 5517, 0 },
   { 5526, 5517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5503, 5504, 0 },
   { 5507, 5504, 0 },
   { 5510, 5504, 0 },
   { 5513, 5504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5488, 5490, 0 },
   { 5493, 5490, 0 },
   { 5496, 5490, 0 },
   { 5499, 5490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5542, 5543, 0 },
   { 5546, 5543, 0 },
   { 5549, 5543, 0 },
   { 5552, 5543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5555, 5556, 0 },
   { 5559, 5556, 0 },
   { 5562, 5556, 0 },
   { 5565, 5556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5698, 5699, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5467, 5468, 0 },
   { 5471, 5468, 0 },
   { 5473, 5475, 0 },
   { 5477, 5475, 0 },
   { 5480, 5482, 0 },
   { 5484, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1302, 1303, 0 },
   { 1305, 1303, 0 },
   { 1308, 1310, 0 },
   { 1313, 1310, 0 },
   { 1317, 1319, 0 },
   { 1322, 1319, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 1768, 1770, 0 },
   { 1873, 1875, 0 },
   { 1953, 1955, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5581, 5582, 0 },
   { 5585, 5582, 0 },
   { 5588, 5582, 0 },
   { 5591, 5582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5594, 5595, 0 },
   { 5598, 5595, 0 },
   { 5601, 5595, 0 },
   { 5604, 5595, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5607, 5608, 0 },
   { 5611, 5608, 0 },
   { 5614, 5608, 0 },
   { 5617, 5608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5620, 5621, 0 },
   { 5624, 5621, 0 },
   { 5627, 5621, 0 },
   { 5630, 5621, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5633, 5634, 0 },
   { 5637, 5634, 0 },
   { 5640, 5634, 0 },
   { 5643, 5634, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5646, 5647, 0 },
   { 5650, 5647, 0 },
   { 5653, 5647, 0 },
   { 5656, 5647, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5568, 5569, 0 },
   { 5572, 5569, 0 },
   { 5575, 5569, 0 },
   { 5578, 5569, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5659, 5660, 0 },
   { 5663, 5660, 0 },
   { 5667, 5669, 0 },
   { 5672, 5669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5677, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2798, 2800, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3603, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3603, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3603, 103, 0 },
   { 5718, 5719, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3603, 103, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2974, 753, 0 },
   { 2975, 1118, 0 },
   { 2978, 2979, 0 },
   { 2980, 2981, 0 },
   { 2984, 2985, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 0 },
   { 2993, 2994, 0 },
   { 2995, 2996, 0 },
   { 2997, 2998, 57 },
   { 2999, 3000, 57 },
   { 3003, 3004, 57 },
   { 3005, 3006, 57 },
   { 3007, 3, 0 },
   { 3009, 2237, 0 },
   { 3010, 3012, 0 },
   { 3014, 1215, 0 },
   { 3015, 3011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1305, 1303, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5529, 5530, 0 },
   { 5533, 5530, 0 },
   { 5536, 5530, 0 },
   { 5539, 5530, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5718, 5719, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5722, 5723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5516, 5517, 0 },
   { 5520, 5517, 0 },
   { 5523, 5517, 0 },
   { 5526, 5517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5503, 5504, 0 },
   { 5507, 5504, 0 },
   { 5510, 5504, 0 },
   { 5513, 5504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5488, 5490, 0 },
   { 5493, 5490, 0 },
   { 5496, 5490, 0 },
   { 5499, 5490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5542, 5543, 0 },
   { 5546, 5543, 0 },
   { 5549, 5543, 0 },
   { 5552, 5543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5555, 5556, 0 },
   { 5559, 5556, 0 },
   { 5562, 5556, 0 },
   { 5565, 5556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5698, 5699, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5467, 5468, 0 },
   { 5471, 5468, 0 },
   { 5473, 5475, 0 },
   { 5477, 5475, 0 },
   { 5480, 5482, 0 },
   { 5484, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1302, 1303, 0 },
   { 1305, 1303, 0 },
   { 1308, 1310, 0 },
   { 1313, 1310, 0 },
   { 1317, 1319, 0 },
   { 1322, 1319, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 1768, 1770, 0 },
   { 1873, 1875, 0 },
   { 1953, 1955, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5581, 5582, 0 },
   { 5585, 5582, 0 },
   { 5588, 5582, 0 },
   { 5591, 5582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5594, 5595, 0 },
   { 5598, 5595, 0 },
   { 5601, 5595, 0 },
   { 5604, 5595, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5607, 5608, 0 },
   { 5611, 5608, 0 },
   { 5614, 5608, 0 },
   { 5617, 5608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5620, 5621, 0 },
   { 5624, 5621, 0 },
   { 5627, 5621, 0 },
   { 5630, 5621, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5633, 5634, 0 },
   { 5637, 5634, 0 },
   { 5640, 5634, 0 },
   { 5643, 5634, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5646, 5647, 0 },
   { 5650, 5647, 0 },
   { 5653, 5647, 0 },
   { 5656, 5647, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5568, 5569, 0 },
   { 5572, 5569, 0 },
   { 5575, 5569, 0 },
   { 5578, 5569, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5659, 5660, 0 },
   { 5663, 5660, 0 },
   { 5667, 5669, 0 },
   { 5672, 5669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5677, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2974, 753, 0 },
   { 2975, 1118, 0 },
   { 2978, 2979, 0 },
   { 2980, 2981, 0 },
   { 2984, 2985, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 0 },
   { 2993, 2994, 0 },
   { 2995, 2996, 0 },
   { 2997, 2998, 57 },
   { 2999, 3000, 57 },
   { 3003, 3004, 57 },
   { 3005, 3006, 57 },
   { 3007, 3, 0 },
   { 3009, 2237, 0 },
   { 3010, 3012, 0 },
   { 3014, 1215, 0 },
   { 3015, 3011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1305, 1303, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5529, 5530, 0 },
   { 5533, 5530, 0 },
   { 5536, 5530, 0 },
   { 5539, 5530, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5718, 5719, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5722, 5723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5516, 5517, 0 },
   { 5520, 5517, 0 },
   { 5523, 5517, 0 },
   { 5526, 5517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5503, 5504, 0 },
   { 5507, 5504, 0 },
   { 5510, 5504, 0 },
   { 5513, 5504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5488, 5490, 0 },
   { 5493, 5490, 0 },
   { 5496, 5490, 0 },
   { 5499, 5490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5542, 5543, 0 },
   { 5546, 5543, 0 },
   { 5549, 5543, 0 },
   { 5552, 5543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5555, 5556, 0 },
   { 5559, 5556, 0 },
   { 5562, 5556, 0 },
   { 5565, 5556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5698, 5699, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5467, 5468, 0 },
   { 5471, 5468, 0 },
   { 5473, 5475, 0 },
   { 5477, 5475, 0 },
   { 5480, 5482, 0 },
   { 5484, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1302, 1303, 0 },
   { 1305, 1303, 0 },
   { 1308, 1310, 0 },
   { 1313, 1310, 0 },
   { 1317, 1319, 0 },
   { 1322, 1319, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 1768, 1770, 0 },
   { 1873, 1875, 0 },
   { 1953, 1955, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5581, 5582, 0 },
   { 5585, 5582, 0 },
   { 5588, 5582, 0 },
   { 5591, 5582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5594, 5595, 0 },
   { 5598, 5595, 0 },
   { 5601, 5595, 0 },
   { 5604, 5595, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5607, 5608, 0 },
   { 5611, 5608, 0 },
   { 5614, 5608, 0 },
   { 5617, 5608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5620, 5621, 0 },
   { 5624, 5621, 0 },
   { 5627, 5621, 0 },
   { 5630, 5621, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5633, 5634, 0 },
   { 5637, 5634, 0 },
   { 5640, 5634, 0 },
   { 5643, 5634, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5646, 5647, 0 },
   { 5650, 5647, 0 },
   { 5653, 5647, 0 },
   { 5656, 5647, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5568, 5569, 0 },
   { 5572, 5569, 0 },
   { 5575, 5569, 0 },
   { 5578, 5569, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5659, 5660, 0 },
   { 5663, 5660, 0 },
   { 5667, 5669, 0 },
   { 5672, 5669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5677, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2974, 753, 0 },
   { 2975, 1118, 0 },
   { 2978, 2979, 0 },
   { 2980, 2981, 0 },
   { 2984, 2985, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 0 },
   { 2993, 2994, 0 },
   { 2995, 2996, 0 },
   { 2997, 2998, 57 },
   { 2999, 3000, 57 },
   { 3003, 3004, 57 },
   { 3005, 3006, 57 },
   { 3007, 3, 0 },
   { 3009, 2237, 0 },
   { 3010, 3012, 0 },
   { 3014, 1215, 0 },
   { 3015, 3011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1305, 1303, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5529, 5530, 0 },
   { 5533, 5530, 0 },
   { 5536, 5530, 0 },
   { 5539, 5530, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5718, 5719, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5722, 5723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5516, 5517, 0 },
   { 5520, 5517, 0 },
   { 5523, 5517, 0 },
   { 5526, 5517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5503, 5504, 0 },
   { 5507, 5504, 0 },
   { 5510, 5504, 0 },
   { 5513, 5504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5488, 5490, 0 },
   { 5493, 5490, 0 },
   { 5496, 5490, 0 },
   { 5499, 5490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5542, 5543, 0 },
   { 5546, 5543, 0 },
   { 5549, 5543, 0 },
   { 5552, 5543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5555, 5556, 0 },
   { 5559, 5556, 0 },
   { 5562, 5556, 0 },
   { 5565, 5556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5698, 5699, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5467, 5468, 0 },
   { 5471, 5468, 0 },
   { 5473, 5475, 0 },
   { 5477, 5475, 0 },
   { 5480, 5482, 0 },
   { 5484, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1302, 1303, 0 },
   { 1305, 1303, 0 },
   { 1308, 1310, 0 },
   { 1313, 1310, 0 },
   { 1317, 1319, 0 },
   { 1322, 1319, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 1768, 1770, 0 },
   { 1873, 1875, 0 },
   { 1953, 1955, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5581, 5582, 0 },
   { 5585, 5582, 0 },
   { 5588, 5582, 0 },
   { 5591, 5582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5594, 5595, 0 },
   { 5598, 5595, 0 },
   { 5601, 5595, 0 },
   { 5604, 5595, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5607, 5608, 0 },
   { 5611, 5608, 0 },
   { 5614, 5608, 0 },
   { 5617, 5608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5620, 5621, 0 },
   { 5624, 5621, 0 },
   { 5627, 5621, 0 },
   { 5630, 5621, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5633, 5634, 0 },
   { 5637, 5634, 0 },
   { 5640, 5634, 0 },
   { 5643, 5634, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5646, 5647, 0 },
   { 5650, 5647, 0 },
   { 5653, 5647, 0 },
   { 5656, 5647, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5568, 5569, 0 },
   { 5572, 5569, 0 },
   { 5575, 5569, 0 },
   { 5578, 5569, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5659, 5660, 0 },
   { 5663, 5660, 0 },
   { 5667, 5669, 0 },
   { 5672, 5669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5677, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2974, 753, 0 },
   { 2975, 1118, 0 },
   { 2978, 2979, 0 },
   { 2980, 2981, 0 },
   { 2984, 2985, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 0 },
   { 2993, 2994, 0 },
   { 2995, 2996, 0 },
   { 2997, 2998, 57 },
   { 2999, 3000, 57 },
   { 3003, 3004, 57 },
   { 3005, 3006, 57 },
   { 3007, 3, 0 },
   { 3009, 2237, 0 },
   { 3010, 3012, 0 },
   { 3014, 1215, 0 },
   { 3015, 3011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1305, 1303, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5529, 5530, 0 },
   { 5533, 5530, 0 },
   { 5536, 5530, 0 },
   { 5539, 5530, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5718, 5719, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5722, 5723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5516, 5517, 0 },
   { 5520, 5517, 0 },
   { 5523, 5517, 0 },
   { 5526, 5517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5503, 5504, 0 },
   { 5507, 5504, 0 },
   { 5510, 5504, 0 },
   { 5513, 5504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5488, 5490, 0 },
   { 5493, 5490, 0 },
   { 5496, 5490, 0 },
   { 5499, 5490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5542, 5543, 0 },
   { 5546, 5543, 0 },
   { 5549, 5543, 0 },
   { 5552, 5543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5555, 5556, 0 },
   { 5559, 5556, 0 },
   { 5562, 5556, 0 },
   { 5565, 5556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5698, 5699, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5467, 5468, 0 },
   { 5471, 5468, 0 },
   { 5473, 5475, 0 },
   { 5477, 5475, 0 },
   { 5480, 5482, 0 },
   { 5484, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1302, 1303, 0 },
   { 1305, 1303, 0 },
   { 1308, 1310, 0 },
   { 1313, 1310, 0 },
   { 1317, 1319, 0 },
   { 1322, 1319, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 1768, 1770, 0 },
   { 1873, 1875, 0 },
   { 1953, 1955, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5581, 5582, 0 },
   { 5585, 5582, 0 },
   { 5588, 5582, 0 },
   { 5591, 5582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5594, 5595, 0 },
   { 5598, 5595, 0 },
   { 5601, 5595, 0 },
   { 5604, 5595, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5607, 5608, 0 },
   { 5611, 5608, 0 },
   { 5614, 5608, 0 },
   { 5617, 5608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5620, 5621, 0 },
   { 5624, 5621, 0 },
   { 5627, 5621, 0 },
   { 5630, 5621, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5633, 5634, 0 },
   { 5637, 5634, 0 },
   { 5640, 5634, 0 },
   { 5643, 5634, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5646, 5647, 0 },
   { 5650, 5647, 0 },
   { 5653, 5647, 0 },
   { 5656, 5647, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5568, 5569, 0 },
   { 5572, 5569, 0 },
   { 5575, 5569, 0 },
   { 5578, 5569, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5659, 5660, 0 },
   { 5663, 5660, 0 },
   { 5667, 5669, 0 },
   { 5672, 5669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5677, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2974, 753, 0 },
   { 2975, 1118, 0 },
   { 2978, 2979, 0 },
   { 2980, 2981, 0 },
   { 2984, 2985, 0 },
   { 2986, 2987, 0 },
   { 2988, 2989, 0 },
   { 2990, 2991, 0 },
   { 2993, 2994, 0 },
   { 2995, 2996, 0 },
   { 2997, 2998, 57 },
   { 2999, 3000, 57 },
   { 3003, 3004, 57 },
   { 3005, 3006, 57 },
   { 3007, 3, 0 },
   { 3009, 2237, 0 },
   { 3010, 3012, 0 },
   { 3014, 1215, 0 },
   { 3015, 3011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1305, 1303, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5529, 5530, 0 },
   { 5533, 5530, 0 },
   { 5536, 5530, 0 },
   { 5539, 5530, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5718, 5719, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5722, 5723, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5516, 5517, 0 },
   { 5520, 5517, 0 },
   { 5523, 5517, 0 },
   { 5526, 5517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5503, 5504, 0 },
   { 5507, 5504, 0 },
   { 5510, 5504, 0 },
   { 5513, 5504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5488, 5490, 0 },
   { 5493, 5490, 0 },
   { 5496, 5490, 0 },
   { 5499, 5490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5542, 5543, 0 },
   { 5546, 5543, 0 },
   { 5549, 5543, 0 },
   { 5552, 5543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5555, 5556, 0 },
   { 5559, 5556, 0 },
   { 5562, 5556, 0 },
   { 5565, 5556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5698, 5699, 0 },
   { 5698, 5699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5467, 5468, 0 },
   { 5471, 5468, 0 },
   { 5473, 5475, 0 },
   { 5477, 5475, 0 },
   { 5480, 5482, 0 },
   { 5484, 5482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1302, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1302, 1303, 0 },
   { 1305, 1303, 0 },
   { 1308, 1310, 0 },
   { 1313, 1310, 0 },
   { 1317, 1319, 0 },
   { 1322, 1319, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3604, 3605, 0 },
   { 3607, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5690, 5691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 1768, 1770, 0 },
   { 1873, 1875, 0 },
   { 1953, 1955, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5581, 5582, 0 },
   { 5585, 5582, 0 },
   { 5588, 5582, 0 },
   { 5591, 5582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5594, 5595, 0 },
   { 5598, 5595, 0 },
   { 5601, 5595, 0 },
   { 5604, 5595, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5607, 5608, 0 },
   { 5611, 5608, 0 },
   { 5614, 5608, 0 },
   { 5617, 5608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5620, 5621, 0 },
   { 5624, 5621, 0 },
   { 5627, 5621, 0 },
   { 5630, 5621, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5633, 5634, 0 },
   { 5637, 5634, 0 },
   { 5640, 5634, 0 },
   { 5643, 5634, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5646, 5647, 0 },
   { 5650, 5647, 0 },
   { 5653, 5647, 0 },
   { 5656, 5647, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4930, 4925, 0 },
   { 4983, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4955, 4925, 0 },
   { 5008, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5060, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 5035, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5568, 5569, 0 },
   { 5572, 5569, 0 },
   { 5575, 5569, 0 },
   { 5578, 5569, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5694, 5695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5659, 5660, 0 },
   { 5663, 5660, 0 },
   { 5667, 5669, 0 },
   { 5672, 5669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5686, 5687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5677, 5679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5682, 5683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5702, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5706, 5707, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5710, 5711, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 5714, 5715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2121, 2122, 0 },
   { 2152, 2153, 0 },
   { 2182, 939, 0 },
   { 2212, 2213, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2121, 2122, 0 },
   { 2152, 2153, 0 },
   { 2182, 939, 0 },
   { 2212, 2213, 0 },
   { 2689, 1216, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2689, 1216, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 816, 818, 0 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 820, 829, 0 },
   { 842, 850, 0 },
   { 863, 870, 0 },
   { 883, 891, 0 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 1013, 1015, 0 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 983, 984, 0 },
   { 990, 991, 0 },
   { 997, 998, 0 },
   { 1006, 1007, 0 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 903, 906, 0 },
   { 911, 914, 0 },
   { 919, 922, 0 },
   { 927, 930, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 903, 906, 0 },
   { 911, 914, 0 },
   { 919, 922, 0 },
   { 927, 930, 0 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 903, 906, 0 },
   { 911, 914, 0 },
   { 919, 922, 0 },
   { 927, 930, 0 },
   { 2121, 2122, 0 },
   { 2152, 2153, 0 },
   { 2182, 939, 0 },
   { 2212, 2213, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 903, 906, 0 },
   { 911, 914, 0 },
   { 919, 922, 0 },
   { 927, 930, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 907, 906, 0 },
   { 915, 914, 0 },
   { 923, 922, 0 },
   { 931, 930, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 907, 906, 0 },
   { 915, 914, 0 },
   { 923, 922, 0 },
   { 931, 930, 0 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 907, 906, 0 },
   { 915, 914, 0 },
   { 923, 922, 0 },
   { 931, 930, 0 },
   { 2121, 2122, 0 },
   { 2152, 2153, 0 },
   { 2182, 939, 0 },
   { 2212, 2213, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 907, 906, 0 },
   { 915, 914, 0 },
   { 923, 922, 0 },
   { 931, 930, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2690, 32, 0 },
   { 3270, 3271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2681, 2682, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4941, 2012, 0 },
   { 4994, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4966, 2012, 0 },
   { 5019, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 5071, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 5046, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 943, 944, 0 },
   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 938, 939, 0 },
   { 985, 984, 0 },
   { 992, 991, 0 },
   { 1000, 998, 0 },
   { 1009, 1007, 0 },
   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 948, 950, 0 },
   { 954, 956, 0 },
   { 960, 962, 0 },
   { 966, 968, 0 },
   { 972, 974, 0 },
   { 978, 980, 0 },
   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2681, 2682, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2681, 2682, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { 3495, 3497, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2680, 3, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 987, 986, 0 },
   { 994, 993, 0 },
   { 1002, 1001, 0 },
   { 1011, 1010, 0 },
   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2667, 61, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { 4941, 2012, 0 },
   { 4994, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { 4966, 2012, 0 },
   { 5019, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { 5071, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { 5046, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2050, 2051, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { 2681, 2682, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 2681, 2682, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2681, 2682, 0 },
   { 4941, 2012, 0 },
   { 4994, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2681, 2682, 0 },
   { 4966, 2012, 0 },
   { 5019, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2681, 2682, 0 },
   { 5071, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2681, 2682, 0 },
   { 5046, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 193, 195, 0 },
   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 2680, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { 4941, 2012, 0 },
   { 4994, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { 4966, 2012, 0 },
   { 5019, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { 5071, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { 5046, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1075, 1070, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2103, 2105, 43 },
   { 2103, 2111, 45 },
   { 2134, 2136, 43 },
   { 2134, 2142, 45 },
   { 2164, 2166, 43 },
   { 2164, 2172, 45 },
   { 2194, 2196, 43 },
   { 2194, 2202, 45 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2115, 2116, 46 },
   { 2146, 2147, 46 },
   { 2176, 2177, 46 },
   { 2206, 2207, 46 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 5356, 5357, 0 },
   { 5359, 5360, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 5345, 5346, 0 },
   { 5349, 5350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 5351, 5352, 0 },
   { 5354, 5355, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1069, 1070, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2640, 2639, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2041, 2043, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2046, 2047, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 2685, 2686, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 4941, 2012, 0 },
   { 4994, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 4966, 2012, 0 },
   { 5019, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 5071, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 5046, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1072, 1070, 0 },
   { 1620, 1622, 0 },
   { 1623, 1625, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1072, 1070, 0 },
   { 1620, 1622, 0 },
   { 1623, 1625, 0 },
   { 1636, 1622, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1072, 1070, 0 },
   { 1620, 1622, 0 },
   { 1623, 1625, 0 },
   { 1746, 1747, 0 },
   { 1748, 1747, 0 },
   { 1851, 1852, 0 },
   { 1853, 1852, 0 },
   { 1931, 1932, 0 },
   { 1933, 1932, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1072, 1070, 0 },
   { 1620, 1622, 0 },
   { 1623, 1625, 0 },
   { 1636, 1622, 0 },
   { 1746, 1747, 0 },
   { 1748, 1747, 0 },
   { 1851, 1852, 0 },
   { 1853, 1852, 0 },
   { 1931, 1932, 0 },
   { 1933, 1932, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1072, 1070, 0 },
   { 1620, 1622, 0 },
   { 1623, 1625, 0 },
   { 1641, 1625, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1072, 1070, 0 },
   { 1620, 1622, 0 },
   { 1623, 1625, 0 },
   { 1641, 1625, 0 },
   { 1746, 1747, 0 },
   { 1748, 1747, 0 },
   { 1851, 1852, 0 },
   { 1853, 1852, 0 },
   { 1931, 1932, 0 },
   { 1933, 1932, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1072, 1070, 0 },
   { 1620, 1622, 0 },
   { 1623, 1625, 0 },
   { 1636, 1622, 0 },
   { 1641, 1625, 0 },
   { 1746, 1747, 0 },
   { 1748, 1747, 0 },
   { 1851, 1852, 0 },
   { 1853, 1852, 0 },
   { 1931, 1932, 0 },
   { 1933, 1932, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1626, 1628, 0 },
   { 1629, 1631, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1626, 1628, 0 },
   { 1629, 1631, 0 },
   { 1644, 1628, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1248, 1249, 38 },
   { 1626, 1628, 0 },
   { 1629, 1631, 0 },
   { 1749, 1750, 0 },
   { 1751, 1750, 0 },
   { 1854, 1855, 0 },
   { 1856, 1855, 0 },
   { 1934, 1935, 0 },
   { 1936, 1935, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1248, 1249, 38 },
   { 1626, 1628, 0 },
   { 1629, 1631, 0 },
   { 1644, 1628, 0 },
   { 1749, 1750, 0 },
   { 1751, 1750, 0 },
   { 1854, 1855, 0 },
   { 1856, 1855, 0 },
   { 1934, 1935, 0 },
   { 1936, 1935, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1626, 1628, 0 },
   { 1629, 1631, 0 },
   { 1647, 1631, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1248, 1249, 38 },
   { 1626, 1628, 0 },
   { 1629, 1631, 0 },
   { 1647, 1631, 0 },
   { 1749, 1750, 0 },
   { 1751, 1750, 0 },
   { 1854, 1855, 0 },
   { 1856, 1855, 0 },
   { 1934, 1935, 0 },
   { 1936, 1935, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1248, 1249, 38 },
   { 1626, 1628, 0 },
   { 1629, 1631, 0 },
   { 1644, 1628, 0 },
   { 1647, 1631, 0 },
   { 1749, 1750, 0 },
   { 1751, 1750, 0 },
   { 1854, 1855, 0 },
   { 1856, 1855, 0 },
   { 1934, 1935, 0 },
   { 1936, 1935, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1077, 1070, 0 },
   { 1688, 1689, 0 },
   { 1690, 1691, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1079, 1070, 0 },
   { 1696, 1697, 0 },
   { 1698, 1699, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1692, 1693, 0 },
   { 1694, 1695, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1700, 1701, 0 },
   { 1702, 1703, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2029, 2030, 0 },
   { 2663, 32, 0 },
   { 4941, 2012, 0 },
   { 4994, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4941, 2012, 0 },
   { 4966, 2012, 0 },
   { 4994, 2020, 0 },
   { 5019, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4941, 2012, 0 },
   { 4994, 2020, 0 },
   { 5071, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4941, 2012, 0 },
   { 4994, 2020, 0 },
   { 5046, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2024, 2026, 0 },
   { 2663, 32, 0 },
   { 4966, 2012, 0 },
   { 5019, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4966, 2012, 0 },
   { 5019, 2020, 0 },
   { 5071, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4966, 2012, 0 },
   { 5019, 2020, 0 },
   { 5046, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2033, 2034, 0 },
   { 2663, 32, 0 },
   { 5071, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 5046, 2020, 0 },
   { 5071, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2037, 2038, 0 },
   { 2663, 32, 0 },
   { 5046, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2678, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2679, 2301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2236, 1224, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2671, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4944, 2054, 0 },
   { 4997, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4969, 2054, 0 },
   { 5022, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 5074, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 5049, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2669, 32, 0 },
   { 2670, 63, 0 },
   { 2678, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2669, 32, 0 },
   { 2670, 63, 0 },
   { 2679, 2301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2669, 32, 0 },
   { 2670, 63, 0 },
   { 2679, 2301, 0 },
   { 3499, 3501, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2236, 1224, 0 },
   { 2668, 32, 0 },
   { 2669, 32, 0 },
   { 2670, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2669, 32, 0 },
   { 2670, 63, 0 },
   { 2671, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2669, 32, 0 },
   { 2670, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2669, 32, 0 },
   { 2670, 63, 0 },
   { 4944, 2054, 0 },
   { 4997, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2669, 32, 0 },
   { 2670, 63, 0 },
   { 4969, 2054, 0 },
   { 5022, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2669, 32, 0 },
   { 2670, 63, 0 },
   { 5074, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2669, 32, 0 },
   { 2670, 63, 0 },
   { 5049, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2074, 2075, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 198, 200, 0 },
   { 2668, 32, 0 },
   { 2678, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2678, 3, 0 },
   { 2679, 2301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2236, 1224, 0 },
   { 2668, 32, 0 },
   { 2678, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2671, 63, 0 },
   { 2678, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2678, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2678, 3, 0 },
   { 4944, 2054, 0 },
   { 4997, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2678, 3, 0 },
   { 4969, 2054, 0 },
   { 5022, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2678, 3, 0 },
   { 5074, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2678, 3, 0 },
   { 5049, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2236, 1224, 0 },
   { 2668, 32, 0 },
   { 2679, 2301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2671, 63, 0 },
   { 2679, 2301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2679, 2301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2679, 2301, 0 },
   { 4944, 2054, 0 },
   { 4997, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2679, 2301, 0 },
   { 4969, 2054, 0 },
   { 5022, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2679, 2301, 0 },
   { 5074, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2679, 2301, 0 },
   { 5049, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2112, 2114, 46 },
   { 2143, 2145, 46 },
   { 2173, 2175, 46 },
   { 2203, 2205, 46 },
   { 2225, 2226, 0 },
   { 2236, 1224, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2236, 1224, 0 },
   { 2668, 32, 0 },
   { 2671, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2236, 1224, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2229, 2230, 0 },
   { 2233, 2234, 0 },
   { 2236, 1224, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2236, 1224, 0 },
   { 2668, 32, 0 },
   { 4944, 2054, 0 },
   { 4997, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2236, 1224, 0 },
   { 2668, 32, 0 },
   { 4969, 2054, 0 },
   { 5022, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2236, 1224, 0 },
   { 2668, 32, 0 },
   { 5074, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2236, 1224, 0 },
   { 2668, 32, 0 },
   { 5049, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2108, 2109, 44 },
   { 2108, 2117, 45 },
   { 2139, 2140, 44 },
   { 2139, 2148, 45 },
   { 2169, 2170, 44 },
   { 2169, 2178, 45 },
   { 2199, 2200, 44 },
   { 2199, 2208, 45 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2641, 2642, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2069, 2071, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2072, 2073, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2671, 63, 0 },
   { 2687, 2688, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2671, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2671, 63, 0 },
   { 4944, 2054, 0 },
   { 4997, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2671, 63, 0 },
   { 4969, 2054, 0 },
   { 5022, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2671, 63, 0 },
   { 5074, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2671, 63, 0 },
   { 5049, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1587, 1589, 0 },
   { 1593, 1595, 0 },
   { 1729, 1045, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4944, 2054, 0 },
   { 4997, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4969, 2054, 0 },
   { 5022, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 5074, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 5049, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1587, 1589, 0 },
   { 1593, 1595, 0 },
   { 1608, 1589, 0 },
   { 1729, 1045, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1587, 1589, 0 },
   { 1593, 1595, 0 },
   { 1729, 1045, 0 },
   { 1732, 1734, 0 },
   { 1737, 1734, 0 },
   { 1837, 1839, 0 },
   { 1842, 1839, 0 },
   { 1917, 1919, 0 },
   { 1922, 1919, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1587, 1589, 0 },
   { 1593, 1595, 0 },
   { 1608, 1589, 0 },
   { 1729, 1045, 0 },
   { 1732, 1734, 0 },
   { 1737, 1734, 0 },
   { 1837, 1839, 0 },
   { 1842, 1839, 0 },
   { 1917, 1919, 0 },
   { 1922, 1919, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1587, 1589, 0 },
   { 1593, 1595, 0 },
   { 1613, 1595, 0 },
   { 1729, 1045, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1587, 1589, 0 },
   { 1593, 1595, 0 },
   { 1613, 1595, 0 },
   { 1729, 1045, 0 },
   { 1732, 1734, 0 },
   { 1737, 1734, 0 },
   { 1837, 1839, 0 },
   { 1842, 1839, 0 },
   { 1917, 1919, 0 },
   { 1922, 1919, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1587, 1589, 0 },
   { 1593, 1595, 0 },
   { 1608, 1589, 0 },
   { 1613, 1595, 0 },
   { 1729, 1045, 0 },
   { 1732, 1734, 0 },
   { 1737, 1734, 0 },
   { 1837, 1839, 0 },
   { 1842, 1839, 0 },
   { 1917, 1919, 0 },
   { 1922, 1919, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1598, 1600, 0 },
   { 1603, 1605, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1598, 1600, 0 },
   { 1603, 1605, 0 },
   { 1616, 1600, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1598, 1600, 0 },
   { 1603, 1605, 0 },
   { 1740, 1742, 0 },
   { 1745, 1742, 0 },
   { 1845, 1847, 0 },
   { 1850, 1847, 0 },
   { 1925, 1927, 0 },
   { 1930, 1927, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1598, 1600, 0 },
   { 1603, 1605, 0 },
   { 1616, 1600, 0 },
   { 1740, 1742, 0 },
   { 1745, 1742, 0 },
   { 1845, 1847, 0 },
   { 1850, 1847, 0 },
   { 1925, 1927, 0 },
   { 1930, 1927, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1598, 1600, 0 },
   { 1603, 1605, 0 },
   { 1619, 1605, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1598, 1600, 0 },
   { 1603, 1605, 0 },
   { 1619, 1605, 0 },
   { 1740, 1742, 0 },
   { 1745, 1742, 0 },
   { 1845, 1847, 0 },
   { 1850, 1847, 0 },
   { 1925, 1927, 0 },
   { 1930, 1927, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1598, 1600, 0 },
   { 1603, 1605, 0 },
   { 1616, 1600, 0 },
   { 1619, 1605, 0 },
   { 1740, 1742, 0 },
   { 1745, 1742, 0 },
   { 1845, 1847, 0 },
   { 1850, 1847, 0 },
   { 1925, 1927, 0 },
   { 1930, 1927, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1650, 1652, 0 },
   { 1655, 1657, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1670, 1672, 0 },
   { 1675, 1677, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1660, 1662, 0 },
   { 1665, 1667, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1680, 1682, 0 },
   { 1685, 1687, 0 },
   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2063, 2064, 0 },
   { 2668, 32, 0 },
   { 4944, 2054, 0 },
   { 4997, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4944, 2054, 0 },
   { 4969, 2054, 0 },
   { 4997, 2058, 0 },
   { 5022, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4944, 2054, 0 },
   { 4997, 2058, 0 },
   { 5074, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4944, 2054, 0 },
   { 4997, 2058, 0 },
   { 5049, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2060, 2062, 0 },
   { 2668, 32, 0 },
   { 4969, 2054, 0 },
   { 5022, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4969, 2054, 0 },
   { 5022, 2058, 0 },
   { 5074, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4969, 2054, 0 },
   { 5022, 2058, 0 },
   { 5049, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2065, 2066, 0 },
   { 2668, 32, 0 },
   { 5074, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 5049, 2058, 0 },
   { 5074, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2067, 2068, 0 },
   { 2668, 32, 0 },
   { 5049, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 3277, 3276, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4947, 2078, 0 },
   { 5000, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4972, 2078, 0 },
   { 5025, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 5077, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 5052, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2675, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2673, 32, 0 },
   { 2676, 2666, 0 },
   { 4947, 2078, 0 },
   { 5000, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2673, 32, 0 },
   { 2676, 2666, 0 },
   { 4972, 2078, 0 },
   { 5025, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2673, 32, 0 },
   { 2676, 2666, 0 },
   { 5077, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2673, 32, 0 },
   { 2676, 2666, 0 },
   { 5052, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2673, 32, 0 },
   { 2675, 3, 0 },
   { 2676, 2666, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2673, 32, 0 },
   { 2675, 3, 0 },
   { 2676, 2666, 0 },
   { 3503, 3505, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2098, 2099, 0 },
   { 2672, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2093, 2095, 0 },
   { 2672, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2096, 2097, 0 },
   { 2672, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2087, 2088, 0 },
   { 2672, 61, 0 },
   { 4947, 2078, 0 },
   { 5000, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4947, 2078, 0 },
   { 4972, 2078, 0 },
   { 5000, 2082, 0 },
   { 5025, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4947, 2078, 0 },
   { 5000, 2082, 0 },
   { 5077, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4947, 2078, 0 },
   { 5000, 2082, 0 },
   { 5052, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2675, 3, 0 },
   { 4947, 2078, 0 },
   { 5000, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2084, 2086, 0 },
   { 2672, 61, 0 },
   { 4972, 2078, 0 },
   { 5025, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4972, 2078, 0 },
   { 5025, 2082, 0 },
   { 5077, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4972, 2078, 0 },
   { 5025, 2082, 0 },
   { 5052, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2675, 3, 0 },
   { 4972, 2078, 0 },
   { 5025, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2089, 2090, 0 },
   { 2672, 61, 0 },
   { 5077, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 5052, 2082, 0 },
   { 5077, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2675, 3, 0 },
   { 5077, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2091, 2092, 0 },
   { 2672, 61, 0 },
   { 5052, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2675, 3, 0 },
   { 5052, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2125, 2126, 0 },
   { 2156, 2157, 0 },
   { 2185, 2186, 0 },
   { 2216, 2217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2125, 2126, 0 },
   { 2156, 2157, 0 },
   { 2185, 2186, 0 },
   { 2216, 2217, 0 },
   { 2695, 1216, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2695, 1216, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 908, 910, 0 },
   { 916, 918, 0 },
   { 924, 926, 0 },
   { 932, 934, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 908, 910, 0 },
   { 916, 918, 0 },
   { 924, 926, 0 },
   { 932, 934, 0 },
   { 2696, 32, 0 },
   { 3162, 3163, 58 },
   { 1010, 424, 58 },
   { 3165, 3167, 58 },
   { 3200, 446, 59 },
   { 1001, 449, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 908, 910, 0 },
   { 916, 918, 0 },
   { 924, 926, 0 },
   { 932, 934, 0 },
   { 2125, 2126, 0 },
   { 2156, 2157, 0 },
   { 2185, 2186, 0 },
   { 2216, 2217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 908, 910, 0 },
   { 916, 918, 0 },
   { 924, 926, 0 },
   { 932, 934, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 831, 833, 0 },
   { 852, 854, 0 },
   { 872, 874, 0 },
   { 893, 895, 0 },
   { 2696, 32, 0 },
   { 3162, 3163, 58 },
   { 1010, 424, 58 },
   { 3165, 3167, 58 },
   { 1001, 449, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2696, 32, 0 },
   { 3162, 3163, 58 },
   { 1010, 424, 58 },
   { 3165, 3167, 58 },
   { 1001, 449, 59 },
   { 3272, 3269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2123, 2124, 0 },
   { 2154, 2155, 0 },
   { 2183, 2184, 0 },
   { 2214, 2215, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2123, 2124, 0 },
   { 2154, 2155, 0 },
   { 2183, 2184, 0 },
   { 2214, 2215, 0 },
   { 2691, 1216, 0 },
   { 2693, 2692, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2694, 32, 0 },
   { 3168, 3169, 58 },
   { 3170, 408, 58 },
   { 3171, 3172, 58 },
   { 3201, 438, 59 },
   { 3202, 441, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2694, 32, 0 },
   { 3168, 3169, 58 },
   { 3170, 408, 58 },
   { 3171, 3172, 58 },
   { 3202, 441, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2123, 2124, 0 },
   { 2154, 2155, 0 },
   { 2183, 2184, 0 },
   { 2214, 2215, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 835, 840, 0 },
   { 856, 861, 0 },
   { 876, 881, 0 },
   { 897, 902, 0 },
   { 2694, 32, 0 },
   { 3168, 3169, 58 },
   { 3170, 408, 58 },
   { 3171, 3172, 58 },
   { 3202, 441, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3345, 3346, 0 },
   { 3348, 421, 0 },
   { 3349, 417, 0 },
   { 3350, 414, 0 },
   { 3352, 3323, 0 },
   { 3354, 3318, 0 },
   { 3356, 3313, 0 },
   { 3358, 3310, 0 },
   { 3360, 3306, 0 },
   { 3362, 3302, 0 },
   { 3364, 3365, 0 },
   { 3840, 3843, 90 },
   { 4921, 11, 0 },
   { 4974, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3295, 3163, 0 },
   { 3297, 417, 0 },
   { 3298, 421, 0 },
   { 3299, 424, 0 },
   { 3301, 3302, 0 },
   { 3304, 3306, 0 },
   { 3308, 3310, 0 },
   { 3311, 3313, 0 },
   { 3316, 3318, 0 },
   { 3321, 3323, 0 },
   { 3324, 3167, 0 },
   { 3840, 3843, 90 },
   { 4921, 11, 0 },
   { 4974, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3325, 3163, 0 },
   { 3327, 417, 0 },
   { 3328, 421, 0 },
   { 3329, 424, 0 },
   { 3331, 3302, 0 },
   { 3333, 3306, 0 },
   { 3335, 3310, 0 },
   { 3337, 3313, 0 },
   { 3339, 3318, 0 },
   { 3341, 3323, 0 },
   { 3342, 3167, 0 },
   { 3840, 3843, 90 },
   { 4921, 11, 0 },
   { 4974, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3199, 3183, 0 },
   { 3840, 3843, 90 },
   { 4921, 11, 0 },
   { 4974, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3198, 3183, 0 },
   { 3840, 3843, 90 },
   { 4921, 11, 0 },
   { 4974, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3343, 3177, 0 },
   { 3840, 3843, 90 },
   { 4921, 11, 0 },
   { 4974, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3287, 3288, 0 },
   { 3289, 3290, 0 },
   { 3291, 3292, 0 },
   { 3293, 3294, 0 },
   { 3840, 3843, 90 },
   { 4921, 11, 0 },
   { 4974, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3366, 3367, 0 },
   { 3368, 404, 0 },
   { 3369, 399, 0 },
   { 3370, 395, 0 },
   { 3371, 3372, 0 },
   { 3373, 3374, 0 },
   { 3375, 3376, 0 },
   { 3377, 3378, 0 },
   { 3379, 3380, 0 },
   { 3381, 3382, 0 },
   { 3383, 3384, 0 },
   { 3835, 3839, 90 },
   { 4949, 11, 0 },
   { 5002, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3279, 3280, 0 },
   { 3281, 3282, 0 },
   { 3283, 3284, 0 },
   { 3285, 3286, 0 },
   { 3835, 3839, 90 },
   { 4949, 11, 0 },
   { 5002, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3147, 21, 0 },
   { 3128, 3230, 61 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 48, 49, 0 },
   { 3145, 3235, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 51, 49, 0 },
   { 3145, 3235, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3145, 3235, 63 },
   { 3245, 3145, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3137, 16, 0 },
   { 3145, 3235, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3134, 16, 0 },
   { 3145, 3235, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3129, 16, 0 },
   { 3145, 3235, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3132, 2390, 0 },
   { 3145, 3235, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 99, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 0 },
   { 3079, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 104, 0 },
   { 3079, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3079, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2360, 2359, 0 },
   { 3079, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2362, 2361, 0 },
   { 3079, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2364, 2363, 0 },
   { 3079, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2366, 2365, 0 },
   { 3079, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3079, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 109, 110, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4057, 753, 0 },
   { 4060, 6, 0 },
   { 4064, 11, 0 },
   { 4066, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3509, 3438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 207, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3436, 3438, 0 },
   { 3440, 3438, 0 },
   { 3509, 3438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3436, 3438, 0 },
   { 3440, 3438, 0 },
   { 3467, 3438, 0 },
   { 3509, 3438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3443, 3445, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3443, 3445, 0 },
   { 3474, 3476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3447, 3449, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3447, 3449, 0 },
   { 3484, 3486, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 5433, 5436, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 216, 3, 0 },
   { 3509, 3438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 157, 159, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 139, 141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 173, 168, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 3396, 3397, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 3409, 3411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 3409, 3411, 0 },
   { 3454, 3411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 3417, 3419, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 3417, 3419, 0 },
   { 3458, 3419, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 5437, 5440, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { 5437, 5440, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 254, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2796, 2797, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2643, 1255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2801, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 3398, 3399, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 3592, 3593, 0 },
   { 3595, 3596, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 117, 0 },
   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 246, 16, 0 },
   { 3398, 3399, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 117, 0 },
   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 246, 16, 0 },
   { 3413, 3415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 117, 0 },
   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 246, 16, 0 },
   { 3413, 3415, 0 },
   { 3456, 3415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 117, 0 },
   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 246, 16, 0 },
   { 5442, 5445, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 117, 0 },
   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 246, 16, 0 },
   { 3592, 3593, 0 },
   { 3595, 3596, 0 },
   { 5442, 5445, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 3398, 3399, 6 },
   { 3592, 3593, 0 },
   { 3595, 3596, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 228, 229, 6 },
   { 232, 229, 0 },
   { 233, 234, 0 },
   { 2803, 698, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 162, 164, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 286, 287, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 286, 287, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { 3427, 3429, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { 3427, 3429, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 162, 164, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { 3427, 3429, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { 3427, 3429, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { 3427, 3429, 0 },
   { 3461, 3429, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { 3427, 3429, 0 },
   { 3461, 3429, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 162, 164, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { 3427, 3429, 0 },
   { 3461, 3429, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { 3427, 3429, 0 },
   { 3461, 3429, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { 3432, 3433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { 3432, 3433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { 3432, 3433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { 3432, 3433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { 3401, 3402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { 3401, 3402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { 3401, 3402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { 3401, 3402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 162, 164, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 141, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 168, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 141, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 168, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 141, 0 },
   { 176, 178, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 141, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 289, 290, 0 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 168, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 289, 290, 0 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { 3430, 3431, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 270, 271, 6 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { 3430, 3431, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 141, 0 },
   { 176, 178, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { 3430, 3431, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 168, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { 3430, 3431, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { 3430, 3431, 0 },
   { 3462, 3431, 0 },
   { 3463, 3433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 270, 271, 6 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { 3430, 3431, 0 },
   { 3462, 3431, 0 },
   { 3463, 3433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 141, 0 },
   { 176, 178, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { 3430, 3431, 0 },
   { 3462, 3431, 0 },
   { 3463, 3433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 168, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 263, 264, 0 },
   { 275, 276, 6 },
   { 281, 283, 6 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { 3430, 3431, 0 },
   { 3462, 3431, 0 },
   { 3463, 3433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { 3403, 389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 270, 271, 6 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { 3403, 389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 141, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { 3403, 389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 168, 0 },
   { 235, 236, 6 },
   { 237, 236, 0 },
   { 238, 239, 0 },
   { 389, 290, 30 },
   { 741, 290, 33 },
   { 3403, 389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 1509, 40 },
   { 3082, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 1509, 40 },
   { 1522, 219, 0 },
   { 3082, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1517, 1519, 0 },
   { 219, 1509, 40 },
   { 3082, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1521, 1520, 0 },
   { 219, 1509, 40 },
   { 3082, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2637, 1246, 0 },
   { 2661, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1178, 1179, 0 },
   { 2661, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1098, 1099, 0 },
   { 2637, 1246, 0 },
   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1221, 1222, 0 },
   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1178, 1179, 0 },
   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1178, 1179, 0 },
   { 1197, 1199, 0 },
   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1109, 1048, 0 },
   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { 5362, 5365, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1213, 1118, 0 },
   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1222, 0 },
   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2622, 1042, 0 },
   { 2630, 1039, 0 },
   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2623, 1039, 0 },
   { 2631, 1042, 0 },
   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2620, 1048, 0 },
   { 2628, 1045, 0 },
   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2621, 1045, 0 },
   { 2629, 1048, 0 },
   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1084, 1085, 0 },
   { 2637, 1246, 0 },
   { 2661, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1178, 1179, 0 },
   { 2637, 1246, 0 },
   { 2661, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1150, 1149, 0 },
   { 1398, 1149, 0 },
   { 1402, 1149, 0 },
   { 1406, 1149, 0 },
   { 2661, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2661, 1224, 0 },
   { 4857, 4859, 112 },
   { 4874, 4859, 112 },
   { 4882, 4883, 0 },
   { 4896, 4898, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1158, 1159, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2268, 1070, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2262, 2263, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1090, 1091, 0 },
   { 1158, 1159, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1241, 1242, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1103, 1105, 0 },
   { 1113, 1114, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { 5386, 5391, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2268, 1070, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2262, 2263, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1088, 1089, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1081, 1071, 0 },
   { 1158, 1159, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1227, 1070, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1158, 1159, 0 },
   { 1174, 1175, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 2268, 1070, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 2262, 2263, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1183, 1186, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { 5378, 5381, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2264, 1071, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2264, 1071, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1158, 1159, 0 },
   { 2264, 1071, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2264, 1071, 0 },
   { 2268, 1070, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2262, 2263, 0 },
   { 2264, 1071, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1237, 1238, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2269, 1070, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2269, 1070, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1158, 1159, 0 },
   { 2269, 1070, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2268, 1070, 0 },
   { 2269, 1070, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2262, 2263, 0 },
   { 2269, 1070, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { 4864, 4865, 112 },
   { 4871, 4872, 112 },
   { 4877, 4865, 112 },
   { 4881, 4872, 112 },
   { 4888, 4889, 0 },
   { 4893, 4894, 0 },
   { 4903, 4904, 0 },
   { 4909, 4910, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1160, 1161, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2266, 1224, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2270, 2271, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1094, 1095, 0 },
   { 1160, 1161, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1245, 1246, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1225, 1226, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { 5396, 5399, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1117, 1118, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2266, 1224, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1235, 1236, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2270, 2271, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1092, 1093, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1082, 1083, 0 },
   { 1160, 1161, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1223, 1224, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1160, 1161, 0 },
   { 1176, 1177, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 2266, 1224, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 2270, 2271, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1176, 1177, 0 },
   { 1192, 1193, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1108, 1039, 0 },
   { 1112, 1095, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { 5392, 5395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2272, 1083, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2272, 1083, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1160, 1161, 0 },
   { 2272, 1083, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2266, 1224, 0 },
   { 2272, 1083, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2270, 2271, 0 },
   { 2272, 1083, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1234, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2267, 1224, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2267, 1224, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1160, 1161, 0 },
   { 2267, 1224, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2266, 1224, 0 },
   { 2267, 1224, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2267, 1224, 0 },
   { 2270, 2271, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { 4862, 4863, 112 },
   { 4868, 4870, 112 },
   { 4876, 4863, 112 },
   { 4880, 4870, 112 },
   { 4886, 4887, 0 },
   { 4891, 4892, 0 },
   { 4901, 4902, 0 },
   { 4906, 4908, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2636, 1242, 0 },
   { 2662, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1180, 1181, 0 },
   { 2662, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1096, 1097, 0 },
   { 2636, 1242, 0 },
   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1219, 1220, 0 },
   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1180, 1181, 0 },
   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1180, 1181, 0 },
   { 1205, 1206, 0 },
   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1110, 1045, 0 },
   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { 5366, 5369, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1214, 753, 0 },
   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1231, 1220, 0 },
   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2626, 1042, 0 },
   { 2634, 1039, 0 },
   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2627, 1039, 0 },
   { 2635, 1042, 0 },
   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2624, 1048, 0 },
   { 2632, 1045, 0 },
   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2625, 1045, 0 },
   { 2633, 1048, 0 },
   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1086, 1087, 0 },
   { 2636, 1242, 0 },
   { 2662, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1180, 1181, 0 },
   { 2636, 1242, 0 },
   { 2662, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1139, 1138, 0 },
   { 1399, 1383, 0 },
   { 1403, 1383, 0 },
   { 1407, 1383, 0 },
   { 2662, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2662, 1070, 0 },
   { 4860, 4861, 112 },
   { 4875, 4861, 112 },
   { 4884, 4885, 0 },
   { 4899, 4900, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1499, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1344, 1272, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 3083, 219, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1499, 32, 0 },
   { 3083, 219, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1563, 1564, 0 },
   { 3083, 219, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1261, 1264, 0 },
   { 1327, 32, 0 },
   { 3083, 219, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1344, 1272, 0 },
   { 3083, 219, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 3083, 219, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1509, 219, 38 },
   { 1513, 1514, 38 },
   { 3083, 219, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 1499, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1344, 1272, 0 },
   { 1494, 1243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1344, 1272, 0 },
   { 1499, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1499, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1257, 1255, 0 },
   { 1327, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1344, 1272, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1505, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1503, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1338, 1270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1505, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1503, 103, 0 },
   { 1507, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1561, 1562, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1511, 219, 38 },
   { 1516, 1514, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1338, 1270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1503, 103, 0 },
   { 1505, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1338, 1270, 0 },
   { 1505, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1338, 1270, 0 },
   { 1503, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1251, 1252, 0 },
   { 1328, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 101, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5727, 5730, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2119, 6, 0 },
   { 2150, 11, 0 },
   { 2180, 16, 0 },
   { 2210, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 106, 0 },
   { 3080, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 107, 106, 0 },
   { 3080, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3080, 32, 0 },
   { 5731, 5734, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 111, 112, 0 },
   { 2965, 2966, 0 },
   { 2967, 2968, 0 },
   { 2969, 1220, 0 },
   { 111, 112, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2965, 2966, 0 },
   { 2967, 2968, 0 },
   { 2969, 1220, 0 },
   { 3044, 112, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2965, 2966, 0 },
   { 2967, 2968, 0 },
   { 2969, 1220, 0 },
   { 3036, 11, 0 },
   { 3038, 16, 0 },
   { 4058, 753, 0 },
   { 4062, 6, 0 },
   { 3036, 11, 0 },
   { 3038, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2965, 2966, 0 },
   { 2967, 2968, 0 },
   { 2969, 1220, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2965, 2966, 0 },
   { 2967, 2968, 0 },
   { 2969, 1220, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1495, 1496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1500, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1348, 1292, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1495, 1496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1500, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1348, 1292, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 3924, 3922, 102 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1495, 1496, 0 },
   { 1500, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1348, 1292, 0 },
   { 1495, 1496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1495, 1496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1348, 1292, 0 },
   { 1500, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1500, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1348, 1292, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1506, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1504, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1342, 1290, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1506, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1504, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 3926, 3922, 102 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1342, 1290, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1504, 106, 0 },
   { 1506, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1342, 1290, 0 },
   { 1506, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1342, 1290, 0 },
   { 1504, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1776, 11, 0 },
   { 1881, 16, 0 },
   { 1961, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4069, 3027, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3040, 3041, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1774, 11, 0 },
   { 1879, 16, 0 },
   { 1959, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1802, 1803, 0 },
   { 1825, 1826, 0 },
   { 1907, 1908, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1985, 1986, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1778, 11, 0 },
   { 1883, 16, 0 },
   { 1963, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4068, 3027, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3042, 3043, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1777, 11, 0 },
   { 1882, 16, 0 },
   { 1962, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1800, 1801, 0 },
   { 1823, 1824, 0 },
   { 1905, 1906, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1983, 1984, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1805, 1806, 0 },
   { 1828, 1806, 0 },
   { 1909, 1804, 0 },
   { 4084, 11, 0 },
   { 4085, 16, 0 },
   { 4086, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1797, 1396, 0 },
   { 1820, 1396, 0 },
   { 1902, 1400, 0 },
   { 4067, 1520, 0 },
   { 4084, 11, 0 },
   { 4085, 16, 0 },
   { 4086, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4084, 11, 0 },
   { 4085, 16, 0 },
   { 4086, 21, 0 },
   { 5789, 5791, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4084, 11, 0 },
   { 4085, 16, 0 },
   { 4086, 21, 0 },
   { 5773, 5775, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4084, 11, 0 },
   { 4085, 16, 0 },
   { 4086, 21, 0 },
   { 5760, 5761, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1808, 1809, 0 },
   { 1830, 1809, 0 },
   { 1910, 1807, 0 },
   { 4084, 11, 0 },
   { 4085, 16, 0 },
   { 4086, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1792, 11, 0 },
   { 1815, 11, 0 },
   { 1897, 16, 0 },
   { 3071, 16, 0 },
   { 4084, 11, 0 },
   { 4085, 16, 0 },
   { 4086, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3064, 16, 0 },
   { 4084, 11, 0 },
   { 4085, 16, 0 },
   { 4086, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3069, 1979, 0 },
   { 4084, 11, 0 },
   { 4085, 16, 0 },
   { 4086, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3070, 1976, 0 },
   { 4084, 11, 0 },
   { 4085, 16, 0 },
   { 4086, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1977, 1978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3058, 1396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5792, 5794, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5776, 5778, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5762, 5764, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1980, 1981, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3047, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3046, 1246, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1062, 1063, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1065, 1066, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5735, 5738, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1044, 1045, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2677, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1038, 1039, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1041, 1042, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1047, 1048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1050, 1051, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1053, 1054, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1056, 1057, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1059, 1060, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 468, 469, 14 },
   { 543, 544, 16 },
   { 609, 610, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 468, 469, 14 },
   { 543, 544, 16 },
   { 609, 610, 18 },
   { 687, 689, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 296, 298, 0 },
   { 472, 474, 14 },
   { 545, 547, 16 },
   { 613, 615, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { 296, 298, 0 },
   { 472, 474, 14 },
   { 545, 547, 16 },
   { 613, 615, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 296, 298, 0 },
   { 468, 469, 14 },
   { 472, 474, 14 },
   { 543, 544, 16 },
   { 545, 547, 16 },
   { 609, 610, 18 },
   { 613, 615, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 482, 485, 14 },
   { 554, 556, 16 },
   { 623, 626, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { 482, 485, 14 },
   { 554, 556, 16 },
   { 623, 626, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 468, 469, 14 },
   { 482, 485, 14 },
   { 543, 544, 16 },
   { 554, 556, 16 },
   { 609, 610, 18 },
   { 623, 626, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 294, 266, 0 },
   { 468, 469, 14 },
   { 543, 544, 16 },
   { 609, 610, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 294, 266, 0 },
   { 468, 469, 14 },
   { 543, 544, 16 },
   { 609, 610, 18 },
   { 687, 689, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 294, 266, 0 },
   { 296, 298, 0 },
   { 472, 474, 14 },
   { 545, 547, 16 },
   { 613, 615, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { 294, 266, 0 },
   { 296, 298, 0 },
   { 472, 474, 14 },
   { 545, 547, 16 },
   { 613, 615, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 294, 266, 0 },
   { 296, 298, 0 },
   { 468, 469, 14 },
   { 472, 474, 14 },
   { 543, 544, 16 },
   { 545, 547, 16 },
   { 609, 610, 18 },
   { 613, 615, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 294, 266, 0 },
   { 482, 485, 14 },
   { 554, 556, 16 },
   { 623, 626, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { 294, 266, 0 },
   { 482, 485, 14 },
   { 554, 556, 16 },
   { 623, 626, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 294, 266, 0 },
   { 468, 469, 14 },
   { 482, 485, 14 },
   { 543, 544, 16 },
   { 554, 556, 16 },
   { 609, 610, 18 },
   { 623, 626, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 296, 298, 0 },
   { 472, 474, 14 },
   { 478, 480, 14 },
   { 545, 547, 16 },
   { 550, 552, 16 },
   { 613, 615, 18 },
   { 619, 621, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { 296, 298, 0 },
   { 472, 474, 14 },
   { 478, 480, 14 },
   { 545, 547, 16 },
   { 550, 552, 16 },
   { 613, 615, 18 },
   { 619, 621, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 296, 298, 0 },
   { 468, 469, 14 },
   { 472, 474, 14 },
   { 478, 480, 14 },
   { 543, 544, 16 },
   { 545, 547, 16 },
   { 550, 552, 16 },
   { 609, 610, 18 },
   { 613, 615, 18 },
   { 619, 621, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 482, 485, 14 },
   { 554, 556, 16 },
   { 623, 626, 18 },
   { 683, 685, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 3, 0 },
   { 293, 0, 0 },
   { 482, 485, 14 },
   { 554, 556, 16 },
   { 623, 626, 18 },
   { 683, 685, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 0, 0 },
   { 468, 469, 14 },
   { 482, 485, 14 },
   { 543, 544, 16 },
   { 554, 556, 16 },
   { 609, 610, 18 },
   { 623, 626, 18 },
   { 683, 685, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1209, 1210, 0 },
   { 2654, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 204, 0 },
   { 2654, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1209, 1210, 0 },
   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 204, 0 },
   { 1413, 1414, 0 },
   { 1418, 1417, 0 },
   { 1435, 1436, 0 },
   { 1440, 1439, 0 },
   { 1457, 1458, 0 },
   { 1462, 1461, 0 },
   { 1477, 1478, 0 },
   { 1482, 1481, 0 },
   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { 5370, 5373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1217, 1118, 0 },
   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1421, 1414, 0 },
   { 1423, 1417, 0 },
   { 1443, 1436, 0 },
   { 1445, 1439, 0 },
   { 1465, 1458, 0 },
   { 1466, 1461, 0 },
   { 1485, 1478, 0 },
   { 1487, 1481, 0 },
   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1426, 1414, 0 },
   { 1428, 1417, 0 },
   { 1448, 1436, 0 },
   { 1450, 1439, 0 },
   { 1469, 1458, 0 },
   { 1470, 1461, 0 },
   { 1490, 1478, 0 },
   { 1492, 1481, 0 },
   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { 4220, 4225, 111 },
   { 4267, 4272, 111 },
   { 4313, 4318, 111 },
   { 4380, 4385, 112 },
   { 4431, 4436, 112 },
   { 4509, 4514, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { 4563, 4566, 111 },
   { 4603, 4607, 111 },
   { 4645, 4650, 111 },
   { 4709, 4714, 112 },
   { 4754, 4759, 112 },
   { 4826, 4831, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { 3801, 3798, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { 3797, 3798, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 204, 0 },
   { 1209, 1210, 0 },
   { 2654, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1381, 1149, 0 },
   { 1386, 1149, 0 },
   { 1390, 1149, 0 },
   { 1394, 1149, 0 },
   { 2654, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1224, 0 },
   { 4202, 4204, 111 },
   { 4259, 4204, 111 },
   { 4304, 4204, 111 },
   { 4351, 4352, 112 },
   { 4365, 4367, 112 },
   { 4416, 4352, 112 },
   { 4424, 4367, 112 },
   { 4468, 4469, 0 },
   { 4481, 4482, 0 },
   { 4494, 4496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1224, 0 },
   { 4547, 4549, 111 },
   { 4595, 4549, 111 },
   { 4637, 4549, 111 },
   { 4681, 4682, 112 },
   { 4694, 4696, 112 },
   { 4739, 4682, 112 },
   { 4747, 4696, 112 },
   { 4786, 4787, 0 },
   { 4799, 4800, 0 },
   { 4811, 4813, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 1212, 0 },
   { 2655, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 206, 0 },
   { 2655, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1211, 1212, 0 },
   { 2655, 1070, 0 },
   { 2971, 1118, 0 },
   { 2972, 753, 0 },
   { 3117, 1224, 0 },
   { 3718, 3720, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 206, 0 },
   { 1415, 1414, 0 },
   { 1416, 1417, 0 },
   { 1437, 1436, 0 },
   { 1438, 1439, 0 },
   { 1459, 1458, 0 },
   { 1460, 1461, 0 },
   { 1479, 1478, 0 },
   { 1480, 1481, 0 },
   { 2655, 1070, 0 },
   { 2971, 1118, 0 },
   { 2972, 753, 0 },
   { 3117, 1224, 0 },
   { 3718, 3720, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 1070, 0 },
   { 2971, 1118, 0 },
   { 2972, 753, 0 },
   { 3117, 1224, 0 },
   { 3718, 3720, 81 },
   { 5374, 5377, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1218, 753, 0 },
   { 2655, 1070, 0 },
   { 2971, 1118, 0 },
   { 2972, 753, 0 },
   { 3117, 1224, 0 },
   { 3718, 3720, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1420, 1417, 0 },
   { 1424, 1414, 0 },
   { 1442, 1439, 0 },
   { 1446, 1436, 0 },
   { 1464, 1461, 0 },
   { 1467, 1458, 0 },
   { 1484, 1481, 0 },
   { 1488, 1478, 0 },
   { 2655, 1070, 0 },
   { 2971, 1118, 0 },
   { 2972, 753, 0 },
   { 3117, 1224, 0 },
   { 3718, 3720, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1425, 1417, 0 },
   { 1429, 1414, 0 },
   { 1447, 1439, 0 },
   { 1451, 1436, 0 },
   { 1468, 1461, 0 },
   { 1471, 1458, 0 },
   { 1489, 1481, 0 },
   { 1493, 1478, 0 },
   { 2655, 1070, 0 },
   { 2971, 1118, 0 },
   { 2972, 753, 0 },
   { 3117, 1224, 0 },
   { 3718, 3720, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 1070, 0 },
   { 2971, 1118, 0 },
   { 2972, 753, 0 },
   { 3117, 1224, 0 },
   { 3718, 3720, 81 },
   { 4226, 4229, 111 },
   { 4273, 4276, 111 },
   { 4319, 4322, 111 },
   { 4386, 4389, 112 },
   { 4437, 4440, 112 },
   { 4515, 4518, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 1070, 0 },
   { 2971, 1118, 0 },
   { 2972, 753, 0 },
   { 3117, 1224, 0 },
   { 3718, 3720, 81 },
   { 4567, 4570, 111 },
   { 4608, 4611, 111 },
   { 4651, 4654, 111 },
   { 4715, 4718, 112 },
   { 4760, 4763, 112 },
   { 4832, 4835, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 1070, 0 },
   { 2971, 1118, 0 },
   { 2972, 753, 0 },
   { 3117, 1224, 0 },
   { 3718, 3720, 81 },
   { 3800, 3796, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 1070, 0 },
   { 2971, 1118, 0 },
   { 2972, 753, 0 },
   { 3117, 1224, 0 },
   { 3718, 3720, 81 },
   { 3791, 3796, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 1070, 0 },
   { 2971, 1118, 0 },
   { 2972, 753, 0 },
   { 3117, 1224, 0 },
   { 3718, 3720, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 1070, 0 },
   { 2971, 1118, 0 },
   { 2972, 753, 0 },
   { 3117, 1224, 0 },
   { 3718, 3720, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 1070, 0 },
   { 2971, 1118, 0 },
   { 2972, 753, 0 },
   { 3117, 1224, 0 },
   { 3718, 3720, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 1070, 0 },
   { 2971, 1118, 0 },
   { 2972, 753, 0 },
   { 3117, 1224, 0 },
   { 3718, 3720, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 206, 0 },
   { 1211, 1212, 0 },
   { 2655, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1382, 1383, 0 },
   { 1387, 1383, 0 },
   { 1391, 1383, 0 },
   { 1395, 1383, 0 },
   { 2655, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 1070, 0 },
   { 4205, 4206, 111 },
   { 4260, 4206, 111 },
   { 4305, 4206, 111 },
   { 4353, 4354, 112 },
   { 4368, 4369, 112 },
   { 4417, 4354, 112 },
   { 4425, 4369, 112 },
   { 4470, 4471, 0 },
   { 4483, 4484, 0 },
   { 4497, 4498, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 1070, 0 },
   { 4550, 4551, 111 },
   { 4596, 4551, 111 },
   { 4638, 4551, 111 },
   { 4683, 4684, 112 },
   { 4697, 4698, 112 },
   { 4740, 4684, 112 },
   { 4748, 4698, 112 },
   { 4788, 4789, 0 },
   { 4801, 4802, 0 },
   { 4814, 4815, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2737, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2300, 1070, 0 },
   { 2656, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2293, 1070, 0 },
   { 2656, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2281, 2282, 0 },
   { 2656, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2300, 1070, 0 },
   { 2656, 1070, 0 },
   { 3126, 1224, 0 },
   { 3723, 3720, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2656, 1070, 0 },
   { 3126, 1224, 0 },
   { 3723, 3720, 81 },
   { 5420, 5423, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2293, 1070, 0 },
   { 2656, 1070, 0 },
   { 3126, 1224, 0 },
   { 3723, 3720, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2293, 1070, 0 },
   { 2345, 2346, 0 },
   { 2656, 1070, 0 },
   { 3126, 1224, 0 },
   { 3723, 3720, 81 },
   { 3765, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2281, 2282, 0 },
   { 2656, 1070, 0 },
   { 3126, 1224, 0 },
   { 3723, 3720, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2281, 2282, 0 },
   { 2322, 2324, 0 },
   { 2656, 1070, 0 },
   { 3126, 1224, 0 },
   { 3723, 3720, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2656, 1070, 0 },
   { 3126, 1224, 0 },
   { 3723, 3720, 81 },
   { 4577, 4582, 111 },
   { 4618, 4623, 111 },
   { 4662, 4668, 111 },
   { 4724, 4728, 112 },
   { 4770, 4775, 112 },
   { 4841, 4845, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2302, 1070, 0 },
   { 2656, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2302, 1070, 0 },
   { 2656, 1070, 0 },
   { 3127, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2300, 1070, 0 },
   { 2302, 1070, 0 },
   { 2656, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2293, 1070, 0 },
   { 2302, 1070, 0 },
   { 2656, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2281, 2282, 0 },
   { 2302, 1070, 0 },
   { 2656, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2656, 1070, 0 },
   { 3127, 1070, 0 },
   { 5416, 5419, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2283, 1078, 0 },
   { 2656, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2283, 1078, 0 },
   { 2656, 1070, 0 },
   { 3127, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2283, 1078, 0 },
   { 2300, 1070, 0 },
   { 2656, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2283, 1078, 0 },
   { 2293, 1070, 0 },
   { 2656, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2281, 2282, 0 },
   { 2283, 1078, 0 },
   { 2656, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2283, 1078, 0 },
   { 2326, 2328, 0 },
   { 2656, 1070, 0 },
   { 3127, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2294, 1070, 0 },
   { 2656, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2294, 1070, 0 },
   { 2656, 1070, 0 },
   { 3127, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2294, 1070, 0 },
   { 2300, 1070, 0 },
   { 2656, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2293, 1070, 0 },
   { 2294, 1070, 0 },
   { 2656, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2281, 2282, 0 },
   { 2294, 1070, 0 },
   { 2656, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2294, 1070, 0 },
   { 2347, 2348, 0 },
   { 2656, 1070, 0 },
   { 3127, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2656, 1070, 0 },
   { 3127, 1070, 0 },
   { 4571, 4576, 111 },
   { 4612, 4617, 111 },
   { 4655, 4661, 111 },
   { 4719, 4723, 112 },
   { 4764, 4769, 112 },
   { 4836, 4840, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2656, 1070, 0 },
   { 4554, 4555, 111 },
   { 4561, 4562, 111 },
   { 4598, 4555, 111 },
   { 4602, 4562, 111 },
   { 4640, 4555, 111 },
   { 4644, 4562, 111 },
   { 4687, 4688, 112 },
   { 4692, 4693, 112 },
   { 4701, 4702, 112 },
   { 4707, 4708, 112 },
   { 4742, 4688, 112 },
   { 4745, 4693, 112 },
   { 4750, 4702, 112 },
   { 4753, 4708, 112 },
   { 4792, 4793, 0 },
   { 4797, 4798, 0 },
   { 4805, 4806, 0 },
   { 4809, 4810, 0 },
   { 4818, 4819, 0 },
   { 4824, 4825, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2303, 1224, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2285, 1224, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2295, 2296, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2303, 1224, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2657, 1224, 0 },
   { 5428, 5431, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2285, 1224, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2285, 1224, 0 },
   { 2330, 2332, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2295, 2296, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2295, 2296, 0 },
   { 2349, 2350, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2657, 1224, 0 },
   { 4589, 4594, 111 },
   { 4630, 4635, 111 },
   { 4675, 4680, 111 },
   { 4734, 4738, 112 },
   { 4781, 4785, 112 },
   { 4851, 4855, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2304, 1224, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2303, 1224, 0 },
   { 2304, 1224, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2285, 1224, 0 },
   { 2304, 1224, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2295, 2296, 0 },
   { 2304, 1224, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2657, 1224, 0 },
   { 5424, 5427, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2297, 2298, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2297, 2298, 0 },
   { 2303, 1224, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2285, 1224, 0 },
   { 2297, 2298, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2295, 2296, 0 },
   { 2297, 2298, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2297, 2298, 0 },
   { 2351, 2352, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2286, 1224, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2286, 1224, 0 },
   { 2303, 1224, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2285, 1224, 0 },
   { 2286, 1224, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2286, 1224, 0 },
   { 2295, 2296, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2286, 1224, 0 },
   { 2334, 2336, 0 },
   { 2657, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2657, 1224, 0 },
   { 4583, 4588, 111 },
   { 4624, 4629, 111 },
   { 4669, 4674, 111 },
   { 4729, 4733, 112 },
   { 4776, 4780, 112 },
   { 4846, 4850, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2657, 1224, 0 },
   { 4552, 4553, 111 },
   { 4558, 4560, 111 },
   { 4597, 4553, 111 },
   { 4601, 4560, 111 },
   { 4639, 4553, 111 },
   { 4643, 4560, 111 },
   { 4685, 4686, 112 },
   { 4690, 4691, 112 },
   { 4699, 4700, 112 },
   { 4704, 4706, 112 },
   { 4741, 4686, 112 },
   { 4744, 4691, 112 },
   { 4749, 4700, 112 },
   { 4752, 4706, 112 },
   { 4790, 4791, 0 },
   { 4795, 4796, 0 },
   { 4803, 4804, 0 },
   { 4807, 4808, 0 },
   { 4816, 4817, 0 },
   { 4821, 4823, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1346, 1282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1332, 61, 0 },
   { 1333, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1332, 61, 0 },
   { 1333, 32, 0 },
   { 1346, 1282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1332, 61, 0 },
   { 1333, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1346, 1282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1346, 1282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3747, 3748, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3745, 2682, 0 },
   { 3747, 3748, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4074, 753, 0 },
   { 4075, 6, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { 4911, 3235, 0 },
   { 4912, 3238, 0 },
   { 4914, 4772, 0 },
   { 4916, 1998, 0 },
   { 4917, 2014, 0 },
   { 4919, 4665, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1798, 1384, 0 },
   { 1821, 1384, 0 },
   { 1903, 1388, 0 },
   { 4073, 3027, 0 },
   { 4074, 753, 0 },
   { 4075, 6, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4074, 753, 0 },
   { 4075, 6, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { 5798, 5800, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4074, 753, 0 },
   { 4075, 6, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { 5782, 5784, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4074, 753, 0 },
   { 4075, 6, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { 5767, 5768, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1794, 11, 0 },
   { 1817, 11, 0 },
   { 1899, 16, 0 },
   { 4074, 753, 0 },
   { 4075, 6, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { 4092, 4093, 0 },
   { 4100, 4093, 0 },
   { 4106, 4093, 0 },
   { 4112, 4093, 0 },
   { 4116, 4117, 0 },
   { 4120, 4091, 0 },
   { 4124, 4091, 0 },
   { 4128, 4091, 0 },
   { 4132, 4133, 0 },
   { 4136, 4133, 0 },
   { 4138, 4139, 0 },
   { 4142, 4099, 0 },
   { 4146, 4099, 0 },
   { 4150, 4151, 0 },
   { 4154, 4151, 0 },
   { 4156, 4157, 0 },
   { 4159, 4151, 0 },
   { 4161, 4157, 0 },
   { 4163, 1793, 0 },
   { 4165, 4105, 0 },
   { 4169, 4170, 0 },
   { 4173, 4170, 0 },
   { 4175, 4176, 0 },
   { 4179, 4170, 0 },
   { 4181, 4176, 0 },
   { 4183, 1816, 0 },
   { 4185, 4170, 0 },
   { 4187, 4176, 0 },
   { 4189, 1816, 0 },
   { 4191, 1898, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4074, 753, 0 },
   { 4075, 6, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { 4095, 4096, 0 },
   { 4102, 4096, 0 },
   { 4108, 4096, 0 },
   { 4113, 4096, 0 },
   { 4121, 4094, 0 },
   { 4125, 4094, 0 },
   { 4129, 4094, 0 },
   { 4143, 4101, 0 },
   { 4147, 4101, 0 },
   { 4166, 4107, 0 },
   { 4948, 11, 0 },
   { 5001, 16, 0 },
   { 5053, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3065, 16, 0 },
   { 4074, 753, 0 },
   { 4075, 6, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3067, 1990, 0 },
   { 4074, 753, 0 },
   { 4075, 6, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4074, 753, 0 },
   { 4075, 6, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { 4193, 4194, 0 },
   { 4193, 4194, 0 },
   { 4195, 4196, 0 },
   { 4195, 4196, 0 },
   { 4197, 4077, 0 },
   { 4197, 4077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1799, 1384, 0 },
   { 1822, 1384, 0 },
   { 1904, 1388, 0 },
   { 4071, 3027, 0 },
   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { 5795, 5797, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { 5779, 5781, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { 5765, 5766, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3180, 3182, 58 },
   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { 4097, 4093, 0 },
   { 4103, 4093, 0 },
   { 4109, 4093, 0 },
   { 4114, 4093, 0 },
   { 4122, 4091, 0 },
   { 4126, 4091, 0 },
   { 4130, 4091, 0 },
   { 4144, 4099, 0 },
   { 4148, 4099, 0 },
   { 4167, 4105, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1796, 11, 0 },
   { 1819, 11, 0 },
   { 1901, 16, 0 },
   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { 4098, 4096, 0 },
   { 4104, 4096, 0 },
   { 4110, 4096, 0 },
   { 4115, 4096, 0 },
   { 4118, 4119, 0 },
   { 4123, 4094, 0 },
   { 4127, 4094, 0 },
   { 4131, 4094, 0 },
   { 4134, 4135, 0 },
   { 4137, 4135, 0 },
   { 4140, 4141, 0 },
   { 4145, 4101, 0 },
   { 4149, 4101, 0 },
   { 4152, 4153, 0 },
   { 4155, 4153, 0 },
   { 4158, 3210, 0 },
   { 4160, 4153, 0 },
   { 4162, 3210, 0 },
   { 4164, 1795, 0 },
   { 4168, 4107, 0 },
   { 4171, 4172, 0 },
   { 4174, 4172, 0 },
   { 4177, 4178, 0 },
   { 4180, 4172, 0 },
   { 4182, 4178, 0 },
   { 4184, 1818, 0 },
   { 4186, 4172, 0 },
   { 4188, 4178, 0 },
   { 4190, 1818, 0 },
   { 4192, 1900, 0 },
   { 4920, 11, 0 },
   { 4973, 16, 0 },
   { 5026, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3066, 16, 0 },
   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3176, 3178, 58 },
   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3068, 1987, 0 },
   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { 4198, 2014, 0 },
   { 4198, 2014, 0 },
   { 4199, 3238, 0 },
   { 4199, 3238, 0 },
   { 4200, 4082, 0 },
   { 4200, 4082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3237, 63 },
   { 3252, 3146, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3139, 1452, 0 },
   { 3146, 3237, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3136, 124, 0 },
   { 3146, 3237, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3130, 36, 0 },
   { 3146, 3237, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3133, 2393, 0 },
   { 3146, 3237, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3154, 3238, 64 },
   { 3242, 3154, 0 },
   { 3154, 3238, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3154, 3238, 64 },
   { 3256, 3154, 0 },
   { 3257, 3156, 0 },
   { 3154, 3238, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3156, 3239, 64 },
   { 3249, 3156, 0 },
   { 3156, 3239, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3750, 3743, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3752, 3743, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3752, 3743, 0 },
   { 3779, 124, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3750, 3743, 0 },
   { 3752, 3743, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3753, 3740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3754, 3740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3754, 3740, 0 },
   { 3780, 124, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3753, 3740, 0 },
   { 3754, 3740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3240, 3241, 0 },
   { 3241, 3919, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3255, 3248, 0 },
   { 3241, 3919, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3253, 3241, 0 },
   { 3254, 3248, 0 },
   { 3241, 3919, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3247, 3248, 0 },
   { 3248, 3920, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3756, 3757, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3759, 3757, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3756, 3757, 0 },
   { 3759, 3757, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2427, 2432, 48 },
   { 5322, 2427, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2427, 2432, 48 },
   { 5323, 2497, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 2439, 48 },
   { 5328, 2433, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 2439, 48 },
   { 5329, 2501, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 2446, 48 },
   { 5332, 2440, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2440, 2446, 48 },
   { 5333, 2507, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2447, 2463, 48 },
   { 5336, 2447, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2447, 2463, 48 },
   { 5337, 2512, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 2496, 48 },
   { 5340, 2464, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 2496, 48 },
   { 5341, 2521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2241, 2242, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2538, 2541, 48 },
   { 5326, 2538, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2538, 2541, 48 },
   { 5327, 2579, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2542, 2547, 48 },
   { 5330, 2542, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2542, 2547, 48 },
   { 5331, 2583, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2548, 2552, 48 },
   { 5334, 2548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2548, 2552, 48 },
   { 5335, 2589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2553, 2561, 48 },
   { 5338, 2553, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2553, 2561, 48 },
   { 5339, 2594, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2562, 2578, 48 },
   { 5342, 2562, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2562, 2578, 48 },
   { 5343, 2603, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2287, 1070, 0 },
   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2274, 2275, 0 },
   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { 5404, 5407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2287, 1070, 0 },
   { 2337, 2338, 0 },
   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2274, 2275, 0 },
   { 2306, 2308, 0 },
   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { 4239, 4245, 111 },
   { 4285, 4290, 111 },
   { 4332, 4338, 111 },
   { 4398, 4403, 112 },
   { 4449, 4455, 112 },
   { 4527, 4533, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { 1481, 3716, 81 },
   { 5400, 5403, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2276, 1076, 0 },
   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2276, 1076, 0 },
   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { 3709, 3711, 80 },
   { 1481, 3716, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2276, 1076, 0 },
   { 2287, 1070, 0 },
   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2274, 2275, 0 },
   { 2276, 1076, 0 },
   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2276, 1076, 0 },
   { 2310, 2312, 0 },
   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { 3709, 3711, 80 },
   { 1481, 3716, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2288, 1070, 0 },
   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2288, 1070, 0 },
   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { 3704, 3707, 80 },
   { 1481, 3716, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2287, 1070, 0 },
   { 2288, 1070, 0 },
   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2274, 2275, 0 },
   { 2288, 1070, 0 },
   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2288, 1070, 0 },
   { 2339, 2340, 0 },
   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { 3704, 3707, 80 },
   { 1481, 3716, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { 1481, 3716, 81 },
   { 4230, 4237, 111 },
   { 4277, 4284, 111 },
   { 4323, 4330, 111 },
   { 4390, 4397, 112 },
   { 4441, 4448, 112 },
   { 4519, 4526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2652, 1070, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { 4209, 4210, 111 },
   { 4218, 4219, 111 },
   { 4262, 4210, 111 },
   { 4266, 4219, 111 },
   { 4307, 4210, 111 },
   { 4311, 4219, 111 },
   { 4357, 4358, 112 },
   { 4362, 4363, 112 },
   { 4372, 4373, 112 },
   { 4378, 4379, 112 },
   { 4419, 4358, 112 },
   { 4422, 4363, 112 },
   { 4427, 4373, 112 },
   { 4430, 4379, 112 },
   { 4474, 4475, 0 },
   { 4479, 4480, 0 },
   { 4487, 4488, 0 },
   { 4491, 4492, 0 },
   { 4501, 4502, 0 },
   { 4507, 4508, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2278, 1224, 0 },
   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2289, 2290, 0 },
   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { 5412, 5415, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2278, 1224, 0 },
   { 2314, 2316, 0 },
   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2289, 2290, 0 },
   { 2341, 2342, 0 },
   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { 4252, 4257, 111 },
   { 4297, 4302, 111 },
   { 4345, 4350, 111 },
   { 4410, 4415, 112 },
   { 4462, 4467, 112 },
   { 4540, 4545, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { 1478, 3717, 81 },
   { 5408, 5411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2291, 2292, 0 },
   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2291, 2292, 0 },
   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { 3714, 3715, 80 },
   { 1478, 3717, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2278, 1224, 0 },
   { 2291, 2292, 0 },
   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2289, 2290, 0 },
   { 2291, 2292, 0 },
   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2291, 2292, 0 },
   { 2343, 2344, 0 },
   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { 3714, 3715, 80 },
   { 1478, 3717, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2279, 1224, 0 },
   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2279, 1224, 0 },
   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { 3712, 3713, 80 },
   { 1478, 3717, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2278, 1224, 0 },
   { 2279, 1224, 0 },
   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2279, 1224, 0 },
   { 2289, 2290, 0 },
   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2279, 1224, 0 },
   { 2318, 2320, 0 },
   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { 3712, 3713, 80 },
   { 1478, 3717, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { 1478, 3717, 81 },
   { 4246, 4251, 111 },
   { 4291, 4296, 111 },
   { 4339, 4344, 111 },
   { 4404, 4409, 112 },
   { 4456, 4461, 112 },
   { 4534, 4539, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { 4207, 4208, 111 },
   { 4215, 4217, 111 },
   { 4261, 4208, 111 },
   { 4265, 4217, 111 },
   { 4306, 4208, 111 },
   { 4310, 4217, 111 },
   { 4355, 4356, 112 },
   { 4360, 4361, 112 },
   { 4370, 4371, 112 },
   { 4375, 4377, 112 },
   { 4418, 4356, 112 },
   { 4421, 4361, 112 },
   { 4426, 4371, 112 },
   { 4429, 4377, 112 },
   { 4472, 4473, 0 },
   { 4477, 4478, 0 },
   { 4485, 4486, 0 },
   { 4489, 4490, 0 },
   { 4499, 4500, 0 },
   { 4504, 4506, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { 1478, 3717, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { 1478, 3717, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { 1478, 3717, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { 1478, 3717, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2653, 1224, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { 1478, 3717, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3922, 3924, 101 },
   { 5739, 5742, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2739, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2792, 2793, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2784, 2785, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2787, 2788, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2790, 2791, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2775, 2777, 0 },
   { 2757, 2810, 54 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2778, 2779, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2809, 2789, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2808, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2811, 2757, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2780, 2783, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3060, 1384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3050, 3051, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3061, 1384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3052, 3053, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4070, 1520, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1810, 1811, 0 },
   { 1831, 1832, 0 },
   { 1911, 1912, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1994, 1995, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4072, 1520, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1772, 690, 0 },
   { 1877, 696, 0 },
   { 1957, 702, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1812, 1813, 0 },
   { 1833, 1834, 0 },
   { 1913, 1914, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1996, 1997, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3059, 1384, 0 },
   { 3059, 1384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5801, 5803, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5785, 5787, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5769, 5771, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1991, 1992, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1988, 1989, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3048, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3049, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3062, 1396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3054, 3055, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3063, 1396, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3056, 3057, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 769, 771, 36 },
   { 781, 782, 0 },
   { 797, 798, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 769, 771, 36 },
   { 776, 778, 0 },
   { 781, 782, 0 },
   { 797, 798, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 769, 771, 36 },
   { 773, 266, 0 },
   { 776, 778, 0 },
   { 781, 782, 0 },
   { 797, 798, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 786, 778, 0 },
   { 795, 796, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 784, 266, 0 },
   { 786, 778, 0 },
   { 795, 796, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 788, 266, 0 },
   { 793, 794, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 788, 266, 0 },
   { 789, 792, 0 },
   { 793, 794, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1334, 32, 0 },
   { 1340, 1280, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1334, 32, 0 },
   { 1335, 32, 0 },
   { 1336, 63, 0 },
   { 1340, 1280, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3225, 3226, 0 },
   { 3849, 3852, 91 },
   { 5027, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3227, 3226, 0 },
   { 3849, 3852, 91 },
   { 5027, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3273, 3269, 0 },
   { 3849, 3852, 91 },
   { 5027, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2363, 2369, 47 },
   { 2375, 2359, 0 },
   { 2383, 2361, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2363, 2369, 47 },
   { 2376, 2361, 0 },
   { 2384, 2359, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2363, 2369, 47 },
   { 2372, 2363, 0 },
   { 2381, 2365, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2363, 2369, 47 },
   { 2374, 2365, 0 },
   { 2382, 2363, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 2370, 47 },
   { 2379, 2359, 0 },
   { 2387, 2361, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 2370, 47 },
   { 2380, 2361, 0 },
   { 2388, 2359, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 2370, 47 },
   { 2377, 2363, 0 },
   { 2385, 2365, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2365, 2370, 47 },
   { 2378, 2365, 0 },
   { 2386, 2363, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2740, 2743, 51 },
   { 2765, 32, 0 },
   { 2766, 253, 0 },
   { 2767, 2764, 0 },
   { 2772, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3140, 3141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3142, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3151, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3153, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3144, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3582, 3547, 65 },
   { 3831, 3834, 89 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3583, 3584, 67 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4959, 3987, 0 },
   { 5012, 4007, 0 },
   { 5064, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4957, 3987, 0 },
   { 5010, 4007, 0 },
   { 5062, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4933, 3987, 0 },
   { 4987, 4007, 0 },
   { 5039, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4931, 3987, 0 },
   { 4985, 4007, 0 },
   { 5037, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 213, 3, 0 },
   { 3451, 3452, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 213, 3, 0 },
   { 3451, 3452, 0 },
   { 3493, 3452, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 208, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 208, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 208, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 208, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 208, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4959, 3987, 0 },
   { 5012, 4007, 0 },
   { 5064, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4957, 3987, 0 },
   { 5010, 4007, 0 },
   { 5062, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4933, 3987, 0 },
   { 4987, 4007, 0 },
   { 5039, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4931, 3987, 0 },
   { 4985, 4007, 0 },
   { 5037, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 211, 3, 0 },
   { 213, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 211, 3, 0 },
   { 213, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 4959, 3987, 0 },
   { 5012, 4007, 0 },
   { 5064, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 4957, 3987, 0 },
   { 5010, 4007, 0 },
   { 5062, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 4933, 3987, 0 },
   { 4987, 4007, 0 },
   { 5039, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 4931, 3987, 0 },
   { 4985, 4007, 0 },
   { 5037, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4959, 3987, 0 },
   { 5012, 4007, 0 },
   { 5064, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4957, 3987, 0 },
   { 5010, 4007, 0 },
   { 5062, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4933, 3987, 0 },
   { 4987, 4007, 0 },
   { 5039, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4931, 3987, 0 },
   { 4985, 4007, 0 },
   { 5037, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 332, 333, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 332, 333, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 4959, 3987, 0 },
   { 5012, 4007, 0 },
   { 5064, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 4957, 3987, 0 },
   { 5010, 4007, 0 },
   { 5062, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 4933, 3987, 0 },
   { 4987, 4007, 0 },
   { 5039, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 332, 333, 0 },
   { 4931, 3987, 0 },
   { 4985, 4007, 0 },
   { 5037, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 335, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 335, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 4959, 3987, 0 },
   { 5012, 4007, 0 },
   { 5064, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 4957, 3987, 0 },
   { 5010, 4007, 0 },
   { 5062, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 4933, 3987, 0 },
   { 4987, 4007, 0 },
   { 5039, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 336, 0 },
   { 4931, 3987, 0 },
   { 4985, 4007, 0 },
   { 5037, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 344, 345, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 344, 345, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { 4959, 3987, 0 },
   { 5012, 4007, 0 },
   { 5064, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { 4957, 3987, 0 },
   { 5010, 4007, 0 },
   { 5062, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { 4933, 3987, 0 },
   { 4987, 4007, 0 },
   { 5039, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 345, 0 },
   { 4931, 3987, 0 },
   { 4985, 4007, 0 },
   { 5037, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 347, 348, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { 4959, 3987, 0 },
   { 5012, 4007, 0 },
   { 5064, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { 4957, 3987, 0 },
   { 5010, 4007, 0 },
   { 5062, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { 4933, 3987, 0 },
   { 4987, 4007, 0 },
   { 5039, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 347, 348, 0 },
   { 4931, 3987, 0 },
   { 4985, 4007, 0 },
   { 5037, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 338, 339, 0 },
   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 338, 339, 0 },
   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 4959, 3987, 0 },
   { 5012, 4007, 0 },
   { 5064, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 4957, 3987, 0 },
   { 5010, 4007, 0 },
   { 5062, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 4933, 3987, 0 },
   { 4987, 4007, 0 },
   { 5039, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 339, 0 },
   { 342, 339, 0 },
   { 4931, 3987, 0 },
   { 4985, 4007, 0 },
   { 5037, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4934, 3987, 0 },
   { 4988, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4934, 3987, 0 },
   { 4988, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4934, 3987, 0 },
   { 4959, 3987, 0 },
   { 4988, 4007, 0 },
   { 5012, 4007, 0 },
   { 5064, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4934, 3987, 0 },
   { 4957, 3987, 0 },
   { 4988, 4007, 0 },
   { 5010, 4007, 0 },
   { 5062, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4933, 3987, 0 },
   { 4934, 3987, 0 },
   { 4987, 4007, 0 },
   { 4988, 4007, 0 },
   { 5039, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4931, 3987, 0 },
   { 4934, 3987, 0 },
   { 4985, 4007, 0 },
   { 4988, 4007, 0 },
   { 5037, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4960, 3987, 0 },
   { 5013, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4960, 3987, 0 },
   { 5013, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4959, 3987, 0 },
   { 4960, 3987, 0 },
   { 5012, 4007, 0 },
   { 5013, 4007, 0 },
   { 5064, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4957, 3987, 0 },
   { 4960, 3987, 0 },
   { 5010, 4007, 0 },
   { 5013, 4007, 0 },
   { 5062, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4933, 3987, 0 },
   { 4960, 3987, 0 },
   { 4987, 4007, 0 },
   { 5013, 4007, 0 },
   { 5039, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4931, 3987, 0 },
   { 4960, 3987, 0 },
   { 4985, 4007, 0 },
   { 5013, 4007, 0 },
   { 5037, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 5065, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 5065, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4959, 3987, 0 },
   { 5012, 4007, 0 },
   { 5064, 4007, 0 },
   { 5065, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4957, 3987, 0 },
   { 5010, 4007, 0 },
   { 5062, 4007, 0 },
   { 5065, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4933, 3987, 0 },
   { 4987, 4007, 0 },
   { 5039, 4007, 0 },
   { 5065, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4931, 3987, 0 },
   { 4985, 4007, 0 },
   { 5037, 4007, 0 },
   { 5065, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 5040, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 5040, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4959, 3987, 0 },
   { 5012, 4007, 0 },
   { 5040, 4007, 0 },
   { 5064, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4957, 3987, 0 },
   { 5010, 4007, 0 },
   { 5040, 4007, 0 },
   { 5062, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4933, 3987, 0 },
   { 4987, 4007, 0 },
   { 5039, 4007, 0 },
   { 5040, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4931, 3987, 0 },
   { 4985, 4007, 0 },
   { 5037, 4007, 0 },
   { 5040, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4959, 3987, 0 },
   { 5012, 4007, 0 },
   { 5064, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4957, 3987, 0 },
   { 5010, 4007, 0 },
   { 5062, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4933, 3987, 0 },
   { 4987, 4007, 0 },
   { 5039, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4931, 3987, 0 },
   { 4985, 4007, 0 },
   { 5037, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4959, 3987, 0 },
   { 5012, 4007, 0 },
   { 5064, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4957, 3987, 0 },
   { 5010, 4007, 0 },
   { 5062, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4933, 3987, 0 },
   { 4987, 4007, 0 },
   { 5039, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 213, 3, 0 },
   { 4931, 3987, 0 },
   { 4985, 4007, 0 },
   { 5037, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4957, 3987, 0 },
   { 4959, 3987, 0 },
   { 5010, 4007, 0 },
   { 5012, 4007, 0 },
   { 5062, 4007, 0 },
   { 5064, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4933, 3987, 0 },
   { 4959, 3987, 0 },
   { 4987, 4007, 0 },
   { 5012, 4007, 0 },
   { 5039, 4007, 0 },
   { 5064, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4931, 3987, 0 },
   { 4959, 3987, 0 },
   { 4985, 4007, 0 },
   { 5012, 4007, 0 },
   { 5037, 4007, 0 },
   { 5064, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4933, 3987, 0 },
   { 4957, 3987, 0 },
   { 4987, 4007, 0 },
   { 5010, 4007, 0 },
   { 5039, 4007, 0 },
   { 5062, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4931, 3987, 0 },
   { 4957, 3987, 0 },
   { 4985, 4007, 0 },
   { 5010, 4007, 0 },
   { 5037, 4007, 0 },
   { 5062, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4931, 3987, 0 },
   { 4933, 3987, 0 },
   { 4985, 4007, 0 },
   { 4987, 4007, 0 },
   { 5037, 4007, 0 },
   { 5039, 4007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3266, 3267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4962, 4936, 0 },
   { 5015, 49, 0 },
   { 5067, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4961, 4936, 0 },
   { 5014, 49, 0 },
   { 5066, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4937, 4936, 0 },
   { 4990, 49, 0 },
   { 5042, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4935, 4936, 0 },
   { 4989, 49, 0 },
   { 5041, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 1025, 1029, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 1017, 1020, 0 },
   { 1025, 1029, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 4962, 4936, 0 },
   { 5015, 49, 0 },
   { 5067, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 4961, 4936, 0 },
   { 5014, 49, 0 },
   { 5066, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 4937, 4936, 0 },
   { 4990, 49, 0 },
   { 5042, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 240, 61, 0 },
   { 248, 32, 0 },
   { 251, 100, 0 },
   { 4935, 4936, 0 },
   { 4989, 49, 0 },
   { 5041, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3404, 3405, 0 },
   { 4962, 4936, 0 },
   { 5015, 49, 0 },
   { 5067, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3404, 3405, 0 },
   { 4961, 4936, 0 },
   { 5014, 49, 0 },
   { 5066, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3404, 3405, 0 },
   { 4937, 4936, 0 },
   { 4990, 49, 0 },
   { 5042, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3404, 3405, 0 },
   { 4935, 4936, 0 },
   { 4989, 49, 0 },
   { 5041, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4938, 4936, 0 },
   { 4962, 4936, 0 },
   { 4991, 49, 0 },
   { 5015, 49, 0 },
   { 5067, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4938, 4936, 0 },
   { 4961, 4936, 0 },
   { 4991, 49, 0 },
   { 5014, 49, 0 },
   { 5066, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4937, 4936, 0 },
   { 4938, 4936, 0 },
   { 4990, 49, 0 },
   { 4991, 49, 0 },
   { 5042, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4935, 4936, 0 },
   { 4938, 4936, 0 },
   { 4989, 49, 0 },
   { 4991, 49, 0 },
   { 5041, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4962, 4936, 0 },
   { 4963, 4936, 0 },
   { 5015, 49, 0 },
   { 5016, 49, 0 },
   { 5067, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4961, 4936, 0 },
   { 4963, 4936, 0 },
   { 5014, 49, 0 },
   { 5016, 49, 0 },
   { 5066, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4937, 4936, 0 },
   { 4963, 4936, 0 },
   { 4990, 49, 0 },
   { 5016, 49, 0 },
   { 5042, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4935, 4936, 0 },
   { 4963, 4936, 0 },
   { 4989, 49, 0 },
   { 5016, 49, 0 },
   { 5041, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4962, 4936, 0 },
   { 5015, 49, 0 },
   { 5067, 49, 0 },
   { 5068, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4961, 4936, 0 },
   { 5014, 49, 0 },
   { 5066, 49, 0 },
   { 5068, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4937, 4936, 0 },
   { 4990, 49, 0 },
   { 5042, 49, 0 },
   { 5068, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4935, 4936, 0 },
   { 4989, 49, 0 },
   { 5041, 49, 0 },
   { 5068, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4962, 4936, 0 },
   { 5015, 49, 0 },
   { 5043, 49, 0 },
   { 5067, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4961, 4936, 0 },
   { 5014, 49, 0 },
   { 5043, 49, 0 },
   { 5066, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4937, 4936, 0 },
   { 4990, 49, 0 },
   { 5042, 49, 0 },
   { 5043, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4935, 4936, 0 },
   { 4989, 49, 0 },
   { 5041, 49, 0 },
   { 5043, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4961, 4936, 0 },
   { 4962, 4936, 0 },
   { 5014, 49, 0 },
   { 5015, 49, 0 },
   { 5066, 49, 0 },
   { 5067, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4937, 4936, 0 },
   { 4962, 4936, 0 },
   { 4990, 49, 0 },
   { 5015, 49, 0 },
   { 5042, 49, 0 },
   { 5067, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4935, 4936, 0 },
   { 4962, 4936, 0 },
   { 4989, 49, 0 },
   { 5015, 49, 0 },
   { 5041, 49, 0 },
   { 5067, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4937, 4936, 0 },
   { 4961, 4936, 0 },
   { 4990, 49, 0 },
   { 5014, 49, 0 },
   { 5042, 49, 0 },
   { 5066, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4935, 4936, 0 },
   { 4961, 4936, 0 },
   { 4989, 49, 0 },
   { 5014, 49, 0 },
   { 5041, 49, 0 },
   { 5066, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4935, 4936, 0 },
   { 4937, 4936, 0 },
   { 4989, 49, 0 },
   { 4990, 49, 0 },
   { 5041, 49, 0 },
   { 5042, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2689, 1216, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 903, 906, 0 },
   { 911, 914, 0 },
   { 919, 922, 0 },
   { 927, 930, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 907, 906, 0 },
   { 915, 914, 0 },
   { 923, 922, 0 },
   { 931, 930, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 1031, 1034, 0 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 809, 813, 0 },
   { 1013, 1015, 0 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 1013, 1015, 0 },
   { 1031, 1034, 0 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2690, 32, 0 },
   { 3260, 3262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2129, 2131, 0 },
   { 2159, 2161, 0 },
   { 2189, 2191, 0 },
   { 2220, 2222, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2695, 1216, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2129, 2131, 0 },
   { 2159, 2161, 0 },
   { 2189, 2191, 0 },
   { 2220, 2222, 0 },
   { 2695, 1216, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 908, 910, 0 },
   { 916, 918, 0 },
   { 924, 926, 0 },
   { 932, 934, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 908, 910, 0 },
   { 916, 918, 0 },
   { 924, 926, 0 },
   { 932, 934, 0 },
   { 2129, 2131, 0 },
   { 2159, 2161, 0 },
   { 2189, 2191, 0 },
   { 2220, 2222, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2696, 32, 0 },
   { 3162, 3163, 58 },
   { 1010, 424, 58 },
   { 3165, 3167, 58 },
   { 1001, 449, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2696, 32, 0 },
   { 3162, 3163, 58 },
   { 1010, 424, 58 },
   { 3165, 3167, 58 },
   { 1001, 449, 59 },
   { 3263, 3259, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3079, 32, 0 },
   { 3602, 3600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3079, 32, 0 },
   { 3599, 3600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3079, 32, 0 },
   { 3599, 3600, 0 },
   { 3602, 3600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1143, 1142, 0 },
   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1147, 1146, 0 },
   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1098, 1099, 0 },
   { 1201, 1204, 0 },
   { 2637, 1246, 0 },
   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1141, 1142, 0 },
   { 1178, 1179, 0 },
   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1145, 1146, 0 },
   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1144, 1142, 0 },
   { 2637, 1246, 0 },
   { 2661, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1084, 1085, 0 },
   { 1151, 1149, 0 },
   { 2637, 1246, 0 },
   { 2661, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1128, 1125, 0 },
   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1135, 1133, 0 },
   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1096, 1097, 0 },
   { 1207, 1208, 0 },
   { 2636, 1242, 0 },
   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1124, 1125, 0 },
   { 1180, 1181, 0 },
   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1132, 1133, 0 },
   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1130, 1125, 0 },
   { 2636, 1242, 0 },
   { 2662, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1086, 1087, 0 },
   { 1140, 1138, 0 },
   { 2636, 1242, 0 },
   { 2662, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 385, 271, 9 },
   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { 5437, 5440, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 257, 255, 0 },
   { 3409, 3411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 257, 255, 0 },
   { 3409, 3411, 0 },
   { 3454, 3411, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3396, 3397, 0 },
   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { 3396, 3397, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 254, 255, 0 },
   { 257, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 380, 381, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 380, 381, 9 },
   { 385, 271, 9 },
   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { 385, 271, 9 },
   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 521, 522, 0 },
   { 589, 590, 0 },
   { 661, 662, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 388, 389, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 388, 389, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 388, 389, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 388, 389, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 521, 522, 0 },
   { 589, 590, 0 },
   { 661, 662, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 388, 389, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 388, 389, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 388, 389, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 388, 389, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 521, 522, 0 },
   { 589, 590, 0 },
   { 661, 662, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 388, 389, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 388, 389, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 388, 389, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 388, 389, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 162, 164, 0 },
   { 388, 389, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 388, 389, 9 },
   { 521, 522, 0 },
   { 589, 590, 0 },
   { 661, 662, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 526, 527, 0 },
   { 593, 594, 0 },
   { 665, 666, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 526, 527, 0 },
   { 593, 594, 0 },
   { 665, 666, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 526, 527, 0 },
   { 593, 594, 0 },
   { 665, 666, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 526, 527, 0 },
   { 593, 594, 0 },
   { 665, 666, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 521, 522, 0 },
   { 526, 527, 0 },
   { 589, 590, 0 },
   { 593, 594, 0 },
   { 661, 662, 0 },
   { 665, 666, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 532, 534, 0 },
   { 598, 600, 0 },
   { 671, 673, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 386, 387, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 386, 387, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 386, 387, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 386, 387, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 386, 387, 9 },
   { 388, 389, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 265, 266, 0 },
   { 267, 268, 5 },
   { 269, 229, 6 },
   { 386, 387, 9 },
   { 388, 389, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 386, 387, 9 },
   { 388, 389, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 147, 0 },
   { 386, 387, 9 },
   { 388, 389, 9 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4968, 2054, 0 },
   { 5021, 2058, 0 },
   { 5073, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4967, 2054, 0 },
   { 5020, 2058, 0 },
   { 5072, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4943, 2054, 0 },
   { 4996, 2058, 0 },
   { 5048, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4942, 2054, 0 },
   { 4995, 2058, 0 },
   { 5047, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2669, 32, 0 },
   { 2670, 63, 0 },
   { 4968, 2054, 0 },
   { 5021, 2058, 0 },
   { 5073, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2669, 32, 0 },
   { 2670, 63, 0 },
   { 4967, 2054, 0 },
   { 5020, 2058, 0 },
   { 5072, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2669, 32, 0 },
   { 2670, 63, 0 },
   { 4943, 2054, 0 },
   { 4996, 2058, 0 },
   { 5048, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2669, 32, 0 },
   { 2670, 63, 0 },
   { 4942, 2054, 0 },
   { 4995, 2058, 0 },
   { 5047, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2704, 2701, 49 },
   { 2711, 2708, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2678, 3, 0 },
   { 4968, 2054, 0 },
   { 5021, 2058, 0 },
   { 5073, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2678, 3, 0 },
   { 4967, 2054, 0 },
   { 5020, 2058, 0 },
   { 5072, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2678, 3, 0 },
   { 4943, 2054, 0 },
   { 4996, 2058, 0 },
   { 5048, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2678, 3, 0 },
   { 4942, 2054, 0 },
   { 4995, 2058, 0 },
   { 5047, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2679, 2301, 0 },
   { 4968, 2054, 0 },
   { 5021, 2058, 0 },
   { 5073, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2679, 2301, 0 },
   { 4967, 2054, 0 },
   { 5020, 2058, 0 },
   { 5072, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2679, 2301, 0 },
   { 4943, 2054, 0 },
   { 4996, 2058, 0 },
   { 5048, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2679, 2301, 0 },
   { 4942, 2054, 0 },
   { 4995, 2058, 0 },
   { 5047, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2236, 1224, 0 },
   { 2668, 32, 0 },
   { 4968, 2054, 0 },
   { 5021, 2058, 0 },
   { 5073, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2236, 1224, 0 },
   { 2668, 32, 0 },
   { 4967, 2054, 0 },
   { 5020, 2058, 0 },
   { 5072, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2236, 1224, 0 },
   { 2668, 32, 0 },
   { 4943, 2054, 0 },
   { 4996, 2058, 0 },
   { 5048, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2236, 1224, 0 },
   { 2668, 32, 0 },
   { 4942, 2054, 0 },
   { 4995, 2058, 0 },
   { 5047, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2716, 2714, 49 },
   { 2721, 2719, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2671, 63, 0 },
   { 4968, 2054, 0 },
   { 5021, 2058, 0 },
   { 5073, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2671, 63, 0 },
   { 4967, 2054, 0 },
   { 5020, 2058, 0 },
   { 5072, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2671, 63, 0 },
   { 4943, 2054, 0 },
   { 4996, 2058, 0 },
   { 5048, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2671, 63, 0 },
   { 4942, 2054, 0 },
   { 4995, 2058, 0 },
   { 5047, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1708, 1711, 0 },
   { 1715, 1711, 0 },
   { 1720, 1723, 0 },
   { 1727, 1723, 0 },
   { 2668, 32, 0 },
   { 2679, 2301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4968, 2054, 0 },
   { 5021, 2058, 0 },
   { 5073, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4967, 2054, 0 },
   { 5020, 2058, 0 },
   { 5072, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4943, 2054, 0 },
   { 4996, 2058, 0 },
   { 5048, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4942, 2054, 0 },
   { 4995, 2058, 0 },
   { 5047, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4944, 2054, 0 },
   { 4968, 2054, 0 },
   { 4997, 2058, 0 },
   { 5021, 2058, 0 },
   { 5073, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4944, 2054, 0 },
   { 4967, 2054, 0 },
   { 4997, 2058, 0 },
   { 5020, 2058, 0 },
   { 5072, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4943, 2054, 0 },
   { 4944, 2054, 0 },
   { 4996, 2058, 0 },
   { 4997, 2058, 0 },
   { 5048, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4942, 2054, 0 },
   { 4944, 2054, 0 },
   { 4995, 2058, 0 },
   { 4997, 2058, 0 },
   { 5047, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4968, 2054, 0 },
   { 4969, 2054, 0 },
   { 5021, 2058, 0 },
   { 5022, 2058, 0 },
   { 5073, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4967, 2054, 0 },
   { 4969, 2054, 0 },
   { 5020, 2058, 0 },
   { 5022, 2058, 0 },
   { 5072, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4943, 2054, 0 },
   { 4969, 2054, 0 },
   { 4996, 2058, 0 },
   { 5022, 2058, 0 },
   { 5048, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4942, 2054, 0 },
   { 4969, 2054, 0 },
   { 4995, 2058, 0 },
   { 5022, 2058, 0 },
   { 5047, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4968, 2054, 0 },
   { 5021, 2058, 0 },
   { 5073, 2058, 0 },
   { 5074, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4967, 2054, 0 },
   { 5020, 2058, 0 },
   { 5072, 2058, 0 },
   { 5074, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4943, 2054, 0 },
   { 4996, 2058, 0 },
   { 5048, 2058, 0 },
   { 5074, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4942, 2054, 0 },
   { 4995, 2058, 0 },
   { 5047, 2058, 0 },
   { 5074, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4968, 2054, 0 },
   { 5021, 2058, 0 },
   { 5049, 2058, 0 },
   { 5073, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4967, 2054, 0 },
   { 5020, 2058, 0 },
   { 5049, 2058, 0 },
   { 5072, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4943, 2054, 0 },
   { 4996, 2058, 0 },
   { 5048, 2058, 0 },
   { 5049, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4942, 2054, 0 },
   { 4995, 2058, 0 },
   { 5047, 2058, 0 },
   { 5049, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2704, 2701, 49 },
   { 2711, 2708, 49 },
   { 2716, 2714, 49 },
   { 2721, 2719, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4943, 2054, 0 },
   { 4996, 2058, 0 },
   { 5048, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4942, 2054, 0 },
   { 4995, 2058, 0 },
   { 5047, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 3018, 3019, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4967, 2054, 0 },
   { 4968, 2054, 0 },
   { 5020, 2058, 0 },
   { 5021, 2058, 0 },
   { 5072, 2058, 0 },
   { 5073, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4943, 2054, 0 },
   { 4968, 2054, 0 },
   { 4996, 2058, 0 },
   { 5021, 2058, 0 },
   { 5048, 2058, 0 },
   { 5073, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4942, 2054, 0 },
   { 4968, 2054, 0 },
   { 4995, 2058, 0 },
   { 5021, 2058, 0 },
   { 5047, 2058, 0 },
   { 5073, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4943, 2054, 0 },
   { 4967, 2054, 0 },
   { 4996, 2058, 0 },
   { 5020, 2058, 0 },
   { 5048, 2058, 0 },
   { 5072, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4942, 2054, 0 },
   { 4967, 2054, 0 },
   { 4995, 2058, 0 },
   { 5020, 2058, 0 },
   { 5047, 2058, 0 },
   { 5072, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4942, 2054, 0 },
   { 4943, 2054, 0 },
   { 4995, 2058, 0 },
   { 4996, 2058, 0 },
   { 5047, 2058, 0 },
   { 5048, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 4942, 2054, 0 },
   { 4995, 2058, 0 },
   { 5047, 2058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 3268, 3267, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4043, 4044, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4049, 4050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4055, 4056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4038, 4041, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4046, 4047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4052, 4053, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1433, 0 },
   { 1454, 1455, 0 },
   { 1474, 1475, 0 },
   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4965, 2012, 0 },
   { 5018, 2020, 0 },
   { 5070, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4964, 2012, 0 },
   { 5017, 2020, 0 },
   { 5069, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4940, 2012, 0 },
   { 4993, 2020, 0 },
   { 5045, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4939, 2012, 0 },
   { 4992, 2020, 0 },
   { 5044, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2680, 3, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2680, 3, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3029, 1520, 0 },
   { 3030, 3027, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1433, 0 },
   { 1454, 1455, 0 },
   { 1474, 1475, 0 },
   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2667, 61, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { 4965, 2012, 0 },
   { 5018, 2020, 0 },
   { 5070, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { 4964, 2012, 0 },
   { 5017, 2020, 0 },
   { 5069, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { 4940, 2012, 0 },
   { 4993, 2020, 0 },
   { 5045, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2001, 2004, 0 },
   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { 4939, 2012, 0 },
   { 4992, 2020, 0 },
   { 5044, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { 2681, 2682, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1433, 0 },
   { 1454, 1455, 0 },
   { 1474, 1475, 0 },
   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 2681, 2682, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2681, 2682, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2681, 2682, 0 },
   { 4965, 2012, 0 },
   { 5018, 2020, 0 },
   { 5070, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2681, 2682, 0 },
   { 4964, 2012, 0 },
   { 5017, 2020, 0 },
   { 5069, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2681, 2682, 0 },
   { 4940, 2012, 0 },
   { 4993, 2020, 0 },
   { 5045, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2681, 2682, 0 },
   { 4939, 2012, 0 },
   { 4992, 2020, 0 },
   { 5044, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 193, 195, 0 },
   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1433, 0 },
   { 1454, 1455, 0 },
   { 1474, 1475, 0 },
   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 2680, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { 4965, 2012, 0 },
   { 5018, 2020, 0 },
   { 5070, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { 4964, 2012, 0 },
   { 5017, 2020, 0 },
   { 5069, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { 4940, 2012, 0 },
   { 4993, 2020, 0 },
   { 5045, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { 4939, 2012, 0 },
   { 4992, 2020, 0 },
   { 5044, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2103, 2105, 43 },
   { 2103, 2111, 45 },
   { 2134, 2136, 43 },
   { 2134, 2142, 45 },
   { 2164, 2166, 43 },
   { 2164, 2172, 45 },
   { 2194, 2196, 43 },
   { 2194, 2202, 45 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1075, 1070, 0 },
   { 2663, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 2680, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1433, 0 },
   { 1454, 1455, 0 },
   { 1474, 1475, 0 },
   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 2685, 2686, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 4965, 2012, 0 },
   { 5018, 2020, 0 },
   { 5070, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 4964, 2012, 0 },
   { 5017, 2020, 0 },
   { 5069, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 4940, 2012, 0 },
   { 4993, 2020, 0 },
   { 5045, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 4939, 2012, 0 },
   { 4992, 2020, 0 },
   { 5044, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { 4941, 2012, 0 },
   { 4994, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1433, 0 },
   { 1454, 1455, 0 },
   { 1474, 1475, 0 },
   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 4941, 2012, 0 },
   { 4994, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4941, 2012, 0 },
   { 4994, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4941, 2012, 0 },
   { 4965, 2012, 0 },
   { 4994, 2020, 0 },
   { 5018, 2020, 0 },
   { 5070, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4941, 2012, 0 },
   { 4964, 2012, 0 },
   { 4994, 2020, 0 },
   { 5017, 2020, 0 },
   { 5069, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4940, 2012, 0 },
   { 4941, 2012, 0 },
   { 4993, 2020, 0 },
   { 4994, 2020, 0 },
   { 5045, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4939, 2012, 0 },
   { 4941, 2012, 0 },
   { 4992, 2020, 0 },
   { 4994, 2020, 0 },
   { 5044, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { 4966, 2012, 0 },
   { 5019, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1433, 0 },
   { 1454, 1455, 0 },
   { 1474, 1475, 0 },
   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 4966, 2012, 0 },
   { 5019, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4966, 2012, 0 },
   { 5019, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4965, 2012, 0 },
   { 4966, 2012, 0 },
   { 5018, 2020, 0 },
   { 5019, 2020, 0 },
   { 5070, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4964, 2012, 0 },
   { 4966, 2012, 0 },
   { 5017, 2020, 0 },
   { 5019, 2020, 0 },
   { 5069, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4940, 2012, 0 },
   { 4966, 2012, 0 },
   { 4993, 2020, 0 },
   { 5019, 2020, 0 },
   { 5045, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4939, 2012, 0 },
   { 4966, 2012, 0 },
   { 4992, 2020, 0 },
   { 5019, 2020, 0 },
   { 5044, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { 5071, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1433, 0 },
   { 1454, 1455, 0 },
   { 1474, 1475, 0 },
   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 5071, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 5071, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4965, 2012, 0 },
   { 5018, 2020, 0 },
   { 5070, 2020, 0 },
   { 5071, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4964, 2012, 0 },
   { 5017, 2020, 0 },
   { 5069, 2020, 0 },
   { 5071, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4940, 2012, 0 },
   { 4993, 2020, 0 },
   { 5045, 2020, 0 },
   { 5071, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4939, 2012, 0 },
   { 4992, 2020, 0 },
   { 5044, 2020, 0 },
   { 5071, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { 5046, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1433, 0 },
   { 1454, 1455, 0 },
   { 1474, 1475, 0 },
   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 5046, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 5046, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4965, 2012, 0 },
   { 5018, 2020, 0 },
   { 5046, 2020, 0 },
   { 5070, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4964, 2012, 0 },
   { 5017, 2020, 0 },
   { 5046, 2020, 0 },
   { 5069, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4940, 2012, 0 },
   { 4993, 2020, 0 },
   { 5045, 2020, 0 },
   { 5046, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4939, 2012, 0 },
   { 4992, 2020, 0 },
   { 5044, 2020, 0 },
   { 5046, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1433, 0 },
   { 1454, 1455, 0 },
   { 1474, 1475, 0 },
   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 2680, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { 4965, 2012, 0 },
   { 5018, 2020, 0 },
   { 5070, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { 4964, 2012, 0 },
   { 5017, 2020, 0 },
   { 5069, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { 4940, 2012, 0 },
   { 4993, 2020, 0 },
   { 5045, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 2680, 3, 0 },
   { 4939, 2012, 0 },
   { 4992, 2020, 0 },
   { 5044, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 3016, 3017, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1433, 0 },
   { 1454, 1455, 0 },
   { 1474, 1475, 0 },
   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1433, 0 },
   { 1454, 1455, 0 },
   { 1474, 1475, 0 },
   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 4965, 2012, 0 },
   { 5018, 2020, 0 },
   { 5070, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1433, 0 },
   { 1454, 1455, 0 },
   { 1474, 1475, 0 },
   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 4964, 2012, 0 },
   { 5017, 2020, 0 },
   { 5069, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1433, 0 },
   { 1454, 1455, 0 },
   { 1474, 1475, 0 },
   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 4940, 2012, 0 },
   { 4993, 2020, 0 },
   { 5045, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1410, 1411, 0 },
   { 1432, 1433, 0 },
   { 1454, 1455, 0 },
   { 1474, 1475, 0 },
   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { 4939, 2012, 0 },
   { 4992, 2020, 0 },
   { 5044, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4965, 2012, 0 },
   { 5018, 2020, 0 },
   { 5070, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4964, 2012, 0 },
   { 5017, 2020, 0 },
   { 5069, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4940, 2012, 0 },
   { 4993, 2020, 0 },
   { 5045, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4939, 2012, 0 },
   { 4992, 2020, 0 },
   { 5044, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2103, 2105, 43 },
   { 2103, 2111, 45 },
   { 2134, 2136, 43 },
   { 2134, 2142, 45 },
   { 2164, 2166, 43 },
   { 2164, 2172, 45 },
   { 2194, 2196, 43 },
   { 2194, 2202, 45 },
   { 2663, 32, 0 },
   { 3159, 3161, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4964, 2012, 0 },
   { 4965, 2012, 0 },
   { 5017, 2020, 0 },
   { 5018, 2020, 0 },
   { 5069, 2020, 0 },
   { 5070, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4940, 2012, 0 },
   { 4965, 2012, 0 },
   { 4993, 2020, 0 },
   { 5018, 2020, 0 },
   { 5045, 2020, 0 },
   { 5070, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4939, 2012, 0 },
   { 4965, 2012, 0 },
   { 4992, 2020, 0 },
   { 5018, 2020, 0 },
   { 5044, 2020, 0 },
   { 5070, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4940, 2012, 0 },
   { 4964, 2012, 0 },
   { 4993, 2020, 0 },
   { 5017, 2020, 0 },
   { 5045, 2020, 0 },
   { 5069, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4939, 2012, 0 },
   { 4964, 2012, 0 },
   { 4992, 2020, 0 },
   { 5017, 2020, 0 },
   { 5044, 2020, 0 },
   { 5069, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4939, 2012, 0 },
   { 4940, 2012, 0 },
   { 4992, 2020, 0 },
   { 4993, 2020, 0 },
   { 5044, 2020, 0 },
   { 5045, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2663, 32, 0 },
   { 4939, 2012, 0 },
   { 4992, 2020, 0 },
   { 5044, 2020, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2358, 2357, 0 },
   { 3080, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3149, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1155, 1125, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1088, 1089, 0 },
   { 1244, 1242, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1088, 1089, 0 },
   { 1188, 1191, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1088, 1089, 0 },
   { 2651, 753, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1266, 1042, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1183, 1186, 0 },
   { 1266, 1042, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1157, 1142, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1092, 1093, 0 },
   { 1247, 1246, 0 },
   { 1247, 1246, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1092, 1093, 0 },
   { 1194, 1195, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1092, 1093, 0 },
   { 1120, 1118, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 1497, 1243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 1573, 1575, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1344, 1272, 0 },
   { 1366, 1368, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 1497, 1243, 0 },
   { 3083, 219, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 1573, 1575, 0 },
   { 3083, 219, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1344, 1272, 0 },
   { 1366, 1368, 0 },
   { 3083, 219, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1344, 1272, 0 },
   { 1366, 1368, 0 },
   { 1494, 1243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 1497, 1243, 0 },
   { 1499, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 1499, 32, 0 },
   { 1573, 1575, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1344, 1272, 0 },
   { 1366, 1368, 0 },
   { 1499, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1344, 1272, 0 },
   { 1494, 1243, 0 },
   { 1497, 1243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1344, 1272, 0 },
   { 1494, 1243, 0 },
   { 1573, 1575, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 1497, 1243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 1573, 1575, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1344, 1272, 0 },
   { 1366, 1368, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 1497, 1243, 0 },
   { 1573, 1575, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1344, 1272, 0 },
   { 1366, 1368, 0 },
   { 1494, 1243, 0 },
   { 1497, 1243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1258, 1259, 0 },
   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1344, 1272, 0 },
   { 1366, 1368, 0 },
   { 1494, 1243, 0 },
   { 1573, 1575, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1501, 32, 0 },
   { 1505, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1505, 103, 0 },
   { 1567, 1570, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1338, 1270, 0 },
   { 1351, 1353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1501, 32, 0 },
   { 1505, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1505, 103, 0 },
   { 1567, 1570, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1579, 1580, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1511, 219, 38 },
   { 1516, 1514, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1338, 1270, 0 },
   { 1351, 1353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1505, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1338, 1270, 0 },
   { 1351, 1353, 0 },
   { 1505, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1501, 32, 0 },
   { 1503, 103, 0 },
   { 1505, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1503, 103, 0 },
   { 1505, 103, 0 },
   { 1567, 1570, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1503, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1338, 1270, 0 },
   { 1351, 1353, 0 },
   { 1503, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1338, 1270, 0 },
   { 1501, 32, 0 },
   { 1505, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1338, 1270, 0 },
   { 1505, 103, 0 },
   { 1567, 1570, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1338, 1270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1501, 32, 0 },
   { 1505, 103, 0 },
   { 1567, 1570, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1501, 32, 0 },
   { 1505, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1338, 1270, 0 },
   { 1351, 1353, 0 },
   { 1501, 32, 0 },
   { 1505, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1254, 1256, 0 },
   { 1328, 32, 0 },
   { 1505, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1505, 103, 0 },
   { 1567, 1570, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1338, 1270, 0 },
   { 1351, 1353, 0 },
   { 1505, 103, 0 },
   { 1567, 1570, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1338, 1270, 0 },
   { 1351, 1353, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 1509, 40 },
   { 1525, 1527, 38 },
   { 3082, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 1509, 40 },
   { 1530, 1532, 38 },
   { 3082, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 1509, 40 },
   { 1535, 1537, 41 },
   { 3082, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 1509, 40 },
   { 1539, 1543, 38 },
   { 3082, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 1509, 40 },
   { 3082, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 1509, 40 },
   { 2644, 1252, 0 },
   { 3082, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 719, 709, 24 },
   { 721, 712, 24 },
   { 723, 715, 25 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 3, 0 },
   { 3509, 3438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 207, 113, 0 },
   { 3469, 3472, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 207, 113, 0 },
   { 3478, 3482, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 207, 113, 0 },
   { 3488, 3491, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 207, 113, 0 },
   { 803, 805, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 207, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 207, 113, 0 },
   { 719, 709, 24 },
   { 721, 712, 24 },
   { 723, 715, 25 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 218, 3, 0 },
   { 3436, 3438, 0 },
   { 3440, 3438, 0 },
   { 3509, 3438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 218, 3, 0 },
   { 3436, 3438, 0 },
   { 3440, 3438, 0 },
   { 3467, 3438, 0 },
   { 3509, 3438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 216, 3, 0 },
   { 218, 3, 0 },
   { 3509, 3438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 216, 3, 0 },
   { 719, 709, 24 },
   { 721, 712, 24 },
   { 723, 715, 25 },
   { 3509, 3438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 222, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 216, 3, 0 },
   { 218, 3, 0 },
   { 719, 709, 24 },
   { 721, 712, 24 },
   { 723, 715, 25 },
   { 3509, 3438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2740, 2743, 51 },
   { 2765, 32, 0 },
   { 2766, 253, 0 },
   { 2767, 2764, 0 },
   { 2774, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2744, 2740, 52 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2744, 2740, 52 },
   { 2756, 2757, 0 },
   { 2760, 253, 0 },
   { 2763, 2764, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1495, 1496, 0 },
   { 1498, 1496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1348, 1292, 0 },
   { 1376, 1378, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1495, 1496, 0 },
   { 1498, 1496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1348, 1292, 0 },
   { 1376, 1378, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1348, 1292, 0 },
   { 1376, 1378, 0 },
   { 1495, 1496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1495, 1496, 0 },
   { 1498, 1496, 0 },
   { 1500, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1348, 1292, 0 },
   { 1376, 1378, 0 },
   { 1500, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1348, 1292, 0 },
   { 1495, 1496, 0 },
   { 1498, 1496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1495, 1496, 0 },
   { 1498, 1496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1348, 1292, 0 },
   { 1376, 1378, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1348, 1292, 0 },
   { 1376, 1378, 0 },
   { 1495, 1496, 0 },
   { 1498, 1496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1495, 1496, 0 },
   { 3032, 3019, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1502, 32, 0 },
   { 1506, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1342, 1290, 0 },
   { 1361, 1363, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1502, 32, 0 },
   { 1506, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 3926, 3922, 102 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1342, 1290, 0 },
   { 1361, 1363, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1506, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1342, 1290, 0 },
   { 1361, 1363, 0 },
   { 1506, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1502, 32, 0 },
   { 1504, 106, 0 },
   { 1506, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1504, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1342, 1290, 0 },
   { 1361, 1363, 0 },
   { 1504, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1342, 1290, 0 },
   { 1502, 32, 0 },
   { 1506, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1342, 1290, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1502, 32, 0 },
   { 1506, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1342, 1290, 0 },
   { 1361, 1363, 0 },
   { 1502, 32, 0 },
   { 1506, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1506, 106, 39 },
   { 3031, 3017, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1330, 32, 0 },
   { 1342, 1290, 0 },
   { 1361, 1363, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2654, 1224, 0 },
   { 2970, 753, 0 },
   { 2973, 1118, 0 },
   { 3020, 1118, 0 },
   { 3021, 753, 0 },
   { 3118, 1070, 0 },
   { 3721, 3722, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2655, 1070, 0 },
   { 2971, 1118, 0 },
   { 2972, 753, 0 },
   { 3022, 753, 0 },
   { 3023, 1118, 0 },
   { 3117, 1224, 0 },
   { 3718, 3720, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2240, 1383, 0 },
   { 2655, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2652, 1070, 0 },
   { 3025, 753, 0 },
   { 3122, 1070, 0 },
   { 3123, 1224, 0 },
   { 3124, 1224, 0 },
   { 1481, 3716, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2293, 1070, 0 },
   { 2656, 1070, 0 },
   { 3761, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2656, 1070, 0 },
   { 3026, 753, 0 },
   { 3126, 1224, 0 },
   { 3723, 3720, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2293, 1070, 0 },
   { 2656, 1070, 0 },
   { 3126, 1224, 0 },
   { 3723, 3720, 81 },
   { 3761, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2293, 1070, 0 },
   { 2345, 2346, 0 },
   { 2656, 1070, 0 },
   { 3126, 1224, 0 },
   { 3723, 3720, 81 },
   { 3761, 1070, 0 },
   { 3765, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2293, 1070, 0 },
   { 2302, 1070, 0 },
   { 2656, 1070, 0 },
   { 3761, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2283, 1078, 0 },
   { 2293, 1070, 0 },
   { 2656, 1070, 0 },
   { 3761, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2293, 1070, 0 },
   { 2294, 1070, 0 },
   { 2656, 1070, 0 },
   { 3761, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2653, 1224, 0 },
   { 3024, 1118, 0 },
   { 3119, 1224, 0 },
   { 3120, 1070, 0 },
   { 3121, 1070, 0 },
   { 1478, 3717, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1346, 1282, 0 },
   { 1371, 1373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1332, 61, 0 },
   { 1333, 32, 0 },
   { 1346, 1282, 0 },
   { 1371, 1373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1346, 1282, 0 },
   { 1371, 1373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1346, 1282, 0 },
   { 1371, 1373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 3034, 3017, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1334, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1334, 32, 0 },
   { 1340, 1280, 0 },
   { 1356, 1358, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1334, 32, 0 },
   { 1335, 32, 0 },
   { 1336, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1334, 32, 0 },
   { 1335, 32, 0 },
   { 1336, 63, 0 },
   { 1340, 1280, 0 },
   { 1356, 1358, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1334, 32, 0 },
   { 1340, 1280, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1334, 32, 0 },
   { 3033, 3019, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1334, 32, 0 },
   { 1340, 1280, 0 },
   { 1356, 1358, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2976, 1104, 0 },
   { 2977, 686, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1297, 1298, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 393, 394, 9 },
   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1299, 1300, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1267, 1268, 0 },
   { 1269, 1270, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 1272, 0 },
   { 1274, 1275, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1287, 1288, 0 },
   { 1289, 1290, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 2355, 2356, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1277, 1278, 0 },
   { 1279, 1280, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4953, 4925, 0 },
   { 5006, 4978, 0 },
   { 5058, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4951, 4925, 0 },
   { 5004, 4978, 0 },
   { 5056, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4928, 4925, 0 },
   { 4981, 4978, 0 },
   { 5033, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1281, 1282, 0 },
   { 1284, 1285, 0 },
   { 1305, 1303, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3607, 3609, 0 },
   { 4924, 4925, 0 },
   { 4977, 4978, 0 },
   { 5030, 4978, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3514, 3512, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3517, 3515, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3520, 3518, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3523, 3521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1291, 1292, 0 },
   { 1294, 1295, 0 },
   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3526, 3524, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3786, 3784, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3789, 3784, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1584, 1583, 0 },
   { 3840, 3843, 90 },
   { 4921, 11, 0 },
   { 4974, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4971, 2078, 0 },
   { 5024, 2082, 0 },
   { 5076, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4970, 2078, 0 },
   { 5023, 2082, 0 },
   { 5075, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4946, 2078, 0 },
   { 4999, 2082, 0 },
   { 5051, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4945, 2078, 0 },
   { 4998, 2082, 0 },
   { 5050, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2673, 32, 0 },
   { 2676, 2666, 0 },
   { 4971, 2078, 0 },
   { 5024, 2082, 0 },
   { 5076, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2673, 32, 0 },
   { 2676, 2666, 0 },
   { 4970, 2078, 0 },
   { 5023, 2082, 0 },
   { 5075, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2673, 32, 0 },
   { 2676, 2666, 0 },
   { 4946, 2078, 0 },
   { 4999, 2082, 0 },
   { 5051, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2673, 32, 0 },
   { 2676, 2666, 0 },
   { 4945, 2078, 0 },
   { 4998, 2082, 0 },
   { 5050, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4947, 2078, 0 },
   { 4971, 2078, 0 },
   { 5000, 2082, 0 },
   { 5024, 2082, 0 },
   { 5076, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4947, 2078, 0 },
   { 4970, 2078, 0 },
   { 5000, 2082, 0 },
   { 5023, 2082, 0 },
   { 5075, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4946, 2078, 0 },
   { 4947, 2078, 0 },
   { 4999, 2082, 0 },
   { 5000, 2082, 0 },
   { 5051, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4945, 2078, 0 },
   { 4947, 2078, 0 },
   { 4998, 2082, 0 },
   { 5000, 2082, 0 },
   { 5050, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4971, 2078, 0 },
   { 4972, 2078, 0 },
   { 5024, 2082, 0 },
   { 5025, 2082, 0 },
   { 5076, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4970, 2078, 0 },
   { 4972, 2078, 0 },
   { 5023, 2082, 0 },
   { 5025, 2082, 0 },
   { 5075, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4946, 2078, 0 },
   { 4972, 2078, 0 },
   { 4999, 2082, 0 },
   { 5025, 2082, 0 },
   { 5051, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4945, 2078, 0 },
   { 4972, 2078, 0 },
   { 4998, 2082, 0 },
   { 5025, 2082, 0 },
   { 5050, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4971, 2078, 0 },
   { 5024, 2082, 0 },
   { 5076, 2082, 0 },
   { 5077, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4970, 2078, 0 },
   { 5023, 2082, 0 },
   { 5075, 2082, 0 },
   { 5077, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4946, 2078, 0 },
   { 4999, 2082, 0 },
   { 5051, 2082, 0 },
   { 5077, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4945, 2078, 0 },
   { 4998, 2082, 0 },
   { 5050, 2082, 0 },
   { 5077, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4971, 2078, 0 },
   { 5024, 2082, 0 },
   { 5052, 2082, 0 },
   { 5076, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4970, 2078, 0 },
   { 5023, 2082, 0 },
   { 5052, 2082, 0 },
   { 5075, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4946, 2078, 0 },
   { 4999, 2082, 0 },
   { 5051, 2082, 0 },
   { 5052, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4945, 2078, 0 },
   { 4998, 2082, 0 },
   { 5050, 2082, 0 },
   { 5052, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2675, 3, 0 },
   { 4971, 2078, 0 },
   { 5024, 2082, 0 },
   { 5076, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2675, 3, 0 },
   { 4970, 2078, 0 },
   { 5023, 2082, 0 },
   { 5075, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2675, 3, 0 },
   { 4946, 2078, 0 },
   { 4999, 2082, 0 },
   { 5051, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 2675, 3, 0 },
   { 4945, 2078, 0 },
   { 4998, 2082, 0 },
   { 5050, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4970, 2078, 0 },
   { 4971, 2078, 0 },
   { 5023, 2082, 0 },
   { 5024, 2082, 0 },
   { 5075, 2082, 0 },
   { 5076, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4946, 2078, 0 },
   { 4971, 2078, 0 },
   { 4999, 2082, 0 },
   { 5024, 2082, 0 },
   { 5051, 2082, 0 },
   { 5076, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4945, 2078, 0 },
   { 4971, 2078, 0 },
   { 4998, 2082, 0 },
   { 5024, 2082, 0 },
   { 5050, 2082, 0 },
   { 5076, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4946, 2078, 0 },
   { 4970, 2078, 0 },
   { 4999, 2082, 0 },
   { 5023, 2082, 0 },
   { 5051, 2082, 0 },
   { 5075, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4945, 2078, 0 },
   { 4970, 2078, 0 },
   { 4998, 2082, 0 },
   { 5023, 2082, 0 },
   { 5050, 2082, 0 },
   { 5075, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4945, 2078, 0 },
   { 4946, 2078, 0 },
   { 4998, 2082, 0 },
   { 4999, 2082, 0 },
   { 5050, 2082, 0 },
   { 5051, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2672, 61, 0 },
   { 4945, 2078, 0 },
   { 4998, 2082, 0 },
   { 5050, 2082, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1796, 11, 0 },
   { 1819, 11, 0 },
   { 1901, 16, 0 },
   { 2007, 2004, 0 },
   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { 4098, 4096, 0 },
   { 4104, 4096, 0 },
   { 4110, 4096, 0 },
   { 4115, 4096, 0 },
   { 4118, 4119, 0 },
   { 4123, 4094, 0 },
   { 4127, 4094, 0 },
   { 4131, 4094, 0 },
   { 4134, 4135, 0 },
   { 4137, 4135, 0 },
   { 4140, 4141, 0 },
   { 4145, 4101, 0 },
   { 4149, 4101, 0 },
   { 4152, 4153, 0 },
   { 4155, 4153, 0 },
   { 4158, 3210, 0 },
   { 4160, 4153, 0 },
   { 4162, 3210, 0 },
   { 4164, 1795, 0 },
   { 4168, 4107, 0 },
   { 4171, 4172, 0 },
   { 4174, 4172, 0 },
   { 4177, 4178, 0 },
   { 4180, 4172, 0 },
   { 4182, 4178, 0 },
   { 4184, 1818, 0 },
   { 4186, 4172, 0 },
   { 4188, 4178, 0 },
   { 4190, 1818, 0 },
   { 4192, 1900, 0 },
   { 4920, 11, 0 },
   { 4973, 16, 0 },
   { 5026, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1796, 11, 0 },
   { 1819, 11, 0 },
   { 1901, 16, 0 },
   { 3188, 3189, 0 },
   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { 4098, 4096, 0 },
   { 4104, 4096, 0 },
   { 4110, 4096, 0 },
   { 4115, 4096, 0 },
   { 4118, 4119, 0 },
   { 4123, 4094, 0 },
   { 4127, 4094, 0 },
   { 4131, 4094, 0 },
   { 4134, 4135, 0 },
   { 4137, 4135, 0 },
   { 4140, 4141, 0 },
   { 4145, 4101, 0 },
   { 4149, 4101, 0 },
   { 4152, 4153, 0 },
   { 4155, 4153, 0 },
   { 4158, 3210, 0 },
   { 4160, 4153, 0 },
   { 4162, 3210, 0 },
   { 4164, 1795, 0 },
   { 4168, 4107, 0 },
   { 4171, 4172, 0 },
   { 4174, 4172, 0 },
   { 4177, 4178, 0 },
   { 4180, 4172, 0 },
   { 4182, 4178, 0 },
   { 4184, 1818, 0 },
   { 4186, 4172, 0 },
   { 4188, 4178, 0 },
   { 4190, 1818, 0 },
   { 4192, 1900, 0 },
   { 4920, 11, 0 },
   { 4973, 16, 0 },
   { 5026, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3185, 3187, 0 },
   { 4074, 753, 0 },
   { 4075, 6, 0 },
   { 4076, 11, 0 },
   { 4077, 16, 0 },
   { 4078, 21, 0 },
   { 4095, 4096, 0 },
   { 4102, 4096, 0 },
   { 4108, 4096, 0 },
   { 4113, 4096, 0 },
   { 4121, 4094, 0 },
   { 4125, 4094, 0 },
   { 4129, 4094, 0 },
   { 4143, 4101, 0 },
   { 4147, 4101, 0 },
   { 4166, 4107, 0 },
   { 4948, 11, 0 },
   { 5001, 16, 0 },
   { 5053, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2119, 6, 0 },
   { 2150, 11, 0 },
   { 2180, 16, 0 },
   { 2210, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1557, 1558, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1332, 61, 0 },
   { 1333, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1332, 61, 0 },
   { 1333, 32, 0 },
   { 1557, 1558, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1557, 1558, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1346, 1282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1346, 1282, 0 },
   { 1557, 1558, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1346, 1282, 0 },
   { 1371, 1373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1346, 1282, 0 },
   { 1371, 1373, 0 },
   { 1557, 1558, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 32, 0 },
   { 1557, 1558, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3558, 3547, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3578, 3542, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3560, 3547, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3580, 3542, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3556, 3547, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3559, 3547, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3577, 3542, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3579, 3542, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3549, 3541, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3554, 3541, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3551, 3547, 65 },
   { 3558, 3547, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3555, 3547, 65 },
   { 3560, 3547, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3570, 3515, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3575, 3515, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3572, 3542, 66 },
   { 3578, 3542, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3576, 3542, 66 },
   { 3580, 3542, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3540, 3541, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3552, 3541, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3546, 3547, 65 },
   { 3556, 3547, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3553, 3547, 65 },
   { 3559, 3547, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3564, 3515, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3573, 3515, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1325, 1133, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3568, 3542, 66 },
   { 3577, 3542, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 3007, 3, 0 },
   { 3574, 3542, 66 },
   { 3579, 3542, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2700, 2701, 49 },
   { 2707, 2708, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2713, 2714, 49 },
   { 2718, 2719, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2700, 2701, 49 },
   { 2707, 2708, 49 },
   { 2716, 2714, 49 },
   { 2721, 2719, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2679, 2301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2704, 2701, 49 },
   { 2711, 2708, 49 },
   { 2713, 2714, 49 },
   { 2718, 2719, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2700, 2701, 49 },
   { 2707, 2708, 49 },
   { 2713, 2714, 49 },
   { 2718, 2719, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 938, 939, 0 },
   { 985, 984, 0 },
   { 992, 991, 0 },
   { 1000, 998, 0 },
   { 1009, 1007, 0 },
   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 987, 986, 0 },
   { 994, 993, 0 },
   { 1002, 1001, 0 },
   { 1011, 1010, 0 },
   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 503, 493, 15 },
   { 573, 564, 17 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 503, 493, 15 },
   { 513, 511, 14 },
   { 573, 564, 17 },
   { 582, 580, 16 },
   { 644, 634, 19 },
   { 653, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 503, 493, 15 },
   { 573, 564, 17 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 503, 493, 15 },
   { 513, 511, 14 },
   { 573, 564, 17 },
   { 582, 580, 16 },
   { 644, 634, 19 },
   { 653, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 207, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 503, 493, 15 },
   { 573, 564, 17 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 503, 493, 15 },
   { 513, 511, 14 },
   { 573, 564, 17 },
   { 582, 580, 16 },
   { 644, 634, 19 },
   { 653, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 503, 493, 15 },
   { 573, 564, 17 },
   { 644, 634, 19 },
   { 3509, 3438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 503, 493, 15 },
   { 513, 511, 14 },
   { 573, 564, 17 },
   { 582, 580, 16 },
   { 644, 634, 19 },
   { 653, 651, 18 },
   { 3509, 3438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 503, 493, 15 },
   { 573, 564, 17 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 492, 493, 15 },
   { 503, 493, 15 },
   { 563, 564, 17 },
   { 573, 564, 17 },
   { 633, 634, 19 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 503, 493, 15 },
   { 513, 511, 14 },
   { 573, 564, 17 },
   { 582, 580, 16 },
   { 644, 634, 19 },
   { 653, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 492, 493, 15 },
   { 503, 493, 15 },
   { 513, 511, 14 },
   { 563, 564, 17 },
   { 573, 564, 17 },
   { 582, 580, 16 },
   { 633, 634, 19 },
   { 644, 634, 19 },
   { 653, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 157, 159, 0 },
   { 503, 493, 15 },
   { 573, 564, 17 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 157, 159, 0 },
   { 503, 493, 15 },
   { 513, 511, 14 },
   { 573, 564, 17 },
   { 582, 580, 16 },
   { 644, 634, 19 },
   { 653, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 503, 493, 15 },
   { 573, 564, 17 },
   { 644, 634, 19 },
   { 719, 709, 24 },
   { 721, 712, 24 },
   { 723, 715, 25 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 503, 493, 15 },
   { 513, 511, 14 },
   { 573, 564, 17 },
   { 582, 580, 16 },
   { 644, 634, 19 },
   { 653, 651, 18 },
   { 719, 709, 24 },
   { 721, 712, 24 },
   { 723, 715, 25 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 3, 0 },
   { 503, 493, 15 },
   { 573, 564, 17 },
   { 644, 634, 19 },
   { 3509, 3438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 3, 0 },
   { 503, 493, 15 },
   { 513, 511, 14 },
   { 573, 564, 17 },
   { 582, 580, 16 },
   { 644, 634, 19 },
   { 653, 651, 18 },
   { 3509, 3438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 503, 493, 15 },
   { 573, 564, 17 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 492, 493, 15 },
   { 503, 493, 15 },
   { 563, 564, 17 },
   { 573, 564, 17 },
   { 633, 634, 19 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 207, 113, 0 },
   { 1782, 1783, 42 },
   { 1887, 1888, 42 },
   { 1967, 1968, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2053, 2055, 0 },
   { 2057, 2059, 0 },
   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2011, 2013, 0 },
   { 2019, 2021, 0 },
   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2077, 2079, 0 },
   { 2081, 2083, 0 },
   { 4079, 753, 0 },
   { 4080, 6, 0 },
   { 4081, 11, 0 },
   { 4082, 16, 0 },
   { 4083, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 983, 984, 0 },
   { 990, 991, 0 },
   { 997, 998, 0 },
   { 1006, 1007, 0 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2696, 32, 0 },
   { 3162, 3163, 58 },
   { 1010, 424, 58 },
   { 3165, 3167, 58 },
   { 1001, 449, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1547, 1548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1547, 1548, 0 },
   { 3083, 219, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1509, 219, 38 },
   { 1513, 1514, 38 },
   { 1547, 1548, 0 },
   { 3083, 219, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 3083, 219, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 1547, 1548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1499, 32, 0 },
   { 1547, 1548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 1499, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1344, 1272, 0 },
   { 1547, 1548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1344, 1272, 0 },
   { 1494, 1243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 1497, 1243, 0 },
   { 1547, 1548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 1497, 1243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 1547, 1548, 0 },
   { 1573, 1575, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 1573, 1575, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1344, 1272, 0 },
   { 1366, 1368, 0 },
   { 1547, 1548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1344, 1272, 0 },
   { 1366, 1368, 0 },
   { 1494, 1243, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 32, 0 },
   { 1494, 1243, 0 },
   { 1547, 1548, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 385, 271, 9 },
   { 3586, 3587, 0 },
   { 3589, 3590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3396, 3397, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 516, 511, 0 },
   { 585, 580, 0 },
   { 656, 651, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 259, 3, 0 },
   { 261, 260, 5 },
   { 262, 36, 6 },
   { 273, 274, 0 },
   { 278, 279, 0 },
   { 516, 511, 0 },
   { 585, 580, 0 },
   { 656, 651, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 516, 511, 0 },
   { 585, 580, 0 },
   { 656, 651, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 162, 164, 0 },
   { 516, 511, 0 },
   { 585, 580, 0 },
   { 656, 651, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 516, 511, 0 },
   { 526, 527, 0 },
   { 585, 580, 0 },
   { 593, 594, 0 },
   { 656, 651, 0 },
   { 665, 666, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 149, 150, 0 },
   { 388, 389, 9 },
   { 516, 511, 0 },
   { 585, 580, 0 },
   { 656, 651, 0 },
   { 730, 732, 29 },
   { 236, 734, 30 },
   { 735, 737, 31 },
   { 738, 732, 32 },
   { 739, 734, 33 },
   { 740, 737, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1148, 1149, 0 },
   { 1178, 1179, 0 },
   { 2661, 1224, 0 },
   { 3099, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1137, 1138, 0 },
   { 1180, 1181, 0 },
   { 2662, 1070, 0 },
   { 3098, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2750, 2753, 52 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1088, 1089, 0 },
   { 1154, 1125, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1092, 1093, 0 },
   { 1156, 1142, 0 },
   { 2660, 1224, 0 },
   { 3102, 1224, 0 },
   { 3105, 1070, 0 },
   { 3108, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1552, 1553, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1552, 1553, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1552, 1553, 0 },
   { 3924, 3922, 102 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1495, 1496, 0 },
   { 1552, 1553, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1500, 32, 0 },
   { 1552, 1553, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1348, 1292, 0 },
   { 1552, 1553, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1495, 1496, 0 },
   { 1498, 1496, 0 },
   { 1552, 1553, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1329, 32, 0 },
   { 1348, 1292, 0 },
   { 1376, 1378, 0 },
   { 1552, 1553, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 208, 61, 0 },
   { 1789, 1790, 42 },
   { 1894, 1895, 42 },
   { 1974, 1975, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3771, 3772, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3752, 3743, 0 },
   { 3771, 3772, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3773, 3774, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3754, 3740, 0 },
   { 3773, 3774, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3777, 3778, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3756, 3757, 0 },
   { 3777, 3778, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 2679, 2301, 0 },
   { 3221, 3223, 60 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 198, 200, 0 },
   { 2668, 32, 0 },
   { 2678, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1183, 1186, 0 },
   { 2658, 1070, 0 },
   { 3087, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1175, 0 },
   { 1183, 1186, 0 },
   { 1266, 1042, 0 },
   { 2658, 1070, 0 },
   { 3091, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1170, 1173, 0 },
   { 2264, 1071, 0 },
   { 2658, 1070, 0 },
   { 3110, 1070, 0 },
   { 3113, 1224, 0 },
   { 3116, 1224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 3094, 3086, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1328, 32, 0 },
   { 1579, 1580, 38 },
   { 3096, 3090, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 113, 0 },
   { 224, 115, 5 },
   { 225, 117, 6 },
   { 244, 32, 0 },
   { 247, 32, 0 },
   { 250, 98, 0 },
   { 752, 760, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 207, 113, 0 },
   { 540, 541, 15 },
   { 606, 607, 17 },
   { 679, 680, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 498, 499, 15 },
   { 569, 570, 17 },
   { 639, 640, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 498, 499, 15 },
   { 503, 493, 15 },
   { 569, 570, 17 },
   { 573, 564, 17 },
   { 639, 640, 19 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 492, 493, 15 },
   { 498, 499, 15 },
   { 503, 493, 15 },
   { 563, 564, 17 },
   { 569, 570, 17 },
   { 573, 564, 17 },
   { 633, 634, 19 },
   { 639, 640, 19 },
   { 644, 634, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 492, 493, 15 },
   { 503, 493, 15 },
   { 510, 511, 14 },
   { 563, 564, 17 },
   { 573, 564, 17 },
   { 579, 580, 16 },
   { 633, 634, 19 },
   { 644, 634, 19 },
   { 650, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 492, 493, 15 },
   { 503, 493, 15 },
   { 510, 511, 14 },
   { 513, 511, 14 },
   { 563, 564, 17 },
   { 573, 564, 17 },
   { 579, 580, 16 },
   { 582, 580, 16 },
   { 633, 634, 19 },
   { 644, 634, 19 },
   { 650, 651, 18 },
   { 653, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 492, 493, 15 },
   { 498, 499, 15 },
   { 503, 493, 15 },
   { 510, 511, 14 },
   { 563, 564, 17 },
   { 569, 570, 17 },
   { 573, 564, 17 },
   { 579, 580, 16 },
   { 633, 634, 19 },
   { 639, 640, 19 },
   { 644, 634, 19 },
   { 650, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 498, 499, 15 },
   { 569, 570, 17 },
   { 639, 640, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 135, 0 },
   { 492, 493, 15 },
   { 503, 493, 15 },
   { 510, 511, 14 },
   { 563, 564, 17 },
   { 573, 564, 17 },
   { 579, 580, 16 },
   { 633, 634, 19 },
   { 644, 634, 19 },
   { 650, 651, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2247, 2250, 0 },
   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2255, 2259, 0 },
   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2247, 2250, 0 },
   { 2255, 2259, 0 },
   { 2663, 32, 0 },
   { 2667, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2696, 32, 0 },
   { 3162, 3163, 58 },
   { 1010, 424, 58 },
   { 3165, 3167, 58 },
   { 1001, 449, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2680, 3, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1323, 1125, 0 },
   { 1324, 1125, 0 },
   { 1326, 1133, 0 },
   { 1758, 1765, 0 },
   { 1863, 1870, 0 },
   { 1943, 1950, 0 },
   { 3007, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 938, 939, 0 },
   { 985, 984, 0 },
   { 992, 991, 0 },
   { 1000, 998, 0 },
   { 1009, 1007, 0 },
   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 987, 986, 0 },
   { 994, 993, 0 },
   { 1002, 1001, 0 },
   { 1011, 1010, 0 },
   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 983, 984, 0 },
   { 990, 991, 0 },
   { 997, 998, 0 },
   { 1006, 1007, 0 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2696, 32, 0 },
   { 3162, 3163, 58 },
   { 1010, 424, 58 },
   { 3165, 3167, 58 },
   { 1001, 449, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 198, 200, 0 },
   { 2668, 32, 0 },
   { 2678, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2696, 32, 0 },
   { 3162, 3163, 58 },
   { 1010, 424, 58 },
   { 3165, 3167, 58 },
   { 1001, 449, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2680, 3, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 938, 939, 0 },
   { 985, 984, 0 },
   { 992, 991, 0 },
   { 1000, 998, 0 },
   { 1009, 1007, 0 },
   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 987, 986, 0 },
   { 994, 993, 0 },
   { 1002, 1001, 0 },
   { 1011, 1010, 0 },
   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 983, 984, 0 },
   { 990, 991, 0 },
   { 997, 998, 0 },
   { 1006, 1007, 0 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2696, 32, 0 },
   { 3162, 3163, 58 },
   { 1010, 424, 58 },
   { 3165, 3167, 58 },
   { 1001, 449, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 198, 200, 0 },
   { 2668, 32, 0 },
   { 2678, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2696, 32, 0 },
   { 3162, 3163, 58 },
   { 1010, 424, 58 },
   { 3165, 3167, 58 },
   { 1001, 449, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 2680, 3, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 938, 939, 0 },
   { 985, 984, 0 },
   { 992, 991, 0 },
   { 1000, 998, 0 },
   { 1009, 1007, 0 },
   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 987, 986, 0 },
   { 994, 993, 0 },
   { 1002, 1001, 0 },
   { 1011, 1010, 0 },
   { 2646, 2647, 0 },
   { 2649, 2650, 0 },
   { 2663, 32, 0 },
   { 2664, 61, 0 },
   { 2665, 32, 0 },
   { 3173, 3174, 58 },
   { 3204, 3205, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 983, 984, 0 },
   { 990, 991, 0 },
   { 997, 998, 0 },
   { 1006, 1007, 0 },
   { 2690, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2696, 32, 0 },
   { 3162, 3163, 58 },
   { 1010, 424, 58 },
   { 3165, 3167, 58 },
   { 1001, 449, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 198, 200, 0 },
   { 2668, 32, 0 },
   { 2678, 3, 0 },
   { 5320, 5245, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2668, 32, 0 },
   { 5244, 5245, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_pass_op_table[nir_num_search_ops] = {
   [nir_op_imul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         10,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         13,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         5,
         13,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         12,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         17,
         15,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         2,
         3,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2107,
         2108,
         2109,
         2110,
         3,
         3,
         360,
         361,
         362,
         363,
         364,
         3,
         365,
         366,
         367,
         368,
         2111,
         2112,
         2113,
         2114,
         2115,
         2116,
         2,
         360,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2107,
         2108,
         2109,
         2110,
         2,
         361,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2107,
         2108,
         2109,
         2110,
         355,
         362,
         355,
         355,
         355,
         355,
         355,
         355,
         369,
         370,
         371,
         372,
         355,
         355,
         2117,
         2118,
         2119,
         2120,
         2,
         363,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2107,
         2108,
         2109,
         2110,
         2,
         364,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2107,
         2108,
         2109,
         2110,
         2,
         3,
         2,
         2,
         355,
         2,
         2,
         373,
         356,
         357,
         358,
         359,
         2,
         2,
         2107,
         2108,
         2109,
         2110,
         356,
         365,
         356,
         356,
         369,
         356,
         356,
         356,
         356,
         374,
         375,
         376,
         356,
         356,
         2121,
         2122,
         2123,
         2124,
         357,
         366,
         357,
         357,
         370,
         357,
         357,
         357,
         374,
         357,
         377,
         378,
         357,
         357,
         2125,
         2126,
         2127,
         2128,
         358,
         367,
         358,
         358,
         371,
         358,
         358,
         358,
         375,
         377,
         358,
         379,
         358,
         358,
         2129,
         2130,
         2131,
         2132,
         359,
         368,
         359,
         359,
         372,
         359,
         359,
         359,
         376,
         378,
         379,
         359,
         359,
         359,
         2133,
         2134,
         2135,
         2136,
         2,
         2111,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2107,
         2108,
         2109,
         2110,
         2,
         2112,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2107,
         2108,
         2109,
         2110,
         2107,
         2113,
         2107,
         2107,
         2117,
         2107,
         2107,
         2107,
         2121,
         2125,
         2129,
         2133,
         2107,
         2107,
         2107,
         2137,
         2138,
         2139,
         2108,
         2114,
         2108,
         2108,
         2118,
         2108,
         2108,
         2108,
         2122,
         2126,
         2130,
         2134,
         2108,
         2108,
         2137,
         2108,
         2140,
         2141,
         2109,
         2115,
         2109,
         2109,
         2119,
         2109,
         2109,
         2109,
         2123,
         2127,
         2131,
         2135,
         2109,
         2109,
         2138,
         2140,
         2109,
         2142,
         2110,
         2116,
         2110,
         2110,
         2120,
         2110,
         2110,
         2110,
         2124,
         2128,
         2132,
         2136,
         2110,
         2110,
         2139,
         2141,
         2142,
         2110,
      },
   },
   [nir_op_ishl] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         0,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         4,
         14,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         4,
         14,
         13,
         13,
         13,
         13,
         13,
         4,
         4,
         4,
         4,
         0,
         11,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         17,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         3,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         19,
         0,
         5,
         5,
         3,
         6,
         20,
         15,
         3,
         6,
         21,
         5,
         5,
         3,
         6,
         22,
         15,
         3,
         6,
         23,
         5,
         5,
         3,
         6,
         0,
         15,
      },
      
      .num_filtered_states = 24,
      .table = (const uint16_t []) {
      
         4,
         5,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         6,
         7,
         6,
         6,
         6,
         1085,
         6,
         6,
         6,
         1086,
         6,
         6,
         6,
         2144,
         6,
         6,
         6,
         1085,
         6,
         1085,
         6,
         1085,
         6,
         1085,
         4,
         1087,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1088,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1089,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1090,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         1091,
         1092,
         1091,
         1091,
         1091,
         1093,
         1091,
         1091,
         1091,
         1094,
         1091,
         1091,
         1091,
         2145,
         1091,
         1091,
         1091,
         1093,
         1091,
         1093,
         1091,
         1093,
         1091,
         1093,
         1095,
         1096,
         1095,
         1095,
         1095,
         1097,
         1095,
         1095,
         1095,
         1098,
         1095,
         1095,
         1095,
         2146,
         1095,
         1095,
         1095,
         1097,
         1095,
         1097,
         1095,
         1097,
         1095,
         1097,
         4,
         1099,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         5,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1100,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2147,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2148,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1089,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2149,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2150,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2151,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2830,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2923,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2929,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2933,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2938,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2942,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         2947,
         4,
         4,
         4,
         1083,
         4,
         4,
         4,
         1084,
         4,
         4,
         4,
         2143,
         4,
         4,
         4,
         1083,
         4,
         1083,
         4,
         1083,
         4,
         1083,
      },
   },
   [nir_op_unpack_64_2x32_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         8,
         1324,
         1325,
         1326,
         1327,
         1328,
         1329,
         1330,
      },
   },
   [nir_op_imul_2x32_64] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         9,
      },
   },
   [nir_op_umul_2x32_64] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_udiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         11,
         0,
         11,
      },
   },
   [nir_op_idiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         12,
         0,
         0,
         12,
         0,
         380,
         381,
         380,
      },
   },
   [nir_op_umod] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         13,
         0,
         13,
      },
   },
   [nir_op_imod] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         14,
         0,
         14,
      },
   },
   [nir_op_irem] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         15,
         0,
         15,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         8,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         14,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         15,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         10,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         17,
         5,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         9,
         9,
         9,
         9,
         9,
         9,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         5,
         5,
         5,
         5,
         5,
         5,
         15,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         17,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         5,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         16,
         1331,
         1332,
         1333,
         1334,
         1335,
         1336,
         1337,
         1338,
         1339,
         1340,
         1341,
         1342,
         1343,
         2487,
         2488,
         2489,
         2823,
      },
   },
   [nir_op_ineg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         11,
         5,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         17,
         1608,
         1609,
         1610,
         1611,
         1612,
         1613,
         1614,
         1615,
         1616,
         1617,
         2754,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         18,
         1344,
         1345,
         1346,
         1347,
         1348,
         1349,
         1350,
         1351,
         2160,
         2161,
         2162,
      },
   },
   [nir_search_op_u2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         19,
         1958,
         1959,
         1960,
      },
   },
   [nir_op_iabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         20,
         1618,
         1619,
         1620,
         2407,
      },
   },
   [nir_search_op_f2b] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         21,
         1352,
         1353,
      },
   },
   [nir_search_op_i2b] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         22,
         1621,
         1622,
         1623,
         1624,
         1625,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         7,
         8,
         7,
         8,
         7,
         8,
         9,
         10,
         9,
         10,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         14,
         2,
         2,
         15,
         16,
         17,
         18,
         19,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         3,
         21,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         20,
         3,
         3,
         3,
         3,
         3,
         5,
         22,
         5,
         5,
         23,
         24,
         5,
         5,
         5,
         5,
         5,
         22,
         5,
         5,
         5,
         23,
         24,
         22,
         5,
         5,
         23,
         24,
         5,
         22,
         22,
         22,
         25,
         26,
         5,
         23,
         24,
         23,
         24,
         5,
         23,
         27,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         9,
         9,
         9,
         10,
         9,
         9,
         9,
         10,
         9,
         9,
         28,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         30,
         31,
         5,
         5,
         30,
         31,
         5,
         5,
         5,
         30,
         31,
         5,
         22,
         32,
         33,
         34,
         22,
         5,
         30,
         31,
         5,
         30,
         31,
         5,
         23,
         35,
         36,
         23,
         24,
         37,
         38,
         24,
         5,
         5,
         30,
         31,
         5,
         30,
         31,
         31,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         39,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         28,
         28,
         11,
         11,
         11,
         20,
         3,
         21,
         21,
         21,
         21,
         21,
         21,
         4,
         4,
         20,
         20,
         3,
         20,
         20,
         3,
         0,
         2,
         40,
         41,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         21,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         20,
         20,
         3,
         3,
         3,
         3,
         20,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         43,
         44,
         43,
         44,
         43,
         44,
         43,
         45,
         43,
         44,
         43,
         44,
         46,
         47,
         48,
         49,
         43,
         44,
         50,
         51,
         52,
         44,
         43,
         44,
         53,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         21,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 54,
      .table = (const uint16_t []) {
      
         23,
         24,
         1354,
         1355,
         1355,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         1354,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         24,
         24,
         1356,
         1357,
         1358,
         24,
         24,
         1359,
         1360,
         1361,
         1362,
         24,
         1363,
         24,
         2472,
         2473,
         2474,
         2475,
         2476,
         2477,
         2478,
         2479,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         2801,
         2801,
         2802,
         2801,
         2801,
         2803,
         2803,
         2801,
         2801,
         2804,
         2805,
         2476,
         2910,
         24,
         2801,
         2801,
         24,
         2803,
         24,
         2801,
         2802,
         2801,
         2801,
         2801,
         1354,
         1356,
         1354,
         1364,
         1364,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2480,
         2480,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2806,
         2806,
         2807,
         2807,
         2806,
         2806,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2807,
         1354,
         2806,
         1354,
         2806,
         2806,
         2806,
         1355,
         1357,
         1364,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1364,
         1364,
         1364,
         1364,
         1364,
         2481,
         2471,
         2471,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         2808,
         2808,
         1355,
         2808,
         2808,
         2809,
         2809,
         2808,
         2808,
         1355,
         1364,
         1364,
         1364,
         1355,
         2808,
         2808,
         1355,
         2809,
         1355,
         2808,
         1355,
         2808,
         2808,
         2808,
         1355,
         1358,
         1364,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1364,
         1364,
         1364,
         1364,
         1364,
         2481,
         2471,
         2471,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         1355,
         2808,
         2808,
         1355,
         2808,
         2808,
         2809,
         2809,
         2808,
         2808,
         1355,
         1364,
         1364,
         1364,
         1355,
         2808,
         2808,
         1355,
         2809,
         1355,
         2808,
         1355,
         2808,
         2808,
         2808,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1365,
         1365,
         1365,
         1365,
         1365,
         1365,
         23,
         23,
         2810,
         2811,
         1365,
         2810,
         2811,
         2812,
         2813,
         2810,
         2811,
         23,
         1354,
         1354,
         1354,
         1365,
         2811,
         2811,
         1365,
         2813,
         1365,
         2811,
         1365,
         2810,
         2811,
         2811,
         23,
         24,
         1354,
         1355,
         1355,
         23,
         1367,
         23,
         23,
         1368,
         1368,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         1354,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         23,
         1359,
         1354,
         1355,
         1355,
         1366,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1366,
         1366,
         1366,
         1366,
         1366,
         1366,
         23,
         23,
         2814,
         2814,
         1366,
         2814,
         2814,
         2815,
         2815,
         2814,
         2814,
         23,
         1354,
         1354,
         1354,
         1366,
         2814,
         2814,
         1366,
         2815,
         1366,
         2814,
         1366,
         2814,
         2814,
         2814,
         23,
         1360,
         1354,
         1355,
         1355,
         1366,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1366,
         1366,
         1366,
         1366,
         1366,
         1366,
         23,
         23,
         2814,
         2814,
         1366,
         2814,
         2814,
         2815,
         2815,
         2814,
         2814,
         23,
         1354,
         1354,
         1354,
         1366,
         2814,
         2814,
         1366,
         2815,
         1366,
         2814,
         1366,
         2814,
         2814,
         2814,
         23,
         1361,
         1354,
         1355,
         1355,
         23,
         1368,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         1354,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         23,
         1362,
         1354,
         1355,
         1355,
         23,
         1368,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         1354,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         23,
         24,
         1354,
         1355,
         1355,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         2482,
         23,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         1354,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         23,
         1363,
         1354,
         1355,
         1355,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         1354,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         23,
         24,
         1354,
         1355,
         1355,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1369,
         1354,
         1354,
         1354,
         1354,
         2483,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1369,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         2483,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         1354,
         2472,
         1354,
         1364,
         1364,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2480,
         2480,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2806,
         2806,
         2807,
         2807,
         2806,
         2806,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2807,
         1354,
         2806,
         1354,
         2806,
         2806,
         2806,
         1354,
         2473,
         1354,
         1364,
         1364,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2480,
         2480,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2806,
         2806,
         2807,
         2807,
         2806,
         2806,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2807,
         1354,
         2806,
         1354,
         2806,
         2806,
         2806,
         1354,
         2474,
         1354,
         1364,
         1364,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2480,
         2480,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2806,
         2806,
         2807,
         2807,
         2806,
         2806,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2807,
         1354,
         2806,
         1354,
         2806,
         2806,
         2806,
         1354,
         2475,
         1354,
         1364,
         1364,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2480,
         2480,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2806,
         2806,
         2807,
         2807,
         2806,
         2806,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2807,
         1354,
         2806,
         1354,
         2806,
         2806,
         2806,
         1354,
         2476,
         1354,
         1364,
         1364,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2483,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2480,
         2480,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2483,
         2806,
         2806,
         1354,
         2806,
         2806,
         2807,
         2807,
         2806,
         2806,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2807,
         1354,
         2806,
         1354,
         2806,
         2806,
         2806,
         2470,
         2477,
         2470,
         2481,
         2481,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2484,
         2484,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2470,
         2816,
         2816,
         2470,
         2816,
         2816,
         2817,
         2817,
         2816,
         2816,
         2470,
         2470,
         2470,
         2470,
         2470,
         2816,
         2816,
         2470,
         2817,
         2470,
         2816,
         2470,
         2816,
         2816,
         2816,
         2471,
         2478,
         2480,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2480,
         2480,
         2480,
         2480,
         2480,
         2484,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2818,
         2818,
         2471,
         2818,
         2818,
         2819,
         2819,
         2818,
         2818,
         2471,
         2480,
         2480,
         2480,
         2471,
         2818,
         2818,
         2471,
         2819,
         2471,
         2818,
         2471,
         2818,
         2818,
         2818,
         2471,
         2479,
         2480,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2480,
         2480,
         2480,
         2480,
         2480,
         2484,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2471,
         2818,
         2818,
         2471,
         2818,
         2818,
         2819,
         2819,
         2818,
         2818,
         2471,
         2480,
         2480,
         2480,
         2471,
         2818,
         2818,
         2471,
         2819,
         2471,
         2818,
         2471,
         2818,
         2818,
         2818,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1365,
         1365,
         1365,
         1365,
         1365,
         1365,
         23,
         23,
         2810,
         2811,
         1365,
         2810,
         2811,
         2812,
         2813,
         2810,
         2811,
         23,
         1354,
         1354,
         1354,
         2911,
         2811,
         2811,
         2911,
         2813,
         2911,
         2811,
         2911,
         2912,
         2913,
         2913,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1365,
         1365,
         1365,
         1365,
         1365,
         1365,
         23,
         23,
         2810,
         2811,
         1365,
         2810,
         2811,
         2812,
         2813,
         2810,
         2811,
         23,
         1354,
         1354,
         1354,
         1365,
         2914,
         2914,
         1365,
         2915,
         1365,
         2914,
         1365,
         2810,
         2811,
         2914,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1365,
         1365,
         2485,
         1365,
         2485,
         2485,
         23,
         23,
         2810,
         2811,
         1365,
         2810,
         2811,
         2812,
         2813,
         2820,
         2821,
         23,
         1354,
         1354,
         1354,
         1365,
         2811,
         2811,
         1365,
         2813,
         2485,
         2821,
         1365,
         2810,
         2811,
         2811,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1365,
         1365,
         1365,
         1365,
         1365,
         1365,
         23,
         23,
         2810,
         2811,
         1365,
         2810,
         2811,
         2812,
         2813,
         2810,
         2811,
         23,
         1354,
         1354,
         1354,
         2911,
         2914,
         2914,
         2911,
         2915,
         2911,
         2914,
         2911,
         2912,
         2913,
         2916,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1365,
         1365,
         2485,
         1365,
         2485,
         2485,
         23,
         23,
         2810,
         2811,
         1365,
         2810,
         2811,
         2812,
         2813,
         2820,
         2821,
         23,
         1354,
         1354,
         1354,
         2911,
         2811,
         2811,
         2911,
         2813,
         2917,
         2821,
         2911,
         2912,
         2913,
         2913,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1365,
         1365,
         2485,
         1365,
         2485,
         2485,
         23,
         23,
         2810,
         2811,
         1365,
         2810,
         2811,
         2812,
         2813,
         2820,
         2821,
         23,
         1354,
         1354,
         1354,
         1365,
         2914,
         2914,
         1365,
         2915,
         2485,
         2918,
         1365,
         2810,
         2811,
         2914,
         23,
         24,
         1354,
         1355,
         1355,
         23,
         23,
         23,
         23,
         23,
         23,
         2482,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         2482,
         23,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         1354,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         23,
         24,
         1354,
         1355,
         1355,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1369,
         1354,
         1354,
         1354,
         1354,
         2483,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1369,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         2822,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         2799,
         2801,
         2806,
         2808,
         2808,
         2810,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2799,
         2799,
         2810,
         2811,
         2810,
         2810,
         2811,
         2812,
         2813,
         2810,
         2811,
         2799,
         2806,
         2806,
         2806,
         2810,
         2811,
         2811,
         2810,
         2813,
         2810,
         2811,
         2810,
         2810,
         2811,
         2811,
         2799,
         2801,
         2806,
         2808,
         2808,
         2811,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2811,
         2811,
         2811,
         2811,
         2811,
         2811,
         2799,
         2799,
         2811,
         2811,
         2811,
         2811,
         2811,
         2813,
         2813,
         2811,
         2811,
         2799,
         2806,
         2806,
         2806,
         2811,
         2811,
         2811,
         2811,
         2813,
         2811,
         2811,
         2811,
         2811,
         2811,
         2811,
         23,
         2802,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         1365,
         1365,
         1365,
         1365,
         1365,
         1365,
         23,
         23,
         2810,
         2811,
         1365,
         2810,
         2811,
         2812,
         2813,
         2810,
         2811,
         23,
         1354,
         1354,
         1354,
         2911,
         2811,
         2811,
         2911,
         2813,
         2911,
         2811,
         2911,
         2912,
         2913,
         2913,
         2799,
         2801,
         2806,
         2808,
         2808,
         2810,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2810,
         2810,
         2810,
         2810,
         2810,
         2810,
         2799,
         2799,
         2810,
         2811,
         2810,
         2810,
         2811,
         2812,
         2813,
         2810,
         2811,
         2799,
         2806,
         2806,
         2806,
         2912,
         2811,
         2811,
         2912,
         2813,
         2912,
         2811,
         2912,
         2912,
         2913,
         2913,
         2799,
         2801,
         2806,
         2808,
         2808,
         2811,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2811,
         2811,
         2811,
         2811,
         2811,
         2811,
         2799,
         2799,
         2811,
         2811,
         2811,
         2811,
         2811,
         2813,
         2813,
         2811,
         2811,
         2799,
         2806,
         2806,
         2806,
         2913,
         2811,
         2811,
         2913,
         2813,
         2913,
         2811,
         2913,
         2913,
         2913,
         2913,
         2800,
         2803,
         2807,
         2809,
         2809,
         2812,
         2800,
         2815,
         2815,
         2800,
         2800,
         2800,
         2800,
         2800,
         2807,
         2807,
         2807,
         2807,
         2807,
         2817,
         2819,
         2819,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2800,
         2800,
         2812,
         2813,
         2812,
         2812,
         2813,
         2812,
         2813,
         2812,
         2813,
         2800,
         2807,
         2807,
         2807,
         2812,
         2915,
         2915,
         2812,
         2915,
         2812,
         2915,
         2812,
         2812,
         2813,
         2915,
         2800,
         2803,
         2807,
         2809,
         2809,
         2813,
         2800,
         2815,
         2815,
         2800,
         2800,
         2800,
         2800,
         2800,
         2807,
         2807,
         2807,
         2807,
         2807,
         2817,
         2819,
         2819,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2800,
         2800,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2813,
         2800,
         2807,
         2807,
         2807,
         2813,
         2915,
         2915,
         2813,
         2915,
         2813,
         2915,
         2813,
         2813,
         2813,
         2915,
         2799,
         2801,
         2806,
         2808,
         2808,
         2810,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2810,
         2810,
         2820,
         2810,
         2820,
         2820,
         2799,
         2799,
         2810,
         2811,
         2810,
         2810,
         2811,
         2812,
         2813,
         2820,
         2821,
         2799,
         2806,
         2806,
         2806,
         2810,
         2811,
         2811,
         2810,
         2813,
         2820,
         2821,
         2810,
         2810,
         2811,
         2811,
         2799,
         2801,
         2806,
         2808,
         2808,
         2811,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2811,
         2811,
         2821,
         2811,
         2821,
         2821,
         2799,
         2799,
         2811,
         2811,
         2811,
         2811,
         2811,
         2813,
         2813,
         2821,
         2821,
         2799,
         2806,
         2806,
         2806,
         2811,
         2811,
         2811,
         2811,
         2813,
         2821,
         2821,
         2811,
         2811,
         2811,
         2811,
         23,
         2804,
         1354,
         1355,
         1355,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         2799,
         2799,
         23,
         2799,
         2799,
         2800,
         2800,
         2799,
         2799,
         23,
         1354,
         1354,
         1354,
         23,
         2799,
         2799,
         23,
         2800,
         23,
         2799,
         23,
         2799,
         2799,
         2799,
         1354,
         2805,
         1354,
         1364,
         1364,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2480,
         2480,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2806,
         2806,
         2807,
         2807,
         2806,
         2806,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2807,
         1354,
         2806,
         1354,
         2806,
         2806,
         2806,
         1354,
         2476,
         1354,
         1364,
         1364,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2483,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2480,
         2480,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2822,
         2806,
         2806,
         1354,
         2806,
         2806,
         2807,
         2807,
         2806,
         2806,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2807,
         1354,
         2806,
         1354,
         2806,
         2806,
         2806,
         1354,
         2910,
         1354,
         1364,
         1364,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2480,
         2480,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2806,
         2806,
         2807,
         2807,
         2806,
         2806,
         1354,
         1354,
         1354,
         1354,
         1354,
         2806,
         2806,
         1354,
         2807,
         1354,
         2806,
         1354,
         2806,
         2806,
         2806,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         2911,
         1365,
         1365,
         2911,
         2911,
         1365,
         23,
         23,
         2810,
         2811,
         2911,
         2912,
         2913,
         2812,
         2813,
         2810,
         2811,
         23,
         1354,
         1354,
         1354,
         2911,
         2811,
         2913,
         2911,
         2813,
         2911,
         2811,
         2911,
         2912,
         2913,
         2913,
         2799,
         2801,
         2806,
         2808,
         2808,
         2811,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2811,
         2914,
         2811,
         2914,
         2811,
         2914,
         2799,
         2799,
         2811,
         2811,
         2811,
         2811,
         2811,
         2915,
         2915,
         2811,
         2811,
         2799,
         2806,
         2806,
         2806,
         2811,
         2811,
         2811,
         2914,
         2915,
         2811,
         2811,
         2811,
         2811,
         2811,
         2811,
         2799,
         2801,
         2806,
         2808,
         2808,
         2811,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2811,
         2914,
         2811,
         2914,
         2811,
         2914,
         2799,
         2799,
         2811,
         2811,
         2811,
         2811,
         2811,
         2915,
         2915,
         2811,
         2811,
         2799,
         2806,
         2806,
         2806,
         2913,
         2811,
         2811,
         2916,
         2915,
         2913,
         2811,
         2913,
         2913,
         2913,
         2913,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         2911,
         1365,
         1365,
         2911,
         2911,
         1365,
         23,
         23,
         2810,
         2811,
         2911,
         2912,
         2913,
         2812,
         2813,
         2810,
         2811,
         23,
         1354,
         1354,
         1354,
         2911,
         2914,
         2916,
         2911,
         2915,
         2911,
         2914,
         2911,
         2912,
         2913,
         2916,
         2800,
         2803,
         2807,
         2809,
         2809,
         2813,
         2800,
         2815,
         2815,
         2800,
         2800,
         2800,
         2800,
         2800,
         2807,
         2807,
         2807,
         2807,
         2807,
         2817,
         2819,
         2819,
         2813,
         2915,
         2813,
         2915,
         2813,
         2915,
         2800,
         2800,
         2813,
         2813,
         2813,
         2813,
         2813,
         2915,
         2915,
         2813,
         2813,
         2800,
         2807,
         2807,
         2807,
         2813,
         2915,
         2915,
         2915,
         2915,
         2813,
         2915,
         2813,
         2813,
         2813,
         2915,
         23,
         24,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         2911,
         1365,
         2485,
         2911,
         2917,
         2485,
         23,
         23,
         2810,
         2811,
         2911,
         2912,
         2913,
         2812,
         2813,
         2820,
         2821,
         23,
         1354,
         1354,
         1354,
         2911,
         2811,
         2913,
         2911,
         2813,
         2917,
         2821,
         2911,
         2912,
         2913,
         2913,
         2799,
         2801,
         2806,
         2808,
         2808,
         2811,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2811,
         2914,
         2821,
         2914,
         2821,
         2918,
         2799,
         2799,
         2811,
         2811,
         2811,
         2811,
         2811,
         2915,
         2915,
         2821,
         2821,
         2799,
         2806,
         2806,
         2806,
         2811,
         2811,
         2811,
         2914,
         2915,
         2821,
         2821,
         2811,
         2811,
         2811,
         2811,
         23,
         2802,
         1354,
         1355,
         1355,
         1365,
         23,
         1366,
         1366,
         23,
         23,
         23,
         23,
         23,
         1354,
         1354,
         1354,
         1354,
         1354,
         2470,
         2471,
         2471,
         2911,
         1365,
         1365,
         2911,
         2911,
         1365,
         23,
         23,
         2810,
         2811,
         2911,
         2912,
         2913,
         2812,
         2813,
         2810,
         2811,
         23,
         1354,
         1354,
         1354,
         2911,
         2811,
         2913,
         2911,
         2813,
         2911,
         2811,
         2911,
         2912,
         2913,
         2913,
         2799,
         2801,
         2806,
         2808,
         2808,
         2810,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2912,
         2810,
         2810,
         2912,
         2912,
         2810,
         2799,
         2799,
         2810,
         2811,
         2912,
         2912,
         2913,
         2812,
         2813,
         2810,
         2811,
         2799,
         2806,
         2806,
         2806,
         2912,
         2811,
         2913,
         2912,
         2813,
         2912,
         2811,
         2912,
         2912,
         2913,
         2913,
         2799,
         2801,
         2806,
         2808,
         2808,
         2811,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2913,
         2811,
         2811,
         2913,
         2913,
         2811,
         2799,
         2799,
         2811,
         2811,
         2913,
         2913,
         2913,
         2813,
         2813,
         2811,
         2811,
         2799,
         2806,
         2806,
         2806,
         2913,
         2811,
         2913,
         2913,
         2813,
         2913,
         2811,
         2913,
         2913,
         2913,
         2913,
         2799,
         2801,
         2806,
         2808,
         2808,
         2811,
         2799,
         2814,
         2814,
         2799,
         2799,
         2799,
         2799,
         2799,
         2806,
         2806,
         2806,
         2806,
         2806,
         2816,
         2818,
         2818,
         2913,
         2914,
         2811,
         2916,
         2913,
         2914,
         2799,
         2799,
         2811,
         2811,
         2913,
         2913,
         2913,
         2915,
         2915,
         2811,
         2811,
         2799,
         2806,
         2806,
         2806,
         2913,
         2811,
         2913,
         2916,
         2915,
         2913,
         2811,
         2913,
         2913,
         2913,
         2913,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         3,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         8,
         0,
         8,
         0,
         9,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         10,
         0,
         11,
         0,
         11,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         0,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         16,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         19,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         21,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         22,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         6,
         6,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         23,
         5,
         5,
         5,
         24,
         25,
         26,
         27,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         32,
         32,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         33,
         34,
         35,
         0,
         0,
         0,
         0,
         0,
         17,
         17,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         22,
         22,
         22,
         22,
         22,
         7,
         7,
         7,
         7,
         21,
         21,
         21,
         21,
         21,
         21,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         31,
         31,
         29,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         13,
         0,
         13,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         13,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 37,
      .table = (const uint16_t []) {
      
         25,
         26,
         25,
         25,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         382,
         26,
         26,
         26,
         393,
         26,
         394,
         395,
         396,
         397,
         398,
         399,
         400,
         401,
         402,
         403,
         404,
         405,
         406,
         26,
         26,
         26,
         2017,
         2018,
         2019,
         2020,
         2021,
         2022,
         2023,
         2024,
         2025,
         2026,
         2027,
         26,
         26,
         26,
         26,
         394,
         25,
         26,
         407,
         407,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         382,
         25,
         393,
         407,
         407,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         382,
         25,
         26,
         25,
         25,
         408,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         382,
         382,
         394,
         382,
         382,
         382,
         382,
         409,
         410,
         411,
         412,
         413,
         414,
         415,
         382,
         416,
         417,
         418,
         419,
         382,
         382,
         382,
         2028,
         2029,
         382,
         382,
         382,
         382,
         382,
         2030,
         2031,
         2032,
         2033,
         382,
         382,
         382,
         382,
         382,
         25,
         395,
         25,
         25,
         25,
         409,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         409,
         409,
         409,
         409,
         409,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         409,
         383,
         396,
         383,
         383,
         383,
         410,
         383,
         383,
         420,
         421,
         422,
         423,
         424,
         383,
         425,
         426,
         427,
         428,
         383,
         383,
         383,
         2012,
         2012,
         410,
         410,
         410,
         410,
         410,
         2034,
         2035,
         2036,
         2037,
         383,
         383,
         383,
         383,
         410,
         384,
         397,
         384,
         384,
         384,
         411,
         384,
         420,
         384,
         429,
         430,
         431,
         432,
         384,
         433,
         434,
         435,
         436,
         384,
         384,
         384,
         2038,
         2039,
         411,
         411,
         411,
         411,
         411,
         2040,
         2041,
         2042,
         2043,
         384,
         384,
         384,
         384,
         411,
         385,
         398,
         385,
         385,
         385,
         412,
         385,
         421,
         429,
         385,
         437,
         438,
         439,
         385,
         440,
         441,
         442,
         443,
         385,
         385,
         385,
         2044,
         2045,
         412,
         412,
         412,
         412,
         412,
         2046,
         2047,
         2048,
         2049,
         385,
         385,
         385,
         385,
         412,
         386,
         399,
         386,
         386,
         386,
         413,
         386,
         422,
         430,
         437,
         386,
         444,
         445,
         386,
         446,
         447,
         448,
         449,
         386,
         386,
         386,
         2050,
         2051,
         413,
         413,
         413,
         413,
         413,
         2052,
         2053,
         2054,
         2055,
         386,
         386,
         386,
         386,
         413,
         387,
         400,
         387,
         387,
         387,
         414,
         387,
         423,
         431,
         438,
         444,
         387,
         450,
         387,
         451,
         452,
         453,
         454,
         387,
         387,
         387,
         2056,
         2057,
         414,
         414,
         414,
         414,
         414,
         2058,
         2059,
         2060,
         2061,
         387,
         387,
         387,
         387,
         414,
         388,
         401,
         388,
         388,
         388,
         415,
         388,
         424,
         432,
         439,
         445,
         450,
         388,
         388,
         455,
         456,
         457,
         458,
         388,
         388,
         388,
         2062,
         2063,
         415,
         415,
         415,
         415,
         415,
         2064,
         2065,
         2066,
         2067,
         388,
         388,
         388,
         388,
         415,
         25,
         402,
         25,
         25,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         382,
         389,
         403,
         389,
         389,
         389,
         416,
         389,
         425,
         433,
         440,
         446,
         451,
         455,
         389,
         389,
         459,
         460,
         461,
         389,
         389,
         389,
         2068,
         2069,
         416,
         416,
         416,
         416,
         416,
         2070,
         2071,
         2072,
         2073,
         389,
         389,
         389,
         389,
         416,
         390,
         404,
         390,
         390,
         390,
         417,
         390,
         426,
         434,
         441,
         447,
         452,
         456,
         390,
         459,
         390,
         462,
         463,
         390,
         390,
         390,
         2074,
         2075,
         417,
         417,
         417,
         417,
         417,
         2076,
         2077,
         2078,
         2079,
         390,
         390,
         390,
         390,
         417,
         391,
         405,
         391,
         391,
         391,
         418,
         391,
         427,
         435,
         442,
         448,
         453,
         457,
         391,
         460,
         462,
         391,
         464,
         391,
         391,
         391,
         2080,
         2081,
         418,
         418,
         418,
         418,
         418,
         2082,
         2083,
         2084,
         2085,
         391,
         391,
         391,
         391,
         418,
         392,
         406,
         392,
         392,
         392,
         419,
         392,
         428,
         436,
         443,
         449,
         454,
         458,
         392,
         461,
         463,
         464,
         392,
         392,
         392,
         392,
         2086,
         2087,
         419,
         419,
         419,
         419,
         419,
         2088,
         2089,
         2090,
         2091,
         392,
         392,
         392,
         392,
         419,
         25,
         26,
         25,
         25,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         465,
         465,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         382,
         25,
         26,
         25,
         25,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         465,
         25,
         465,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         382,
         25,
         26,
         25,
         25,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         465,
         465,
         465,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         382,
         2011,
         2017,
         2011,
         2011,
         2011,
         2028,
         2011,
         2012,
         2038,
         2044,
         2050,
         2056,
         2062,
         2011,
         2068,
         2074,
         2080,
         2086,
         2011,
         2011,
         2011,
         2011,
         2012,
         2028,
         2028,
         2028,
         2028,
         2028,
         2092,
         2093,
         2094,
         2095,
         2011,
         2011,
         2011,
         2011,
         2028,
         2012,
         2018,
         2012,
         2012,
         2012,
         2029,
         2012,
         2012,
         2039,
         2045,
         2051,
         2057,
         2063,
         2012,
         2069,
         2075,
         2081,
         2087,
         2012,
         2012,
         2012,
         2012,
         2012,
         2029,
         2029,
         2029,
         2029,
         2029,
         2096,
         2097,
         2098,
         2099,
         2012,
         2012,
         2012,
         2012,
         2029,
         382,
         2019,
         382,
         382,
         382,
         382,
         409,
         410,
         411,
         412,
         413,
         414,
         415,
         382,
         416,
         417,
         418,
         419,
         382,
         382,
         382,
         2028,
         2029,
         382,
         382,
         382,
         382,
         382,
         2030,
         2031,
         2032,
         2033,
         382,
         382,
         382,
         382,
         382,
         382,
         2020,
         382,
         382,
         382,
         382,
         409,
         410,
         411,
         412,
         413,
         414,
         415,
         382,
         416,
         417,
         418,
         419,
         382,
         382,
         382,
         2028,
         2029,
         382,
         382,
         382,
         382,
         382,
         2030,
         2031,
         2032,
         2033,
         382,
         382,
         382,
         382,
         382,
         382,
         2021,
         382,
         382,
         382,
         382,
         409,
         410,
         411,
         412,
         413,
         414,
         415,
         382,
         416,
         417,
         418,
         419,
         382,
         382,
         382,
         2028,
         2029,
         382,
         382,
         382,
         382,
         382,
         2030,
         2031,
         2032,
         2033,
         382,
         382,
         382,
         382,
         382,
         382,
         2022,
         382,
         382,
         382,
         382,
         409,
         410,
         411,
         412,
         413,
         414,
         415,
         382,
         416,
         417,
         418,
         419,
         382,
         382,
         382,
         2028,
         2029,
         382,
         382,
         382,
         382,
         382,
         2030,
         2031,
         2032,
         2033,
         382,
         382,
         382,
         382,
         382,
         382,
         2023,
         382,
         382,
         382,
         382,
         409,
         410,
         411,
         412,
         413,
         414,
         415,
         382,
         416,
         417,
         418,
         419,
         382,
         382,
         382,
         2028,
         2029,
         382,
         382,
         382,
         382,
         382,
         2030,
         2031,
         2032,
         2033,
         382,
         382,
         382,
         382,
         382,
         2013,
         2024,
         2013,
         2013,
         2013,
         2030,
         2013,
         2034,
         2040,
         2046,
         2052,
         2058,
         2064,
         2013,
         2070,
         2076,
         2082,
         2088,
         2013,
         2013,
         2013,
         2092,
         2096,
         2030,
         2030,
         2030,
         2030,
         2030,
         2013,
         2100,
         2101,
         2102,
         2013,
         2013,
         2013,
         2013,
         2030,
         2014,
         2025,
         2014,
         2014,
         2014,
         2031,
         2014,
         2035,
         2041,
         2047,
         2053,
         2059,
         2065,
         2014,
         2071,
         2077,
         2083,
         2089,
         2014,
         2014,
         2014,
         2093,
         2097,
         2031,
         2031,
         2031,
         2031,
         2031,
         2100,
         2014,
         2103,
         2104,
         2014,
         2014,
         2014,
         2014,
         2031,
         2015,
         2026,
         2015,
         2015,
         2015,
         2032,
         2015,
         2036,
         2042,
         2048,
         2054,
         2060,
         2066,
         2015,
         2072,
         2078,
         2084,
         2090,
         2015,
         2015,
         2015,
         2094,
         2098,
         2032,
         2032,
         2032,
         2032,
         2032,
         2101,
         2103,
         2015,
         2105,
         2015,
         2015,
         2015,
         2015,
         2032,
         2016,
         2027,
         2016,
         2016,
         2016,
         2033,
         2016,
         2037,
         2043,
         2049,
         2055,
         2061,
         2067,
         2016,
         2073,
         2079,
         2085,
         2091,
         2016,
         2016,
         2016,
         2095,
         2099,
         2033,
         2033,
         2033,
         2033,
         2033,
         2102,
         2104,
         2105,
         2016,
         2016,
         2016,
         2016,
         2016,
         2033,
         25,
         26,
         25,
         25,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         25,
         25,
         2894,
         25,
         26,
         25,
         25,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         25,
         2106,
         2106,
         382,
         25,
         26,
         25,
         25,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         2106,
         25,
         2106,
         382,
         25,
         26,
         25,
         25,
         25,
         382,
         25,
         383,
         384,
         385,
         386,
         387,
         388,
         25,
         389,
         390,
         391,
         392,
         25,
         25,
         25,
         2011,
         2012,
         382,
         382,
         382,
         382,
         382,
         2013,
         2014,
         2015,
         2016,
         25,
         2106,
         2106,
         2106,
         382,
         382,
         394,
         382,
         382,
         382,
         382,
         409,
         410,
         411,
         412,
         413,
         414,
         415,
         382,
         416,
         417,
         418,
         419,
         382,
         382,
         382,
         2028,
         2029,
         382,
         382,
         382,
         382,
         382,
         2030,
         2031,
         2032,
         2033,
         2894,
         382,
         382,
         382,
         382,
      },
   },
   [nir_op_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         27,
         28,
         28,
         28,
      },
   },
   [nir_op_isub_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         29,
         30,
         29,
         30,
      },
   },
   [nir_op_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         31,
         32,
         32,
         32,
      },
   },
   [nir_op_usub_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         33,
         34,
         33,
         34,
      },
   },
   [nir_op_usadd_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         35,
         35,
         35,
      },
   },
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         9,
         10,
         0,
         0,
         11,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         16,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         17,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         20,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         21,
         4,
         4,
         4,
         4,
         3,
         20,
         3,
         3,
         3,
         20,
         3,
         20,
         3,
         3,
         3,
         20,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         20,
         20,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         22,
         7,
         18,
         0,
         19,
         19,
         19,
         19,
         23,
         19,
         0,
         0,
         18,
         18,
         0,
         18,
         18,
         0,
         0,
         2,
         2,
         2,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         19,
         18,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         18,
         0,
         0,
         0,
         0,
         18,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 25,
      .table = (const uint16_t []) {
      
         36,
         37,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1372,
         36,
         1373,
         36,
         1374,
         1375,
         36,
         36,
         2177,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
         37,
         37,
         1376,
         1377,
         1378,
         1379,
         1380,
         1381,
         1382,
         1383,
         1384,
         37,
         1385,
         1386,
         37,
         1383,
         2181,
         1376,
         2182,
         2183,
         2184,
         2185,
         2852,
         2853,
         2909,
         1370,
         1376,
         1370,
         1370,
         1370,
         1370,
         1370,
         1387,
         1388,
         1370,
         1389,
         1370,
         1390,
         1391,
         1370,
         1370,
         2186,
         1370,
         2187,
         2188,
         2189,
         2189,
         2854,
         2855,
         1370,
         36,
         1377,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1392,
         36,
         1373,
         36,
         1374,
         1375,
         36,
         36,
         2177,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
         36,
         1378,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1392,
         36,
         1373,
         36,
         1374,
         1375,
         36,
         36,
         2177,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
         36,
         1379,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1372,
         36,
         1373,
         36,
         1374,
         1375,
         36,
         36,
         2177,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
         36,
         1380,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1372,
         36,
         1373,
         36,
         1374,
         1375,
         36,
         36,
         2177,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
         1371,
         1381,
         1387,
         1371,
         1371,
         1371,
         1371,
         1393,
         1394,
         1371,
         1395,
         1371,
         1396,
         1397,
         1371,
         1371,
         2190,
         2191,
         2192,
         2193,
         2194,
         2194,
         2856,
         2857,
         1371,
         1372,
         1382,
         1388,
         1392,
         1392,
         1372,
         1372,
         1394,
         1372,
         1372,
         1398,
         1372,
         1399,
         1400,
         1372,
         1372,
         2195,
         1388,
         2196,
         2197,
         2198,
         2198,
         2858,
         2859,
         1372,
         36,
         1383,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1372,
         36,
         1373,
         36,
         1374,
         1375,
         36,
         36,
         2177,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
         1373,
         1384,
         1389,
         1373,
         1373,
         1373,
         1373,
         1395,
         1398,
         1373,
         1373,
         1373,
         1401,
         1402,
         1373,
         1373,
         2177,
         1389,
         2199,
         2200,
         2201,
         2201,
         2860,
         2861,
         1373,
         36,
         37,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1372,
         36,
         1373,
         1403,
         1374,
         1375,
         36,
         36,
         2177,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
         1374,
         1385,
         1390,
         1374,
         1374,
         1374,
         1374,
         1396,
         1399,
         1374,
         1401,
         1374,
         1404,
         1405,
         1374,
         1374,
         2202,
         1390,
         2203,
         2204,
         2205,
         2205,
         2862,
         2863,
         1374,
         1375,
         1386,
         1391,
         1375,
         1375,
         1375,
         1375,
         1397,
         1400,
         1375,
         1402,
         1375,
         1405,
         1375,
         1375,
         1375,
         2206,
         1391,
         2207,
         2208,
         2209,
         2209,
         2864,
         2865,
         1375,
         36,
         37,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1372,
         36,
         1373,
         36,
         1374,
         1375,
         1406,
         36,
         2177,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
         36,
         1383,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1372,
         36,
         1373,
         36,
         1374,
         1375,
         36,
         2210,
         2211,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
         2177,
         2181,
         2186,
         2177,
         2177,
         2177,
         2177,
         2190,
         2195,
         2177,
         2177,
         2177,
         2202,
         2206,
         2177,
         2211,
         2211,
         2186,
         2212,
         2213,
         2214,
         2214,
         2866,
         2867,
         2177,
         1370,
         1376,
         1370,
         1370,
         1370,
         1370,
         1370,
         2191,
         1388,
         1370,
         1389,
         1370,
         1390,
         1391,
         1370,
         1370,
         2186,
         1370,
         2187,
         2188,
         2189,
         2189,
         2868,
         2855,
         1370,
         2178,
         2182,
         2187,
         2178,
         2178,
         2178,
         2178,
         2192,
         2196,
         2178,
         2199,
         2178,
         2203,
         2207,
         2178,
         2178,
         2212,
         2187,
         2178,
         2179,
         2215,
         2215,
         2869,
         2851,
         2178,
         2179,
         2183,
         2188,
         2179,
         2179,
         2179,
         2179,
         2193,
         2197,
         2179,
         2200,
         2179,
         2204,
         2208,
         2179,
         2179,
         2213,
         2188,
         2179,
         2216,
         2217,
         2217,
         2870,
         2871,
         2179,
         2180,
         2184,
         2189,
         2180,
         2180,
         2180,
         2180,
         2194,
         2198,
         2180,
         2201,
         2180,
         2205,
         2209,
         2180,
         2180,
         2214,
         2189,
         2215,
         2217,
         2180,
         2180,
         2872,
         2873,
         2180,
         2180,
         2185,
         2189,
         2180,
         2180,
         2180,
         2180,
         2194,
         2198,
         2180,
         2201,
         2180,
         2205,
         2209,
         2180,
         2180,
         2214,
         2189,
         2215,
         2217,
         2180,
         2180,
         2872,
         2873,
         2180,
         2850,
         2852,
         2854,
         2850,
         2850,
         2850,
         2850,
         2856,
         2858,
         2850,
         2860,
         2850,
         2862,
         2864,
         2850,
         2850,
         2866,
         2868,
         2869,
         2870,
         2872,
         2872,
         2856,
         2874,
         2850,
         2851,
         2853,
         2855,
         2851,
         2851,
         2851,
         2851,
         2857,
         2859,
         2851,
         2861,
         2851,
         2863,
         2865,
         2851,
         2851,
         2867,
         2855,
         2851,
         2871,
         2873,
         2873,
         2874,
         2871,
         2851,
         36,
         2909,
         1370,
         36,
         36,
         36,
         36,
         1371,
         1372,
         36,
         1373,
         36,
         1374,
         1375,
         36,
         36,
         2177,
         1370,
         2178,
         2179,
         2180,
         2180,
         2850,
         2851,
         36,
      },
   },
   [nir_op_fmulz] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         38,
         39,
         1407,
         38,
         38,
         38,
         1408,
         38,
         39,
         39,
         1409,
         1410,
         1411,
         1412,
         1413,
         39,
         1407,
         1409,
         1407,
         1407,
         1407,
         1407,
         1414,
         1407,
         38,
         1410,
         1407,
         38,
         38,
         38,
         1408,
         38,
         38,
         1411,
         1407,
         38,
         38,
         38,
         1408,
         38,
         38,
         1412,
         1407,
         38,
         38,
         38,
         1408,
         38,
         1408,
         1413,
         1414,
         1408,
         1408,
         1408,
         1408,
         1408,
         38,
         39,
         1407,
         38,
         38,
         38,
         1408,
         1415,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         11,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         12,
         4,
         3,
         3,
         3,
         11,
         3,
         3,
         3,
         3,
         3,
         11,
         3,
         3,
         11,
         3,
         11,
         3,
         3,
         11,
         11,
         3,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         13,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         11,
         11,
         11,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         14,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         10,
         10,
         10,
         15,
         10,
         0,
         0,
         10,
         10,
         0,
         10,
         10,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         10,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         11,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         6,
         6,
         13,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         44,
         45,
         44,
         1425,
         1425,
         44,
         1426,
         44,
         44,
         44,
         44,
         1425,
         1425,
         1426,
         1426,
         44,
         1427,
         1428,
         1427,
         1429,
         1429,
         1427,
         1430,
         1427,
         1427,
         1427,
         1427,
         1429,
         1429,
         1430,
         1430,
         1427,
         1431,
         1432,
         1431,
         1433,
         1433,
         1431,
         1434,
         1431,
         1431,
         1431,
         1431,
         1433,
         1433,
         1434,
         1434,
         1431,
         1435,
         1436,
         1435,
         1437,
         1437,
         1435,
         1438,
         1435,
         1435,
         1435,
         1435,
         1437,
         1437,
         1438,
         1438,
         1435,
         1439,
         1440,
         1439,
         1441,
         1441,
         1439,
         1442,
         1439,
         1439,
         1439,
         1439,
         1441,
         1441,
         1442,
         1442,
         1439,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         2223,
         42,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         2224,
         2225,
         2224,
         2226,
         2226,
         2224,
         2227,
         2224,
         2224,
         2224,
         2224,
         2226,
         2226,
         2227,
         2227,
         2224,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         1431,
         1432,
         1431,
         1433,
         1433,
         1431,
         1434,
         1431,
         1431,
         1431,
         1431,
         1433,
         1433,
         1434,
         1434,
         1431,
         1435,
         1436,
         1435,
         1437,
         1437,
         1435,
         1438,
         1435,
         1435,
         1435,
         1435,
         1437,
         1437,
         1438,
         1438,
         1435,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         2876,
         2876,
         1419,
         1419,
         42,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         1427,
         1428,
         1427,
         1429,
         1429,
         1427,
         1430,
         1427,
         1427,
         1427,
         1427,
         1429,
         1429,
         1430,
         1430,
         1427,
         1443,
         1444,
         1443,
         1445,
         1445,
         1443,
         1446,
         1443,
         1443,
         1443,
         1443,
         1445,
         1445,
         1446,
         1446,
         1443,
         1420,
         1421,
         1420,
         1447,
         1447,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1447,
         1447,
         1423,
         1423,
         1420,
         1420,
         1421,
         1420,
         1447,
         1447,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1447,
         1447,
         1423,
         1423,
         1420,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         1448,
         1449,
         1448,
         1450,
         1450,
         1448,
         1451,
         1448,
         1448,
         1448,
         1448,
         1450,
         1450,
         1451,
         2228,
         1448,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         2229,
         2230,
         2229,
         2231,
         2231,
         2229,
         2232,
         2229,
         2229,
         2229,
         2229,
         2231,
         2231,
         2232,
         2232,
         2229,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         1420,
         1421,
         1420,
         1447,
         1447,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1447,
         1447,
         1423,
         1423,
         1420,
         1420,
         1421,
         1420,
         1447,
         1447,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1447,
         1447,
         1423,
         1423,
         1420,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         2877,
         2877,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         1431,
         1432,
         1431,
         1433,
         1433,
         1431,
         1434,
         1431,
         1431,
         1431,
         1431,
         1433,
         1433,
         1434,
         1434,
         1431,
         1420,
         1421,
         1420,
         1447,
         1447,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1447,
         1447,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2233,
         2233,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2233,
         2233,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         2878,
         2878,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         1435,
         1436,
         1435,
         1437,
         1437,
         1435,
         1438,
         1435,
         1435,
         1435,
         1435,
         1437,
         1437,
         1438,
         1438,
         1435,
         1420,
         1421,
         1420,
         1447,
         1447,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1447,
         1447,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2233,
         2233,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2233,
         2233,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         2878,
         2878,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         1439,
         1440,
         1439,
         1441,
         1441,
         1439,
         1442,
         1439,
         1439,
         1439,
         1439,
         1441,
         1441,
         1442,
         1442,
         1439,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         2218,
         40,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         2223,
         42,
         1448,
         1449,
         1448,
         1450,
         1450,
         1448,
         1451,
         1448,
         1448,
         1448,
         1448,
         1450,
         1450,
         1451,
         2228,
         1448,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         2218,
         40,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2234,
         2219,
         2235,
         2236,
         2235,
         2237,
         2237,
         2235,
         2238,
         2235,
         2235,
         2235,
         2235,
         2237,
         2237,
         2238,
         2239,
         2235,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         2218,
         40,
         40,
         41,
         40,
         2240,
         2240,
         40,
         1417,
         40,
         40,
         40,
         40,
         2240,
         2240,
         1417,
         2218,
         40,
         40,
         41,
         40,
         2240,
         2240,
         40,
         1417,
         40,
         40,
         40,
         40,
         2240,
         2240,
         1417,
         2218,
         40,
         2235,
         2236,
         2235,
         2237,
         2237,
         2235,
         2238,
         2235,
         2235,
         2235,
         2235,
         2879,
         2879,
         2238,
         2239,
         2235,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         2218,
         40,
         2241,
         2242,
         2241,
         2243,
         2243,
         2241,
         2244,
         2241,
         2241,
         2241,
         2241,
         2243,
         2243,
         2244,
         2244,
         2241,
         2245,
         2246,
         2245,
         2247,
         2247,
         2245,
         2248,
         2245,
         2245,
         2245,
         2245,
         2247,
         2247,
         2248,
         2248,
         2245,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         2224,
         2225,
         2224,
         2226,
         2226,
         2224,
         2227,
         2224,
         2224,
         2224,
         2224,
         2226,
         2226,
         2227,
         2227,
         2224,
         2229,
         2230,
         2229,
         2231,
         2231,
         2229,
         2232,
         2229,
         2229,
         2229,
         2229,
         2231,
         2231,
         2232,
         2232,
         2229,
         2219,
         2220,
         2219,
         2233,
         2233,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2233,
         2233,
         2222,
         2222,
         2219,
         2219,
         2220,
         2219,
         2233,
         2233,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2233,
         2233,
         2222,
         2222,
         2219,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2234,
         2219,
         2245,
         2246,
         2245,
         2247,
         2247,
         2245,
         2248,
         2245,
         2245,
         2245,
         2245,
         2247,
         2247,
         2248,
         2248,
         2245,
         2245,
         2246,
         2245,
         2247,
         2247,
         2245,
         2248,
         2245,
         2245,
         2245,
         2245,
         2247,
         2247,
         2248,
         2248,
         2245,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         2219,
         2220,
         2219,
         2233,
         2233,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2233,
         2233,
         2222,
         2222,
         2219,
         2219,
         2220,
         2219,
         2233,
         2233,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2233,
         2233,
         2222,
         2222,
         2219,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2880,
         2880,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         2235,
         2236,
         2235,
         2237,
         2237,
         2235,
         2238,
         2235,
         2235,
         2235,
         2235,
         2237,
         2237,
         2238,
         2239,
         2235,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         1431,
         1432,
         1431,
         1433,
         1433,
         1431,
         1434,
         1431,
         1431,
         1431,
         1431,
         1433,
         1433,
         1434,
         1434,
         1431,
         1420,
         1421,
         1420,
         1447,
         1447,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1447,
         1447,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2233,
         2233,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2233,
         2233,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         2878,
         2878,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         1435,
         1436,
         1435,
         1437,
         1437,
         1435,
         1438,
         1435,
         1435,
         1435,
         1435,
         1437,
         1437,
         1438,
         1438,
         1435,
         1420,
         1421,
         1420,
         1447,
         1447,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1447,
         1447,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2233,
         2233,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2233,
         2233,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         2878,
         2878,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         2240,
         2240,
         40,
         1417,
         40,
         40,
         40,
         40,
         2240,
         2240,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         1418,
         1418,
         1419,
         1419,
         42,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         1422,
         1422,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         2240,
         2240,
         40,
         1417,
         40,
         40,
         40,
         40,
         2240,
         2240,
         1417,
         2218,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2221,
         2221,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         1424,
         1424,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         1416,
         1416,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         42,
         43,
         42,
         1418,
         1418,
         42,
         1419,
         42,
         42,
         42,
         42,
         2876,
         2876,
         1419,
         1419,
         42,
         1420,
         1421,
         1420,
         1422,
         1422,
         1420,
         1423,
         1420,
         1420,
         1420,
         1420,
         2877,
         2877,
         1423,
         1423,
         1420,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         2878,
         2878,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         2878,
         2878,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         2235,
         2236,
         2235,
         2237,
         2237,
         2235,
         2238,
         2235,
         2235,
         2235,
         2235,
         2879,
         2879,
         2238,
         2239,
         2235,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         2219,
         2220,
         2219,
         2221,
         2221,
         2219,
         2222,
         2219,
         2219,
         2219,
         2219,
         2880,
         2880,
         2222,
         2222,
         2219,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         2878,
         2878,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1424,
         1424,
         40,
         1417,
         40,
         40,
         40,
         40,
         2878,
         2878,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
         40,
         41,
         40,
         1416,
         1416,
         40,
         1417,
         40,
         40,
         40,
         40,
         2875,
         2875,
         1417,
         1417,
         40,
      },
   },
   [nir_op_ffmaz] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         46,
         47,
         46,
         1452,
         1452,
         1453,
         48,
         49,
         48,
         1454,
         1454,
         1455,
         46,
         47,
         46,
         1452,
         1452,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1452,
         1452,
         1453,
         48,
         49,
         48,
         1454,
         1454,
         1455,
         50,
         51,
         50,
         1457,
         1457,
         1458,
         48,
         49,
         48,
         1454,
         1454,
         1455,
         1459,
         1460,
         1459,
         1461,
         1461,
         1462,
         1463,
         1464,
         1463,
         1465,
         1465,
         1466,
         48,
         49,
         48,
         1454,
         1454,
         1455,
         46,
         47,
         46,
         1452,
         1452,
         1453,
         48,
         49,
         48,
         1454,
         1454,
         1455,
         1467,
         1468,
         1467,
         1469,
         1469,
         1470,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1452,
         1452,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         1459,
         1460,
         1459,
         1461,
         1461,
         1462,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         1463,
         1464,
         1463,
         1465,
         1465,
         1466,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1452,
         1452,
         1453,
         48,
         49,
         48,
         1454,
         1454,
         1455,
         46,
         47,
         46,
         1452,
         1452,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1456,
         1456,
         1453,
         46,
         47,
         46,
         1452,
         1452,
         1453,
      },
   },
   [nir_op_iand] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         3,
         4,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         9,
         9,
         10,
         11,
         12,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         17,
         16,
         17,
         18,
         19,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         26,
         27,
         28,
         29,
         29,
         30,
         31,
         32,
         32,
         32,
         32,
         33,
         33,
         34,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         35,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         37,
         38,
         39,
         40,
         41,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         3,
         4,
         3,
         3,
         3,
         4,
         3,
         3,
         4,
         4,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         44,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         17,
         16,
         16,
         17,
         17,
         18,
         18,
         19,
         18,
         19,
         18,
         19,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         21,
         21,
         21,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         22,
         21,
         22,
         21,
         22,
         21,
         21,
         21,
         22,
         22,
         21,
         22,
         21,
         21,
         21,
         22,
         21,
         22,
         21,
         21,
         21,
         21,
         25,
         25,
         25,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         26,
         25,
         26,
         25,
         26,
         25,
         25,
         25,
         26,
         26,
         26,
         25,
         26,
         25,
         25,
         25,
         26,
         25,
         26,
         25,
         25,
         25,
         25,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         45,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         20,
         20,
         20,
         20,
         46,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         11,
         11,
         11,
         11,
         11,
         47,
         11,
         11,
         48,
         49,
         11,
         11,
         11,
         11,
         11,
         11,
         10,
         10,
         10,
         10,
         12,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         12,
         12,
         12,
         12,
         0,
         0,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         50,
         51,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         30,
         30,
         30,
         30,
         30,
         31,
         30,
         31,
         30,
         30,
         31,
         30,
         31,
         30,
         30,
         31,
         31,
         30,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         42,
         42,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         54,
         4,
         16,
         16,
         16,
         16,
         16,
         16,
         55,
         17,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         43,
         43,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         20,
         20,
         20,
         20,
         20,
         20,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         23,
         22,
         22,
         22,
         22,
         22,
         27,
         26,
         26,
         26,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         13,
         12,
         31,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         53,
         53,
         51,
         45,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         56,
         57,
         58,
         4,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         29,
         0,
         22,
         26,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         59,
         22,
         22,
         22,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         60,
         61,
         8,
         0,
         8,
         8,
         4,
         17,
         9,
         62,
         63,
         64,
         8,
         8,
         8,
         4,
         17,
         9,
         65,
         66,
         67,
         8,
         8,
         8,
         4,
         17,
         9,
         65,
      },
      
      .num_filtered_states = 68,
      .table = (const uint16_t []) {
      
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         53,
         53,
         1108,
         53,
         1109,
         1110,
         53,
         1111,
         1112,
         1113,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1114,
         53,
         53,
         1115,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1116,
         53,
         1117,
         53,
         1118,
         53,
         1119,
         2322,
         2323,
         2324,
         2325,
         2326,
         53,
         53,
         2327,
         2328,
         2329,
         2330,
         2797,
         2798,
         1115,
         1115,
         1115,
         2925,
         2927,
         2928,
         2935,
         2936,
         2937,
         2944,
         2945,
         2946,
         52,
         1108,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         1120,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         1120,
         52,
         1103,
         1103,
         1103,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         52,
         1109,
         52,
         1120,
         1120,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         1120,
         52,
         1103,
         1103,
         1103,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         52,
         1110,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         2331,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1101,
         1111,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1121,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1122,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1123,
         1101,
         1124,
         1101,
         1125,
         1101,
         1126,
         2332,
         1121,
         1101,
         2333,
         2334,
         1101,
         1101,
         2335,
         2336,
         2337,
         2338,
         1101,
         1101,
         1122,
         1122,
         1122,
         1121,
         1101,
         1101,
         1121,
         1101,
         1101,
         1121,
         1101,
         1101,
         1101,
         1112,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1121,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1122,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1101,
         1123,
         1101,
         1124,
         1101,
         1125,
         1101,
         1126,
         2332,
         1121,
         1101,
         2333,
         2334,
         1101,
         1101,
         2335,
         2336,
         2337,
         2338,
         1101,
         1101,
         1122,
         1122,
         1122,
         1121,
         1101,
         1101,
         1121,
         1101,
         1101,
         1121,
         1101,
         1101,
         1102,
         1113,
         1102,
         1102,
         1102,
         1102,
         1102,
         1121,
         1121,
         1127,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1128,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1129,
         1102,
         1130,
         1102,
         1131,
         1102,
         1132,
         2339,
         1127,
         1102,
         2340,
         2341,
         1102,
         1102,
         2342,
         2343,
         2344,
         2345,
         1102,
         1102,
         1128,
         1128,
         1128,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         1133,
         1133,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         1134,
         1133,
         1133,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2346,
         1134,
         1134,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         1133,
         1133,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2347,
         1133,
         1133,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         1133,
         1133,
         52,
         1135,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2347,
         1133,
         1133,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1136,
         52,
         52,
         52,
         52,
         52,
         1103,
         1137,
         1137,
         1137,
         1137,
         1138,
         1138,
         1138,
         1138,
         1139,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         1140,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1141,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         1141,
         1103,
         1103,
         1103,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         52,
         1114,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         1141,
         1141,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         1141,
         1103,
         1103,
         1103,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1142,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1142,
         1142,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1103,
         1115,
         1103,
         1103,
         1103,
         1103,
         1103,
         1122,
         1122,
         1128,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1143,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1144,
         1103,
         1145,
         1103,
         1146,
         1103,
         1147,
         2348,
         1128,
         1103,
         2349,
         2350,
         1103,
         1103,
         2351,
         2352,
         2353,
         2354,
         1103,
         1103,
         1143,
         1143,
         1143,
         1128,
         1103,
         1103,
         1128,
         1103,
         1103,
         1128,
         1103,
         1103,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1137,
         52,
         52,
         52,
         52,
         52,
         1103,
         1148,
         1148,
         1148,
         1148,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1137,
         52,
         52,
         52,
         52,
         52,
         1103,
         1148,
         1149,
         1150,
         1151,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1137,
         52,
         52,
         52,
         52,
         52,
         1103,
         1148,
         1150,
         1152,
         1153,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1137,
         52,
         52,
         52,
         52,
         52,
         1103,
         1148,
         1151,
         1153,
         1154,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1138,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         1155,
         1155,
         1155,
         1155,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1138,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         1155,
         1156,
         1157,
         1158,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1138,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         1155,
         1157,
         1159,
         1160,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1138,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         1155,
         1158,
         1160,
         1161,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         1139,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1162,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1163,
         1163,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1163,
         1163,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         2919,
         2920,
         2921,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1164,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1165,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1166,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1167,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1104,
         1116,
         1104,
         1104,
         1104,
         1104,
         1104,
         1123,
         1123,
         1129,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1144,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1104,
         1167,
         1167,
         1104,
         1168,
         1104,
         1169,
         1104,
         1170,
         2355,
         1129,
         1104,
         2356,
         2357,
         1104,
         1104,
         2358,
         2359,
         2360,
         2361,
         1104,
         1104,
         1144,
         1144,
         1144,
         1129,
         1104,
         1104,
         1129,
         1104,
         1104,
         1129,
         1104,
         1104,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1171,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1105,
         1117,
         1105,
         1105,
         1105,
         1105,
         1105,
         1124,
         1124,
         1130,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1145,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1105,
         1168,
         1171,
         1171,
         1105,
         1172,
         1105,
         1173,
         2362,
         1130,
         1105,
         2363,
         2364,
         1105,
         1105,
         2365,
         2366,
         2367,
         2368,
         1105,
         1105,
         1145,
         1145,
         1145,
         1130,
         1105,
         1105,
         1130,
         1105,
         1105,
         1130,
         1105,
         1105,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1174,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1106,
         1118,
         1106,
         1106,
         1106,
         1106,
         1106,
         1125,
         1125,
         1131,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1146,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1106,
         1169,
         1106,
         1172,
         1174,
         1174,
         1106,
         1175,
         2369,
         1131,
         1106,
         2370,
         2371,
         1106,
         1106,
         2372,
         2373,
         2374,
         2375,
         1106,
         1106,
         1146,
         1146,
         1146,
         1131,
         1106,
         1106,
         1131,
         1106,
         1106,
         1131,
         1106,
         1106,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1176,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1107,
         1119,
         1107,
         1107,
         1107,
         1107,
         1107,
         1126,
         1126,
         1132,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1147,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1107,
         1170,
         1107,
         1173,
         1107,
         1175,
         1176,
         1176,
         2376,
         1132,
         1107,
         2377,
         2378,
         1107,
         1107,
         2379,
         2380,
         2381,
         2382,
         1107,
         1107,
         1147,
         1147,
         1147,
         1132,
         1107,
         1107,
         1132,
         1107,
         1107,
         1132,
         1107,
         1107,
         2315,
         2322,
         2315,
         2315,
         2315,
         2315,
         2315,
         2332,
         2332,
         2339,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2348,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2315,
         2355,
         2315,
         2362,
         2315,
         2369,
         2315,
         2376,
         2339,
         2339,
         2315,
         2383,
         2384,
         2315,
         2315,
         2385,
         2386,
         2387,
         2388,
         2315,
         2315,
         2348,
         2348,
         2348,
         2339,
         2315,
         2315,
         2339,
         2315,
         2315,
         2339,
         2315,
         2315,
         1102,
         2323,
         1102,
         1102,
         1102,
         1102,
         1102,
         1121,
         1121,
         1127,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1128,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1129,
         1102,
         1130,
         1102,
         1131,
         1102,
         1132,
         2339,
         1127,
         1102,
         2340,
         2341,
         1102,
         1102,
         2342,
         2343,
         2344,
         2345,
         1102,
         1102,
         1128,
         1128,
         1128,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         52,
         2324,
         52,
         52,
         52,
         52,
         2331,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         2389,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         2316,
         2325,
         2316,
         2316,
         2316,
         2316,
         2316,
         2333,
         2333,
         2340,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2349,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2316,
         2356,
         2316,
         2363,
         2316,
         2370,
         2316,
         2377,
         2383,
         2340,
         2316,
         2349,
         2390,
         2316,
         2316,
         2391,
         2392,
         2393,
         2394,
         2316,
         2316,
         2349,
         2349,
         2349,
         2340,
         2316,
         2316,
         2340,
         2316,
         2316,
         2340,
         2316,
         2316,
         2317,
         2326,
         2317,
         2317,
         2317,
         2317,
         2317,
         2334,
         2334,
         2341,
         2317,
         2346,
         2347,
         2347,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2350,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2317,
         2357,
         2317,
         2364,
         2317,
         2371,
         2317,
         2378,
         2384,
         2341,
         2317,
         2390,
         2346,
         2346,
         2346,
         2395,
         2396,
         2397,
         2398,
         2317,
         2317,
         2350,
         2350,
         2350,
         2341,
         2317,
         2317,
         2341,
         2317,
         2317,
         2341,
         2317,
         2317,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         1134,
         1133,
         1133,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2346,
         1134,
         2399,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         52,
         53,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         1134,
         1133,
         1133,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2346,
         2399,
         1134,
         2318,
         2319,
         2320,
         2321,
         52,
         52,
         1103,
         1103,
         1103,
         1102,
         52,
         52,
         1102,
         52,
         52,
         1102,
         52,
         52,
         2318,
         2327,
         2318,
         2318,
         2318,
         2318,
         2318,
         2335,
         2335,
         2342,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2351,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2318,
         2358,
         2318,
         2365,
         2318,
         2372,
         2318,
         2379,
         2385,
         2342,
         2318,
         2391,
         2395,
         2318,
         2318,
         2318,
         2400,
         2401,
         2402,
         2318,
         2318,
         2351,
         2351,
         2351,
         2342,
         2318,
         2318,
         2342,
         2318,
         2318,
         2342,
         2318,
         2318,
         2319,
         2328,
         2319,
         2319,
         2319,
         2319,
         2319,
         2336,
         2336,
         2343,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2352,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2319,
         2359,
         2319,
         2366,
         2319,
         2373,
         2319,
         2380,
         2386,
         2343,
         2319,
         2392,
         2396,
         2319,
         2319,
         2400,
         2319,
         2403,
         2404,
         2319,
         2319,
         2352,
         2352,
         2352,
         2343,
         2319,
         2319,
         2343,
         2319,
         2319,
         2343,
         2319,
         2319,
         2320,
         2329,
         2320,
         2320,
         2320,
         2320,
         2320,
         2337,
         2337,
         2344,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2353,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2320,
         2360,
         2320,
         2367,
         2320,
         2374,
         2320,
         2381,
         2387,
         2344,
         2320,
         2393,
         2397,
         2320,
         2320,
         2401,
         2403,
         2320,
         2405,
         2320,
         2320,
         2353,
         2353,
         2353,
         2344,
         2320,
         2320,
         2344,
         2320,
         2320,
         2344,
         2320,
         2320,
         2321,
         2330,
         2321,
         2321,
         2321,
         2321,
         2321,
         2338,
         2338,
         2345,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2354,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2321,
         2361,
         2321,
         2368,
         2321,
         2375,
         2321,
         2382,
         2388,
         2345,
         2321,
         2394,
         2398,
         2321,
         2321,
         2402,
         2404,
         2405,
         2406,
         2321,
         2321,
         2354,
         2354,
         2354,
         2345,
         2321,
         2321,
         2345,
         2321,
         2321,
         2345,
         2321,
         2321,
         52,
         2797,
         52,
         1120,
         1120,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         1120,
         52,
         1103,
         1103,
         1103,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         52,
         2798,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         1141,
         1141,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         1141,
         1103,
         1103,
         1103,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         1103,
         1115,
         1103,
         1103,
         1103,
         1103,
         1103,
         1122,
         1122,
         1128,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1143,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         2919,
         1103,
         1103,
         1103,
         1103,
         1144,
         1103,
         1145,
         1103,
         1146,
         1103,
         1147,
         2348,
         1128,
         1103,
         2349,
         2350,
         1103,
         1103,
         2351,
         2352,
         2353,
         2354,
         1103,
         1103,
         1143,
         1143,
         1143,
         1128,
         1103,
         1103,
         1128,
         1103,
         1103,
         1128,
         1103,
         1103,
         1103,
         1115,
         1103,
         1103,
         1103,
         1103,
         1103,
         1122,
         1122,
         1128,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1143,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         2920,
         1103,
         1103,
         1103,
         1103,
         1144,
         1103,
         1145,
         1103,
         1146,
         1103,
         1147,
         2348,
         1128,
         1103,
         2349,
         2350,
         1103,
         1103,
         2351,
         2352,
         2353,
         2354,
         1103,
         1103,
         1143,
         1143,
         1143,
         1128,
         1103,
         1103,
         1128,
         1103,
         1103,
         1128,
         1103,
         1103,
         1103,
         1115,
         1103,
         1103,
         1103,
         1103,
         1103,
         1122,
         1122,
         1128,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1143,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         1103,
         2921,
         1103,
         1103,
         1103,
         1103,
         1144,
         1103,
         1145,
         1103,
         1146,
         1103,
         1147,
         2348,
         1128,
         1103,
         2349,
         2350,
         1103,
         1103,
         2351,
         2352,
         2353,
         2354,
         1103,
         1103,
         1143,
         1143,
         1143,
         1128,
         1103,
         1103,
         1128,
         1103,
         1103,
         1128,
         1103,
         1103,
         1102,
         2925,
         1102,
         1102,
         1102,
         1102,
         1102,
         1121,
         1121,
         1127,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1128,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1129,
         1102,
         1130,
         1102,
         1131,
         1102,
         1132,
         2339,
         1127,
         1102,
         2340,
         2341,
         1102,
         1102,
         2342,
         2343,
         2344,
         2345,
         1102,
         1102,
         1128,
         1128,
         1128,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         52,
         2927,
         52,
         1120,
         1120,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         1120,
         52,
         1103,
         1103,
         1103,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         52,
         2928,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         1141,
         1141,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         1141,
         1103,
         1103,
         1103,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         1102,
         2935,
         1102,
         1102,
         1102,
         1102,
         1102,
         1121,
         1121,
         1127,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1128,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1129,
         1102,
         1130,
         1102,
         1131,
         1102,
         1132,
         2339,
         1127,
         1102,
         2340,
         2341,
         1102,
         1102,
         2342,
         2343,
         2344,
         2345,
         1102,
         1102,
         1128,
         1128,
         1128,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         52,
         2936,
         52,
         1120,
         1120,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         1120,
         52,
         1103,
         1103,
         1103,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         52,
         2937,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         1141,
         1141,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         1141,
         1103,
         1103,
         1103,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         1102,
         2944,
         1102,
         1102,
         1102,
         1102,
         1102,
         1121,
         1121,
         1127,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1128,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1102,
         1129,
         1102,
         1130,
         1102,
         1131,
         1102,
         1132,
         2339,
         1127,
         1102,
         2340,
         2341,
         1102,
         1102,
         2342,
         2343,
         2344,
         2345,
         1102,
         1102,
         1128,
         1128,
         1128,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         1127,
         1102,
         1102,
         52,
         2945,
         52,
         1120,
         1120,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         1120,
         52,
         1103,
         1103,
         1103,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         1102,
         1120,
         52,
         52,
         2946,
         52,
         52,
         52,
         52,
         52,
         1101,
         1101,
         1102,
         52,
         52,
         52,
         52,
         52,
         52,
         1141,
         1141,
         52,
         52,
         1103,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1104,
         52,
         1105,
         52,
         1106,
         52,
         1107,
         2315,
         1102,
         52,
         2316,
         2317,
         52,
         52,
         2318,
         2319,
         2320,
         2321,
         52,
         1141,
         1103,
         1103,
         1103,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
         1102,
         52,
         1141,
      },
   },
   [nir_op_ior] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         3,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         6,
         0,
         7,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         11,
         12,
         13,
         14,
         13,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         24,
         25,
         25,
         26,
         26,
         26,
         26,
         27,
         27,
         28,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         31,
         0,
         0,
         0,
         0,
         32,
         0,
         0,
         33,
         34,
         35,
         36,
         37,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         39,
         40,
         41,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         42,
         2,
         42,
         3,
         3,
         3,
         3,
         2,
         3,
         2,
         42,
         2,
         3,
         2,
         42,
         43,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         45,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         46,
         11,
         46,
         11,
         12,
         11,
         46,
         12,
         12,
         13,
         13,
         14,
         13,
         14,
         13,
         14,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         34,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         16,
         16,
         16,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         17,
         16,
         17,
         16,
         17,
         16,
         16,
         16,
         17,
         17,
         16,
         17,
         16,
         16,
         16,
         17,
         16,
         17,
         16,
         16,
         16,
         16,
         20,
         20,
         20,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         21,
         20,
         21,
         20,
         21,
         20,
         20,
         20,
         21,
         21,
         21,
         20,
         21,
         20,
         20,
         20,
         21,
         20,
         21,
         20,
         20,
         20,
         20,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         47,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         28,
         28,
         28,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         48,
         49,
         0,
         0,
         0,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         50,
         51,
         32,
         32,
         32,
         32,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         54,
         0,
         0,
         0,
         0,
         0,
         38,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         55,
         55,
         55,
         55,
         3,
         3,
         3,
         3,
         3,
         56,
         11,
         56,
         11,
         56,
         11,
         12,
         12,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         44,
         44,
         44,
         44,
         5,
         5,
         5,
         5,
         57,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         57,
         57,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         15,
         15,
         15,
         15,
         15,
         15,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         18,
         17,
         17,
         17,
         17,
         17,
         22,
         21,
         21,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         25,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         27,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         51,
         51,
         49,
         47,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         58,
         5,
         5,
         59,
         60,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         32,
         32,
         32,
         15,
         15,
         15,
         61,
         62,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         24,
         0,
         17,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         17,
         17,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         3,
         12,
         4,
         0,
         63,
         64,
         65,
         66,
         5,
         5,
         3,
         12,
         4,
         67,
         68,
         69,
         70,
         5,
         5,
         3,
         12,
         4,
         71,
         72,
         73,
         74,
         5,
         5,
      },
      
      .num_filtered_states = 75,
      .table = (const uint16_t []) {
      
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         55,
         55,
         55,
         55,
         1186,
         1187,
         1188,
         1189,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1190,
         1191,
         1191,
         1191,
         1191,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1192,
         55,
         55,
         1193,
         55,
         1194,
         55,
         1195,
         55,
         55,
         55,
         55,
         55,
         1187,
         1188,
         55,
         55,
         2253,
         2254,
         2255,
         2256,
         55,
         55,
         55,
         55,
         55,
         1187,
         1187,
         1186,
         1186,
         55,
         55,
         1186,
         1186,
         55,
         55,
         1186,
         1186,
         55,
         55,
         1186,
         1186,
         55,
         55,
         54,
         55,
         54,
         1196,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         1196,
         1178,
         1178,
         2257,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         2791,
         1178,
         1178,
         1177,
         1177,
         1196,
         54,
         1177,
         1177,
         1196,
         54,
         1177,
         1177,
         1196,
         54,
         1177,
         1177,
         1196,
         54,
         54,
         55,
         1196,
         1196,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         1197,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         1196,
         1196,
         1178,
         1178,
         2257,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         1196,
         2791,
         1178,
         1178,
         1177,
         1177,
         1196,
         1197,
         1177,
         1177,
         1196,
         1197,
         1177,
         1177,
         1196,
         1197,
         1177,
         1177,
         1196,
         1197,
         1177,
         1186,
         1177,
         1177,
         1198,
         1199,
         1199,
         1200,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1201,
         1202,
         1202,
         1202,
         1202,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1203,
         1177,
         1177,
         1204,
         1177,
         1205,
         1177,
         1206,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1177,
         1177,
         2258,
         2259,
         2260,
         2261,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1178,
         1187,
         1178,
         1178,
         1199,
         1178,
         1178,
         1207,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1208,
         1209,
         1209,
         1209,
         1209,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1210,
         1178,
         1178,
         1211,
         1178,
         1212,
         1178,
         1213,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         2262,
         2263,
         2264,
         2265,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1178,
         1188,
         1178,
         1178,
         1199,
         1178,
         1178,
         1207,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1208,
         1209,
         1209,
         1209,
         1209,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1210,
         1178,
         1178,
         1211,
         1178,
         1212,
         1178,
         1213,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         2262,
         2263,
         2264,
         2265,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1179,
         1189,
         1179,
         1179,
         1200,
         1207,
         1207,
         1214,
         1179,
         1179,
         1179,
         1179,
         1179,
         1179,
         1179,
         1215,
         1216,
         1216,
         1216,
         1216,
         1179,
         1179,
         1179,
         1179,
         1179,
         1179,
         1179,
         1179,
         1179,
         1217,
         1179,
         1218,
         1179,
         1179,
         1219,
         1179,
         1220,
         1179,
         1221,
         1179,
         1179,
         1179,
         1179,
         1179,
         1207,
         1207,
         1179,
         1179,
         2266,
         2267,
         2268,
         2269,
         1179,
         1179,
         1179,
         1179,
         1179,
         1207,
         1207,
         1200,
         1200,
         1179,
         1179,
         1200,
         1200,
         1179,
         1179,
         1200,
         1200,
         1179,
         1179,
         1200,
         1200,
         1179,
         1179,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         1222,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         1223,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         1224,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         1225,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         1226,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         2270,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         2792,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         1226,
         1177,
         1177,
         54,
         1226,
         1177,
         1177,
         54,
         1226,
         1177,
         1177,
         54,
         1226,
         54,
         55,
         54,
         1197,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         1226,
         1226,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         2270,
         1197,
         1178,
         1178,
         1226,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         2792,
         1226,
         1178,
         1178,
         1177,
         1177,
         1197,
         1226,
         1177,
         1177,
         1197,
         1226,
         1177,
         1177,
         1197,
         1226,
         1177,
         1177,
         1197,
         1226,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         1227,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         1227,
         1227,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1180,
         1190,
         1180,
         1180,
         1201,
         1208,
         1208,
         1215,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1228,
         1229,
         1229,
         1229,
         1229,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1180,
         1230,
         1180,
         1180,
         1231,
         1180,
         1232,
         1180,
         1233,
         1180,
         1180,
         1180,
         1180,
         1180,
         1208,
         1208,
         1180,
         1180,
         2271,
         2272,
         2273,
         2274,
         1180,
         1180,
         1180,
         1180,
         1180,
         1208,
         1208,
         1201,
         1201,
         1180,
         1180,
         1201,
         1201,
         1180,
         1180,
         1201,
         1201,
         1180,
         1180,
         1201,
         1201,
         1180,
         1180,
         1181,
         1191,
         1181,
         1181,
         1202,
         1209,
         1209,
         1216,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1229,
         1234,
         1234,
         1234,
         1234,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1235,
         1181,
         1181,
         1236,
         1181,
         1237,
         1181,
         1238,
         1181,
         1181,
         1181,
         1181,
         1181,
         2275,
         2275,
         1181,
         1181,
         2276,
         2277,
         2278,
         2279,
         1181,
         1181,
         1181,
         1181,
         1181,
         1209,
         1209,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1181,
         1191,
         1181,
         1181,
         1202,
         1209,
         1209,
         1216,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1229,
         1234,
         1239,
         1240,
         1241,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1235,
         1181,
         1181,
         1236,
         1181,
         1237,
         1181,
         1238,
         1181,
         1181,
         1181,
         1181,
         1181,
         2275,
         2275,
         1181,
         1181,
         2276,
         2277,
         2278,
         2279,
         1181,
         1181,
         1181,
         1181,
         1181,
         1209,
         1209,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1181,
         1191,
         1181,
         1181,
         1202,
         1209,
         1209,
         1216,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1229,
         1234,
         1240,
         1242,
         1243,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1235,
         1181,
         1181,
         1236,
         1181,
         1237,
         1181,
         1238,
         1181,
         1181,
         1181,
         1181,
         1181,
         2275,
         2275,
         1181,
         1181,
         2276,
         2277,
         2278,
         2279,
         1181,
         1181,
         1181,
         1181,
         1181,
         1209,
         1209,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1181,
         1191,
         1181,
         1181,
         1202,
         1209,
         1209,
         1216,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1229,
         1234,
         1241,
         1243,
         1244,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1181,
         1235,
         1181,
         1181,
         1236,
         1181,
         1237,
         1181,
         1238,
         1181,
         1181,
         1181,
         1181,
         1181,
         2275,
         2275,
         1181,
         1181,
         2276,
         2277,
         2278,
         2279,
         1181,
         1181,
         1181,
         1181,
         1181,
         1209,
         1209,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         1202,
         1202,
         1181,
         1181,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         1245,
         1245,
         1245,
         1245,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         1245,
         1246,
         1247,
         1248,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         1245,
         1247,
         1249,
         1250,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         1245,
         1248,
         1250,
         1251,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         1224,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         1252,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         1253,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         1254,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1255,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1256,
         1256,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1217,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1256,
         1256,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1257,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1182,
         1192,
         1182,
         1182,
         1203,
         1210,
         1210,
         1218,
         1182,
         1182,
         1182,
         1182,
         1182,
         1182,
         1182,
         1230,
         1235,
         1235,
         1235,
         1235,
         1182,
         1182,
         1182,
         1182,
         1182,
         1182,
         1182,
         1182,
         1182,
         1182,
         1257,
         1257,
         1182,
         1182,
         1258,
         1182,
         1259,
         1182,
         1260,
         1182,
         1182,
         1182,
         1182,
         1182,
         1210,
         1210,
         1182,
         1182,
         2280,
         2281,
         2282,
         2283,
         1182,
         1182,
         1182,
         1182,
         1182,
         1210,
         1210,
         1203,
         1203,
         1182,
         1182,
         1203,
         1203,
         1182,
         1182,
         1203,
         1203,
         1182,
         1182,
         1203,
         1203,
         1182,
         1182,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         2284,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1261,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1183,
         1193,
         1183,
         1183,
         1204,
         1211,
         1211,
         1219,
         1183,
         1183,
         1183,
         1183,
         1183,
         1183,
         1183,
         1231,
         1236,
         1236,
         1236,
         1236,
         1183,
         1183,
         1183,
         1183,
         1183,
         1183,
         1183,
         1183,
         1183,
         1183,
         1183,
         1258,
         1183,
         1261,
         1261,
         1183,
         1262,
         1183,
         1263,
         1183,
         1183,
         1183,
         1183,
         1183,
         1211,
         1211,
         1183,
         1183,
         2285,
         2286,
         2287,
         2288,
         1183,
         1183,
         1183,
         1183,
         1183,
         1211,
         1211,
         1204,
         1204,
         1183,
         1183,
         1204,
         1204,
         1183,
         1183,
         1204,
         1204,
         1183,
         1183,
         1204,
         1204,
         1183,
         1183,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1264,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1184,
         1194,
         1184,
         1184,
         1205,
         1212,
         1212,
         1220,
         1184,
         1184,
         1184,
         1184,
         1184,
         1184,
         1184,
         1232,
         1237,
         1237,
         1237,
         1237,
         1184,
         1184,
         1184,
         1184,
         1184,
         1184,
         1184,
         1184,
         1184,
         1184,
         1184,
         1259,
         1184,
         1184,
         1262,
         1264,
         1264,
         1184,
         1265,
         1184,
         1184,
         1184,
         1184,
         1184,
         1212,
         1212,
         1184,
         1184,
         2289,
         2290,
         2291,
         2292,
         1184,
         1184,
         1184,
         1184,
         1184,
         1212,
         1212,
         1205,
         1205,
         1184,
         1184,
         1205,
         1205,
         1184,
         1184,
         1205,
         1205,
         1184,
         1184,
         1205,
         1205,
         1184,
         1184,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1266,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1185,
         1195,
         1185,
         1185,
         1206,
         1213,
         1213,
         1221,
         1185,
         1185,
         1185,
         1185,
         1185,
         1185,
         1185,
         1233,
         1238,
         1238,
         1238,
         1238,
         1185,
         1185,
         1185,
         1185,
         1185,
         1185,
         1185,
         1185,
         1185,
         1185,
         1185,
         1260,
         1185,
         1185,
         1263,
         1185,
         1265,
         1266,
         1266,
         1185,
         1185,
         1185,
         1185,
         1185,
         1213,
         1213,
         1185,
         1185,
         2293,
         2294,
         2295,
         2296,
         1185,
         1185,
         1185,
         1185,
         1185,
         1213,
         1213,
         1206,
         1206,
         1185,
         1185,
         1206,
         1206,
         1185,
         1185,
         1206,
         1206,
         1185,
         1185,
         1206,
         1206,
         1185,
         1185,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         1267,
         1267,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         1267,
         54,
         1267,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         1267,
         1267,
         1267,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         1196,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         2270,
         2270,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         1196,
         1178,
         1178,
         2297,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         2793,
         1178,
         1178,
         1177,
         1177,
         1196,
         2270,
         1177,
         1177,
         1196,
         2270,
         1177,
         1177,
         1196,
         2270,
         1177,
         1177,
         1196,
         2270,
         54,
         55,
         1196,
         1196,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         1197,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         2284,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         1196,
         1196,
         1178,
         1178,
         2257,
         54,
         2249,
         2250,
         2298,
         2299,
         54,
         54,
         54,
         1196,
         2791,
         2794,
         2901,
         1177,
         1177,
         1196,
         1197,
         1177,
         1177,
         1196,
         1197,
         1177,
         1177,
         1196,
         1197,
         1177,
         1177,
         1196,
         1197,
         1178,
         1187,
         1178,
         1178,
         1199,
         1178,
         1178,
         1207,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1208,
         2275,
         2275,
         2275,
         2275,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1210,
         1178,
         1178,
         1211,
         1178,
         1212,
         1178,
         1213,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         2262,
         2263,
         2264,
         2265,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1178,
         1188,
         1178,
         1178,
         1199,
         1178,
         1178,
         1207,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1208,
         2275,
         2275,
         2275,
         2275,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1210,
         1178,
         1178,
         1211,
         1178,
         1212,
         1178,
         1213,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         2262,
         2263,
         2264,
         2265,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         54,
         55,
         2257,
         2257,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         1226,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         2297,
         2257,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         2795,
         54,
         1178,
         1178,
         1177,
         1177,
         2257,
         1226,
         1177,
         1177,
         2257,
         1226,
         1177,
         1177,
         2257,
         1226,
         1177,
         1177,
         2257,
         1226,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         2300,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         2249,
         2253,
         2249,
         2249,
         2258,
         2262,
         2262,
         2266,
         2249,
         2249,
         2249,
         2249,
         2249,
         2249,
         2249,
         2271,
         2276,
         2276,
         2276,
         2276,
         2249,
         2249,
         2249,
         2249,
         2249,
         2249,
         2249,
         2249,
         2249,
         2249,
         2249,
         2280,
         2249,
         2249,
         2285,
         2249,
         2289,
         2249,
         2293,
         2249,
         2249,
         2249,
         2249,
         2249,
         2262,
         2262,
         2249,
         2249,
         2249,
         2301,
         2302,
         2303,
         2249,
         2249,
         2249,
         2249,
         2249,
         2262,
         2262,
         2258,
         2258,
         2249,
         2249,
         2258,
         2258,
         2249,
         2249,
         2258,
         2258,
         2249,
         2249,
         2258,
         2258,
         2249,
         2249,
         2250,
         2254,
         2250,
         2250,
         2259,
         2263,
         2263,
         2267,
         2250,
         2250,
         2250,
         2250,
         2250,
         2250,
         2250,
         2272,
         2277,
         2277,
         2277,
         2277,
         2250,
         2250,
         2250,
         2250,
         2250,
         2250,
         2250,
         2250,
         2250,
         2250,
         2250,
         2281,
         2250,
         2250,
         2286,
         2250,
         2290,
         2250,
         2294,
         2250,
         2250,
         2250,
         2250,
         2250,
         2263,
         2263,
         2250,
         2250,
         2301,
         2250,
         2304,
         2305,
         2250,
         2250,
         2250,
         2250,
         2250,
         2263,
         2263,
         2259,
         2259,
         2250,
         2250,
         2259,
         2259,
         2250,
         2250,
         2259,
         2259,
         2250,
         2250,
         2259,
         2259,
         2250,
         2250,
         2251,
         2255,
         2251,
         2251,
         2260,
         2264,
         2264,
         2268,
         2251,
         2251,
         2251,
         2251,
         2251,
         2251,
         2251,
         2273,
         2278,
         2278,
         2278,
         2278,
         2251,
         2251,
         2251,
         2251,
         2251,
         2251,
         2251,
         2251,
         2251,
         2251,
         2251,
         2282,
         2251,
         2251,
         2287,
         2251,
         2291,
         2251,
         2295,
         2251,
         2251,
         2251,
         2251,
         2298,
         2264,
         2264,
         2251,
         2251,
         2302,
         2304,
         2251,
         2306,
         2251,
         2251,
         2251,
         2251,
         2251,
         2264,
         2264,
         2260,
         2260,
         2251,
         2251,
         2260,
         2260,
         2251,
         2251,
         2260,
         2260,
         2251,
         2251,
         2260,
         2260,
         2251,
         2251,
         2252,
         2256,
         2252,
         2252,
         2261,
         2265,
         2265,
         2269,
         2252,
         2252,
         2252,
         2252,
         2252,
         2252,
         2252,
         2274,
         2279,
         2279,
         2279,
         2279,
         2252,
         2252,
         2252,
         2252,
         2252,
         2252,
         2252,
         2252,
         2252,
         2252,
         2252,
         2283,
         2252,
         2252,
         2288,
         2252,
         2292,
         2252,
         2296,
         2252,
         2252,
         2252,
         2252,
         2299,
         2265,
         2265,
         2252,
         2252,
         2303,
         2305,
         2306,
         2307,
         2252,
         2252,
         2252,
         2252,
         2252,
         2265,
         2265,
         2261,
         2261,
         2252,
         2252,
         2261,
         2261,
         2252,
         2252,
         2261,
         2261,
         2252,
         2252,
         2261,
         2261,
         2252,
         2252,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         2308,
         2308,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         2308,
         54,
         2308,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         54,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         54,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         2308,
         2308,
         2308,
         54,
         54,
         1178,
         1178,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         1177,
         1177,
         54,
         54,
         54,
         55,
         54,
         1196,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         2792,
         2792,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         54,
         1196,
         1178,
         1178,
         2795,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         54,
         2796,
         1178,
         1178,
         1177,
         1177,
         1196,
         2792,
         1177,
         1177,
         1196,
         2792,
         1177,
         1177,
         1196,
         2792,
         1177,
         1177,
         1196,
         2792,
         54,
         55,
         2791,
         2791,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         1226,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         2793,
         2791,
         1178,
         1178,
         54,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         2796,
         54,
         1178,
         1178,
         1177,
         1177,
         2791,
         1226,
         1177,
         1177,
         2791,
         1226,
         1177,
         1177,
         2791,
         1226,
         1177,
         1177,
         2791,
         1226,
         1178,
         1187,
         1178,
         1178,
         1199,
         1178,
         1178,
         1207,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1208,
         1209,
         1209,
         1209,
         1209,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1210,
         1178,
         1178,
         1211,
         1178,
         1212,
         1178,
         1213,
         1178,
         1178,
         1178,
         1178,
         2794,
         1178,
         1178,
         1178,
         1178,
         2262,
         2263,
         2264,
         2265,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1178,
         1187,
         1178,
         1178,
         1199,
         1178,
         1178,
         1207,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1208,
         1209,
         1209,
         1209,
         1209,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1210,
         1178,
         1178,
         1211,
         1178,
         1212,
         1178,
         1213,
         1178,
         1178,
         1178,
         1178,
         2901,
         1178,
         1178,
         1178,
         1178,
         2262,
         2263,
         2264,
         2265,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1199,
         1199,
         1178,
         1178,
         1177,
         1186,
         1177,
         1177,
         1198,
         1199,
         1199,
         1200,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1201,
         1202,
         1202,
         1202,
         1202,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1203,
         1177,
         1177,
         1204,
         1177,
         1205,
         1177,
         1206,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1177,
         1177,
         2258,
         2259,
         2260,
         2261,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1198,
         2902,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1177,
         1186,
         1177,
         1177,
         1198,
         1199,
         1199,
         1200,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1201,
         1202,
         1202,
         1202,
         1202,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1203,
         1177,
         1177,
         1204,
         1177,
         1205,
         1177,
         1206,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1177,
         1177,
         2258,
         2259,
         2260,
         2261,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         2902,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         54,
         55,
         1196,
         1196,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         1197,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         1196,
         1196,
         1178,
         1178,
         2257,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         1196,
         2791,
         1178,
         1178,
         1177,
         1177,
         1196,
         2903,
         1177,
         1177,
         1196,
         2903,
         1177,
         1177,
         1196,
         2903,
         1177,
         1177,
         1196,
         2903,
         54,
         55,
         54,
         1197,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         1226,
         1226,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         2270,
         1197,
         1178,
         1178,
         1226,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         2792,
         1226,
         1178,
         1178,
         1177,
         1177,
         2903,
         1226,
         1177,
         1177,
         2903,
         1226,
         1177,
         1177,
         2903,
         1226,
         1177,
         1177,
         2903,
         1226,
         1177,
         1186,
         1177,
         1177,
         1198,
         1199,
         1199,
         1200,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1201,
         1202,
         1202,
         1202,
         1202,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1203,
         1177,
         1177,
         1204,
         1177,
         1205,
         1177,
         1206,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1177,
         1177,
         2258,
         2259,
         2260,
         2261,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1198,
         1198,
         1177,
         1177,
         1198,
         2931,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1177,
         1186,
         1177,
         1177,
         1198,
         1199,
         1199,
         1200,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1201,
         1202,
         1202,
         1202,
         1202,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1203,
         1177,
         1177,
         1204,
         1177,
         1205,
         1177,
         1206,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1177,
         1177,
         2258,
         2259,
         2260,
         2261,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1198,
         1198,
         1177,
         1177,
         2931,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         54,
         55,
         1196,
         1196,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         1197,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         1196,
         1196,
         1178,
         1178,
         2257,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         1196,
         2791,
         1178,
         1178,
         1177,
         1177,
         1196,
         2903,
         1177,
         1177,
         1196,
         2932,
         1177,
         1177,
         1196,
         2932,
         1177,
         1177,
         1196,
         2932,
         54,
         55,
         54,
         1197,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         1226,
         1226,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         2270,
         1197,
         1178,
         1178,
         1226,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         2792,
         1226,
         1178,
         1178,
         1177,
         1177,
         2903,
         1226,
         1177,
         1177,
         2932,
         1226,
         1177,
         1177,
         2932,
         1226,
         1177,
         1177,
         2932,
         1226,
         1177,
         1186,
         1177,
         1177,
         1198,
         1199,
         1199,
         1200,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1201,
         1202,
         1202,
         1202,
         1202,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1203,
         1177,
         1177,
         1204,
         1177,
         1205,
         1177,
         1206,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1177,
         1177,
         2258,
         2259,
         2260,
         2261,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         2940,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1177,
         1186,
         1177,
         1177,
         1198,
         1199,
         1199,
         1200,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1201,
         1202,
         1202,
         1202,
         1202,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1203,
         1177,
         1177,
         1204,
         1177,
         1205,
         1177,
         1206,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1177,
         1177,
         2258,
         2259,
         2260,
         2261,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         2940,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         54,
         55,
         1196,
         1196,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         1197,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         1196,
         1196,
         1178,
         1178,
         2257,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         1196,
         2791,
         1178,
         1178,
         1177,
         1177,
         1196,
         2903,
         1177,
         1177,
         1196,
         2932,
         1177,
         1177,
         1196,
         2941,
         1177,
         1177,
         1196,
         2941,
         54,
         55,
         54,
         1197,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         1226,
         1226,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         2270,
         1197,
         1178,
         1178,
         1226,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         2792,
         1226,
         1178,
         1178,
         1177,
         1177,
         2903,
         1226,
         1177,
         1177,
         2932,
         1226,
         1177,
         1177,
         2941,
         1226,
         1177,
         1177,
         2941,
         1226,
         1177,
         1186,
         1177,
         1177,
         1198,
         1199,
         1199,
         1200,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1201,
         1202,
         1202,
         1202,
         1202,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1203,
         1177,
         1177,
         1204,
         1177,
         1205,
         1177,
         1206,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1177,
         1177,
         2258,
         2259,
         2260,
         2261,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         2949,
         1177,
         1177,
         1177,
         1186,
         1177,
         1177,
         1198,
         1199,
         1199,
         1200,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1201,
         1202,
         1202,
         1202,
         1202,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1177,
         1203,
         1177,
         1177,
         1204,
         1177,
         1205,
         1177,
         1206,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1177,
         1177,
         2258,
         2259,
         2260,
         2261,
         1177,
         1177,
         1177,
         1177,
         1177,
         1199,
         1199,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         1198,
         1198,
         1177,
         1177,
         2949,
         1198,
         1177,
         1177,
         54,
         55,
         1196,
         1196,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         54,
         1197,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         1196,
         1196,
         1178,
         1178,
         2257,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         1196,
         2791,
         1178,
         1178,
         1177,
         1177,
         1196,
         2903,
         1177,
         1177,
         1196,
         2932,
         1177,
         1177,
         1196,
         2941,
         1177,
         1177,
         1196,
         2950,
         54,
         55,
         54,
         1197,
         1177,
         1178,
         1178,
         1179,
         54,
         54,
         54,
         1226,
         1226,
         54,
         54,
         1180,
         1181,
         1181,
         1181,
         1181,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1182,
         54,
         54,
         1183,
         54,
         1184,
         54,
         1185,
         54,
         54,
         54,
         2270,
         1197,
         1178,
         1178,
         1226,
         54,
         2249,
         2250,
         2251,
         2252,
         54,
         54,
         54,
         2792,
         1226,
         1178,
         1178,
         1177,
         1177,
         2903,
         1226,
         1177,
         1177,
         2932,
         1226,
         1177,
         1177,
         2941,
         1226,
         1177,
         1177,
         2950,
         1226,
      },
   },
   [nir_op_ieq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         0,
         13,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         16,
         17,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         9,
         19,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         0,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
      },
      
      .num_filtered_states = 20,
      .table = (const uint16_t []) {
      
         56,
         57,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         57,
         57,
         1718,
         1719,
         1720,
         1721,
         1722,
         1723,
         1724,
         1725,
         1726,
         1727,
         1728,
         1729,
         1730,
         1731,
         1732,
         1733,
         1734,
         2522,
         1716,
         1718,
         1716,
         1735,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1717,
         1719,
         1735,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         1717,
         56,
         1720,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1721,
         1716,
         1717,
         56,
         1736,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1722,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1723,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1724,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1725,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         1737,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1726,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         1738,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1727,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1728,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1729,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1730,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1731,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1732,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1733,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         1734,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         2522,
         1716,
         1717,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
         56,
      },
   },
   [nir_op_ine] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         8,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         0,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
      },
      
      .num_filtered_states = 17,
      .table = (const uint16_t []) {
      
         58,
         59,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         59,
         59,
         1741,
         1742,
         1743,
         1744,
         1745,
         1746,
         1747,
         1748,
         1749,
         1750,
         1751,
         1752,
         1753,
         1754,
         2523,
         1739,
         1741,
         1739,
         1755,
         1739,
         1739,
         1739,
         1739,
         1739,
         1739,
         1739,
         1739,
         1739,
         1739,
         1739,
         1739,
         1739,
         1740,
         1742,
         1755,
         1740,
         1740,
         1740,
         1740,
         1740,
         1740,
         1740,
         1740,
         1740,
         1740,
         1740,
         1740,
         1740,
         1740,
         58,
         1743,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1744,
         1739,
         1740,
         58,
         1756,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1745,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1746,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1747,
         1739,
         1740,
         58,
         58,
         58,
         58,
         1757,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1748,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         1758,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1749,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1750,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1751,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1752,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1753,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         1754,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         2523,
         1739,
         1740,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         58,
         2524,
      },
   },
   [nir_op_fsat] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         5,
         5,
         6,
         7,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         60,
         1471,
         1472,
         1473,
         1474,
         2464,
         2465,
         2466,
         2467,
         2468,
         2469,
      },
   },
   [nir_op_umul_unorm_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         61,
         61,
         61,
      },
   },
   [nir_op_fsign] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         62,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         63,
         64,
         63,
         63,
         1694,
         65,
         66,
         65,
         65,
         1695,
         1696,
         1697,
         1696,
         1696,
         1698,
         1699,
         1700,
         1699,
         1699,
         1701,
         63,
         64,
         63,
         63,
         1694,
         67,
         68,
         67,
         67,
         1702,
         69,
         70,
         69,
         69,
         1703,
         1704,
         1705,
         1704,
         1704,
         1706,
         1707,
         1708,
         1707,
         1707,
         1709,
         67,
         68,
         67,
         67,
         1702,
         63,
         64,
         63,
         63,
         1694,
         65,
         66,
         65,
         65,
         1695,
         1710,
         1711,
         1710,
         1710,
         1712,
         1699,
         1700,
         1699,
         1699,
         1701,
         63,
         64,
         63,
         63,
         1694,
         63,
         64,
         63,
         63,
         1694,
         65,
         66,
         65,
         65,
         1695,
         1696,
         1697,
         1696,
         1696,
         1698,
         1713,
         1714,
         1713,
         1713,
         1715,
         63,
         64,
         63,
         63,
         1694,
         63,
         64,
         63,
         63,
         1694,
         65,
         66,
         65,
         65,
         1695,
         1696,
         1697,
         1696,
         1696,
         1698,
         1699,
         1700,
         1699,
         1699,
         1701,
         63,
         64,
         63,
         63,
         1694,
      },
   },
   [nir_op_sdot_4x8_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         71,
         72,
         73,
         74,
         73,
         74,
         75,
         76,
      },
   },
   [nir_op_udot_4x8_uadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         77,
         78,
         79,
         80,
         79,
         80,
         81,
         82,
      },
   },
   [nir_op_sdot_4x8_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         83,
         83,
         84,
         84,
         84,
         84,
         85,
         85,
      },
   },
   [nir_op_udot_4x8_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         86,
         87,
         88,
         89,
         88,
         89,
         90,
         91,
      },
   },
   [nir_op_sdot_2x16_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         92,
         93,
         94,
         95,
         94,
         95,
         96,
         97,
      },
   },
   [nir_op_udot_2x16_uadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         98,
         99,
         100,
         101,
         100,
         101,
         102,
         103,
      },
   },
   [nir_op_sdot_2x16_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         104,
         104,
         105,
         105,
         105,
         105,
         106,
         106,
      },
   },
   [nir_op_udot_2x16_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         107,
         107,
         108,
         108,
         108,
         108,
         109,
         109,
      },
   },
   [nir_op_sudot_4x8_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         110,
         111,
         112,
         113,
         114,
         115,
         116,
         117,
      },
   },
   [nir_op_sudot_4x8_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         118,
         118,
         119,
         119,
         120,
         120,
         121,
         121,
      },
   },
   [nir_op_bcsel] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         4,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         10,
         0,
         11,
         0,
         12,
         0,
         0,
         13,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         0,
         16,
         17,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         19,
         19,
         19,
         20,
         21,
         22,
         21,
         22,
         23,
         23,
         23,
         23,
         0,
         0,
         24,
         25,
         26,
         26,
         26,
         26,
         27,
         27,
         28,
         28,
         29,
         29,
         0,
         30,
         30,
         31,
         31,
         32,
         32,
         33,
         33,
         34,
         34,
         0,
         35,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         36,
         0,
         37,
         0,
         38,
         39,
         39,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         40,
         41,
         41,
         41,
         41,
         42,
         43,
         44,
         0,
         0,
         45,
         46,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         47,
         48,
         49,
         50,
         51,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         36,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         22,
         21,
         22,
         21,
         22,
         21,
         21,
         21,
         22,
         22,
         21,
         22,
         21,
         21,
         21,
         22,
         21,
         22,
         21,
         21,
         21,
         21,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         0,
         0,
         0,
         0,
         0,
         54,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         55,
         56,
         57,
         58,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         59,
         60,
         61,
         62,
         0,
         0,
         0,
         0,
         63,
         17,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         64,
         65,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         66,
         67,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         24,
         24,
         24,
         24,
         24,
         25,
         24,
         25,
         24,
         24,
         25,
         24,
         25,
         24,
         24,
         25,
         25,
         24,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         68,
         69,
         70,
         71,
         72,
         0,
         40,
         40,
         40,
         40,
         40,
         42,
         43,
         43,
         43,
         43,
         44,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         18,
         18,
         34,
         34,
         38,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         41,
         0,
         0,
         0,
         0,
         0,
         47,
         51,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         73,
         74,
         75,
         76,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         16,
         16,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         20,
         20,
         20,
         20,
         20,
         20,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         21,
         22,
         22,
         22,
         22,
         22,
         23,
         23,
         23,
         23,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         41,
         3,
         3,
         3,
         63,
         63,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         11,
         12,
         0,
         25,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         27,
         33,
         33,
         33,
         33,
         33,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         0,
         0,
         35,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         67,
         67,
         65,
         0,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         10,
         10,
         10,
         10,
         10,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         20,
         20,
         20,
         0,
         0,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         17,
         22,
         23,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         22,
         22,
         22,
         30,
         30,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         77,
         0,
         0,
         9,
         15,
         9,
         9,
         0,
         0,
         10,
         10,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         10,
         10,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         10,
         10,
      },
      
      .num_filtered_states = 78,
      .table = (const uint16_t []) {
      
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         128,
         129,
         128,
         525,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         526,
         128,
         128,
         527,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         128,
         126,
         127,
         528,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         529,
         530,
         529,
         531,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         532,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         126,
         127,
         126,
         523,
         533,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         534,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         534,
         534,
         534,
         534,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         535,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         536,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         537,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         538,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         539,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         540,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         541,
         542,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         544,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         545,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         545,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         546,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         547,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         548,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         549,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         550,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         551,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         552,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         553,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         554,
         555,
         554,
         556,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         557,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         554,
         558,
         559,
         558,
         560,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         561,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         562,
         563,
         562,
         564,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         565,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         566,
         567,
         566,
         568,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         569,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         566,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         570,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         571,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         572,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         573,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         574,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         575,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         576,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         577,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         578,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         579,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         545,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         545,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         2562,
         2563,
         2562,
         2564,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2565,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2562,
         2566,
         2567,
         2566,
         2568,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2569,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2566,
         2570,
         2571,
         2570,
         2572,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2573,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2570,
         2574,
         2575,
         2574,
         2576,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2577,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         2574,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         534,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         534,
         534,
         534,
         534,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         534,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         534,
         534,
         534,
         534,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         534,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         534,
         534,
         534,
         534,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         534,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         534,
         534,
         534,
         534,
         126,
         126,
         127,
         126,
         523,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         524,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         126,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         584,
         585,
         584,
         586,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         587,
         584,
         584,
         588,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         584,
         580,
         581,
         589,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         590,
         591,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         593,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         580,
         581,
         580,
         582,
         594,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         595,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         595,
         595,
         595,
         595,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         596,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         597,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         598,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         599,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         600,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         601,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         602,
         603,
         602,
         604,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         605,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         602,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         606,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         606,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         607,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         608,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         609,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         610,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         611,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         612,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         613,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         614,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         615,
         616,
         615,
         617,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         618,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         615,
         619,
         620,
         619,
         621,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         622,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         619,
         623,
         624,
         623,
         625,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         626,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         623,
         627,
         628,
         627,
         629,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         630,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         631,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         632,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         633,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         634,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         635,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         636,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         637,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         638,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         639,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         640,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         606,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         606,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         2578,
         2579,
         2578,
         2580,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2581,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2578,
         2582,
         2583,
         2582,
         2584,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2585,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2582,
         2586,
         2587,
         2586,
         2588,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2589,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2586,
         2590,
         2591,
         2590,
         2592,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2593,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         2590,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         595,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         595,
         595,
         595,
         595,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         595,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         595,
         595,
         595,
         595,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         595,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         595,
         595,
         595,
         595,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         595,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         595,
         595,
         595,
         595,
         580,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         2767,
         124,
         2768,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2769,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2770,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         641,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         642,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         643,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         644,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         645,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2771,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2772,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2773,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2774,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         646,
         647,
         646,
         648,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         649,
         646,
         646,
         650,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         2594,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         2926,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         655,
         656,
         655,
         657,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         658,
         655,
         655,
         659,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         655,
         651,
         652,
         660,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         661,
         662,
         661,
         663,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         664,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         661,
         651,
         652,
         651,
         653,
         665,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         666,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         666,
         666,
         666,
         666,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         667,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         668,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         669,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         670,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         671,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         672,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         673,
         674,
         673,
         675,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         676,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         673,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         677,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         677,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         678,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         679,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         680,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         681,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         682,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         683,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         684,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         685,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         686,
         687,
         686,
         688,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         689,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         686,
         690,
         691,
         690,
         692,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         693,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         690,
         694,
         695,
         694,
         696,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         697,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         694,
         698,
         699,
         698,
         700,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         701,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         698,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         702,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         703,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         704,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         705,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         706,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         707,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         708,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         709,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         710,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         711,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         677,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         677,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         2595,
         2596,
         2595,
         2597,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2598,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2595,
         2599,
         2600,
         2599,
         2601,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2602,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2599,
         2603,
         2604,
         2603,
         2605,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2606,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2603,
         2607,
         2608,
         2607,
         2609,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2610,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         2607,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         666,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         666,
         666,
         666,
         666,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         666,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         666,
         666,
         666,
         666,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         666,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         666,
         666,
         666,
         666,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         666,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         666,
         666,
         666,
         666,
         651,
         651,
         652,
         651,
         653,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         654,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         651,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         716,
         717,
         716,
         718,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         719,
         716,
         716,
         720,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         712,
         713,
         721,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         722,
         723,
         722,
         724,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         725,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         712,
         713,
         712,
         714,
         726,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         728,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         729,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         730,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         731,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         732,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         733,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         734,
         735,
         734,
         736,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         737,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         738,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         738,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         739,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         740,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         741,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         742,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         743,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         744,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         745,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         746,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         747,
         748,
         747,
         749,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         750,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         751,
         752,
         751,
         753,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         754,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         755,
         756,
         755,
         757,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         758,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         759,
         760,
         759,
         761,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         762,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         763,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         764,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         765,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         766,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         767,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         768,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         769,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         770,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         771,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         772,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         738,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         738,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         2611,
         2612,
         2611,
         2613,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2614,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2615,
         2616,
         2615,
         2617,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2618,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2619,
         2620,
         2619,
         2621,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2622,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2623,
         2624,
         2623,
         2625,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2626,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         716,
         717,
         716,
         718,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         719,
         716,
         716,
         720,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         773,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         716,
         712,
         713,
         721,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         774,
         775,
         774,
         776,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         777,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         774,
         712,
         713,
         712,
         714,
         726,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         728,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         729,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         730,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         731,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         732,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         733,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         734,
         735,
         734,
         736,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         737,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         734,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         738,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         738,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         739,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         740,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         741,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         742,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         743,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         744,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         745,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         746,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         747,
         748,
         747,
         749,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         750,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         747,
         751,
         752,
         751,
         753,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         754,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         751,
         755,
         756,
         755,
         757,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         758,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         755,
         759,
         760,
         759,
         761,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         762,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         759,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         763,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         764,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         765,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         766,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         767,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         768,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         769,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         770,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         771,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         772,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         738,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         738,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         2611,
         2612,
         2611,
         2613,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2614,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2611,
         2615,
         2616,
         2615,
         2617,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2618,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2615,
         2619,
         2620,
         2619,
         2621,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2622,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2619,
         2623,
         2624,
         2623,
         2625,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2626,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         2623,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         727,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         727,
         727,
         727,
         727,
         712,
         712,
         713,
         712,
         714,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         715,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         712,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         782,
         783,
         782,
         784,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         785,
         782,
         782,
         786,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         778,
         779,
         787,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         788,
         789,
         788,
         790,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         791,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         788,
         778,
         779,
         778,
         780,
         792,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         793,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         793,
         793,
         793,
         793,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         794,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         795,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         796,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         797,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         798,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         799,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         800,
         801,
         800,
         802,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         803,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         800,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         804,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         804,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         805,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         806,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         807,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         808,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         809,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         810,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         811,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         812,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         813,
         814,
         813,
         815,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         816,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         813,
         817,
         818,
         817,
         819,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         820,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         817,
         821,
         822,
         821,
         823,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         824,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         821,
         825,
         826,
         825,
         827,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         828,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         825,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         829,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         830,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         831,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         832,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         833,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         834,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         835,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         836,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         837,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         838,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         804,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         804,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         2627,
         2628,
         2627,
         2629,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2630,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2627,
         2631,
         2632,
         2631,
         2633,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2634,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2631,
         2635,
         2636,
         2635,
         2637,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2638,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2635,
         2639,
         2640,
         2639,
         2641,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2642,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         2639,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         793,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         793,
         793,
         793,
         793,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         793,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         793,
         793,
         793,
         793,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         793,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         793,
         793,
         793,
         793,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         793,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         793,
         793,
         793,
         793,
         778,
         778,
         779,
         778,
         780,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         781,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         778,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         843,
         844,
         843,
         845,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         846,
         843,
         843,
         847,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         839,
         840,
         848,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         849,
         850,
         849,
         851,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         852,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         839,
         840,
         839,
         841,
         853,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         855,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         856,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         857,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         858,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         859,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         860,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         861,
         862,
         861,
         863,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         864,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         865,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         865,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         866,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         867,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         868,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         869,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         870,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         871,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         872,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         873,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         874,
         875,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         877,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         878,
         879,
         878,
         880,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         881,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         882,
         883,
         882,
         884,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         885,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         886,
         887,
         886,
         888,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         889,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         890,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         891,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         892,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         893,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         894,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         895,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         896,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         897,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         898,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         899,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         865,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         865,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         2643,
         2644,
         2643,
         2645,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2646,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2647,
         2648,
         2647,
         2649,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2650,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2651,
         2652,
         2651,
         2653,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2654,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2655,
         2656,
         2655,
         2657,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2658,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         843,
         844,
         843,
         845,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         846,
         843,
         843,
         847,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         843,
         839,
         840,
         848,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         849,
         850,
         849,
         851,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         852,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         849,
         839,
         840,
         839,
         841,
         853,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         855,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         856,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         857,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         858,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         859,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         860,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         861,
         862,
         861,
         863,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         864,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         861,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         865,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         865,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         866,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         867,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         868,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         869,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         870,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         871,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         872,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         873,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         874,
         875,
         874,
         876,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         877,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         874,
         878,
         879,
         878,
         880,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         881,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         882,
         883,
         882,
         884,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         885,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         882,
         886,
         887,
         886,
         888,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         889,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         886,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         890,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         891,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         892,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         893,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         894,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         895,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         896,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         897,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         898,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         899,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         2659,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         865,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         865,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         2643,
         2644,
         2643,
         2645,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2646,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2643,
         2647,
         2648,
         2647,
         2649,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2650,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2647,
         2651,
         2652,
         2651,
         2653,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2654,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2651,
         2655,
         2656,
         2655,
         2657,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2658,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         2655,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         854,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         854,
         854,
         854,
         854,
         839,
         839,
         840,
         839,
         841,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         842,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         839,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         904,
         905,
         904,
         906,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         907,
         904,
         904,
         908,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         904,
         900,
         901,
         909,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         910,
         911,
         910,
         912,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         913,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         910,
         900,
         901,
         900,
         902,
         914,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         915,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         915,
         915,
         915,
         915,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         916,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         917,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         918,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         919,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         920,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         921,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         922,
         923,
         922,
         924,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         925,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         922,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         926,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         926,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         927,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         928,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         929,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         930,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         931,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         932,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         933,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         934,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         935,
         936,
         935,
         937,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         938,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         935,
         939,
         940,
         939,
         941,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         942,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         939,
         943,
         944,
         943,
         945,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         946,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         943,
         947,
         948,
         947,
         949,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         950,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         947,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         951,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         952,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         953,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         954,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         955,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         956,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         957,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         958,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         959,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         960,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         926,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         926,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         2660,
         2661,
         2660,
         2662,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2663,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2660,
         2664,
         2665,
         2664,
         2666,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2667,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2664,
         2668,
         2669,
         2668,
         2670,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2671,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2668,
         2672,
         2673,
         2672,
         2674,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2675,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         2672,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         915,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         915,
         915,
         915,
         915,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         915,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         915,
         915,
         915,
         915,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         915,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         915,
         915,
         915,
         915,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         915,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         915,
         915,
         915,
         915,
         900,
         900,
         901,
         900,
         902,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         903,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         900,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         965,
         966,
         965,
         967,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         968,
         965,
         965,
         969,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         961,
         962,
         970,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         971,
         972,
         971,
         973,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         974,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         961,
         962,
         961,
         963,
         975,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         977,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         978,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         979,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         980,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         981,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         982,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         983,
         984,
         983,
         985,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         986,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         988,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         989,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         990,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         991,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         992,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         993,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         994,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         995,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         996,
         997,
         996,
         998,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         999,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         1000,
         1001,
         1000,
         1002,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1003,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1004,
         1005,
         1004,
         1006,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1007,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1008,
         1009,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1011,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1012,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1013,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1014,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1015,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1016,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1017,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1018,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1019,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1020,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1021,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2676,
         2677,
         2676,
         2678,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2679,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2680,
         2681,
         2680,
         2682,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2683,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2684,
         2685,
         2684,
         2686,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2687,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2688,
         2689,
         2688,
         2690,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2691,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1026,
         1027,
         1026,
         1028,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1029,
         1026,
         1026,
         1030,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1026,
         1022,
         1023,
         1031,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1032,
         1033,
         1032,
         1034,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1035,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1032,
         1022,
         1023,
         1022,
         1024,
         1036,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1037,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1037,
         1037,
         1037,
         1037,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1038,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1039,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1040,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1041,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1042,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1043,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1044,
         1045,
         1044,
         1046,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1047,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1044,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1048,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1048,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1049,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1050,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1051,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1052,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1053,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1054,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1055,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1056,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1057,
         1058,
         1057,
         1059,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1060,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1057,
         1061,
         1062,
         1061,
         1063,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1064,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1061,
         1065,
         1066,
         1065,
         1067,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1068,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1065,
         1069,
         1070,
         1069,
         1071,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1072,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1069,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1073,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1074,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1075,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1076,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1077,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1078,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1079,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1080,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1081,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1082,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1048,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1048,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         2692,
         2693,
         2692,
         2694,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2695,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2696,
         2697,
         2696,
         2698,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2699,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2696,
         2700,
         2701,
         2700,
         2702,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2703,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2700,
         2704,
         2705,
         2704,
         2706,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2707,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         2704,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1037,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1037,
         1037,
         1037,
         1037,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1037,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1037,
         1037,
         1037,
         1037,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1037,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1037,
         1037,
         1037,
         1037,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1037,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1037,
         1037,
         1037,
         1037,
         1022,
         1022,
         1023,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         2775,
         2767,
         124,
         2768,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2776,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2769,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2770,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         2777,
         124,
         2768,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2778,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2770,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         2767,
         2779,
         2768,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2769,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2780,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2770,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         2767,
         124,
         2781,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2769,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2782,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         641,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         642,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         643,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         644,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         645,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2783,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2784,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2771,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2772,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2773,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2774,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         641,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         642,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         643,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         644,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         645,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2785,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2786,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2773,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2774,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         641,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         642,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         643,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         644,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         645,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2771,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2772,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2787,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2788,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2773,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2774,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         641,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         642,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         643,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         644,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         645,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2771,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2772,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         2789,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2790,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         965,
         966,
         965,
         967,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         968,
         965,
         965,
         969,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         961,
         962,
         970,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         971,
         972,
         971,
         973,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         974,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         961,
         962,
         961,
         963,
         975,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         977,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         978,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         979,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         980,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         981,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         982,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         983,
         984,
         983,
         985,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         986,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         988,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         989,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         990,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         991,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         992,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         993,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         994,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         995,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         996,
         997,
         996,
         998,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         999,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         1000,
         1001,
         1000,
         1002,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1003,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1004,
         1005,
         1004,
         1006,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1007,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1008,
         1009,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1011,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1012,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1013,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1014,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1015,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1016,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1017,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1018,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1019,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2708,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1020,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1021,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2676,
         2677,
         2676,
         2678,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2679,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2680,
         2681,
         2680,
         2682,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2683,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2684,
         2685,
         2684,
         2686,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2687,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2688,
         2689,
         2688,
         2690,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2691,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         965,
         966,
         965,
         967,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         968,
         965,
         965,
         969,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         961,
         962,
         970,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         971,
         972,
         971,
         973,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         974,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         961,
         962,
         961,
         963,
         975,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         977,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         978,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         979,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         980,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         981,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         982,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         983,
         984,
         983,
         985,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         986,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         988,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         989,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         990,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         991,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         992,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         993,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         994,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         995,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         996,
         997,
         996,
         998,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         999,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         1000,
         1001,
         1000,
         1002,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1003,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1004,
         1005,
         1004,
         1006,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1007,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1008,
         1009,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1011,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1012,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1013,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1014,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1015,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1016,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1017,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1018,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1019,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2709,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1020,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1021,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2676,
         2677,
         2676,
         2678,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2679,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2680,
         2681,
         2680,
         2682,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2683,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2684,
         2685,
         2684,
         2686,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2687,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2688,
         2689,
         2688,
         2690,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2691,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         965,
         966,
         965,
         967,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         968,
         965,
         965,
         969,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         961,
         962,
         970,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         971,
         972,
         971,
         973,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         974,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         961,
         962,
         961,
         963,
         975,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         977,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         978,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         979,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         980,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         981,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         982,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         983,
         984,
         983,
         985,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         986,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         988,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         989,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         990,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         991,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         992,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         993,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         994,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         995,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         996,
         997,
         996,
         998,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         999,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         1000,
         1001,
         1000,
         1002,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1003,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1004,
         1005,
         1004,
         1006,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1007,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1008,
         1009,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1011,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1012,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1013,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1014,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1015,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1016,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1017,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1018,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1019,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2710,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1020,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1021,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2676,
         2677,
         2676,
         2678,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2679,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2680,
         2681,
         2680,
         2682,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2683,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2684,
         2685,
         2684,
         2686,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2687,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2688,
         2689,
         2688,
         2690,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2691,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         965,
         966,
         965,
         967,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         968,
         965,
         965,
         969,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         961,
         962,
         970,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         971,
         972,
         971,
         973,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         974,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         961,
         962,
         961,
         963,
         975,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         977,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         978,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         979,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         980,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         981,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         982,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         983,
         984,
         983,
         985,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         986,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         988,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         989,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         990,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         991,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         992,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         993,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         994,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         995,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         996,
         997,
         996,
         998,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         999,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         1000,
         1001,
         1000,
         1002,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1003,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1004,
         1005,
         1004,
         1006,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1007,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1008,
         1009,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1011,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1012,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1013,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1014,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1015,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1016,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1017,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1018,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1019,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2711,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1020,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1021,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2676,
         2677,
         2676,
         2678,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2679,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2680,
         2681,
         2680,
         2682,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2683,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2684,
         2685,
         2684,
         2686,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2687,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2688,
         2689,
         2688,
         2690,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2691,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         965,
         966,
         965,
         967,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         968,
         965,
         965,
         969,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         965,
         961,
         962,
         970,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         971,
         972,
         971,
         973,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         974,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         971,
         961,
         962,
         961,
         963,
         975,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         977,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         978,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         979,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         980,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         981,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         982,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         983,
         984,
         983,
         985,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         986,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         983,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         988,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         989,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         990,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         991,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         992,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         993,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         994,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         995,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         996,
         997,
         996,
         998,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         999,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         996,
         1000,
         1001,
         1000,
         1002,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1003,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1000,
         1004,
         1005,
         1004,
         1006,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1007,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1004,
         1008,
         1009,
         1008,
         1010,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1011,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         1008,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1012,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1013,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1014,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1015,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1016,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1017,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1018,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1019,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2712,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1020,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         1021,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         987,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         2676,
         2677,
         2676,
         2678,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2679,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2676,
         2680,
         2681,
         2680,
         2682,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2683,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2680,
         2684,
         2685,
         2684,
         2686,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2687,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2684,
         2688,
         2689,
         2688,
         2690,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2691,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         2688,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         976,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         976,
         976,
         976,
         976,
         961,
         961,
         962,
         961,
         963,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         964,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         961,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         124,
         125,
         124,
         468,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         469,
         124,
         124,
         470,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         124,
         122,
         123,
         471,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         472,
         473,
         472,
         474,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         475,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         472,
         122,
         123,
         122,
         466,
         476,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         478,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         479,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         480,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         481,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         482,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         483,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         484,
         485,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         487,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         489,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         490,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         491,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         492,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         493,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         494,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         495,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         496,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         497,
         498,
         497,
         499,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         500,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         497,
         501,
         502,
         501,
         503,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         504,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         501,
         505,
         506,
         505,
         507,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         508,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         505,
         509,
         510,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         512,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         513,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         514,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         515,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         516,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         517,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         518,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         519,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         520,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         521,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         522,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         488,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         2546,
         2547,
         2546,
         2548,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2549,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2546,
         2550,
         2551,
         2550,
         2552,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2553,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2550,
         2554,
         2555,
         2554,
         2556,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2557,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2554,
         2558,
         2559,
         2558,
         2560,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2561,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         2558,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         477,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         477,
         477,
         477,
         477,
         122,
         122,
         123,
         122,
         466,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         467,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
      },
   },
   [nir_op_feq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         13,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         17,
         2,
         2,
         2,
         2,
         2,
         18,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         21,
         4,
         4,
         0,
         2,
         2,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         21,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 22,
      .table = (const uint16_t []) {
      
         130,
         131,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         131,
         131,
         1477,
         1478,
         1479,
         1480,
         1481,
         1482,
         1483,
         1484,
         131,
         1485,
         1486,
         1487,
         1488,
         2163,
         2164,
         2165,
         1477,
         2166,
         2167,
         2881,
         1475,
         1477,
         1489,
         1475,
         1490,
         1490,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1489,
         1489,
         1490,
         1475,
         1490,
         130,
         1478,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         1476,
         1479,
         1490,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1490,
         1490,
         1476,
         1476,
         1476,
         1476,
         1480,
         1490,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1490,
         1490,
         1476,
         1476,
         1476,
         130,
         1481,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         130,
         1482,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         130,
         1483,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         1491,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         2168,
         1476,
         130,
         1476,
         130,
         1484,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         130,
         131,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         1492,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         130,
         1485,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         130,
         1486,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         130,
         1487,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         130,
         1488,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         130,
         2163,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         130,
         2164,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         1475,
         2165,
         1489,
         1475,
         1490,
         1490,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1489,
         1489,
         1490,
         1475,
         1490,
         1475,
         1477,
         1489,
         1475,
         1490,
         1490,
         1475,
         1475,
         2168,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1475,
         1489,
         2169,
         1490,
         1475,
         1490,
         1476,
         2166,
         1490,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1490,
         1490,
         1476,
         1476,
         1476,
         130,
         2167,
         1475,
         130,
         1476,
         1476,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         130,
         1475,
         1475,
         1476,
         130,
         1476,
         1476,
         2881,
         1490,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1476,
         1490,
         1490,
         1476,
         1476,
         1476,
      },
   },
   [nir_op_fexp2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         3,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         4,
         1,
         1,
         1,
         1,
         3,
         1,
         1,
         1,
         1,
         1,
         3,
         1,
         1,
         3,
         1,
         3,
         1,
         1,
         3,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         3,
         3,
         3,
         3,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         3,
         3,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         132,
         1759,
         1760,
         2490,
         2491,
         2883,
      },
   },
   [nir_search_op_b2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         1,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         133,
         1987,
         1988,
         1989,
      },
   },
   [nir_op_ftrunc] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         134,
      },
   },
   [nir_op_ffloor] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         135,
      },
   },
   [nir_op_ffract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         136,
      },
   },
   [nir_op_fceil] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         137,
      },
   },
   [nir_search_op_b2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         138,
         1885,
         1886,
         1887,
         1888,
         2713,
         2714,
      },
   },
   [nir_op_fdph] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         139,
      },
   },
   [nir_op_fdot4] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         140,
         1977,
         1978,
         1979,
         1977,
         1977,
         1978,
         1979,
         1978,
         1978,
         1978,
         1979,
         1979,
         1979,
         1979,
         1979,
      },
   },
   [nir_op_vec4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         141,
         142,
         141,
         143,
         141,
         142,
         141,
         144,
         141,
         142,
         141,
         143,
         141,
         142,
         141,
         144,
      },
   },
   [nir_op_fdot3] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         145,
         1980,
         1981,
         1980,
         1980,
         1981,
         1981,
         1981,
         1981,
      },
   },
   [nir_op_vec3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         146,
         147,
         146,
         148,
         146,
         147,
         146,
         148,
      },
   },
   [nir_op_fdot2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         149,
         150,
         1982,
         150,
         150,
         1983,
         1982,
         1983,
         1982,
      },
   },
   [nir_op_vec2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         151,
         152,
         151,
         151,
         153,
         154,
         153,
         153,
         151,
         152,
         151,
         1322,
         151,
         152,
         151,
         151,
      },
   },
   [nir_op_fsum2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         155,
      },
   },
   [nir_op_ushr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         8,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         4,
         13,
         0,
         3,
         3,
         8,
         4,
         14,
         9,
         2,
         4,
         15,
         3,
         3,
         8,
         4,
         16,
         9,
         2,
         4,
         17,
         3,
         3,
         8,
         4,
         0,
         9,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         156,
         157,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         158,
         159,
         158,
         1298,
         158,
         1299,
         158,
         2154,
         2155,
         158,
         158,
         1298,
         158,
         1298,
         158,
         1298,
         158,
         1298,
         1300,
         1301,
         1300,
         1302,
         1300,
         1303,
         1300,
         2156,
         2157,
         1300,
         1300,
         1302,
         1300,
         1302,
         1300,
         1302,
         1300,
         1302,
         156,
         157,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1304,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         157,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1305,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         157,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         1300,
         1301,
         1300,
         1302,
         1300,
         1303,
         1300,
         2156,
         2157,
         1300,
         1300,
         1302,
         1300,
         1302,
         1300,
         1302,
         1300,
         1302,
         156,
         2158,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         2159,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         2831,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         2924,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         2930,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         2934,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         2939,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         2943,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         2948,
         156,
         1296,
         156,
         1297,
         156,
         2152,
         2153,
         156,
         156,
         1296,
         156,
         1296,
         156,
         1296,
         156,
         1296,
      },
   },
   [nir_op_ishr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         4,
         0,
         4,
         4,
         2,
         0,
         0,
         0,
         2,
         0,
         4,
         4,
         4,
         2,
         0,
         0,
         0,
         2,
         0,
         4,
         4,
         4,
         2,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         160,
         161,
         160,
         160,
         1306,
         160,
         162,
         163,
         162,
         162,
         1307,
         162,
         160,
         1308,
         160,
         160,
         1306,
         160,
         1309,
         1310,
         1309,
         1309,
         1311,
         1309,
         160,
         161,
         160,
         160,
         1306,
         160,
         160,
         1312,
         160,
         160,
         1306,
         160,
      },
   },
   [nir_op_inot] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         7,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         10,
         10,
         11,
         11,
         12,
         12,
         12,
         12,
         13,
         13,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         0,
         0,
         22,
         0,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         22,
         22,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         23,
         21,
         21,
         21,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         11,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         10,
         0,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 24,
      .table = (const uint16_t []) {
      
         164,
         1680,
         1681,
         1682,
         1683,
         1684,
         1685,
         1686,
         1687,
         1688,
         1689,
         1690,
         1691,
         1692,
         1693,
         2309,
         2310,
         2311,
         2312,
         2313,
         2314,
         2827,
         2828,
         2829,
      },
   },
   [nir_op_flt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         13,
         2,
         14,
         2,
         2,
         2,
         2,
         2,
         15,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         16,
         5,
         17,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         16,
         5,
         5,
         5,
         5,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         7,
         7,
         7,
         7,
         7,
         7,
         16,
         5,
         17,
         17,
         17,
         17,
         17,
         17,
         6,
         6,
         16,
         16,
         5,
         16,
         16,
         5,
         0,
         19,
         2,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         20,
         6,
         6,
         21,
         16,
         16,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         16,
         16,
         5,
         5,
         5,
         5,
         16,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         22,
         9,
         9,
         22,
         9,
         9,
         22,
         9,
         22,
         22,
         9,
         22,
         9,
         22,
         9,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         0,
         17,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 23,
      .table = (const uint16_t []) {
      
         165,
         166,
         1493,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1493,
         1493,
         1493,
         165,
         165,
         165,
         1493,
         165,
         165,
         1494,
         167,
         168,
         1496,
         1497,
         1498,
         167,
         167,
         1499,
         1500,
         1501,
         1502,
         1503,
         167,
         1496,
         1496,
         1496,
         167,
         167,
         2409,
         1496,
         167,
         167,
         1501,
         165,
         1504,
         1505,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1505,
         1505,
         1505,
         165,
         165,
         165,
         1505,
         165,
         165,
         1494,
         165,
         166,
         1493,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1493,
         1493,
         1493,
         165,
         165,
         165,
         1493,
         165,
         165,
         1494,
         165,
         1506,
         1493,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1493,
         1493,
         1493,
         165,
         165,
         165,
         1493,
         165,
         165,
         1494,
         1507,
         1508,
         1509,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1510,
         1507,
         1511,
         1507,
         1509,
         1509,
         1509,
         1507,
         1507,
         1507,
         1509,
         1507,
         1507,
         1510,
         1507,
         1512,
         1509,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1510,
         1507,
         1511,
         1507,
         1509,
         1509,
         1509,
         1507,
         1507,
         1507,
         1509,
         1507,
         1507,
         1510,
         165,
         166,
         1493,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1493,
         1493,
         1493,
         165,
         165,
         165,
         1493,
         165,
         165,
         1494,
         165,
         1513,
         1493,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1493,
         1493,
         1493,
         165,
         165,
         165,
         1493,
         165,
         165,
         1494,
         1514,
         1515,
         1516,
         1514,
         1514,
         1514,
         1514,
         1514,
         1514,
         1517,
         1514,
         1518,
         1514,
         1516,
         1516,
         1516,
         1514,
         1514,
         1514,
         1516,
         1514,
         1514,
         1517,
         165,
         1519,
         1493,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1493,
         1493,
         1493,
         165,
         165,
         165,
         1493,
         165,
         165,
         1494,
         1520,
         1521,
         1522,
         1520,
         1520,
         1520,
         1520,
         1520,
         1520,
         1523,
         1520,
         1524,
         1520,
         1522,
         1522,
         1522,
         1520,
         1520,
         1520,
         1522,
         1520,
         1520,
         1523,
         165,
         166,
         1493,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         1525,
         1493,
         1493,
         1493,
         165,
         165,
         165,
         1493,
         165,
         165,
         1494,
         165,
         2410,
         1505,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1505,
         1505,
         1505,
         165,
         165,
         165,
         1505,
         165,
         165,
         1494,
         165,
         2411,
         1505,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1505,
         1505,
         1505,
         165,
         165,
         165,
         1505,
         165,
         165,
         1494,
         165,
         2412,
         1505,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1505,
         1505,
         1505,
         165,
         165,
         165,
         1505,
         165,
         165,
         1494,
         1507,
         2413,
         1509,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1510,
         1507,
         1511,
         1507,
         1509,
         1509,
         1509,
         1507,
         1507,
         1507,
         1509,
         1507,
         1507,
         1510,
         1507,
         2414,
         1509,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1510,
         1507,
         1511,
         1507,
         1509,
         1509,
         1509,
         1507,
         1507,
         1507,
         1509,
         1507,
         1507,
         1510,
         1507,
         1508,
         1509,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1510,
         1507,
         1511,
         1507,
         1509,
         1509,
         1509,
         1507,
         1507,
         1507,
         1509,
         1507,
         1507,
         1510,
         165,
         2884,
         1505,
         165,
         165,
         165,
         165,
         165,
         165,
         1494,
         165,
         1495,
         165,
         1505,
         1505,
         1505,
         165,
         165,
         165,
         1505,
         165,
         165,
         1494,
         1507,
         2904,
         1509,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1510,
         1507,
         1511,
         1507,
         1509,
         1509,
         1509,
         1507,
         1507,
         1507,
         1509,
         1507,
         1507,
         1510,
         1507,
         2905,
         1509,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1510,
         1507,
         1511,
         1507,
         1509,
         1509,
         1509,
         1507,
         1507,
         1507,
         1509,
         1507,
         1507,
         1510,
         1514,
         2906,
         1516,
         1514,
         1514,
         1514,
         1514,
         1514,
         1514,
         1517,
         1514,
         1518,
         1514,
         1516,
         1516,
         1516,
         1514,
         1514,
         1514,
         1516,
         1514,
         1514,
         1517,
      },
   },
   [nir_op_fge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         14,
         2,
         15,
         2,
         2,
         2,
         2,
         2,
         16,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         7,
         7,
         7,
         7,
         7,
         7,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         18,
         2,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 19,
      .table = (const uint16_t []) {
      
         169,
         170,
         1526,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1526,
         1526,
         1526,
         169,
         1526,
         171,
         172,
         1529,
         1530,
         1531,
         171,
         171,
         171,
         1532,
         1533,
         1534,
         1535,
         1536,
         171,
         1529,
         1529,
         1529,
         2415,
         1529,
         169,
         1537,
         1538,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1538,
         1538,
         1538,
         169,
         1538,
         169,
         170,
         1526,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1526,
         1526,
         1526,
         169,
         1526,
         169,
         1539,
         1526,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1526,
         1526,
         1526,
         169,
         1526,
         1540,
         1541,
         1542,
         1540,
         1540,
         1540,
         1540,
         1540,
         1540,
         1540,
         1543,
         1540,
         1544,
         1540,
         1542,
         1542,
         1542,
         1540,
         1542,
         1540,
         1545,
         1542,
         1540,
         1540,
         1540,
         1540,
         1540,
         1540,
         1540,
         1543,
         1540,
         1544,
         1540,
         1542,
         1542,
         1542,
         1540,
         1542,
         169,
         1546,
         1526,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1526,
         1526,
         1526,
         169,
         1526,
         169,
         1547,
         1526,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1526,
         1526,
         1526,
         169,
         1526,
         169,
         170,
         1526,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1526,
         1526,
         1526,
         169,
         1526,
         1548,
         1549,
         1550,
         1548,
         1548,
         1548,
         1548,
         1548,
         1548,
         1548,
         1551,
         1548,
         1552,
         1548,
         1550,
         1550,
         1550,
         1548,
         1550,
         169,
         1553,
         1526,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1526,
         1526,
         1526,
         169,
         1526,
         1554,
         1555,
         1556,
         1554,
         1554,
         1554,
         1554,
         1554,
         1554,
         1554,
         1557,
         1554,
         1558,
         1554,
         1556,
         1556,
         1556,
         1554,
         1556,
         169,
         170,
         1526,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         1559,
         1526,
         1526,
         1526,
         169,
         1526,
         169,
         2416,
         1538,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1538,
         1538,
         1538,
         169,
         1538,
         169,
         2417,
         1538,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1538,
         1538,
         1538,
         169,
         1538,
         169,
         2418,
         1538,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1538,
         1538,
         1538,
         169,
         1538,
         1540,
         1541,
         1542,
         1540,
         1540,
         1540,
         1540,
         1540,
         1540,
         1540,
         1543,
         1540,
         1544,
         1540,
         1542,
         1542,
         1542,
         1540,
         1542,
         169,
         2885,
         1538,
         169,
         169,
         169,
         169,
         169,
         169,
         169,
         1527,
         169,
         1528,
         169,
         1538,
         1538,
         1538,
         169,
         1538,
      },
   },
   [nir_op_fneu] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         13,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         17,
         2,
         2,
         2,
         2,
         2,
         18,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         21,
         4,
         4,
         0,
         2,
         2,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         21,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 22,
      .table = (const uint16_t []) {
      
         173,
         174,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         174,
         174,
         1562,
         1563,
         1564,
         1565,
         1566,
         1567,
         1568,
         1569,
         174,
         1570,
         1571,
         1572,
         1573,
         2170,
         2171,
         2172,
         1562,
         2173,
         2174,
         2882,
         1560,
         1562,
         1574,
         1560,
         1575,
         1575,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1574,
         1574,
         1575,
         1560,
         1575,
         173,
         1563,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         1561,
         1564,
         1575,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1575,
         1575,
         1561,
         1561,
         1561,
         1561,
         1565,
         1575,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1575,
         1575,
         1561,
         1561,
         1561,
         173,
         1566,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         173,
         1567,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         173,
         1568,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         1576,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         2175,
         1561,
         173,
         1561,
         173,
         1569,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         173,
         174,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         1577,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         173,
         1570,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         173,
         1571,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         173,
         1572,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         173,
         1573,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         173,
         2170,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         173,
         2171,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         1560,
         2172,
         1574,
         1560,
         1575,
         1575,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1574,
         1574,
         1575,
         1560,
         1575,
         1560,
         1562,
         1574,
         1560,
         1575,
         1575,
         1560,
         1560,
         2175,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1560,
         1574,
         2176,
         1575,
         1560,
         1575,
         1561,
         2173,
         1575,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1575,
         1575,
         1561,
         1561,
         1561,
         173,
         2174,
         1560,
         173,
         1561,
         1561,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         173,
         1560,
         1560,
         1561,
         173,
         1561,
         1561,
         2882,
         1575,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1561,
         1575,
         1575,
         1561,
         1561,
         1561,
      },
   },
   [nir_op_ilt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         175,
         176,
         175,
         1899,
         1899,
         1900,
         1900,
         175,
         175,
         175,
         176,
         1901,
         1899,
         1902,
         1900,
         1903,
         1904,
         175,
         175,
         1905,
         175,
         1899,
         1899,
         1900,
         1900,
         175,
         175,
         1906,
         1907,
         1906,
         1908,
         1908,
         1909,
         1909,
         1906,
         1906,
         1906,
         1910,
         1906,
         1908,
         1908,
         1909,
         1909,
         1906,
         1906,
         1911,
         1912,
         1911,
         1913,
         1913,
         1914,
         1914,
         1911,
         1911,
         1911,
         1915,
         1911,
         1913,
         1913,
         1914,
         1914,
         1911,
         1911,
         175,
         1916,
         175,
         1899,
         1899,
         1900,
         1900,
         1917,
         175,
         175,
         2525,
         175,
         1899,
         1899,
         1900,
         1900,
         175,
         175,
      },
   },
   [nir_op_ult] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         5,
         5,
         12,
         6,
         6,
         11,
         11,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         11,
         5,
         5,
         7,
         7,
         8,
         8,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         10,
         5,
         5,
         6,
         6,
         11,
         11,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
      },
      
      .num_filtered_states = 13,
      .table = (const uint16_t []) {
      
         177,
         178,
         1761,
         177,
         177,
         1762,
         1762,
         1763,
         1763,
         177,
         177,
         2526,
         2526,
         179,
         180,
         1764,
         179,
         1765,
         1766,
         1767,
         1768,
         1769,
         1770,
         2527,
         2528,
         2529,
         177,
         178,
         1761,
         177,
         177,
         1762,
         1762,
         1763,
         1763,
         177,
         177,
         2526,
         2526,
         1771,
         1772,
         1773,
         1771,
         1771,
         1774,
         1774,
         1775,
         1775,
         1771,
         1771,
         2530,
         2530,
         177,
         1776,
         1761,
         177,
         177,
         1762,
         1762,
         1763,
         1763,
         177,
         177,
         2526,
         2526,
         1777,
         1778,
         1779,
         1777,
         1777,
         1780,
         1780,
         1781,
         1781,
         1777,
         1777,
         2531,
         2531,
         1777,
         1782,
         1779,
         1777,
         1777,
         1780,
         1780,
         1781,
         1781,
         1777,
         1777,
         2531,
         2531,
         1783,
         1784,
         1785,
         1783,
         1783,
         1786,
         1786,
         1787,
         1787,
         1783,
         1783,
         2532,
         2532,
         1783,
         1788,
         1785,
         1783,
         1783,
         1786,
         1786,
         1787,
         1787,
         1783,
         1783,
         2532,
         2532,
         177,
         1789,
         1761,
         177,
         177,
         1762,
         1762,
         1763,
         1763,
         1790,
         177,
         2526,
         2526,
         177,
         178,
         1761,
         177,
         177,
         1762,
         1762,
         1763,
         1763,
         177,
         177,
         2526,
         2526,
         1777,
         1778,
         1779,
         1777,
         1777,
         1780,
         1780,
         1781,
         1781,
         1777,
         1777,
         2531,
         2531,
         1777,
         1782,
         1779,
         1777,
         1777,
         1780,
         1780,
         1781,
         1781,
         1777,
         1777,
         2531,
         2531,
      },
   },
   [nir_op_ige] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         10,
         11,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 14,
      .table = (const uint16_t []) {
      
         181,
         182,
         181,
         1918,
         1918,
         1919,
         1919,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         182,
         1920,
         1918,
         1921,
         1919,
         1922,
         1923,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         1924,
         181,
         1918,
         1918,
         1919,
         1919,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         1925,
         1926,
         1925,
         1927,
         1927,
         1928,
         1928,
         1925,
         1925,
         1925,
         1925,
         1925,
         1925,
         1925,
         1925,
         1929,
         1925,
         1927,
         1927,
         1928,
         1928,
         1925,
         1925,
         1925,
         1925,
         1925,
         1925,
         1925,
         1930,
         1931,
         1930,
         1932,
         1932,
         1933,
         1933,
         1930,
         1930,
         1930,
         1930,
         1930,
         1930,
         1930,
         1930,
         1934,
         1930,
         1932,
         1932,
         1933,
         1933,
         1930,
         1930,
         1930,
         1930,
         1930,
         1930,
         1930,
         181,
         1935,
         181,
         1918,
         1918,
         1919,
         1919,
         1936,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         1937,
         181,
         1918,
         1918,
         1919,
         1919,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         1938,
         181,
         1918,
         1918,
         1919,
         1919,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         1939,
         181,
         1918,
         1918,
         1919,
         1919,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         1940,
         181,
         1918,
         1918,
         1919,
         1919,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         1941,
         181,
         1918,
         1918,
         1919,
         1919,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
         2533,
         181,
         1918,
         1918,
         1919,
         1919,
         181,
         181,
         181,
         181,
         181,
         181,
         181,
      },
   },
   [nir_op_uge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         7,
         7,
         8,
         8,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         5,
         5,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
      },
      
      .num_filtered_states = 10,
      .table = (const uint16_t []) {
      
         183,
         183,
         1791,
         183,
         183,
         1792,
         1792,
         1793,
         1793,
         183,
         184,
         184,
         1794,
         184,
         1795,
         1796,
         1797,
         1798,
         1799,
         1800,
         183,
         183,
         1791,
         183,
         183,
         1792,
         1792,
         1793,
         1793,
         183,
         1801,
         1801,
         1802,
         1801,
         1801,
         1803,
         1803,
         1804,
         1804,
         1801,
         183,
         1805,
         1791,
         183,
         183,
         1792,
         1792,
         1793,
         1793,
         183,
         1806,
         1806,
         1807,
         1806,
         1806,
         1808,
         1808,
         1809,
         1809,
         1806,
         1806,
         1810,
         1807,
         1806,
         1806,
         1808,
         1808,
         1809,
         1809,
         1806,
         1811,
         1811,
         1812,
         1811,
         1811,
         1813,
         1813,
         1814,
         1814,
         1811,
         1811,
         1815,
         1812,
         1811,
         1811,
         1813,
         1813,
         1814,
         1814,
         1811,
         183,
         1816,
         1791,
         183,
         183,
         1792,
         1792,
         1793,
         1793,
         1817,
      },
   },
   [nir_op_fmin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         9,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         10,
         2,
         2,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         12,
         6,
         6,
         6,
         6,
         6,
         12,
         6,
         6,
         6,
         12,
         6,
         12,
         6,
         6,
         12,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         12,
         6,
         6,
         12,
         12,
         6,
         6,
         12,
         12,
         12,
         6,
         6,
         12,
         6,
         12,
         6,
         12,
         7,
         7,
         13,
         7,
         8,
         8,
         8,
         14,
         14,
         8,
         13,
         7,
         7,
         7,
         13,
         7,
         7,
         7,
         13,
         7,
         13,
         7,
         7,
         13,
         7,
         13,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         2,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         12,
         12,
         6,
         6,
         6,
         6,
         6,
         12,
         12,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         185,
         186,
         1578,
         1579,
         185,
         185,
         1580,
         1581,
         1581,
         2419,
         1578,
         2420,
         2421,
         2832,
         2832,
         2833,
         186,
         186,
         1582,
         1583,
         1584,
         1585,
         1586,
         1587,
         1588,
         2422,
         1582,
         2423,
         2424,
         2834,
         2835,
         2836,
         1578,
         1582,
         1578,
         1589,
         1578,
         1578,
         1590,
         1591,
         1591,
         2419,
         1578,
         2420,
         2425,
         2837,
         2837,
         2833,
         1579,
         1583,
         1589,
         1579,
         1579,
         1579,
         1592,
         1593,
         1593,
         2426,
         1589,
         2427,
         2428,
         2838,
         2838,
         2839,
         185,
         1584,
         1578,
         1579,
         185,
         185,
         1580,
         1581,
         1581,
         2419,
         1578,
         2420,
         2421,
         2832,
         2832,
         2833,
         185,
         1585,
         1578,
         1579,
         185,
         1594,
         1580,
         1581,
         1581,
         2419,
         1578,
         2420,
         2421,
         2832,
         2832,
         2833,
         1580,
         1586,
         1590,
         1592,
         1580,
         1580,
         1580,
         1595,
         1595,
         2429,
         1590,
         2430,
         2421,
         2840,
         2840,
         2841,
         1581,
         1587,
         1591,
         1593,
         1581,
         1581,
         1595,
         1581,
         1581,
         2431,
         1591,
         2432,
         2433,
         2832,
         2832,
         2842,
         1581,
         1588,
         1591,
         1593,
         1581,
         1581,
         1595,
         1581,
         1581,
         2431,
         1591,
         2432,
         2433,
         2832,
         2832,
         2842,
         2419,
         2422,
         2419,
         2426,
         2419,
         2419,
         2429,
         2431,
         2431,
         2419,
         2419,
         2434,
         2435,
         2843,
         2843,
         2844,
         1578,
         1582,
         1578,
         1589,
         1578,
         1578,
         1590,
         1591,
         1591,
         2419,
         2436,
         2420,
         2425,
         2837,
         2837,
         2833,
         2420,
         2423,
         2420,
         2427,
         2420,
         2420,
         2430,
         2432,
         2432,
         2434,
         2420,
         2420,
         2437,
         2845,
         2845,
         2846,
         2421,
         2424,
         2425,
         2428,
         2421,
         2421,
         2421,
         2433,
         2433,
         2435,
         2425,
         2437,
         2421,
         2847,
         2847,
         2848,
         2832,
         2834,
         2837,
         2838,
         2832,
         2832,
         2840,
         2832,
         2832,
         2843,
         2837,
         2845,
         2847,
         2832,
         2832,
         2849,
         2832,
         2835,
         2837,
         2838,
         2832,
         2832,
         2840,
         2832,
         2832,
         2843,
         2837,
         2845,
         2847,
         2832,
         2832,
         2849,
         2833,
         2836,
         2833,
         2839,
         2833,
         2833,
         2841,
         2842,
         2842,
         2844,
         2833,
         2846,
         2848,
         2849,
         2849,
         2833,
      },
   },
   [nir_search_op_i2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         187,
         1961,
         1962,
         1963,
         1964,
         2922,
      },
   },
   [nir_op_fmax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         8,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         9,
         2,
         10,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         6,
         6,
         6,
         6,
         6,
         13,
         13,
         0,
         0,
         12,
         0,
         12,
         0,
         12,
         7,
         7,
         14,
         7,
         7,
         7,
         7,
         14,
         7,
         14,
         14,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         14,
         7,
         7,
         7,
         7,
         7,
         14,
         7,
         14,
         7,
         7,
         7,
         14,
         14,
         14,
         14,
         7,
         7,
         14,
         7,
         7,
         14,
         14,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         13,
         13,
         6,
         12,
         12,
         0,
         12,
         0,
         12,
         12,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 17,
      .table = (const uint16_t []) {
      
         188,
         189,
         1596,
         1597,
         188,
         188,
         188,
         1598,
         2438,
         1596,
         2439,
         188,
         2440,
         2440,
         2441,
         188,
         188,
         189,
         189,
         1599,
         1600,
         1601,
         189,
         1602,
         1603,
         2442,
         1599,
         2443,
         2444,
         2445,
         2446,
         2447,
         2907,
         2908,
         1596,
         1599,
         1596,
         1604,
         1596,
         1596,
         1596,
         1605,
         2438,
         1596,
         2439,
         1596,
         2448,
         2448,
         2449,
         1596,
         1596,
         1597,
         1600,
         1604,
         1597,
         1597,
         1597,
         1597,
         1606,
         2450,
         1604,
         2451,
         1597,
         2452,
         2452,
         2453,
         1597,
         1597,
         188,
         1601,
         1596,
         1597,
         188,
         188,
         188,
         1598,
         2438,
         1596,
         2439,
         188,
         2440,
         2440,
         2441,
         188,
         188,
         188,
         189,
         1596,
         1597,
         188,
         1607,
         188,
         1598,
         2438,
         1596,
         2439,
         188,
         2440,
         2440,
         2441,
         188,
         188,
         188,
         1602,
         1596,
         1597,
         188,
         188,
         188,
         1598,
         2438,
         1596,
         2439,
         188,
         2440,
         2440,
         2441,
         188,
         188,
         1598,
         1603,
         1605,
         1606,
         1598,
         1598,
         1598,
         1598,
         2454,
         1605,
         2455,
         1598,
         2456,
         2456,
         2441,
         1598,
         1598,
         2438,
         2442,
         2438,
         2450,
         2438,
         2438,
         2438,
         2454,
         2438,
         2438,
         2457,
         2438,
         2458,
         2458,
         2459,
         2438,
         2438,
         1596,
         1599,
         1596,
         1604,
         1596,
         1596,
         1596,
         1605,
         2438,
         2460,
         2439,
         1596,
         2448,
         2448,
         2449,
         1596,
         1596,
         2439,
         2443,
         2439,
         2451,
         2439,
         2439,
         2439,
         2455,
         2457,
         2439,
         2439,
         2439,
         2461,
         2461,
         2462,
         2439,
         2439,
         188,
         2444,
         1596,
         1597,
         188,
         188,
         188,
         1598,
         2438,
         1596,
         2439,
         188,
         2440,
         2440,
         2441,
         188,
         188,
         2440,
         2445,
         2448,
         2452,
         2440,
         2440,
         2440,
         2456,
         2458,
         2448,
         2461,
         2440,
         2440,
         2440,
         2463,
         2440,
         2440,
         2440,
         2446,
         2448,
         2452,
         2440,
         2440,
         2440,
         2456,
         2458,
         2448,
         2461,
         2440,
         2440,
         2440,
         2463,
         2440,
         2440,
         2441,
         2447,
         2449,
         2453,
         2441,
         2441,
         2441,
         2441,
         2459,
         2449,
         2462,
         2441,
         2463,
         2463,
         2441,
         2441,
         2441,
         188,
         2907,
         1596,
         1597,
         188,
         188,
         188,
         1598,
         2438,
         1596,
         2439,
         188,
         2440,
         2440,
         2441,
         188,
         188,
         188,
         2908,
         1596,
         1597,
         188,
         188,
         188,
         1598,
         2438,
         1596,
         2439,
         188,
         2440,
         2440,
         2441,
         188,
         188,
      },
   },
   [nir_op_imin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         7,
         2,
         2,
         8,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         9,
         4,
         4,
         4,
         9,
         4,
         4,
         4,
         9,
         4,
         9,
         4,
         9,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         9,
         4,
         9,
         9,
         4,
         9,
         9,
         4,
         9,
         9,
         4,
         5,
         10,
         5,
         6,
         11,
         11,
         6,
         10,
         5,
         5,
         10,
         5,
         5,
         10,
         10,
         5,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         9,
         4,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         190,
         191,
         1626,
         1627,
         1628,
         1629,
         1629,
         2492,
         1626,
         2493,
         2886,
         2886,
         191,
         191,
         1630,
         1631,
         1632,
         1633,
         1634,
         2494,
         1630,
         2495,
         2887,
         2888,
         1626,
         1630,
         1626,
         1635,
         1636,
         1637,
         1637,
         2492,
         1626,
         2496,
         2889,
         2889,
         1627,
         1631,
         1635,
         1627,
         1638,
         1639,
         1639,
         2497,
         1635,
         2498,
         2890,
         2890,
         1628,
         1632,
         1636,
         1638,
         1628,
         1640,
         1640,
         2499,
         1636,
         2493,
         2891,
         2891,
         1629,
         1633,
         1637,
         1639,
         1640,
         1629,
         1629,
         2500,
         1637,
         2501,
         2886,
         2886,
         1629,
         1634,
         1637,
         1639,
         1640,
         1629,
         1629,
         2500,
         1637,
         2501,
         2886,
         2886,
         2492,
         2494,
         2492,
         2497,
         2499,
         2500,
         2500,
         2492,
         2492,
         2502,
         2892,
         2892,
         1626,
         1630,
         1626,
         1635,
         1636,
         1637,
         1637,
         2492,
         2503,
         2496,
         2889,
         2889,
         2493,
         2495,
         2496,
         2498,
         2493,
         2501,
         2501,
         2502,
         2496,
         2493,
         2893,
         2893,
         2886,
         2887,
         2889,
         2890,
         2891,
         2886,
         2886,
         2892,
         2889,
         2893,
         2886,
         2886,
         2886,
         2888,
         2889,
         2890,
         2891,
         2886,
         2886,
         2892,
         2889,
         2893,
         2886,
         2886,
      },
   },
   [nir_op_imax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         6,
         2,
         2,
         7,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         4,
         4,
         4,
         9,
         9,
         0,
         0,
         8,
         0,
         8,
         8,
         5,
         5,
         10,
         5,
         5,
         5,
         10,
         5,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         5,
         5,
         10,
         5,
         5,
         5,
         10,
         5,
         10,
         5,
         5,
         10,
         10,
         10,
         5,
         10,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         9,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         192,
         193,
         1641,
         1642,
         192,
         1643,
         2504,
         1641,
         2505,
         2505,
         2506,
         193,
         193,
         1644,
         1645,
         1646,
         1647,
         2507,
         1644,
         2508,
         2509,
         2510,
         1641,
         1644,
         1641,
         1648,
         1641,
         1649,
         2504,
         1641,
         2511,
         2511,
         2512,
         1642,
         1645,
         1648,
         1642,
         1642,
         1650,
         2513,
         1648,
         2514,
         2514,
         2515,
         192,
         1646,
         1641,
         1642,
         192,
         1643,
         2504,
         1641,
         2505,
         2505,
         2506,
         1643,
         1647,
         1649,
         1650,
         1643,
         1643,
         2516,
         1649,
         2517,
         2517,
         2506,
         2504,
         2507,
         2504,
         2513,
         2504,
         2516,
         2504,
         2504,
         2518,
         2518,
         2519,
         1641,
         1644,
         1641,
         1648,
         1641,
         1649,
         2504,
         2520,
         2511,
         2511,
         2512,
         2505,
         2508,
         2511,
         2514,
         2505,
         2517,
         2518,
         2511,
         2505,
         2505,
         2521,
         2505,
         2509,
         2511,
         2514,
         2505,
         2517,
         2518,
         2511,
         2505,
         2505,
         2521,
         2506,
         2510,
         2512,
         2515,
         2506,
         2506,
         2519,
         2512,
         2521,
         2521,
         2506,
      },
   },
   [nir_op_umin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         3,
         3,
         6,
         3,
         6,
         3,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         3,
         8,
         4,
         8,
         4,
         8,
         4,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         3,
         3,
         3,
         3,
         3,
         3,
         6,
         6,
         3,
         6,
         6,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         194,
         195,
         1818,
         1819,
         1820,
         194,
         2534,
         2755,
         2756,
         195,
         195,
         1821,
         1822,
         1823,
         195,
         2535,
         2757,
         2758,
         1818,
         1821,
         1818,
         1824,
         1825,
         1818,
         2536,
         2759,
         2760,
         1819,
         1822,
         1824,
         1819,
         1826,
         1819,
         2534,
         2761,
         2762,
         1820,
         1823,
         1825,
         1826,
         1820,
         1820,
         2537,
         2763,
         2756,
         194,
         195,
         1818,
         1819,
         1820,
         2538,
         2534,
         2755,
         2756,
         2534,
         2535,
         2536,
         2534,
         2537,
         2534,
         2534,
         2764,
         2765,
         2755,
         2757,
         2759,
         2761,
         2763,
         2755,
         2764,
         2755,
         2766,
         2756,
         2758,
         2760,
         2762,
         2756,
         2756,
         2765,
         2766,
         2756,
      },
   },
   [nir_op_umax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         4,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         2,
         5,
         2,
         5,
         5,
         2,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         4,
         0,
         4,
         0,
         4,
         0,
         4,
         4,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         196,
         197,
         1990,
         196,
         2539,
         2540,
         197,
         197,
         1991,
         197,
         2541,
         2542,
         1990,
         1991,
         1990,
         1990,
         2543,
         2540,
         196,
         197,
         1990,
         2544,
         2539,
         2540,
         2539,
         2541,
         2543,
         2539,
         2539,
         2545,
         2540,
         2542,
         2540,
         2540,
         2545,
         2540,
      },
   },
   [nir_op_extract_u8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         3,
         3,
         0,
         0,
         4,
         0,
         4,
         0,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
      },
      
      .num_filtered_states = 10,
      .table = (const uint16_t []) {
      
         198,
         199,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         199,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         1313,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         1314,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         1315,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         1316,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         1317,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         1318,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         1319,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         2715,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
         198,
      },
   },
   [nir_search_op_f2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         200,
         1651,
         1652,
         1653,
         1654,
         1655,
         1656,
      },
   },
   [nir_search_op_f2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         201,
         1657,
         1658,
         1659,
         1660,
         1661,
         1662,
      },
   },
   [nir_search_op_f2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         202,
         1663,
         1664,
         1665,
         1666,
         1667,
         1668,
         1669,
         1670,
         1671,
         1672,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         7,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         7,
         11,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         203,
         1829,
         1830,
         1831,
         1832,
         1833,
         1834,
         1835,
         1836,
         1837,
         1838,
         2753,
      },
   },
   [nir_search_op_u2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         8,
         9,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         5,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         14,
         9,
         9,
         9,
         9,
         9,
         15,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         9,
         9,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         1,
         0,
         1,
         1,
         0,
         6,
         0,
         0,
         0,
         6,
         1,
         1,
         1,
         0,
         6,
         0,
         0,
         0,
         6,
         1,
         1,
         1,
         0,
         6,
         0,
         0,
      },
      
      .num_filtered_states = 19,
      .table = (const uint16_t []) {
      
         204,
         1839,
         1840,
         1841,
         1842,
         1843,
         1844,
         1845,
         1846,
         1847,
         1848,
         1849,
         1850,
         1851,
         2751,
         2752,
         2824,
         2825,
         2826,
      },
   },
   [nir_op_f2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         205,
         1673,
         1674,
         1675,
         1676,
         1677,
         1678,
         1679,
      },
   },
   [nir_op_i2imp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         3,
         3,
         3,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         206,
         1965,
         1966,
         1967,
         1968,
         1969,
         1970,
         1971,
         1972,
      },
   },
   [nir_op_extract_i8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         207,
         208,
         207,
         207,
         207,
         208,
         207,
         207,
         207,
         1320,
         207,
         207,
         207,
         1321,
         207,
         207,
      },
   },
   [nir_op_extract_i16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         209,
         210,
         209,
         210,
      },
   },
   [nir_op_extract_u16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         211,
         212,
         211,
         211,
         211,
         211,
         212,
         211,
         211,
         211,
         211,
         1992,
         211,
         211,
         211,
         211,
         1993,
         211,
         211,
         211,
         211,
         1994,
         211,
         211,
         211,
      },
   },
   [nir_op_ixor] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         3,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         4,
         5,
         6,
         7,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         12,
         13,
         14,
         15,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         2,
         3,
         2,
         2,
         2,
         3,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         17,
         17,
         17,
         17,
         17,
         17,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         4,
         4,
         4,
         4,
         4,
         5,
         4,
         4,
         5,
         5,
         6,
         6,
         7,
         6,
         7,
         6,
         7,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         16,
         16,
         16,
         16,
         17,
         17,
         17,
         17,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         21,
         21,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
      },
      
      .num_filtered_states = 22,
      .table = (const uint16_t []) {
      
         213,
         214,
         213,
         213,
         213,
         213,
         213,
         213,
         213,
         1268,
         213,
         1269,
         213,
         1270,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         214,
         214,
         214,
         214,
         214,
         214,
         214,
         214,
         214,
         1273,
         214,
         1274,
         214,
         1275,
         214,
         1276,
         1277,
         1278,
         2720,
         2721,
         2722,
         2723,
         213,
         214,
         213,
         1279,
         213,
         213,
         213,
         213,
         213,
         1268,
         213,
         1269,
         213,
         1270,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         213,
         214,
         1279,
         1279,
         213,
         213,
         213,
         213,
         213,
         1268,
         213,
         1269,
         213,
         1270,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         213,
         214,
         213,
         213,
         213,
         1280,
         213,
         213,
         213,
         1268,
         213,
         1269,
         213,
         1270,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         213,
         214,
         213,
         213,
         1280,
         1280,
         213,
         213,
         213,
         1268,
         213,
         1269,
         213,
         1270,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         213,
         214,
         213,
         213,
         213,
         213,
         213,
         1281,
         213,
         1268,
         213,
         1269,
         213,
         1270,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         213,
         214,
         213,
         213,
         213,
         213,
         1281,
         1281,
         213,
         1268,
         213,
         1269,
         213,
         1270,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         213,
         214,
         213,
         213,
         213,
         213,
         213,
         213,
         213,
         1282,
         213,
         1269,
         213,
         1270,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         1268,
         1273,
         1268,
         1268,
         1268,
         1268,
         1268,
         1268,
         1282,
         1282,
         1268,
         1283,
         1268,
         1284,
         1268,
         1285,
         1286,
         1286,
         2724,
         2725,
         2726,
         2727,
         213,
         214,
         213,
         213,
         213,
         213,
         213,
         213,
         213,
         1268,
         213,
         1287,
         213,
         1270,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         1269,
         1274,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1269,
         1283,
         1287,
         1287,
         1269,
         1288,
         1269,
         1289,
         1290,
         1290,
         2728,
         2729,
         2730,
         2731,
         213,
         214,
         213,
         213,
         213,
         213,
         213,
         213,
         213,
         1268,
         213,
         1269,
         213,
         1291,
         213,
         1271,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         1270,
         1275,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1284,
         1270,
         1288,
         1291,
         1291,
         1270,
         1292,
         1293,
         1293,
         2732,
         2733,
         2734,
         2735,
         213,
         214,
         213,
         213,
         213,
         213,
         213,
         213,
         213,
         1268,
         213,
         1269,
         213,
         1270,
         213,
         1294,
         1272,
         1272,
         2716,
         2717,
         2718,
         2719,
         1271,
         1276,
         1271,
         1271,
         1271,
         1271,
         1271,
         1271,
         1271,
         1285,
         1271,
         1289,
         1271,
         1292,
         1294,
         1294,
         1295,
         1295,
         2736,
         2737,
         2738,
         2739,
         1272,
         1277,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1286,
         1272,
         1290,
         1272,
         1293,
         1272,
         1295,
         1272,
         1272,
         2740,
         2741,
         2742,
         2743,
         1272,
         1278,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1272,
         1286,
         1272,
         1290,
         1272,
         1293,
         1272,
         1295,
         1272,
         1272,
         2740,
         2741,
         2742,
         2743,
         2716,
         2720,
         2716,
         2716,
         2716,
         2716,
         2716,
         2716,
         2716,
         2724,
         2716,
         2728,
         2716,
         2732,
         2716,
         2736,
         2740,
         2740,
         2716,
         2744,
         2745,
         2746,
         2717,
         2721,
         2717,
         2717,
         2717,
         2717,
         2717,
         2717,
         2717,
         2725,
         2717,
         2729,
         2717,
         2733,
         2717,
         2737,
         2741,
         2741,
         2744,
         2717,
         2747,
         2748,
         2718,
         2722,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2718,
         2726,
         2718,
         2730,
         2718,
         2734,
         2718,
         2738,
         2742,
         2742,
         2745,
         2747,
         2718,
         2749,
         2719,
         2723,
         2719,
         2719,
         2719,
         2719,
         2719,
         2719,
         2719,
         2727,
         2719,
         2731,
         2719,
         2735,
         2719,
         2739,
         2743,
         2743,
         2746,
         2748,
         2749,
         2750,
      },
   },
   [nir_op_slt] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         215,
      },
   },
   [nir_op_sge] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         216,
      },
   },
   [nir_op_seq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         217,
         217,
         217,
         217,
         217,
         217,
         217,
         217,
         1995,
         1996,
         1997,
         1998,
         217,
         1995,
         217,
         217,
         217,
         217,
         217,
         1996,
         217,
         217,
         217,
         217,
         217,
         1997,
         217,
         217,
         217,
         217,
         217,
         1998,
         217,
         217,
         217,
         217,
      },
   },
   [nir_op_sne] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         218,
         218,
         218,
         218,
         218,
         218,
         218,
         218,
         1999,
         2000,
         2001,
         2002,
         218,
         1999,
         218,
         218,
         218,
         218,
         218,
         2000,
         218,
         218,
         218,
         218,
         218,
         2001,
         218,
         218,
         218,
         218,
         218,
         2002,
         218,
         218,
         218,
         218,
      },
   },
   [nir_op_fall_equal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         219,
      },
   },
   [nir_op_fall_equal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         220,
      },
   },
   [nir_op_fall_equal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         221,
      },
   },
   [nir_op_fall_equal8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         222,
      },
   },
   [nir_op_fall_equal16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         223,
      },
   },
   [nir_op_fany_nequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         224,
      },
   },
   [nir_op_fany_nequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         225,
      },
   },
   [nir_op_fany_nequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         226,
      },
   },
   [nir_op_fany_nequal8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         227,
      },
   },
   [nir_op_fany_nequal16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         228,
      },
   },
   [nir_op_ball_iequal2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         229,
         229,
         229,
         229,
         229,
         229,
         1875,
         1876,
         229,
         1875,
         229,
         229,
         229,
         1876,
         229,
         229,
      },
   },
   [nir_op_ball_iequal3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         230,
         230,
         230,
         230,
         230,
         230,
         1877,
         1878,
         230,
         1877,
         230,
         230,
         230,
         1878,
         230,
         230,
      },
   },
   [nir_op_ball_iequal4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         231,
         231,
         231,
         231,
         231,
         231,
         1879,
         1880,
         231,
         1879,
         231,
         231,
         231,
         1880,
         231,
         231,
      },
   },
   [nir_op_ball_iequal8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         232,
         232,
         232,
         232,
         232,
         232,
         1881,
         1882,
         232,
         1881,
         232,
         232,
         232,
         1882,
         232,
         232,
      },
   },
   [nir_op_ball_iequal16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         233,
         233,
         233,
         233,
         233,
         233,
         1883,
         1884,
         233,
         1883,
         233,
         233,
         233,
         1884,
         233,
         233,
      },
   },
   [nir_op_ball_fequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         234,
      },
   },
   [nir_op_ball_fequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         235,
      },
   },
   [nir_op_ball_fequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         236,
      },
   },
   [nir_op_ball_fequal8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         237,
      },
   },
   [nir_op_ball_fequal16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         238,
      },
   },
   [nir_op_bany_inequal2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         239,
         239,
         239,
         239,
         239,
         239,
         1889,
         1890,
         239,
         1889,
         239,
         239,
         239,
         1890,
         239,
         239,
      },
   },
   [nir_op_bany_inequal3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         240,
         240,
         240,
         240,
         240,
         240,
         1891,
         1892,
         240,
         1891,
         240,
         240,
         240,
         1892,
         240,
         240,
      },
   },
   [nir_op_bany_inequal4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         241,
         241,
         241,
         241,
         241,
         241,
         1893,
         1894,
         241,
         1893,
         241,
         241,
         241,
         1894,
         241,
         241,
      },
   },
   [nir_op_bany_inequal8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         242,
         242,
         242,
         242,
         242,
         242,
         1895,
         1896,
         242,
         1895,
         242,
         242,
         242,
         1896,
         242,
         242,
      },
   },
   [nir_op_bany_inequal16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         243,
         243,
         243,
         243,
         243,
         243,
         1897,
         1898,
         243,
         1897,
         243,
         243,
         243,
         1898,
         243,
         243,
      },
   },
   [nir_op_bany_fnequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         244,
      },
   },
   [nir_op_bany_fnequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         245,
      },
   },
   [nir_op_bany_fnequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         246,
      },
   },
   [nir_op_bany_fnequal8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         247,
      },
   },
   [nir_op_bany_fnequal16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         248,
      },
   },
   [nir_op_isub] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         249,
         249,
         250,
         250,
      },
   },
   [nir_op_urol] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         251,
      },
   },
   [nir_op_uror] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         252,
      },
   },
   [nir_op_flog2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         4,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         253,
         1943,
         1944,
         1945,
         1946,
         1947,
      },
   },
   [nir_op_fpow] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         254,
         255,
         254,
         254,
         256,
         257,
         256,
         256,
         254,
         2003,
         254,
         254,
         254,
         2486,
         254,
         254,
      },
   },
   [nir_op_fsqrt] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         258,
         1948,
      },
   },
   [nir_op_frcp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         3,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         259,
         1949,
         1950,
         1951,
         1952,
      },
   },
   [nir_op_frsq] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         260,
         1953,
      },
   },
   [nir_op_fdiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         261,
         261,
         262,
         262,
      },
   },
   [nir_op_fsin] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         263,
      },
   },
   [nir_op_fcos] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         264,
      },
   },
   [nir_op_fcsel] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         265,
      },
   },
   [nir_op_f2imp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         266,
         1954,
         1955,
      },
   },
   [nir_op_f2ump] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         267,
         1956,
         1957,
      },
   },
   [nir_op_i2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         268,
         1973,
         1974,
      },
   },
   [nir_op_u2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         269,
         1975,
         1976,
      },
   },
   [nir_op_fround_even] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         270,
      },
   },
   [nir_op_pack_64_2x32_split] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         271,
         271,
         271,
         271,
         271,
         1323,
         271,
         271,
         271,
      },
   },
   [nir_op_unpack_64_2x32_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         272,
         1852,
         1853,
         1854,
         1855,
         1856,
      },
   },
   [nir_op_pack_64_2x32] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         273,
         2006,
         2408,
      },
   },
   [nir_op_unpack_64_2x32] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         274,
         2004,
         2005,
      },
   },
   [nir_op_unpack_double_2x32_dxil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         275,
         2008,
      },
   },
   [nir_op_pack_double_2x32_dxil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         276,
         2007,
      },
   },
   [nir_op_unpack_32_2x16_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         277,
         1857,
         1858,
      },
   },
   [nir_op_unpack_32_2x16_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         278,
         1859,
      },
   },
   [nir_op_ubfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         279,
         1860,
         2895,
         0,
         280,
         1860,
         2895,
         1861,
         1862,
         1863,
         2896,
         0,
         279,
         1860,
         2895,
         0,
         279,
         1860,
         2895,
         0,
         280,
         1860,
         2895,
         1861,
         1862,
         1863,
         2896,
         0,
         279,
         1860,
         2895,
         0,
         279,
         1860,
         2895,
         0,
         280,
         1860,
         2895,
         1861,
         1862,
         1863,
         2896,
         0,
         279,
         1860,
         2895,
         0,
         279,
         1860,
         2895,
         0,
         280,
         1860,
         2895,
         1861,
         1862,
         1863,
         2896,
         0,
         279,
         1860,
         2895,
      },
   },
   [nir_op_ibfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         281,
         1864,
         2897,
         0,
         282,
         1864,
         2897,
         1865,
         1866,
         1867,
         2898,
         0,
         281,
         1864,
         2897,
         0,
         281,
         1864,
         2897,
         0,
         282,
         1864,
         2897,
         1865,
         1866,
         1867,
         2898,
         0,
         281,
         1864,
         2897,
         0,
         281,
         1864,
         2897,
         0,
         282,
         1864,
         2897,
         1865,
         1866,
         1867,
         2898,
         0,
         281,
         1864,
         2897,
         0,
         281,
         1864,
         2897,
         0,
         282,
         1864,
         2897,
         1865,
         1866,
         1867,
         2898,
         0,
         281,
         1864,
         2897,
      },
   },
   [nir_op_pack_32_2x16_split] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         283,
      },
   },
   [nir_op_unpack_half_2x16_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         0,
         1,
         1,
         0,
         2,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         0,
         2,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         0,
         2,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         284,
         1868,
         1869,
         1870,
      },
   },
   [nir_op_unpack_half_2x16_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         285,
         1871,
      },
   },
   [nir_op_pack_half_2x16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         1984,
         1985,
         1986,
      },
   },
   [nir_op_pack_half_2x16_split] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         286,
         287,
         288,
         289,
      },
   },
   [nir_op_pack_32_4x8_split] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         290,
      },
   },
   [nir_op_ussub_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         291,
         0,
         291,
      },
   },
   [nir_op_fsub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         292,
      },
   },
   [nir_op_uabs_usub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         293,
      },
   },
   [nir_op_uabs_isub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         294,
      },
   },
   [nir_op_find_lsb] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         295,
         2009,
      },
   },
   [nir_op_ifind_msb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         296,
      },
   },
   [nir_op_ufind_msb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         297,
      },
   },
   [nir_op_ifind_msb_rev] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         298,
      },
   },
   [nir_op_ufind_msb_rev] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         299,
         2010,
      },
   },
   [nir_op_bitfield_reverse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         300,
      },
   },
   [nir_op_fmod] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         301,
      },
   },
   [nir_op_frem] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         302,
      },
   },
   [nir_op_uadd_carry] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         303,
      },
   },
   [nir_op_usub_borrow] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         304,
      },
   },
   [nir_op_bitfield_insert] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         305,
      },
   },
   [nir_op_ihadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         306,
      },
   },
   [nir_op_uhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         307,
      },
   },
   [nir_op_irhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         308,
      },
   },
   [nir_op_urhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         309,
      },
   },
   [nir_op_imul_32x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         310,
      },
   },
   [nir_op_umul_32x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         311,
      },
   },
   [nir_op_ibitfield_extract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         312,
      },
   },
   [nir_op_ubitfield_extract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         313,
      },
   },
   [nir_op_bitfield_select] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         314,
         0,
         0,
         314,
         0,
         1827,
         1828,
         1827,
         0,
         314,
         0,
         0,
         314,
         0,
         1827,
         1828,
         1827,
         0,
         314,
         0,
         0,
         314,
         0,
         1827,
         1828,
         1827,
      },
   },
   [nir_op_bfm] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         2,
         0,
         2,
         0,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         1872,
         0,
         1873,
         1874,
         1873,
         2899,
         2900,
         2899,
      },
   },
   [nir_op_uclz] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         315,
      },
   },
   [nir_op_pack_unorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         316,
      },
   },
   [nir_op_pack_unorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         317,
      },
   },
   [nir_op_pack_snorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         318,
      },
   },
   [nir_op_pack_snorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         319,
      },
   },
   [nir_op_unpack_unorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         320,
      },
   },
   [nir_op_unpack_unorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         321,
      },
   },
   [nir_op_unpack_snorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         322,
      },
   },
   [nir_op_unpack_snorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         323,
      },
   },
   [nir_op_isign] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         324,
         1942,
      },
   },
   [nir_op_amul] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         325,
      },
   },
   [nir_op_umul24] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         326,
      },
   },
   [nir_op_umad24] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         327,
      },
   },
   [nir_op_imul24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         328,
      },
   },
   [nir_op_umad24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         329,
      },
   },
   [nir_op_umul24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         330,
      },
   },
   [nir_op_imad24_ir3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         331,
         332,
         333,
         332,
         333,
         334,
         335,
      },
   },
   [nir_op_imul24] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         336,
         336,
         336,
      },
   },
   [nir_op_b2b1] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         337,
      },
   },
   [nir_op_b2b8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         338,
      },
   },
   [nir_op_b2b16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         339,
      },
   },
   [nir_op_b2b32] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         340,
      },
   },
   [nir_op_ldexp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         341,
      },
   },
   [nir_op_fddx] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         342,
      },
   },
   [nir_op_fddx_fine] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         343,
      },
   },
   [nir_op_fddx_coarse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         344,
      },
   },
   [nir_op_fddy] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         345,
      },
   },
   [nir_op_fddy_fine] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         346,
      },
   },
   [nir_op_fddy_coarse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         347,
      },
   },
   [nir_op_umul_low] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         348,
         348,
         348,
      },
   },
   [nir_op_imadsh_mix16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         349,
         349,
         350,
         350,
         351,
         351,
      },
   },
   [nir_op_fsin_amd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         352,
      },
   },
   [nir_op_fcos_amd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         353,
      },
   },
   [nir_op_fisnormal] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         354,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_transform_offsets[] = {
   0,
   0,
   0,
   1,
   0,
   12,
   15,
   17,
   21,
   23,
   25,
   27,
   30,
   34,
   37,
   42,
   0,
   0,
   47,
   0,
   49,
   0,
   51,
   0,
   55,
   0,
   59,
   61,
   67,
   74,
   80,
   87,
   90,
   94,
   97,
   101,
   0,
   104,
   111,
   115,
   121,
   128,
   138,
   150,
   165,
   178,
   194,
   200,
   207,
   216,
   226,
   236,
   247,
   249,
   257,
   259,
   263,
   265,
   271,
   273,
   279,
   282,
   285,
   287,
   289,
   293,
   296,
   301,
   304,
   309,
   313,
   319,
   321,
   323,
   326,
   329,
   333,
   337,
   339,
   341,
   344,
   347,
   351,
   355,
   357,
   360,
   364,
   366,
   369,
   372,
   376,
   380,
   385,
   387,
   389,
   392,
   395,
   399,
   403,
   405,
   407,
   410,
   413,
   417,
   421,
   423,
   426,
   430,
   432,
   435,
   439,
   441,
   443,
   446,
   449,
   452,
   455,
   460,
   465,
   467,
   470,
   473,
   478,
   482,
   487,
   492,
   516,
   522,
   529,
   536,
   562,
   564,
   0,
   0,
   567,
   572,
   577,
   582,
   0,
   585,
   587,
   0,
   0,
   0,
   0,
   589,
   0,
   0,
   0,
   591,
   593,
   0,
   0,
   0,
   0,
   596,
   0,
   598,
   604,
   606,
   0,
   613,
   619,
   622,
   0,
   630,
   635,
   640,
   645,
   650,
   655,
   660,
   665,
   670,
   672,
   675,
   680,
   686,
   688,
   691,
   695,
   700,
   705,
   711,
   713,
   715,
   717,
   0,
   720,
   722,
   724,
   726,
   728,
   730,
   732,
   734,
   738,
   740,
   744,
   746,
   0,
   0,
   750,
   754,
   760,
   0,
   0,
   766,
   768,
   772,
   774,
   777,
   779,
   782,
   784,
   788,
   790,
   792,
   794,
   796,
   798,
   800,
   802,
   804,
   806,
   808,
   810,
   812,
   814,
   816,
   818,
   820,
   822,
   824,
   826,
   828,
   830,
   832,
   834,
   836,
   838,
   840,
   842,
   844,
   846,
   848,
   850,
   852,
   854,
   856,
   858,
   860,
   865,
   0,
   870,
   872,
   877,
   880,
   886,
   0,
   0,
   888,
   890,
   893,
   895,
   897,
   0,
   0,
   0,
   0,
   899,
   901,
   903,
   0,
   0,
   0,
   0,
   905,
   908,
   911,
   913,
   922,
   924,
   932,
   935,
   937,
   939,
   941,
   943,
   945,
   0,
   947,
   950,
   952,
   954,
   956,
   958,
   961,
   0,
   0,
   0,
   963,
   965,
   967,
   969,
   971,
   975,
   978,
   981,
   984,
   987,
   989,
   991,
   994,
   997,
   999,
   1001,
   1003,
   1005,
   1007,
   1009,
   1011,
   1013,
   1015,
   1017,
   1019,
   1021,
   1023,
   1025,
   1028,
   1031,
   1034,
   1036,
   1039,
   1043,
   1047,
   1052,
   1056,
   1058,
   1060,
   1062,
   1064,
   1068,
   1070,
   1072,
   1074,
   1076,
   1078,
   1080,
   1082,
   1084,
   1086,
   0,
   0,
   1089,
   1093,
   1095,
   1098,
   1101,
   1103,
   1105,
   1117,
   1130,
   1142,
   1154,
   1166,
   1179,
   1192,
   1204,
   1216,
   1220,
   1224,
   1227,
   1230,
   1232,
   1237,
   1241,
   1245,
   1249,
   1253,
   1256,
   1258,
   1263,
   0,
   1265,
   1267,
   1269,
   1271,
   1273,
   1276,
   1279,
   1282,
   1284,
   1286,
   1288,
   1291,
   1294,
   1298,
   1302,
   1306,
   1310,
   1314,
   1319,
   1322,
   1326,
   1330,
   1333,
   1336,
   1338,
   1340,
   1343,
   1346,
   1349,
   1352,
   1355,
   1358,
   1362,
   1366,
   1370,
   1373,
   1376,
   1378,
   1380,
   1382,
   1384,
   1387,
   1390,
   1393,
   1395,
   1397,
   1400,
   1403,
   1406,
   1410,
   1414,
   1418,
   1421,
   1424,
   1427,
   1430,
   1434,
   1438,
   1442,
   1445,
   1448,
   1451,
   1455,
   1459,
   1463,
   1466,
   1469,
   1473,
   1477,
   1481,
   1484,
   1487,
   1492,
   1497,
   1501,
   1505,
   1510,
   1514,
   1518,
   1522,
   1526,
   1529,
   1531,
   1535,
   1541,
   1546,
   1553,
   1558,
   1566,
   1570,
   1575,
   1580,
   1586,
   1591,
   1599,
   1607,
   1615,
   1623,
   1631,
   1637,
   1647,
   1653,
   1660,
   1666,
   1678,
   1683,
   1688,
   1695,
   1703,
   1711,
   1719,
   1727,
   1735,
   1743,
   1749,
   1756,
   1762,
   1770,
   1776,
   1783,
   1789,
   1797,
   1802,
   1808,
   1813,
   1820,
   1825,
   1831,
   1836,
   1843,
   1851,
   1856,
   1864,
   1869,
   1874,
   1879,
   1884,
   1889,
   1894,
   1899,
   1905,
   1913,
   1920,
   1929,
   1936,
   1946,
   1952,
   1959,
   1966,
   1974,
   1981,
   1991,
   2001,
   2011,
   2021,
   2031,
   2039,
   2051,
   2059,
   2068,
   2076,
   2090,
   2097,
   2104,
   2113,
   2123,
   2133,
   2143,
   2153,
   2163,
   2173,
   2181,
   2190,
   2198,
   2208,
   2216,
   2225,
   2233,
   2243,
   2250,
   2258,
   2265,
   2274,
   2281,
   2289,
   2296,
   2305,
   2315,
   2322,
   2332,
   2339,
   2346,
   2353,
   2360,
   2367,
   2374,
   2381,
   2386,
   2392,
   2397,
   2404,
   2410,
   2435,
   2441,
   2449,
   2455,
   2464,
   2469,
   2475,
   2481,
   2488,
   2494,
   2503,
   2512,
   2521,
   2530,
   2539,
   2546,
   2557,
   2564,
   2572,
   2579,
   2592,
   2598,
   2604,
   2612,
   2621,
   2630,
   2639,
   2648,
   2657,
   2666,
   2673,
   2681,
   2688,
   2697,
   2704,
   2712,
   2719,
   2728,
   2734,
   2741,
   2747,
   2755,
   2761,
   2768,
   2774,
   2782,
   2791,
   2797,
   2806,
   2812,
   2818,
   2824,
   2830,
   2836,
   2842,
   2848,
   2854,
   2861,
   2867,
   2874,
   2880,
   2885,
   2909,
   2914,
   2921,
   2926,
   2931,
   2937,
   2942,
   2949,
   2955,
   2980,
   2986,
   2994,
   3000,
   3009,
   3014,
   3020,
   3026,
   3033,
   3039,
   3048,
   3057,
   3066,
   3075,
   3084,
   3091,
   3102,
   3109,
   3117,
   3124,
   3137,
   3143,
   3149,
   3157,
   3166,
   3175,
   3184,
   3193,
   3202,
   3211,
   3218,
   3226,
   3233,
   3242,
   3249,
   3257,
   3264,
   3273,
   3279,
   3286,
   3292,
   3300,
   3306,
   3313,
   3319,
   3327,
   3336,
   3342,
   3351,
   3357,
   3363,
   3369,
   3375,
   3381,
   3387,
   3393,
   3399,
   3406,
   3412,
   3420,
   3427,
   3453,
   3460,
   3469,
   3476,
   3486,
   3492,
   3499,
   3506,
   3514,
   3521,
   3531,
   3541,
   3551,
   3561,
   3571,
   3579,
   3591,
   3599,
   3608,
   3616,
   3630,
   3637,
   3644,
   3653,
   3663,
   3673,
   3683,
   3693,
   3703,
   3713,
   3721,
   3730,
   3738,
   3748,
   3756,
   3765,
   3773,
   3783,
   3790,
   3798,
   3805,
   3814,
   3821,
   3829,
   3836,
   3845,
   3855,
   3862,
   3872,
   3879,
   3886,
   3893,
   3900,
   3907,
   3914,
   3921,
   3929,
   3936,
   3944,
   3952,
   3961,
   3967,
   3974,
   3980,
   3988,
   3995,
   4021,
   4028,
   4037,
   4044,
   4054,
   4060,
   4067,
   4074,
   4082,
   4089,
   4099,
   4109,
   4119,
   4129,
   4139,
   4147,
   4159,
   4167,
   4176,
   4184,
   4198,
   4205,
   4212,
   4221,
   4231,
   4241,
   4251,
   4261,
   4271,
   4281,
   4289,
   4298,
   4306,
   4316,
   4324,
   4333,
   4341,
   4351,
   4358,
   4366,
   4373,
   4382,
   4389,
   4397,
   4404,
   4413,
   4423,
   4430,
   4440,
   4447,
   4454,
   4461,
   4468,
   4475,
   4482,
   4489,
   4495,
   4502,
   4508,
   4516,
   4523,
   4549,
   4556,
   4565,
   4572,
   4582,
   4588,
   4595,
   4602,
   4610,
   4617,
   4627,
   4637,
   4647,
   4657,
   4667,
   4675,
   4687,
   4695,
   4704,
   4712,
   4726,
   4733,
   4740,
   4749,
   4759,
   4769,
   4779,
   4789,
   4799,
   4809,
   4817,
   4826,
   4834,
   4844,
   4852,
   4861,
   4869,
   4879,
   4886,
   4894,
   4901,
   4910,
   4917,
   4925,
   4932,
   4941,
   4951,
   4958,
   4968,
   4975,
   4982,
   4989,
   4996,
   5003,
   5010,
   5017,
   5023,
   5030,
   5036,
   5044,
   5051,
   5077,
   5084,
   5093,
   5100,
   5110,
   5116,
   5123,
   5130,
   5138,
   5145,
   5155,
   5165,
   5175,
   5185,
   5195,
   5203,
   5215,
   5223,
   5232,
   5240,
   5254,
   5261,
   5268,
   5277,
   5287,
   5297,
   5307,
   5317,
   5327,
   5337,
   5345,
   5354,
   5362,
   5372,
   5380,
   5389,
   5397,
   5407,
   5414,
   5422,
   5429,
   5438,
   5445,
   5453,
   5460,
   5469,
   5479,
   5486,
   5496,
   5503,
   5510,
   5517,
   5524,
   5531,
   5538,
   5545,
   5551,
   5558,
   5564,
   5572,
   5579,
   5605,
   5612,
   5621,
   5628,
   5638,
   5644,
   5651,
   5658,
   5666,
   5673,
   5683,
   5693,
   5703,
   5713,
   5723,
   5731,
   5743,
   5751,
   5760,
   5768,
   5782,
   5789,
   5796,
   5805,
   5815,
   5825,
   5835,
   5845,
   5855,
   5865,
   5873,
   5882,
   5890,
   5900,
   5908,
   5917,
   5925,
   5935,
   5942,
   5950,
   5957,
   5966,
   5973,
   5981,
   5988,
   5997,
   6007,
   6014,
   6024,
   6031,
   6038,
   6045,
   6052,
   6059,
   6066,
   6073,
   6079,
   6086,
   6092,
   6100,
   6107,
   6133,
   6140,
   6149,
   6156,
   6166,
   6172,
   6179,
   6186,
   6194,
   6201,
   6211,
   6221,
   6231,
   6241,
   6251,
   6259,
   6271,
   6279,
   6288,
   6296,
   6310,
   6317,
   6324,
   6333,
   6343,
   6353,
   6363,
   6373,
   6383,
   6393,
   6401,
   6410,
   6418,
   6428,
   6436,
   6445,
   6453,
   6463,
   6470,
   6478,
   6485,
   6494,
   6501,
   6509,
   6516,
   6525,
   6535,
   6542,
   6552,
   6559,
   6566,
   6573,
   6580,
   6587,
   6594,
   6601,
   0,
   6606,
   6612,
   6614,
   6618,
   6625,
   6629,
   6636,
   6641,
   6648,
   6657,
   6662,
   6667,
   6674,
   6683,
   6688,
   6691,
   6695,
   6698,
   6701,
   6704,
   6708,
   6712,
   6715,
   6718,
   6727,
   6740,
   6754,
   6763,
   6773,
   6782,
   6794,
   6803,
   6813,
   6823,
   6832,
   6841,
   6844,
   6848,
   6852,
   6857,
   6862,
   6866,
   6870,
   6874,
   6878,
   6883,
   6888,
   6892,
   6896,
   6899,
   6909,
   6915,
   6919,
   6923,
   6927,
   6930,
   6933,
   6936,
   6939,
   6943,
   6948,
   6953,
   6957,
   6961,
   6966,
   6972,
   6983,
   6995,
   7001,
   7013,
   7026,
   7030,
   7035,
   7046,
   7058,
   7063,
   7075,
   7088,
   7090,
   7095,
   7100,
   7104,
   7108,
   7113,
   7119,
   7124,
   7129,
   7134,
   7139,
   7144,
   7148,
   7152,
   7156,
   7159,
   7162,
   7165,
   7168,
   7170,
   7174,
   7178,
   7181,
   7184,
   7189,
   7194,
   7200,
   7205,
   7210,
   7214,
   7220,
   7226,
   7231,
   7236,
   7239,
   7241,
   7245,
   7249,
   7253,
   7257,
   7260,
   7265,
   7270,
   7274,
   7278,
   7282,
   7286,
   7289,
   7294,
   7299,
   7303,
   7307,
   7315,
   7319,
   7322,
   7327,
   7332,
   7337,
   7341,
   7345,
   7355,
   7357,
   7359,
   7362,
   7365,
   7368,
   7372,
   7375,
   7380,
   7385,
   7389,
   7393,
   7398,
   7402,
   7406,
   7409,
   7412,
   7418,
   7429,
   7441,
   7447,
   7459,
   7472,
   7476,
   7481,
   7491,
   7502,
   7507,
   7518,
   7530,
   7532,
   7536,
   7540,
   7544,
   7548,
   7553,
   7559,
   7564,
   7569,
   7574,
   7579,
   7584,
   7588,
   7592,
   7596,
   7599,
   7603,
   7607,
   7610,
   7613,
   7616,
   7622,
   7628,
   7633,
   7638,
   7643,
   7649,
   7652,
   7655,
   7658,
   7663,
   7669,
   7674,
   7679,
   7684,
   7689,
   7694,
   7699,
   7704,
   7708,
   7712,
   7716,
   7720,
   7724,
   0,
   7729,
   7735,
   7737,
   7742,
   7753,
   7762,
   7767,
   7777,
   7784,
   7789,
   7796,
   0,
   7803,
   7809,
   7814,
   7824,
   7839,
   7854,
   7869,
   7874,
   7879,
   7884,
   7892,
   7907,
   0,
   7915,
   7918,
   7921,
   7924,
   7927,
   7930,
   7933,
   7936,
   7939,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   7941,
   7944,
   7947,
   7949,
   7952,
   7955,
   7958,
   7961,
   7963,
   7965,
   7970,
   7972,
   7974,
   7979,
   7986,
   7994,
   7999,
   8005,
   8010,
   8016,
   8021,
   8025,
   8027,
   8029,
   8031,
   0,
   8033,
   0,
   0,
   8035,
   0,
   0,
   8038,
   8046,
   8054,
   8063,
   8071,
   8080,
   8087,
   8094,
   8102,
   8112,
   8119,
   8126,
   8128,
   8130,
   8134,
   8136,
   8138,
   0,
   0,
   8140,
   0,
   0,
   8143,
   0,
   0,
   8146,
   8149,
   8152,
   8154,
   0,
   8156,
   8158,
   8163,
   8169,
   8176,
   8183,
   8191,
   8198,
   8207,
   8214,
   8219,
   8227,
   8235,
   8248,
   8261,
   8268,
   8278,
   8286,
   8294,
   8303,
   8317,
   8331,
   8343,
   8358,
   8371,
   8384,
   8397,
   8413,
   8428,
   8442,
   8456,
   8473,
   8489,
   8504,
   8517,
   8533,
   8547,
   8561,
   8569,
   8580,
   8589,
   8598,
   8607,
   8614,
   8624,
   8632,
   8640,
   8647,
   8654,
   8664,
   8674,
   8682,
   8693,
   8704,
   8714,
   8725,
   8737,
   8748,
   8760,
   8773,
   8787,
   8800,
   8807,
   8815,
   8823,
   8831,
   8834,
   8838,
   8842,
   8846,
   8849,
   8852,
   8857,
   8861,
   8865,
   8870,
   8874,
   8878,
   8882,
   8886,
   8891,
   8896,
   8901,
   8906,
   8910,
   8914,
   8920,
   8926,
   8932,
   8938,
   8944,
   8951,
   8957,
   8963,
   8970,
   8976,
   8982,
   8988,
   8994,
   9000,
   9007,
   9013,
   9019,
   9025,
   9032,
   9039,
   9046,
   9053,
   9059,
   9065,
   9071,
   9078,
   9085,
   9092,
   9098,
   9104,
   9110,
   9117,
   9124,
   9131,
   9144,
   9150,
   9156,
   9162,
   9169,
   9175,
   9181,
   9187,
   9193,
   9199,
   9205,
   9211,
   9217,
   9224,
   9230,
   9236,
   9242,
   9249,
   9256,
   9263,
   9270,
   9277,
   9283,
   9289,
   9295,
   9302,
   9309,
   9316,
   9322,
   9328,
   9334,
   9341,
   9348,
   9355,
   9368,
   9371,
   9374,
   9379,
   9383,
   9387,
   9392,
   9396,
   9400,
   9404,
   9408,
   9413,
   9418,
   9423,
   9428,
   9432,
   9436,
   9442,
   9448,
   9451,
   9454,
   9457,
   9459,
   9463,
   9467,
   9471,
   9475,
   9479,
   9482,
   9487,
   9491,
   9495,
   9498,
   9502,
   9505,
   9508,
   9511,
   9514,
   9517,
   9520,
   9523,
   9527,
   9530,
   9534,
   9537,
   9541,
   9545,
   9549,
   9552,
   0,
   0,
   9554,
   9556,
   0,
   0,
   0,
   0,
   0,
   9561,
   9564,
   9567,
   9570,
   9576,
   9581,
   9591,
   9595,
   9599,
   9602,
   9605,
   9608,
   9610,
   9613,
   9616,
   9619,
   9621,
   9624,
   9628,
   9632,
   9635,
   9639,
   9642,
   9645,
   9648,
   9651,
   9654,
   9657,
   9660,
   9663,
   9666,
   9670,
   9674,
   9678,
   9682,
   9684,
   9686,
   9690,
   9694,
   9696,
   9700,
   9702,
   9704,
   9708,
   9712,
   9714,
   9721,
   9729,
   9734,
   9739,
   9744,
   9751,
   9759,
   9764,
   9769,
   9774,
   9776,
   9778,
   9780,
   9782,
   9784,
   9786,
   9788,
   9790,
   9792,
   9794,
   9796,
   0,
   9798,
   9800,
   9802,
   9804,
   9806,
   9808,
   9810,
   9812,
   9814,
   9819,
   9825,
   9831,
   9839,
   9848,
   9853,
   9860,
   9868,
   9874,
   9881,
   9888,
   9897,
   9907,
   9913,
   9921,
   9930,
   9939,
   9950,
   9962,
   9968,
   9976,
   9985,
   9988,
   9991,
   9998,
   10013,
   10020,
   10027,
   10041,
   10055,
   10061,
   10073,
   10085,
   10091,
   10097,
   10104,
   10111,
   10117,
   10123,
   10129,
   10135,
   10139,
   10145,
   10157,
   10169,
   10172,
   10175,
   10182,
   10197,
   10204,
   10211,
   10225,
   10239,
   10251,
   10263,
   10270,
   10277,
   10283,
   10289,
   10295,
   10301,
   10305,
   10311,
   10323,
   0,
   10335,
   10337,
   10340,
   10343,
   10346,
   10351,
   10356,
   10361,
   10368,
   10373,
   10379,
   10389,
   10392,
   10396,
   10400,
   10404,
   10408,
   10412,
   10415,
   10419,
   10423,
   10427,
   10431,
   10436,
   10439,
   10443,
   10447,
   10451,
   10455,
   10460,
   10469,
   10491,
   10494,
   10497,
   10500,
   10503,
   10506,
   10509,
   10513,
   10516,
   10520,
   10528,
   10531,
   10535,
   10539,
   10543,
   10546,
   10549,
   10553,
   10557,
   10561,
   10565,
   10568,
   10572,
   10576,
   10580,
   10584,
   10592,
   10614,
   10616,
   10619,
   10621,
   10625,
   10630,
   10634,
   10637,
   10639,
   10642,
   10644,
   10647,
   10659,
   10669,
   10676,
   10683,
   10690,
   10729,
   10748,
   10755,
   10762,
   10774,
   10780,
   10790,
   10797,
   10804,
   10811,
   10818,
   10824,
   10840,
   10882,
   10889,
   10896,
   10903,
   10915,
   10918,
   10921,
   10924,
   10927,
   10930,
   10934,
   10939,
   10943,
   10945,
   10947,
   10950,
   10953,
   10955,
   10957,
   10960,
   10963,
   10966,
   10969,
   10973,
   10976,
   10978,
   10980,
   10983,
   10986,
   10989,
   10992,
   10995,
   10998,
   11001,
   11004,
   11007,
   11010,
   11013,
   0,
   0,
   0,
   11015,
   11018,
   11021,
   11024,
   11027,
   11030,
   11033,
   11036,
   11039,
   11042,
   11045,
   11051,
   11057,
   11063,
   11070,
   11077,
   11088,
   11095,
   11101,
   11109,
   11116,
   11123,
   11132,
   11138,
   11146,
   11153,
   11160,
   11169,
   11181,
   11206,
   11212,
   11218,
   11224,
   11231,
   11238,
   11249,
   11256,
   11262,
   11270,
   11277,
   11284,
   11293,
   11299,
   11307,
   11314,
   11321,
   11330,
   11342,
   11367,
   11373,
   11379,
   11385,
   11391,
   11397,
   11400,
   11402,
   11404,
   11406,
   11408,
   11410,
   11413,
   11415,
   11417,
   11419,
   11421,
   11423,
   11425,
   11427,
   11429,
   11431,
   11433,
   11437,
   11439,
   11441,
   11445,
   11449,
   11451,
   11454,
   11456,
   11458,
   11460,
   11462,
   11464,
   11466,
   11468,
   11470,
   11472,
   11474,
   11476,
   11480,
   11485,
   11491,
   11494,
   11498,
   11501,
   0,
   0,
   0,
   0,
   0,
   0,
   11505,
   11508,
   11513,
   11517,
   11521,
   11525,
   11529,
   11533,
   11537,
   11541,
   11545,
   11549,
   11553,
   11557,
   11563,
   11565,
   11567,
   11569,
   11571,
   11573,
   11576,
   11578,
   11580,
   11582,
   11586,
   11590,
   11594,
   11598,
   11602,
   11607,
   11610,
   11613,
   11616,
   11619,
   11622,
   11627,
   11632,
   11637,
   11642,
   11646,
   11650,
   11655,
   11660,
   11665,
   11670,
   11674,
   11678,
   11682,
   11686,
   11689,
   11692,
   11697,
   11702,
   11707,
   11712,
   11715,
   11718,
   11723,
   11728,
   11733,
   11738,
   11741,
   11744,
   11749,
   11754,
   11759,
   11764,
   11767,
   11770,
   11775,
   11780,
   11785,
   11790,
   11794,
   11798,
   11804,
   11810,
   11816,
   11822,
   11826,
   11830,
   11836,
   11842,
   11848,
   11854,
   11858,
   11862,
   11868,
   11874,
   11880,
   11886,
   11889,
   11892,
   11897,
   11902,
   11907,
   11912,
   11915,
   11918,
   11923,
   11928,
   11933,
   11938,
   11943,
   11948,
   11953,
   11958,
   11963,
   11968,
   11973,
   11978,
   11985,
   11992,
   11999,
   12006,
   12013,
   12020,
   12022,
   12026,
   12030,
   12034,
   12038,
   12050,
   12063,
   12077,
   12091,
   12105,
   12119,
   12124,
   12129,
   12134,
   12139,
   12145,
   12151,
   12157,
   12163,
   12169,
   12175,
   12181,
   12187,
   12192,
   12197,
   12202,
   12207,
   12212,
   12217,
   12222,
   12227,
   12234,
   12241,
   12248,
   12255,
   12262,
   0,
   12269,
   12271,
   12276,
   12281,
   12285,
   12290,
   12295,
   12298,
   0,
   12302,
   12307,
   12309,
   12315,
   12320,
   12329,
   12335,
   12342,
   12345,
   12348,
   12352,
   12356,
   12360,
   12366,
   12371,
   12375,
   12379,
   12384,
   12388,
   12392,
   12398,
   12403,
   12407,
   12411,
   12416,
   0,
   0,
   12420,
   12422,
   12433,
   12440,
   12447,
   12456,
   12466,
   12471,
   12473,
   12475,
   12478,
   12482,
   0,
   0,
   12484,
   12486,
   0,
   0,
   12490,
   12493,
   12496,
   12499,
   12503,
   0,
   0,
   12507,
   12509,
   0,
   0,
   12513,
   12515,
   12517,
   12522,
   12526,
   12530,
   12535,
   0,
   12537,
   12539,
   12550,
   12558,
   12569,
   12578,
   12587,
   12603,
   12616,
   12632,
   12646,
   12660,
   12671,
   12679,
   12690,
   12699,
   12708,
   12718,
   12730,
   12740,
   12753,
   12764,
   12775,
   12789,
   12800,
   12808,
   12819,
   12828,
   12837,
   12846,
   12858,
   12868,
   12878,
   12883,
   12888,
   12893,
   12898,
   12905,
   12912,
   12919,
   12926,
   12930,
   12936,
   12942,
   12948,
   12954,
   12960,
   12966,
   12972,
   12978,
   12984,
   12990,
   12996,
   13002,
   13006,
   13012,
   13018,
   13024,
   13030,
   13037,
   13042,
   13047,
   13052,
   13057,
   13064,
   13071,
   13078,
   13085,
   13087,
   13094,
   13101,
   13108,
   13115,
   13121,
   13127,
   13133,
   13139,
   13145,
   13151,
   13157,
   13163,
   13169,
   13174,
   13179,
   13182,
   13190,
   13198,
   13206,
   13214,
   13222,
   13230,
   13235,
   13238,
   13240,
   13242,
   13244,
   13246,
   13248,
   13250,
   13253,
   13260,
   13262,
   13267,
   13272,
   13277,
   13282,
   13291,
   13300,
   13310,
   13323,
   13331,
   13342,
   13353,
   13364,
   13376,
   13378,
   13382,
   13390,
   13393,
   13399,
   13405,
   13411,
   13417,
   13421,
   13429,
   13432,
   13438,
   13444,
   13450,
   13456,
   13466,
   13469,
   13473,
   13481,
   13484,
   13490,
   13496,
   13502,
   13508,
   13513,
   13522,
   13526,
   13533,
   13540,
   13547,
   13554,
   13559,
   13568,
   13572,
   13579,
   13586,
   13593,
   13600,
   13604,
   13612,
   13615,
   13621,
   13627,
   13633,
   13639,
   13643,
   13651,
   13654,
   13660,
   13666,
   13672,
   13678,
   13686,
   13689,
   13695,
   13701,
   13707,
   13713,
   13716,
   13723,
   13733,
   13743,
   13753,
   13763,
   13768,
   13773,
   13778,
   13783,
   13794,
   13802,
   13810,
   13818,
   13826,
   13834,
   13842,
   13847,
   13850,
   13852,
   13858,
   13865,
   13872,
   13879,
   13886,
   13894,
   13900,
   13908,
   13915,
   13922,
   13926,
   13930,
   13934,
   13939,
   13944,
   13949,
   13954,
   13959,
   13964,
   13969,
   13974,
   13979,
   13983,
   13987,
   13991,
   13996,
   14002,
   14006,
   14012,
   14016,
   14020,
   14022,
   14026,
   14030,
   14034,
   14037,
   14039,
   14043,
   14047,
   14050,
   14055,
   14060,
   14065,
   14068,
   14073,
   14078,
   14083,
   14086,
   14091,
   14095,
   14101,
   14105,
   14109,
   14115,
   14119,
   14123,
   14127,
   14131,
   14135,
   14138,
   14142,
   14147,
   14150,
   14156,
   14162,
   14168,
   14174,
   14179,
   14187,
   14195,
   14204,
   14209,
   14216,
   14218,
   14220,
   14228,
   14230,
   0,
   0,
   0,
   14236,
   14238,
   14243,
   14247,
   14251,
   14255,
   14259,
   14264,
   14269,
   14274,
   14279,
   14283,
   14287,
   14293,
   14297,
   14301,
   14303,
   14307,
   14311,
   14313,
   14316,
   14320,
   14323,
   14328,
   14333,
   14336,
   14341,
   14346,
   14349,
   14353,
   14359,
   14363,
   14367,
   14375,
   14383,
   14386,
   14393,
   14397,
   14402,
   14408,
   14416,
   14421,
   14426,
   14431,
   14438,
   14442,
   14448,
   14452,
   14456,
   14459,
   14461,
   14465,
   14469,
   14475,
   14478,
   14481,
   14485,
   14492,
   14500,
   14507,
   14516,
   14523,
   14531,
   14538,
   14547,
   14554,
   14562,
   14569,
   14578,
   14585,
   14593,
   14600,
   14609,
   14618,
   14628,
   14637,
   14648,
   14657,
   14667,
   14676,
   14687,
   14696,
   14706,
   14715,
   14726,
   14735,
   14745,
   14754,
   14765,
   14773,
   14782,
   14790,
   14800,
   14808,
   14817,
   14825,
   14835,
   14843,
   14852,
   14860,
   14870,
   14878,
   14887,
   14895,
   14905,
   14911,
   14919,
   14928,
   14936,
   14946,
   14954,
   14963,
   14971,
   14981,
   14989,
   14998,
   15006,
   15016,
   15024,
   15033,
   15041,
   15051,
   15060,
   15070,
   15079,
   15090,
   15099,
   15109,
   15118,
   15129,
   15138,
   15148,
   15157,
   15168,
   15177,
   15187,
   15196,
   15207,
   15216,
   15226,
   15235,
   15246,
   15255,
   15265,
   15274,
   15285,
   15294,
   15304,
   15313,
   15324,
   15333,
   15343,
   15352,
   15363,
   15372,
   15382,
   15391,
   15402,
   15411,
   15421,
   15430,
   15441,
   15450,
   15460,
   15469,
   15480,
   15489,
   15499,
   15508,
   15519,
   15526,
   15535,
   15545,
   15554,
   15565,
   15574,
   15584,
   15593,
   15604,
   15613,
   15623,
   15632,
   15643,
   15652,
   15662,
   15671,
   15682,
   15691,
   15701,
   15710,
   15721,
   15730,
   15740,
   15749,
   15760,
   15769,
   15779,
   15788,
   15799,
   15808,
   15818,
   15827,
   15838,
   15847,
   15857,
   15866,
   15877,
   15886,
   15896,
   15905,
   15916,
   15925,
   15935,
   15944,
   15955,
   15964,
   15974,
   15983,
   15994,
   16002,
   16010,
   16018,
   16026,
   16034,
   16036,
   16038,
   16043,
   16048,
   16053,
   16058,
   16063,
   16070,
   16077,
   16084,
   16091,
   16098,
   16105,
   16112,
   16119,
   16126,
   16133,
   16140,
   16147,
   16153,
   16159,
   16165,
   16171,
   16177,
   16183,
   16189,
   16195,
   16201,
   16207,
   16213,
   16219,
   16227,
   16235,
   16243,
   16251,
   16259,
   16267,
   16272,
   16315,
   16358,
   16378,
   16383,
   16385,
   16388,
   16392,
   16397,
   16399,
   16402,
   16405,
   16409,
   16411,
   16415,
   16420,
   16423,
   16429,
   16435,
   16440,
   16445,
   16451,
   16456,
   16462,
   16467,
   16473,
   16478,
   16485,
   16491,
   16497,
   16502,
   16509,
   16515,
   16521,
   16526,
   16533,
   16539,
   16545,
   16550,
   16557,
   16563,
   16567,
   16571,
   16577,
   16580,
   16586,
   16592,
   16605,
   16617,
   16621,
   16628,
   16635,
   16639,
   16649,
   16653,
   16658,
   16663,
   16671,
   16676,
   16684,
   16689,
   16697,
   16705,
   16716,
   16721,
   16729,
   16737,
   16748,
   16754,
   16763,
   16768,
   16776,
   0,
   16781,
   16789,
   16797,
   0,
   0,
   0,
   16805,
   16812,
   16818,
   16821,
   16824,
   16828,
   16834,
   16838,
   16842,
   16846,
   16850,
   16854,
   16858,
   16861,
   16866,
   16870,
   16875,
   16879,
   16884,
   16889,
   0,
   0,
   16893,
   16900,
   16907,
   16909,
   0,
   0,
   0,
   0,
   16911,
   16914,
   0,
   0,
   0,
   0,
   16917,
   16921,
   16925,
   0,
   0,
   0,
   16927,
   16929,
   0,
   16931,
   16942,
   16958,
   16969,
   16981,
   16995,
   17007,
   17012,
   17017,
   17019,
   17026,
   17033,
   17036,
   17039,
   17043,
   17047,
   17051,
   17055,
   17060,
   17065,
   17070,
   17072,
   17075,
   17077,
   17080,
   17082,
   17085,
   17089,
   17093,
   17095,
   17103,
   17112,
   17119,
   17122,
   17126,
   17134,
   17142,
   17147,
   17155,
   17166,
   17177,
   17191,
   17205,
   17210,
   17221,
   17225,
   17229,
   0,
   17234,
   17237,
   17243,
   17252,
   17260,
   17273,
   17285,
   17292,
   17298,
   17302,
   17304,
   17307,
   17313,
   17322,
   17335,
   17347,
   17354,
   17360,
   17364,
   17366,
   17369,
   17375,
   17384,
   17397,
   17409,
   17416,
   17422,
   17427,
};

static const nir_algebraic_table nir_opt_algebraic_table = {
   .transforms = nir_opt_algebraic_transforms,
   .transform_offsets = nir_opt_algebraic_transform_offsets,
   .pass_op_table = nir_opt_algebraic_pass_op_table,
   .values = nir_opt_algebraic_values,
   .expression_cond = nir_opt_algebraic_expression_cond,
   .variable_cond = nir_opt_algebraic_variable_cond,
};

bool
nir_opt_algebraic(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[118];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(5804 == ARRAY_SIZE(nir_opt_algebraic_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_ftrunc || (options->lower_doubles_options & nir_lower_dtrunc);
   condition_flags[22] = options->lower_ffloor;
   condition_flags[23] = (options->lower_ffloor || (options->lower_doubles_options & nir_lower_dfloor)) && !(options->lower_doubles_options & nir_lower_dfract);
   condition_flags[24] = !options->lower_ffloor;
   condition_flags[25] = !options->lower_ffloor && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[26] = options->lower_ffract;
   condition_flags[27] = options->lower_ffract || (options->lower_doubles_options & nir_lower_dfract);
   condition_flags[28] = options->lower_fceil;
   condition_flags[29] = options->lower_ffma16;
   condition_flags[30] = options->lower_ffma32;
   condition_flags[31] = options->lower_ffma64;
   condition_flags[32] = options->fuse_ffma16;
   condition_flags[33] = options->fuse_ffma32;
   condition_flags[34] = options->fuse_ffma64;
   condition_flags[35] = options->lower_fdph;
   condition_flags[36] = !options->lower_fdph;
   condition_flags[37] = options->lower_fdot;
   condition_flags[38] = !options->lower_fsat;
   condition_flags[39] = !options->lower_iabs;
   condition_flags[40] = options->lower_fsat;
   condition_flags[41] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[42] = !options->lower_fsign;
   condition_flags[43] = options->lower_umax;
   condition_flags[44] = options->lower_umin;
   condition_flags[45] = !options->lower_umax;
   condition_flags[46] = !options->lower_umin;
   condition_flags[47] = options->lower_scmp;
   condition_flags[48] = options->lower_vector_cmp;
   condition_flags[49] = !options->lower_rotate;
   condition_flags[50] = options->lower_rotate;
   condition_flags[51] = options->lower_fpow;
   condition_flags[52] = !options->lower_fpow;
   condition_flags[53] = options->lower_fdiv;
   condition_flags[54] = options->lower_fsqrt;
   condition_flags[55] = !options->lower_fsqrt;
   condition_flags[56] = options->lower_sincos;
   condition_flags[57] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[58] = !options->lower_extract_byte;
   condition_flags[59] = !options->lower_extract_word;
   condition_flags[60] = options->has_pack_32_4x8;
   condition_flags[61] = options->lower_pack_64_2x32_split;
   condition_flags[62] = options->lower_pack_32_2x16_split;
   condition_flags[63] = options->lower_unpack_64_2x32_split;
   condition_flags[64] = options->lower_unpack_32_2x16_split;
   condition_flags[65] = options->has_find_msb_rev;
   condition_flags[66] = !options->lower_find_msb_to_reverse;
   condition_flags[67] = !options->lower_find_lsb;
   condition_flags[68] = options->lower_fmod;
   condition_flags[69] = options->lower_uadd_carry;
   condition_flags[70] = options->lower_usub_borrow;
   condition_flags[71] = options->lower_bitfield_insert;
   condition_flags[72] = options->lower_hadd;
   condition_flags[73] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[74] = options->lower_mul_32x16;
   condition_flags[75] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[76] = options->lower_uadd_sat;
   condition_flags[77] = options->lower_usub_sat;
   condition_flags[78] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[79] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[80] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[81] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[82] = options->lower_bitfield_insert_to_shifts;
   condition_flags[83] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[84] = options->lower_bitfield_extract;
   condition_flags[85] = options->lower_bitfield_extract_to_shifts;
   condition_flags[86] = options->lower_ifind_msb;
   condition_flags[87] = options->lower_find_msb_to_reverse;
   condition_flags[88] = options->lower_uclz;
   condition_flags[89] = options->lower_find_lsb;
   condition_flags[90] = options->lower_extract_byte;
   condition_flags[91] = options->lower_extract_word;
   condition_flags[92] = options->lower_pack_unorm_2x16;
   condition_flags[93] = options->lower_pack_unorm_4x8;
   condition_flags[94] = options->lower_pack_snorm_2x16;
   condition_flags[95] = options->lower_pack_snorm_4x8;
   condition_flags[96] = options->lower_unpack_unorm_2x16;
   condition_flags[97] = options->lower_unpack_unorm_4x8;
   condition_flags[98] = options->lower_unpack_snorm_2x16;
   condition_flags[99] = options->lower_unpack_snorm_4x8;
   condition_flags[100] = options->lower_pack_split;
   condition_flags[101] = options->lower_isign;
   condition_flags[102] = !options->lower_isign;
   condition_flags[103] = options->lower_fsign;
   condition_flags[104] = !options->has_imul24;
   condition_flags[105] = !options->has_umul24;
   condition_flags[106] = !options->has_umad24;
   condition_flags[107] = options->has_imul24;
   condition_flags[108] = options->has_umad24;
   condition_flags[109] = options->has_umul24;
   condition_flags[110] = options->lower_iadd_sat;
   condition_flags[111] = options->support_8bit_alu;
   condition_flags[112] = options->support_16bit_alu;
   condition_flags[113] = options->lower_ldexp;
   condition_flags[114] = !options->lower_bitfield_reverse;
   condition_flags[115] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[116] = options->lower_fisnormal;
   condition_flags[117] = !options->vectorize_vec2_16bit;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 15
 * transforms:
 *    ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c'))
 *    ('~fadd', ('fneg', 'a'), 'a') => 0.0
 *    ('iadd', ('ineg', 'a'), 'a') => 0
 *    ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b
 *    ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b
 *    ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b
 *    ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b
 *    ('~flrp', ('fadd(is_used_once)', 'a', -1.0), ('fadd(is_used_once)', 'a', 1.0), 'd') => ('fadd', ('flrp', -1.0, 1.0, 'd'), 'a')
 *    ('~flrp', ('fadd(is_used_once)', 'a', 1.0), ('fadd(is_used_once)', 'a', -1.0), 'd') => ('fadd', ('flrp', 1.0, -1.0, 'd'), 'a')
 *    ('~flrp', ('fadd(is_used_once)', 'a', '#b'), ('fadd(is_used_once)', 'a', '#c'), 'd') => ('fadd', ('fmul', 'd', ('fadd', 'c', ('fneg', 'b'))), ('fadd', 'a', 'b'))
 */


static const nir_search_value_union nir_opt_algebraic_before_ffma_values[] = {
   /* ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fmul', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 0, 1 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 2, 3 },
      0,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 5, 6 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 7, 8 },
      -1,
   } },

   /* ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search2016_0_0 -> 0 in the cache */
   /* search2016_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search2016_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 10, 3 },
      0,
   } },

   /* replace2016_0_0 -> 5 in the cache */
   /* replace2016_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace2016_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 12, 8 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search2017_0_0 -> 0 in the cache */
   /* search2017_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search2017_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 14, 3 },
      0,
   } },

   /* replace2017_0_0 -> 5 in the cache */
   /* replace2017_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace2017_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 16, 8 },
      -1,
   } },

   /* ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search2018_0_0 -> 0 in the cache */
   /* search2018_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search2018_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 18, 3 },
      0,
   } },

   /* replace2018_0_0 -> 5 in the cache */
   /* replace2018_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace2018_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 20, 8 },
      -1,
   } },

   /* ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   /* search2019_0_0 -> 5 in the cache */
   /* search2019_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 5, 8 },
      -1,
   } },
   /* search2019_1_0 -> 5 in the cache */
   /* search2019_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 5, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 22, 23 },
      -1,
   } },

   /* replace2019_0 -> 5 in the cache */
   /* replace2019_1_0 -> 8 in the cache */
   /* replace2019_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 8, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 5, 25 },
      -1,
   } },

   /* ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c')) */
   /* search2020_0_0 -> 5 in the cache */
   /* search2020_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 5, 8 },
      -1,
   } },
   /* search2020_1_0 -> 5 in the cache */
   /* search2020_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 5, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 27, 28 },
      -1,
   } },

   /* replace2020_0 -> 5 in the cache */
   /* replace2020_1_0 -> 8 in the cache */
   /* replace2020_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 8, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 5, 30 },
      -1,
   } },

   /* ('~fadd', ('fneg', 'a'), 'a') => 0.0 */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search2021_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 33, 32 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },

   /* ('iadd', ('ineg', 'a'), 'a') => 0 */
   /* search2022_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search2022_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 36, 32 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },

   /* ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 39 },
      -1,
   } },
   /* search2023_1_0 -> 39 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 39, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 40, 42 },
      -1,
   } },

   /* replace2023 -> 41 in the cache */

   /* ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b */
   /* search2024_0 -> 39 in the cache */
   /* search2024_1_0_0 -> 39 in the cache */
   /* search2024_1_0 -> 40 in the cache */
   /* search2024_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 40, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 39, 44 },
      -1,
   } },

   /* replace2024 -> 41 in the cache */

   /* ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b */
   /* search2025_0_0 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 39 },
      -1,
   } },
   /* search2025_1_0 -> 39 in the cache */
   /* search2025_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 46, 47 },
      -1,
   } },

   /* replace2025 -> 41 in the cache */

   /* ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b */
   /* search2026_0 -> 39 in the cache */
   /* search2026_1_0_0 -> 39 in the cache */
   /* search2026_1_0 -> 46 in the cache */
   /* search2026_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 46, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 39, 49 },
      -1,
   } },

   /* replace2026 -> 41 in the cache */

   /* ('~flrp', ('fadd(is_used_once)', 'a', -1.0), ('fadd(is_used_once)', 'a', 1.0), 'd') => ('fadd', ('flrp', -1.0, 1.0, 'd'), 'a') */
   /* search2027_0_0 -> 39 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 39, 51 },
      0,
   } },
   /* search2027_1_0 -> 39 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 53 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 52, 54, 55 },
      -1,
   } },

   /* replace2027_0_0 -> 51 in the cache */
   /* replace2027_0_1 -> 53 in the cache */
   /* replace2027_0_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 51, 53, 55 },
      -1,
   } },
   /* replace2027_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 57, 39 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', 1.0), ('fadd(is_used_once)', 'a', -1.0), 'd') => ('fadd', ('flrp', 1.0, -1.0, 'd'), 'a') */
   /* search2028_0_0 -> 39 in the cache */
   /* search2028_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 39, 53 },
      0,
   } },
   /* search2028_1_0 -> 39 in the cache */
   /* search2028_1_1 -> 51 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 51 },
      0,
   } },
   /* search2028_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 59, 60, 55 },
      -1,
   } },

   /* replace2028_0_0 -> 53 in the cache */
   /* replace2028_0_1 -> 51 in the cache */
   /* replace2028_0_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 53, 51, 55 },
      -1,
   } },
   /* replace2028_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 62, 39 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', '#b'), ('fadd(is_used_once)', 'a', '#c'), 'd') => ('fadd', ('fmul', 'd', ('fadd', 'c', ('fneg', 'b'))), ('fadd', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 64, 65 },
      0,
   } },
   /* search2029_1_0 -> 64 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 64, 67 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 66, 68, 69 },
      -1,
   } },

   /* replace2029_0_0 -> 69 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 72 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 71, 73 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 69, 74 },
      -1,
   } },
   /* replace2029_1_0 -> 64 in the cache */
   /* replace2029_1_1 -> 72 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 64, 72 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 75, 76 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_before_ffma_expression_cond[] = {
   (is_used_once),
};

static const nir_search_variable_cond nir_opt_algebraic_before_ffma_variable_cond[] = {
   (is_not_const),
};

static const struct transform nir_opt_algebraic_before_ffma_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 24, 26, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { 48, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 34, 35, 0 },
   { 48, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 29, 31, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { 43, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 37, 38, 0 },
   { 43, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 13, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 13, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 56, 58, 0 },
   { 61, 63, 0 },
   { 70, 77, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { 48, 41, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 34, 35, 0 },
   { 48, 41, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { 43, 41, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 37, 38, 0 },
   { 43, 41, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_before_ffma_pass_op_table[nir_num_search_ops] = {
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         2,
         3,
         19,
         3,
         3,
         20,
         19,
         20,
         19,
      },
   },
   [nir_op_imul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         4,
         5,
         28,
         5,
         5,
         29,
         28,
         29,
         28,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         3,
         4,
         0,
         0,
         5,
         0,
         3,
         6,
         4,
         7,
         3,
         6,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         6,
         7,
         6,
         6,
         12,
         13,
         31,
         32,
         7,
         7,
         7,
         7,
         14,
         15,
         33,
         34,
         6,
         7,
         16,
         6,
         12,
         13,
         31,
         32,
         6,
         7,
         6,
         6,
         12,
         17,
         31,
         32,
         12,
         14,
         12,
         12,
         12,
         18,
         32,
         32,
         13,
         15,
         13,
         17,
         18,
         13,
         35,
         36,
         31,
         33,
         31,
         31,
         32,
         35,
         31,
         32,
         32,
         34,
         32,
         32,
         32,
         36,
         32,
         32,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         2,
         0,
         0,
         3,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         4,
         7,
         3,
         6,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         6,
         6,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         8,
         9,
         8,
         8,
         21,
         22,
         37,
         38,
         9,
         9,
         9,
         9,
         23,
         24,
         39,
         40,
         8,
         9,
         25,
         8,
         21,
         22,
         37,
         38,
         8,
         9,
         8,
         8,
         21,
         26,
         37,
         38,
         21,
         23,
         21,
         21,
         21,
         27,
         38,
         38,
         22,
         24,
         22,
         26,
         27,
         22,
         41,
         42,
         37,
         39,
         37,
         37,
         38,
         41,
         37,
         38,
         38,
         40,
         38,
         38,
         38,
         42,
         38,
         38,
      },
   },
   [nir_op_fneg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_ineg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         11,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         30,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_before_ffma_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   3,
   5,
   7,
   9,
   11,
   14,
   18,
   20,
   22,
   24,
   26,
   28,
   30,
   32,
   35,
   39,
   41,
   43,
   47,
   49,
   52,
   54,
   57,
   61,
   66,
   68,
   71,
   73,
   76,
   80,
};

static const nir_algebraic_table nir_opt_algebraic_before_ffma_table = {
   .transforms = nir_opt_algebraic_before_ffma_transforms,
   .transform_offsets = nir_opt_algebraic_before_ffma_transform_offsets,
   .pass_op_table = nir_opt_algebraic_before_ffma_pass_op_table,
   .values = nir_opt_algebraic_before_ffma_values,
   .expression_cond = nir_opt_algebraic_before_ffma_expression_cond,
   .variable_cond = nir_opt_algebraic_before_ffma_variable_cond,
};

bool
nir_opt_algebraic_before_ffma(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[118];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(78 == ARRAY_SIZE(nir_opt_algebraic_before_ffma_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_ftrunc || (options->lower_doubles_options & nir_lower_dtrunc);
   condition_flags[22] = options->lower_ffloor;
   condition_flags[23] = (options->lower_ffloor || (options->lower_doubles_options & nir_lower_dfloor)) && !(options->lower_doubles_options & nir_lower_dfract);
   condition_flags[24] = !options->lower_ffloor;
   condition_flags[25] = !options->lower_ffloor && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[26] = options->lower_ffract;
   condition_flags[27] = options->lower_ffract || (options->lower_doubles_options & nir_lower_dfract);
   condition_flags[28] = options->lower_fceil;
   condition_flags[29] = options->lower_ffma16;
   condition_flags[30] = options->lower_ffma32;
   condition_flags[31] = options->lower_ffma64;
   condition_flags[32] = options->fuse_ffma16;
   condition_flags[33] = options->fuse_ffma32;
   condition_flags[34] = options->fuse_ffma64;
   condition_flags[35] = options->lower_fdph;
   condition_flags[36] = !options->lower_fdph;
   condition_flags[37] = options->lower_fdot;
   condition_flags[38] = !options->lower_fsat;
   condition_flags[39] = !options->lower_iabs;
   condition_flags[40] = options->lower_fsat;
   condition_flags[41] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[42] = !options->lower_fsign;
   condition_flags[43] = options->lower_umax;
   condition_flags[44] = options->lower_umin;
   condition_flags[45] = !options->lower_umax;
   condition_flags[46] = !options->lower_umin;
   condition_flags[47] = options->lower_scmp;
   condition_flags[48] = options->lower_vector_cmp;
   condition_flags[49] = !options->lower_rotate;
   condition_flags[50] = options->lower_rotate;
   condition_flags[51] = options->lower_fpow;
   condition_flags[52] = !options->lower_fpow;
   condition_flags[53] = options->lower_fdiv;
   condition_flags[54] = options->lower_fsqrt;
   condition_flags[55] = !options->lower_fsqrt;
   condition_flags[56] = options->lower_sincos;
   condition_flags[57] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[58] = !options->lower_extract_byte;
   condition_flags[59] = !options->lower_extract_word;
   condition_flags[60] = options->has_pack_32_4x8;
   condition_flags[61] = options->lower_pack_64_2x32_split;
   condition_flags[62] = options->lower_pack_32_2x16_split;
   condition_flags[63] = options->lower_unpack_64_2x32_split;
   condition_flags[64] = options->lower_unpack_32_2x16_split;
   condition_flags[65] = options->has_find_msb_rev;
   condition_flags[66] = !options->lower_find_msb_to_reverse;
   condition_flags[67] = !options->lower_find_lsb;
   condition_flags[68] = options->lower_fmod;
   condition_flags[69] = options->lower_uadd_carry;
   condition_flags[70] = options->lower_usub_borrow;
   condition_flags[71] = options->lower_bitfield_insert;
   condition_flags[72] = options->lower_hadd;
   condition_flags[73] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[74] = options->lower_mul_32x16;
   condition_flags[75] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[76] = options->lower_uadd_sat;
   condition_flags[77] = options->lower_usub_sat;
   condition_flags[78] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[79] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[80] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[81] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[82] = options->lower_bitfield_insert_to_shifts;
   condition_flags[83] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[84] = options->lower_bitfield_extract;
   condition_flags[85] = options->lower_bitfield_extract_to_shifts;
   condition_flags[86] = options->lower_ifind_msb;
   condition_flags[87] = options->lower_find_msb_to_reverse;
   condition_flags[88] = options->lower_uclz;
   condition_flags[89] = options->lower_find_lsb;
   condition_flags[90] = options->lower_extract_byte;
   condition_flags[91] = options->lower_extract_word;
   condition_flags[92] = options->lower_pack_unorm_2x16;
   condition_flags[93] = options->lower_pack_unorm_4x8;
   condition_flags[94] = options->lower_pack_snorm_2x16;
   condition_flags[95] = options->lower_pack_snorm_4x8;
   condition_flags[96] = options->lower_unpack_unorm_2x16;
   condition_flags[97] = options->lower_unpack_unorm_4x8;
   condition_flags[98] = options->lower_unpack_snorm_2x16;
   condition_flags[99] = options->lower_unpack_snorm_4x8;
   condition_flags[100] = options->lower_pack_split;
   condition_flags[101] = options->lower_isign;
   condition_flags[102] = !options->lower_isign;
   condition_flags[103] = options->lower_fsign;
   condition_flags[104] = !options->has_imul24;
   condition_flags[105] = !options->has_umul24;
   condition_flags[106] = !options->has_umad24;
   condition_flags[107] = options->has_imul24;
   condition_flags[108] = options->has_umad24;
   condition_flags[109] = options->has_umul24;
   condition_flags[110] = options->lower_iadd_sat;
   condition_flags[111] = options->support_8bit_alu;
   condition_flags[112] = options->support_16bit_alu;
   condition_flags[113] = options->lower_ldexp;
   condition_flags[114] = !options->lower_bitfield_reverse;
   condition_flags[115] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[116] = options->lower_fisnormal;
   condition_flags[117] = !options->vectorize_vec2_16bit;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_before_ffma_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 211
 * transforms:
 *    ('flt', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('flt', 'a', ('fneg', 'b'))
 *    ('flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('flt', ('fneg', 'a'), 'b')
 *    ('flt', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('flt', ('fneg', 'a'), 'b')
 *    ('flt', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('flt', 'a', ('fneg', 'b'))
 *    ('~fge', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b'))
 *    ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b')
 *    ('~fge', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('fge', ('fneg', 'a'), 'b')
 *    ('~fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fge', 'a', ('fneg', 'b'))
 *    ('~feq', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b'))
 *    ('~fneu', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b'))
 *    ('fge', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b'))
 *    ('fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b')
 *    ('fge', 0.0, ('fadd(is_used_once)', 'a(is_finite)', 'b')) => ('fge', ('fneg', 'a'), 'b')
 *    ('fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b'))) => ('fge', 'a', ('fneg', 'b'))
 *    ('feq', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b'))
 *    ('fneu', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b'))
 *    ('iand', ('fneu', 'a', 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a'))
 *    ('iand', ('fneu', 'a', 0.0), ('feq', 'a', 'a')) => ('!flt', 0.0, ('fabs', 'a'))
 *    ('ior', ('feq', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a')))
 *    ('ior', ('feq', 'a', 0.0), ('fneu', 'a', 'a')) => ('inot', ('!flt', 0.0, ('fabs', 'a')))
 *    ('fneg', ('fneg', 'a')) => a
 *    ('~fadd@16', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@16', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c')
 *    ('~fadd@16', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c')
 *    ('~fadd@16', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c')
 *    ('~fadd@32', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c')
 *    ('~fadd@32', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c')
 *    ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c')
 *    ('~fadd@32', ('fmulz(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fmulz(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffmaz', ('fneg', 'a'), 'b', 'c')
 *    ('~fadd@32', ('fabs(is_only_used_by_fadd)', ('fmulz(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffmaz', ('fabs', 'a'), ('fabs', 'b'), 'c')
 *    ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmulz(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffmaz', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c')
 *    ('~fadd@64', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@64', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c')
 *    ('~fadd@64', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c')
 *    ('~fadd@64', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c')
 *    ('fadd@8', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fadd@16', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fadd@32', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fadd@64', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fneg', 'a') => ('fmul', 'a', -1.0)
 *    ('iadd', 'a', ('ineg', 'b')) => ('isub', 'a', 'b')
 *    ('ineg', 'a') => ('isub', 0, 'a')
 *    ('iabs', 'a') => ('imax', 'a', ('ineg', 'a'))
 *    ('iadd', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), 'c')
 *    ('isub', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), ('ineg', 'c'))
 *    ('vec2(is_only_used_as_float)', ('fneg@16', 'a'), 'b') => ('fmul', ('vec2', 'a', 'b'), ('vec2', -1.0, 1.0))
 *    ('vec2(is_only_used_as_float)', 'a', ('fneg@16', 'b')) => ('fmul', ('vec2', 'a', 'b'), ('vec2', 1.0, -1.0))
 *    ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a')
 *    ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b')
 *    ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b')
 *    ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b')
 *    ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0)
 *    ('~fge', ('fmin(is_used_once)', ('fadd(is_used_once)', 'a', 'b'), ('fadd', 'c', 'd')), 0.0) => ('iand', ('fge', 'a', ('fneg', 'b')), ('fge', 'c', ('fneg', 'd')))
 *    ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a')
 *    ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a')
 *    ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a')
 *    ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a')
 *    ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a')
 *    ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0)
 *    ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a')
 *    ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0)
 *    ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a')
 *    ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0)
 *    ('ior', 'a', 'a') => a
 *    ('iand', 'a', 'a') => a
 *    ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a')))
 *    ('fdot2', 'a', 'b') => ('fdot2_replicated', 'a', 'b')
 *    ('fdot3', 'a', 'b') => ('fdot3_replicated', 'a', 'b')
 *    ('fdot4', 'a', 'b') => ('fdot4_replicated', 'a', 'b')
 *    ('fdph', 'a', 'b') => ('fdph_replicated', 'a', 'b')
 *    ('~flrp', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('fround_even', 'a') => ('bcsel', ('feq', ('ffract', 'a'), 0.5), ('fadd', ('ffloor', ('fadd', 'a', 0.5)), 1.0), ('ffloor', ('fadd', 'a', 0.5)))
 *    ('~ffma@32', 'a', 2.0, -1.0) => ('flrp', -1.0, 1.0, 'a')
 *    ('~ffma@32', 'a', -2.0, -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a'))
 *    ('~ffma@32', 'a', -2.0, 1.0) => ('flrp', 1.0, -1.0, 'a')
 *    ('~ffma@32', 'a', 2.0, 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a'))
 *    ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, 'a')
 *    ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a'))
 *    ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, 'a')
 *    ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a'))
 *    ('~ffma@32', ('fadd', 'b', ('fneg', 'a')), 'a', 'a') => ('flrp', 'a', 'b', 'a')
 *    ('~ffma@32', 'a', 2.0, ('fneg', ('fmul', 'a', 'a'))) => ('flrp', 'a', 1.0, 'a')
 *    ('~ffma@32', 'a', 2.0, ('fmul', ('fneg', 'a'), 'a')) => ('flrp', 'a', 1.0, 'a')
 *    ('~ffma@32', 'a', ('fneg', 'a'), ('fmul', 2.0, 'a')) => ('flrp', 'a', 1.0, 'a')
 *    ('~fmul@32', 'a', ('fadd', 2.0, ('fneg', 'a'))) => ('flrp', 'a', 1.0, 'a')
 *    ('fmin', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmin', 'a', 'b'))
 *    ('fmax', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmax', 'a', 'b'))
 *    ('bcsel', ('feq', ('fsqrt', 'a(is_not_negative)'), 0.0), 3.4028234663852886e+38, ('frsq', 'a')) => ('fmin', ('frsq', 'a'), 3.4028234663852886e+38)
 *    ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', ('ffma', 'e', 'f', 'g')))
 *    ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('fmul(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', 'e'))
 *    ('~fadd', ('fneg', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffma', ('fneg', 'a'), 'b', ('ffma', ('fneg', 'c'), 'd', ('ffma', ('fneg', 'e'), 'f', 'g')))
 *    ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', ('ffmaz', 'e', 'f', 'g')))
 *    ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('fmulz(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', 'e'))
 *    ('~fadd', ('fneg', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffmaz', ('fneg', 'a'), 'b', ('ffmaz', ('fneg', 'c'), 'd', ('ffmaz', ('fneg', 'e'), 'f', 'g')))
 *    ('ubfe', 'a', 'b', 0) => 0
 *    ('ibfe', 'a', 'b', 0) => 0
 *    ('ubfe', 'a', '#b', '#c') => ('iand', ('ushr', 4294967295, ('ineg', 'c')), ('ushr', 'a', 'b'))
 *    ('ibfe', 'a', '#b', '#c') => ('ishr', ('ishl', 'a', ('ineg', ('iadd', 'b', 'c'))), ('ineg', 'c'))
 *    ('ishl', 'a', 0) => a
 *    ('ishl', 'a', -32) => a
 *    ('ishr', 'a', 0) => a
 *    ('ishr', 'a', -32) => a
 *    ('ushr', 'a', 0) => a
 *    ('extract_i8', ('extract_i8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b')
 *    ('extract_i8', ('extract_u8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b')
 *    ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('u2u16', ('u2u8', 'a@16')) => ('extract_u8', 'a', 0)
 *    ('u2u16', ('i2i8', 'a@16')) => ('extract_u8', 'a', 0)
 *    ('i2i16', ('u2u8', 'a@16')) => ('extract_i8', 'a', 0)
 *    ('i2i16', ('i2i8', 'a@16')) => ('extract_i8', 'a', 0)
 *    ('u2u32', ('u2u8', 'a@32')) => ('extract_u8', 'a', 0)
 *    ('u2u32', ('i2i8', 'a@32')) => ('extract_u8', 'a', 0)
 *    ('u2u32', ('u2u16', 'a@32')) => ('extract_u16', 'a', 0)
 *    ('u2u32', ('i2i16', 'a@32')) => ('extract_u16', 'a', 0)
 *    ('i2i32', ('u2u8', 'a@32')) => ('extract_i8', 'a', 0)
 *    ('i2i32', ('i2i8', 'a@32')) => ('extract_i8', 'a', 0)
 *    ('i2i32', ('u2u16', 'a@32')) => ('extract_i16', 'a', 0)
 *    ('i2i32', ('i2i16', 'a@32')) => ('extract_i16', 'a', 0)
 *    ('ishl', ('extract_u8', 'a@32', 0), 8) => ('insert_u8', 'a', 1)
 *    ('ishl', ('extract_u8', 'a@32', 0), 16) => ('insert_u8', 'a', 2)
 *    ('ishl', ('extract_u8', 'a@32', 0), 24) => ('insert_u8', 'a', 3)
 *    ('iand', ('ishl', 'a@32', 8), 65280) => ('insert_u8', 'a', 1)
 *    ('iand', ('ishl', 'a@32', 16), 16711680) => ('insert_u8', 'a', 2)
 *    ('iand', ('ishl', 'a@32', 24), 4278190080) => ('insert_u8', 'a', 3)
 *    ('ishl', 'a@32', 24) => ('insert_u8', 'a', 3)
 *    ('ishl', 'a@32', 16) => ('insert_u16', 'a', 1)
 *    ('insert_u8', ('extract_u8', 'a', 0), 'b') => ('insert_u8', 'a', 'b')
 *    ('insert_u16', ('extract_u16', 'a', 0), 'b') => ('insert_u16', 'a', 'b')
 *    ('iand', ('ine(is_used_once)', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('~fadd@16', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f16', ('inot', 'b@bool'))) => ('b2f16', ('inot', ('ior', 'a', 'b')))
 *    ('~fadd@32', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f32', ('inot', 'b@bool'))) => ('b2f32', ('inot', ('ior', 'a', 'b')))
 *    ('~fadd@64', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f64', ('inot', 'b@bool'))) => ('b2f64', ('inot', ('ior', 'a', 'b')))
 *    ('bcsel', 'a', ('fadd(is_used_once)', 'b', 'c'), ('fadd', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fadd', 'b', 'c'), ('fadd(is_used_once)', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('~f2f32', ('fabs', ('f2fmp', 'a'))) => ('fabs', 'a')
 *    ('~f2f32', ('fceil', ('f2fmp', 'a'))) => ('fceil', 'a')
 *    ('~f2f32', ('fcos', ('f2fmp', 'a'))) => ('fcos', 'a')
 *    ('~f2f32', ('fddx', ('f2fmp', 'a'))) => ('fddx', 'a')
 *    ('~f2f32', ('fddx_coarse', ('f2fmp', 'a'))) => ('fddx_coarse', 'a')
 *    ('~f2f32', ('fddx_fine', ('f2fmp', 'a'))) => ('fddx_fine', 'a')
 *    ('~f2f32', ('fddy', ('f2fmp', 'a'))) => ('fddy', 'a')
 *    ('~f2f32', ('fddy_coarse', ('f2fmp', 'a'))) => ('fddy_coarse', 'a')
 *    ('~f2f32', ('fddy_fine', ('f2fmp', 'a'))) => ('fddy_fine', 'a')
 *    ('~f2f32', ('fexp2', ('f2fmp', 'a'))) => ('fexp2', 'a')
 *    ('~f2f32', ('ffloor', ('f2fmp', 'a'))) => ('ffloor', 'a')
 *    ('~f2f32', ('ffract', ('f2fmp', 'a'))) => ('ffract', 'a')
 *    ('~f2f32', ('flog2', ('f2fmp', 'a'))) => ('flog2', 'a')
 *    ('~f2f32', ('fneg', ('f2fmp', 'a'))) => ('fneg', 'a')
 *    ('~f2f32', ('frcp', ('f2fmp', 'a'))) => ('frcp', 'a')
 *    ('~f2f32', ('fround_even', ('f2fmp', 'a'))) => ('fround_even', 'a')
 *    ('~f2f32', ('frsq', ('f2fmp', 'a'))) => ('frsq', 'a')
 *    ('~f2f32', ('fsat', ('f2fmp', 'a'))) => ('fsat', 'a')
 *    ('~f2f32', ('fsign', ('f2fmp', 'a'))) => ('fsign', 'a')
 *    ('~f2f32', ('fsin', ('f2fmp', 'a'))) => ('fsin', 'a')
 *    ('~f2f32', ('fsqrt', ('f2fmp', 'a'))) => ('fsqrt', 'a')
 *    ('~f2f32', ('fadd', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fadd', 'a', 'b')
 *    ('~f2f32', ('fdiv', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fdiv', 'a', 'b')
 *    ('~f2f32', ('fmax', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmax', 'a', 'b')
 *    ('~f2f32', ('fmin', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmin', 'a', 'b')
 *    ('~f2f32', ('fmod', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmod', 'a', 'b')
 *    ('~f2f32', ('fmul', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmul', 'a', 'b')
 *    ('~f2f32', ('fpow', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fpow', 'a', 'b')
 *    ('~f2f32', ('frem', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('frem', 'a', 'b')
 *    ('~f2f32', ('ffma', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('ffma', 'a', 'b', 'c')
 *    ('~f2f32', ('flrp', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('flrp', 'a', 'b', 'c')
 *    ('~feq', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('feq', 'a', 'b')
 *    ('~fge', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fge', 'a', 'b')
 *    ('~flt', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('flt', 'a', 'b')
 *    ('~fneu', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fneu', 'a', 'b')
 *    ('f2fmp', 'a') => ('f2f16', 'a')
 *    ('f2imp', 'a') => ('f2i16', 'a')
 *    ('f2ump', 'a') => ('f2u16', 'a')
 *    ('i2imp', 'a') => ('i2i16', 'a')
 *    ('i2fmp', 'a') => ('i2f16', 'a')
 *    ('i2imp', 'a') => ('u2u16', 'a')
 *    ('u2fmp', 'a') => ('u2f16', 'a')
 *    ('fisfinite', 'a') => ('flt', ('fabs', 'a'), inf)
 *    ('fcsel', ('slt', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'b', 'c')
 *    ('fcsel', ('slt', 'a', 0), 'b', 'c') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c')
 *    ('fcsel', ('sge', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'b', 'c')
 *    ('fcsel', ('sge', 0, 'a'), 'b', 'c') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c')
 *    ('bcsel', ('ilt', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'b', 'c')
 *    ('bcsel', ('ilt', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'c', 'b')
 *    ('bcsel', ('ige', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'b', 'c')
 *    ('bcsel', ('ige', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'c', 'b')
 *    ('bcsel', ('flt', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'b', 'c')
 *    ('bcsel', ('flt', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c')
 *    ('bcsel', ('fge', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'b', 'c')
 *    ('bcsel', ('fge', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c')
 */


static const nir_search_value_union nir_opt_algebraic_late_values[] = {
   /* ('flt', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('flt', 'a', ('fneg', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 2, 3 },
      -1,
   } },

   /* replace2030_0 -> 0 in the cache */
   /* replace2030_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 5 },
      -1,
   } },

   /* ('flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('flt', ('fneg', 'a'), 'b') */
   /* search2031_0_0_0 -> 0 in the cache */
   /* search2031_0_0_1 -> 1 in the cache */
   /* search2031_0_0 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 2 },
      0,
   } },
   /* search2031_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 7, 3 },
      -1,
   } },

   /* replace2031_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace2031_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 1 },
      -1,
   } },

   /* ('flt', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('flt', ('fneg', 'a'), 'b') */
   /* search2032_0 -> 3 in the cache */
   /* search2032_1_0 -> 0 in the cache */
   /* search2032_1_1 -> 1 in the cache */
   /* search2032_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 3, 2 },
      -1,
   } },

   /* replace2032_0_0 -> 0 in the cache */
   /* replace2032_0 -> 9 in the cache */
   /* replace2032_1 -> 1 in the cache */
   /* replace2032 -> 10 in the cache */

   /* ('flt', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('flt', 'a', ('fneg', 'b')) */
   /* search2033_0 -> 3 in the cache */
   /* search2033_1_0_0 -> 0 in the cache */
   /* search2033_1_0_1 -> 1 in the cache */
   /* search2033_1_0 -> 2 in the cache */
   /* search2033_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 3, 7 },
      -1,
   } },

   /* replace2033_0 -> 0 in the cache */
   /* replace2033_1_0 -> 1 in the cache */
   /* replace2033_1 -> 5 in the cache */
   /* replace2033 -> 6 in the cache */

   /* ('~fge', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b')) */
   /* search2034_0_0 -> 0 in the cache */
   /* search2034_0_1 -> 1 in the cache */
   /* search2034_0 -> 2 in the cache */
   /* search2034_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 2, 3 },
      -1,
   } },

   /* replace2034_0 -> 0 in the cache */
   /* replace2034_1_0 -> 1 in the cache */
   /* replace2034_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 5 },
      -1,
   } },

   /* ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b') */
   /* search2035_0_0_0 -> 0 in the cache */
   /* search2035_0_0_1 -> 1 in the cache */
   /* search2035_0_0 -> 2 in the cache */
   /* search2035_0 -> 7 in the cache */
   /* search2035_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 7, 3 },
      -1,
   } },

   /* replace2035_0_0 -> 0 in the cache */
   /* replace2035_0 -> 9 in the cache */
   /* replace2035_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 1 },
      -1,
   } },

   /* ('~fge', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('fge', ('fneg', 'a'), 'b') */
   /* search2036_0 -> 3 in the cache */
   /* search2036_1_0 -> 0 in the cache */
   /* search2036_1_1 -> 1 in the cache */
   /* search2036_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 2 },
      -1,
   } },

   /* replace2036_0_0 -> 0 in the cache */
   /* replace2036_0 -> 9 in the cache */
   /* replace2036_1 -> 1 in the cache */
   /* replace2036 -> 16 in the cache */

   /* ('~fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fge', 'a', ('fneg', 'b')) */
   /* search2037_0 -> 3 in the cache */
   /* search2037_1_0_0 -> 0 in the cache */
   /* search2037_1_0_1 -> 1 in the cache */
   /* search2037_1_0 -> 2 in the cache */
   /* search2037_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 7 },
      -1,
   } },

   /* replace2037_0 -> 0 in the cache */
   /* replace2037_1_0 -> 1 in the cache */
   /* replace2037_1 -> 5 in the cache */
   /* replace2037 -> 14 in the cache */

   /* ('~feq', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b')) */
   /* search2038_0_0 -> 0 in the cache */
   /* search2038_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search2038_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 19, 3 },
      -1,
   } },

   /* replace2038_0 -> 0 in the cache */
   /* replace2038_1_0 -> 1 in the cache */
   /* replace2038_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* ('~fneu', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b')) */
   /* search2039_0_0 -> 0 in the cache */
   /* search2039_0_1 -> 1 in the cache */
   /* search2039_0 -> 19 in the cache */
   /* search2039_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 19, 3 },
      -1,
   } },

   /* replace2039_0 -> 0 in the cache */
   /* replace2039_1_0 -> 1 in the cache */
   /* replace2039_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* ('fge', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2040_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 24, 1 },
      0,
   } },
   /* search2040_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 25, 3 },
      -1,
   } },

   /* replace2040_0 -> 0 in the cache */
   /* replace2040_1_0 -> 1 in the cache */
   /* replace2040_1 -> 5 in the cache */
   /* replace2040 -> 14 in the cache */

   /* ('fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b') */
   /* search2041_0_0_0 -> 24 in the cache */
   /* search2041_0_0_1 -> 1 in the cache */
   /* search2041_0_0 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 25 },
      0,
   } },
   /* search2041_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 27, 3 },
      -1,
   } },

   /* replace2041_0_0 -> 0 in the cache */
   /* replace2041_0 -> 9 in the cache */
   /* replace2041_1 -> 1 in the cache */
   /* replace2041 -> 16 in the cache */

   /* ('fge', 0.0, ('fadd(is_used_once)', 'a(is_finite)', 'b')) => ('fge', ('fneg', 'a'), 'b') */
   /* search2042_0 -> 3 in the cache */
   /* search2042_1_0 -> 24 in the cache */
   /* search2042_1_1 -> 1 in the cache */
   /* search2042_1 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 25 },
      -1,
   } },

   /* replace2042_0_0 -> 0 in the cache */
   /* replace2042_0 -> 9 in the cache */
   /* replace2042_1 -> 1 in the cache */
   /* replace2042 -> 16 in the cache */

   /* ('fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b'))) => ('fge', 'a', ('fneg', 'b')) */
   /* search2043_0 -> 3 in the cache */
   /* search2043_1_0_0 -> 24 in the cache */
   /* search2043_1_0_1 -> 1 in the cache */
   /* search2043_1_0 -> 25 in the cache */
   /* search2043_1 -> 27 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 27 },
      -1,
   } },

   /* replace2043_0 -> 0 in the cache */
   /* replace2043_1_0 -> 1 in the cache */
   /* replace2043_1 -> 5 in the cache */
   /* replace2043 -> 14 in the cache */

   /* ('feq', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b')) */
   /* search2044_0_0 -> 24 in the cache */
   /* search2044_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 24, 1 },
      0,
   } },
   /* search2044_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 31, 3 },
      -1,
   } },

   /* replace2044_0 -> 0 in the cache */
   /* replace2044_1_0 -> 1 in the cache */
   /* replace2044_1 -> 5 in the cache */
   /* replace2044 -> 21 in the cache */

   /* ('fneu', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b')) */
   /* search2045_0_0 -> 24 in the cache */
   /* search2045_0_1 -> 1 in the cache */
   /* search2045_0 -> 31 in the cache */
   /* search2045_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 31, 3 },
      -1,
   } },

   /* replace2045_0 -> 0 in the cache */
   /* replace2045_1_0 -> 1 in the cache */
   /* replace2045_1 -> 5 in the cache */
   /* replace2045 -> 23 in the cache */

   /* ('iand', ('fneu', 'a', 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a')) */
   /* search2046_0_0 -> 0 in the cache */
   /* search2046_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search2046_1_0_0 -> 0 in the cache */
   /* search2046_1_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search2046_1_1_0 -> 1 in the cache */
   /* search2046_1_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 1, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 35, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 34, 37 },
      -1,
   } },

   /* replace2046_0_0 -> 0 in the cache */
   /* replace2046_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   /* replace2046_1_0 -> 1 in the cache */
   /* replace2046_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 39, 40 },
      -1,
   } },

   /* ('iand', ('fneu', 'a', 0.0), ('feq', 'a', 'a')) => ('!flt', 0.0, ('fabs', 'a')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 42, 43 },
      -1,
   } },
   /* search2047_1_0 -> 42 in the cache */
   /* search2047_1_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 42, 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 44, 45 },
      -1,
   } },

   /* replace2047_0 -> 43 in the cache */
   /* replace2047_1_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 43, 47 },
      -1,
   } },

   /* ('ior', ('feq', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a'))) */
   /* search2048_0_0 -> 0 in the cache */
   /* search2048_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search2048_1_0_0 -> 0 in the cache */
   /* search2048_1_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search2048_1_1_0 -> 1 in the cache */
   /* search2048_1_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 1, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 50, 51 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 49, 52 },
      -1,
   } },

   /* replace2048_0_0_0 -> 0 in the cache */
   /* replace2048_0_0_1 -> 1 in the cache */
   /* replace2048_0_0 -> 39 in the cache */
   /* replace2048_0_1_0 -> 1 in the cache */
   /* replace2048_0_1_1 -> 0 in the cache */
   /* replace2048_0_1 -> 40 in the cache */
   /* replace2048_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 41 },
      -1,
   } },

   /* ('ior', ('feq', 'a', 0.0), ('fneu', 'a', 'a')) => ('inot', ('!flt', 0.0, ('fabs', 'a'))) */
   /* search2049_0_0 -> 42 in the cache */
   /* search2049_0_1 -> 43 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 42, 43 },
      -1,
   } },
   /* search2049_1_0 -> 42 in the cache */
   /* search2049_1_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 42, 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 55, 56 },
      -1,
   } },

   /* replace2049_0_0 -> 43 in the cache */
   /* replace2049_0_1_0 -> 42 in the cache */
   /* replace2049_0_1 -> 47 in the cache */
   /* replace2049_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 48 },
      -1,
   } },

   /* ('fneg', ('fneg', 'a')) => a */
   /* search2050_0_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 59 },
      -1,
   } },

   /* replace2050 -> 42 in the cache */

   /* ('~fadd@16', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 61, 62 },
      1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 63, 64 },
      -1,
   } },

   /* replace2051_0 -> 61 in the cache */
   /* replace2051_1 -> 62 in the cache */
   /* replace2051_2 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 61, 62, 64 },
      -1,
   } },

   /* ('~fadd@16', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c') */
   /* search2052_0_0_0 -> 61 in the cache */
   /* search2052_0_0_1 -> 62 in the cache */
   /* search2052_0_0 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 63 },
      1,
   } },
   /* search2052_1 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 67, 64 },
      -1,
   } },

   /* replace2052_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 61 },
      -1,
   } },
   /* replace2052_1 -> 62 in the cache */
   /* replace2052_2 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 69, 62, 64 },
      -1,
   } },

   /* ('~fadd@16', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c') */
   /* search2053_0_0_0 -> 61 in the cache */
   /* search2053_0_0_1 -> 62 in the cache */
   /* search2053_0_0 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 63 },
      1,
   } },
   /* search2053_1 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 71, 64 },
      -1,
   } },

   /* replace2053_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 61 },
      -1,
   } },
   /* replace2053_1_0 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 62 },
      -1,
   } },
   /* replace2053_2 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 73, 74, 64 },
      -1,
   } },

   /* ('~fadd@16', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c') */
   /* search2054_0_0_0_0 -> 61 in the cache */
   /* search2054_0_0_0_1 -> 62 in the cache */
   /* search2054_0_0_0 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 63 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 76 },
      1,
   } },
   /* search2054_1 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 77, 64 },
      -1,
   } },

   /* replace2054_0_0_0 -> 61 in the cache */
   /* replace2054_0_0 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 73 },
      -1,
   } },
   /* replace2054_1_0 -> 62 in the cache */
   /* replace2054_1 -> 74 in the cache */
   /* replace2054_2 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 79, 74, 64 },
      -1,
   } },

   /* ('~fadd@32', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 81, 82 },
      1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 83, 84 },
      -1,
   } },

   /* replace2055_0 -> 81 in the cache */
   /* replace2055_1 -> 82 in the cache */
   /* replace2055_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 81, 82, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c') */
   /* search2056_0_0_0 -> 81 in the cache */
   /* search2056_0_0_1 -> 82 in the cache */
   /* search2056_0_0 -> 83 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 83 },
      1,
   } },
   /* search2056_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 87, 84 },
      -1,
   } },

   /* replace2056_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 81 },
      -1,
   } },
   /* replace2056_1 -> 82 in the cache */
   /* replace2056_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 89, 82, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c') */
   /* search2057_0_0_0 -> 81 in the cache */
   /* search2057_0_0_1 -> 82 in the cache */
   /* search2057_0_0 -> 83 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 83 },
      1,
   } },
   /* search2057_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 91, 84 },
      -1,
   } },

   /* replace2057_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 81 },
      -1,
   } },
   /* replace2057_1_0 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 82 },
      -1,
   } },
   /* replace2057_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 93, 94, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c') */
   /* search2058_0_0_0_0 -> 81 in the cache */
   /* search2058_0_0_0_1 -> 82 in the cache */
   /* search2058_0_0_0 -> 83 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 83 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 96 },
      1,
   } },
   /* search2058_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 97, 84 },
      -1,
   } },

   /* replace2058_0_0_0 -> 81 in the cache */
   /* replace2058_0_0 -> 93 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 93 },
      -1,
   } },
   /* replace2058_1_0 -> 82 in the cache */
   /* replace2058_1 -> 94 in the cache */
   /* replace2058_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 99, 94, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fmulz(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search2059_0_0 -> 81 in the cache */
   /* search2059_0_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 81, 82 },
      1,
   } },
   /* search2059_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 101, 84 },
      -1,
   } },

   /* replace2059_0 -> 81 in the cache */
   /* replace2059_1 -> 82 in the cache */
   /* replace2059_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 81, 82, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fmulz(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffmaz', ('fneg', 'a'), 'b', 'c') */
   /* search2060_0_0_0 -> 81 in the cache */
   /* search2060_0_0_1 -> 82 in the cache */
   /* search2060_0_0 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 101 },
      1,
   } },
   /* search2060_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 104, 84 },
      -1,
   } },

   /* replace2060_0_0 -> 81 in the cache */
   /* replace2060_0 -> 89 in the cache */
   /* replace2060_1 -> 82 in the cache */
   /* replace2060_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 89, 82, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fabs(is_only_used_by_fadd)', ('fmulz(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffmaz', ('fabs', 'a'), ('fabs', 'b'), 'c') */
   /* search2061_0_0_0 -> 81 in the cache */
   /* search2061_0_0_1 -> 82 in the cache */
   /* search2061_0_0 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 101 },
      1,
   } },
   /* search2061_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 107, 84 },
      -1,
   } },

   /* replace2061_0_0 -> 81 in the cache */
   /* replace2061_0 -> 93 in the cache */
   /* replace2061_1_0 -> 82 in the cache */
   /* replace2061_1 -> 94 in the cache */
   /* replace2061_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 93, 94, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmulz(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffmaz', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c') */
   /* search2062_0_0_0_0 -> 81 in the cache */
   /* search2062_0_0_0_1 -> 82 in the cache */
   /* search2062_0_0_0 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 110 },
      1,
   } },
   /* search2062_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 111, 84 },
      -1,
   } },

   /* replace2062_0_0_0 -> 81 in the cache */
   /* replace2062_0_0 -> 93 in the cache */
   /* replace2062_0 -> 99 in the cache */
   /* replace2062_1_0 -> 82 in the cache */
   /* replace2062_1 -> 94 in the cache */
   /* replace2062_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 99, 94, 84 },
      -1,
   } },

   /* ('~fadd@64', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 114, 115 },
      1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 116, 117 },
      -1,
   } },

   /* replace2063_0 -> 114 in the cache */
   /* replace2063_1 -> 115 in the cache */
   /* replace2063_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 114, 115, 117 },
      -1,
   } },

   /* ('~fadd@64', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c') */
   /* search2064_0_0_0 -> 114 in the cache */
   /* search2064_0_0_1 -> 115 in the cache */
   /* search2064_0_0 -> 116 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 116 },
      1,
   } },
   /* search2064_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 120, 117 },
      -1,
   } },

   /* replace2064_0_0 -> 114 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 114 },
      -1,
   } },
   /* replace2064_1 -> 115 in the cache */
   /* replace2064_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 122, 115, 117 },
      -1,
   } },

   /* ('~fadd@64', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c') */
   /* search2065_0_0_0 -> 114 in the cache */
   /* search2065_0_0_1 -> 115 in the cache */
   /* search2065_0_0 -> 116 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 116 },
      1,
   } },
   /* search2065_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 124, 117 },
      -1,
   } },

   /* replace2065_0_0 -> 114 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 114 },
      -1,
   } },
   /* replace2065_1_0 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 115 },
      -1,
   } },
   /* replace2065_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 126, 127, 117 },
      -1,
   } },

   /* ('~fadd@64', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c') */
   /* search2066_0_0_0_0 -> 114 in the cache */
   /* search2066_0_0_0_1 -> 115 in the cache */
   /* search2066_0_0_0 -> 116 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 116 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 129 },
      1,
   } },
   /* search2066_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 130, 117 },
      -1,
   } },

   /* replace2066_0_0_0 -> 114 in the cache */
   /* replace2066_0_0 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 126 },
      -1,
   } },
   /* replace2066_1_0 -> 115 in the cache */
   /* replace2066_1 -> 127 in the cache */
   /* replace2066_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 132, 127, 117 },
      -1,
   } },

   /* ('fadd@8', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 134, 136 },
      -1,
   } },

   /* replace2067_0 -> 134 in the cache */
   /* replace2067_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 134, 135 },
      -1,
   } },

   /* ('fadd@16', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   /* search2068_0 -> 61 in the cache */
   /* search2068_1_0 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 62 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 61, 139 },
      -1,
   } },

   /* replace2068_0 -> 61 in the cache */
   /* replace2068_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 61, 62 },
      -1,
   } },

   /* ('fadd@32', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   /* search2069_0 -> 81 in the cache */
   /* search2069_1_0 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 82 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 81, 142 },
      -1,
   } },

   /* replace2069_0 -> 81 in the cache */
   /* replace2069_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('fadd@64', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   /* search2070_0 -> 114 in the cache */
   /* search2070_1_0 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 114, 145 },
      -1,
   } },

   /* replace2070_0 -> 114 in the cache */
   /* replace2070_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 114, 115 },
      -1,
   } },

   /* ('fneg', 'a') => ('fmul', 'a', -1.0) */
   /* search2071_0 -> 42 in the cache */
   /* search2071 -> 59 in the cache */

   /* replace2071_0 -> 42 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 42, 148 },
      -1,
   } },

   /* ('iadd', 'a', ('ineg', 'b')) => ('isub', 'a', 'b') */
   /* search2072_0 -> 0 in the cache */
   /* search2072_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 150 },
      -1,
   } },

   /* replace2072_0 -> 0 in the cache */
   /* replace2072_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('ineg', 'a') => ('isub', 0, 'a') */
   /* search2073_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 42 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   /* replace2073_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 154, 42 },
      -1,
   } },

   /* ('iabs', 'a') => ('imax', 'a', ('ineg', 'a')) */
   /* search2074_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 42 },
      -1,
   } },

   /* replace2074_0 -> 42 in the cache */
   /* replace2074_1_0 -> 42 in the cache */
   /* replace2074_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 42, 153 },
      -1,
   } },

   /* ('iadd', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 158, 159 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 160, 161 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 163, 164, 165 },
      -1,
   } },

   /* ('iadd', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), 'c') */
   /* search2076_0_0 -> 158 in the cache */
   /* search2076_0_1 -> 159 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 158, 159 },
      0,
   } },
   /* search2076_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 167, 161 },
      -1,
   } },

   /* replace2076_0 -> 163 in the cache */
   /* replace2076_1_0 -> 164 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 164 },
      -1,
   } },
   /* replace2076_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 163, 169, 165 },
      -1,
   } },

   /* ('isub', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), ('ineg', 'c')) */
   /* search2077_0_0 -> 158 in the cache */
   /* search2077_0_1 -> 159 in the cache */
   /* search2077_0 -> 167 in the cache */
   /* search2077_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 167, 161 },
      -1,
   } },

   /* replace2077_0 -> 163 in the cache */
   /* replace2077_1_0 -> 164 in the cache */
   /* replace2077_1 -> 169 in the cache */
   /* replace2077_2_0 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 163, 169, 172 },
      -1,
   } },

   /* ('vec2(is_only_used_as_float)', ('fneg@16', 'a'), 'b') => ('fmul', ('vec2', 'a', 'b'), ('vec2', -1.0, 1.0)) */
   /* search2078_0_0 -> 61 in the cache */
   /* search2078_0 -> 69 in the cache */
   /* search2078_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 69, 62 },
      2,
   } },

   /* replace2078_0_0 -> 61 in the cache */
   /* replace2078_0_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 61, 62 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 176, 177 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 175, 178 },
      -1,
   } },

   /* ('vec2(is_only_used_as_float)', 'a', ('fneg@16', 'b')) => ('fmul', ('vec2', 'a', 'b'), ('vec2', 1.0, -1.0)) */
   /* search2079_0 -> 61 in the cache */
   /* search2079_1_0 -> 62 in the cache */
   /* search2079_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 61, 139 },
      2,
   } },

   /* replace2079_0_0 -> 61 in the cache */
   /* replace2079_0_1 -> 62 in the cache */
   /* replace2079_0 -> 175 in the cache */
   /* replace2079_1_0 -> 177 in the cache */
   /* replace2079_1_1 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 177, 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 175, 181 },
      -1,
   } },

   /* ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 184 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 183, 185 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace2080_1 -> 184 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 187, 184 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b') */
   /* search2081_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 189, 190 },
      -1,
   } },

   /* replace2081_0 -> 0 in the cache */
   /* replace2081_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b') */
   /* search2082_0_0 -> 0 in the cache */
   /* search2082_0 -> 189 in the cache */
   /* search2082_1 -> 190 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 189, 190 },
      -1,
   } },

   /* replace2082_0 -> 0 in the cache */
   /* replace2082_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b') */
   /* search2083_0_0 -> 0 in the cache */
   /* search2083_0 -> 189 in the cache */
   /* search2083_1 -> 190 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 189, 190 },
      -1,
   } },

   /* replace2083_0 -> 0 in the cache */
   /* replace2083_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0) */
   /* search2084_0_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 42 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 197, 198 },
      -1,
   } },

   /* replace2084_0 -> 42 in the cache */
   /* replace2084_1 -> 198 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 42, 198 },
      -1,
   } },

   /* ('~fge', ('fmin(is_used_once)', ('fadd(is_used_once)', 'a', 'b'), ('fadd', 'c', 'd')), 0.0) => ('iand', ('fge', 'a', ('fneg', 'b')), ('fge', 'c', ('fneg', 'd'))) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 201, 202 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 204, 205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 203, 206 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 3,
      { 207, 208 },
      -1,
   } },

   /* replace2085_0_0 -> 201 in the cache */
   /* replace2085_0_1_0 -> 202 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 202 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 201, 210 },
      -1,
   } },
   /* replace2085_1_0 -> 204 in the cache */
   /* replace2085_1_1_0 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 204, 212 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 211, 213 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a') */
   /* search2086_0_0 -> 0 in the cache */
   /* search2086_0 -> 9 in the cache */
   /* search2086_1_0 -> 1 in the cache */
   /* search2086_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 5 },
      -1,
   } },

   /* replace2086_0 -> 1 in the cache */
   /* replace2086_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 0 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a') */
   /* search2087_0_0 -> 0 in the cache */
   /* search2087_0 -> 9 in the cache */
   /* search2087_1_0 -> 1 in the cache */
   /* search2087_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 5 },
      -1,
   } },

   /* replace2087_0 -> 1 in the cache */
   /* replace2087_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1, 0 },
      -1,
   } },

   /* ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a') */
   /* search2088_0_0 -> 0 in the cache */
   /* search2088_0 -> 9 in the cache */
   /* search2088_1_0 -> 1 in the cache */
   /* search2088_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 9, 5 },
      -1,
   } },

   /* replace2088_0 -> 1 in the cache */
   /* replace2088_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1, 0 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a') */
   /* search2089_0_0 -> 0 in the cache */
   /* search2089_0 -> 9 in the cache */
   /* search2089_1_0 -> 1 in the cache */
   /* search2089_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 9, 5 },
      -1,
   } },

   /* replace2089_0 -> 1 in the cache */
   /* replace2089_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1, 0 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a') */
   /* search2090_0_0 -> 42 in the cache */
   /* search2090_0 -> 59 in the cache */
   /* search2090_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 59, 148 },
      -1,
   } },

   /* replace2090_0 -> 198 in the cache */
   /* replace2090_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 198, 42 },
      -1,
   } },

   /* ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0) */
   /* search2091_0 -> 148 in the cache */
   /* search2091_1_0 -> 42 in the cache */
   /* search2091_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 148, 59 },
      -1,
   } },

   /* replace2091_0 -> 42 in the cache */
   /* replace2091_1 -> 198 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 42, 198 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a') */
   /* search2092_0_0 -> 42 in the cache */
   /* search2092_0 -> 59 in the cache */
   /* search2092_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 59, 148 },
      -1,
   } },

   /* replace2092_0 -> 198 in the cache */
   /* replace2092_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 198, 42 },
      -1,
   } },

   /* ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0) */
   /* search2093_0 -> 148 in the cache */
   /* search2093_1_0 -> 42 in the cache */
   /* search2093_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 148, 59 },
      -1,
   } },

   /* replace2093_0 -> 42 in the cache */
   /* replace2093_1 -> 198 in the cache */
   /* replace2093 -> 200 in the cache */

   /* ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a') */
   /* search2094_0_0 -> 42 in the cache */
   /* search2094_0 -> 59 in the cache */
   /* search2094_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 59, 148 },
      -1,
   } },

   /* replace2094_0 -> 198 in the cache */
   /* replace2094_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 198, 42 },
      -1,
   } },

   /* ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0) */
   /* search2095_0 -> 148 in the cache */
   /* search2095_1_0 -> 42 in the cache */
   /* search2095_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 148, 59 },
      -1,
   } },

   /* replace2095_0 -> 42 in the cache */
   /* replace2095_1 -> 198 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 42, 198 },
      -1,
   } },

   /* ('ior', 'a', 'a') => a */
   /* search2096_0 -> 42 in the cache */
   /* search2096_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 0,
      { 42, 42 },
      -1,
   } },

   /* replace2096 -> 42 in the cache */

   /* ('iand', 'a', 'a') => a */
   /* search2097_0 -> 42 in the cache */
   /* search2097_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 0,
      { 42, 42 },
      -1,
   } },

   /* replace2097 -> 42 in the cache */

   /* ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a'))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 236 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 237 },
      0,
   } },
   /* search2098_1 -> 198 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 238, 198 },
      -1,
   } },

   /* replace2098_0_0 -> 198 in the cache */
   /* replace2098_0_1_0 -> 42 in the cache */
   /* replace2098_0_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 198, 59 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 240 },
      -1,
   } },

   /* ('fdot2', 'a', 'b') => ('fdot2_replicated', 'a', 'b') */
   /* search2099_0 -> 0 in the cache */
   /* search2099_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace2099_0 -> 0 in the cache */
   /* replace2099_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdot3', 'a', 'b') => ('fdot3_replicated', 'a', 'b') */
   /* search2100_0 -> 0 in the cache */
   /* search2100_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace2100_0 -> 0 in the cache */
   /* replace2100_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdot4', 'a', 'b') => ('fdot4_replicated', 'a', 'b') */
   /* search2101_0 -> 0 in the cache */
   /* search2101_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace2101_0 -> 0 in the cache */
   /* replace2101_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdph', 'a', 'b') => ('fdph_replicated', 'a', 'b') */
   /* search2102_0 -> 0 in the cache */
   /* search2102_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace2102_0 -> 0 in the cache */
   /* replace2102_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search2103_0_0 -> 201 in the cache */
   /* search2103_0_1 -> 202 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 201, 202 },
      0,
   } },
   /* search2103_1_0 -> 201 in the cache */
   /* search2103_1_1 -> 204 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 201, 204 },
      0,
   } },
   /* search2103_2 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 250, 251, 205 },
      -1,
   } },

   /* replace2103_0_0 -> 202 in the cache */
   /* replace2103_0_1 -> 204 in the cache */
   /* replace2103_0_2 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 202, 204, 205 },
      -1,
   } },
   /* replace2103_1 -> 201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 253, 201 },
      -1,
   } },

   /* ('fround_even', 'a') => ('bcsel', ('feq', ('ffract', 'a'), 0.5), ('fadd', ('ffloor', ('fadd', 'a', 0.5)), 1.0), ('ffloor', ('fadd', 'a', 0.5))) */
   /* search2104_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 42 },
      -1,
   } },

   /* replace2104_0_0_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 42 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe0000000000000 /* 0.5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 256, 257 },
      -1,
   } },
   /* replace2104_1_0_0_0 -> 42 in the cache */
   /* replace2104_1_0_0_1 -> 257 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 42, 257 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 1,
      { 259 },
      -1,
   } },
   /* replace2104_1_1 -> 198 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 260, 198 },
      -1,
   } },
   /* replace2104_2_0_0 -> 42 in the cache */
   /* replace2104_2_0_1 -> 257 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 42, 257 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 1,
      { 262 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 258, 261, 263 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, -1.0) => ('flrp', -1.0, 1.0, 'a') */
   /* search2105_0 -> 81 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x4000000000000000 /* 2.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 81, 265, 266 },
      -1,
   } },

   /* replace2105_0 -> 266 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace2105_2 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 266, 268, 81 },
      -1,
   } },

   /* ('~ffma@32', 'a', -2.0, -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a')) */
   /* search2106_0 -> 81 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xc000000000000000 /* -2.0 */ },
   } },
   /* search2106_2 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 81, 270, 266 },
      -1,
   } },

   /* replace2106_0 -> 266 in the cache */
   /* replace2106_1 -> 268 in the cache */
   /* replace2106_2_0 -> 81 in the cache */
   /* replace2106_2 -> 89 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 266, 268, 89 },
      -1,
   } },

   /* ('~ffma@32', 'a', -2.0, 1.0) => ('flrp', 1.0, -1.0, 'a') */
   /* search2107_0 -> 81 in the cache */
   /* search2107_1 -> 270 in the cache */
   /* search2107_2 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 81, 270, 268 },
      -1,
   } },

   /* replace2107_0 -> 268 in the cache */
   /* replace2107_1 -> 266 in the cache */
   /* replace2107_2 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 268, 266, 81 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a')) */
   /* search2108_0 -> 81 in the cache */
   /* search2108_1 -> 265 in the cache */
   /* search2108_2 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 81, 265, 268 },
      -1,
   } },

   /* replace2108_0 -> 268 in the cache */
   /* replace2108_1 -> 266 in the cache */
   /* replace2108_2_0 -> 81 in the cache */
   /* replace2108_2 -> 89 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 268, 266, 89 },
      -1,
   } },

   /* ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, 'a') */
   /* search2109_0_0 -> 265 in the cache */
   /* search2109_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 265, 81 },
      0,
   } },
   /* search2109_1 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 277, 266 },
      -1,
   } },

   /* replace2109_0 -> 266 in the cache */
   /* replace2109_1 -> 268 in the cache */
   /* replace2109_2 -> 81 in the cache */
   /* replace2109 -> 269 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a')) */
   /* search2110_0_0 -> 270 in the cache */
   /* search2110_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 270, 81 },
      0,
   } },
   /* search2110_1 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 279, 266 },
      -1,
   } },

   /* replace2110_0 -> 266 in the cache */
   /* replace2110_1 -> 268 in the cache */
   /* replace2110_2_0 -> 81 in the cache */
   /* replace2110_2 -> 89 in the cache */
   /* replace2110 -> 272 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, 'a') */
   /* search2111_0_0 -> 270 in the cache */
   /* search2111_0_1 -> 81 in the cache */
   /* search2111_0 -> 279 in the cache */
   /* search2111_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 279, 268 },
      -1,
   } },

   /* replace2111_0 -> 268 in the cache */
   /* replace2111_1 -> 266 in the cache */
   /* replace2111_2 -> 81 in the cache */
   /* replace2111 -> 274 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a')) */
   /* search2112_0_0 -> 265 in the cache */
   /* search2112_0_1 -> 81 in the cache */
   /* search2112_0 -> 277 in the cache */
   /* search2112_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 277, 268 },
      -1,
   } },

   /* replace2112_0 -> 268 in the cache */
   /* replace2112_1 -> 266 in the cache */
   /* replace2112_2_0 -> 81 in the cache */
   /* replace2112_2 -> 89 in the cache */
   /* replace2112 -> 276 in the cache */

   /* ('~ffma@32', ('fadd', 'b', ('fneg', 'a')), 'a', 'a') => ('flrp', 'a', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 284 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 283, 285 },
      -1,
   } },
   /* search2113_1 -> 284 in the cache */
   /* search2113_2 -> 284 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 286, 284, 284 },
      -1,
   } },

   /* replace2113_0 -> 284 in the cache */
   /* replace2113_1 -> 283 in the cache */
   /* replace2113_2 -> 284 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 284, 283, 284 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, ('fneg', ('fmul', 'a', 'a'))) => ('flrp', 'a', 1.0, 'a') */
   /* search2114_0 -> 81 in the cache */
   /* search2114_1 -> 265 in the cache */
   /* search2114_2_0_0 -> 81 in the cache */
   /* search2114_2_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 81, 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 289 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 81, 265, 290 },
      -1,
   } },

   /* replace2114_0 -> 81 in the cache */
   /* replace2114_1 -> 268 in the cache */
   /* replace2114_2 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 81, 268, 81 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, ('fmul', ('fneg', 'a'), 'a')) => ('flrp', 'a', 1.0, 'a') */
   /* search2115_0 -> 81 in the cache */
   /* search2115_1 -> 265 in the cache */
   /* search2115_2_0_0 -> 81 in the cache */
   /* search2115_2_0 -> 89 in the cache */
   /* search2115_2_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 89, 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 81, 265, 293 },
      -1,
   } },

   /* replace2115_0 -> 81 in the cache */
   /* replace2115_1 -> 268 in the cache */
   /* replace2115_2 -> 81 in the cache */
   /* replace2115 -> 292 in the cache */

   /* ('~ffma@32', 'a', ('fneg', 'a'), ('fmul', 2.0, 'a')) => ('flrp', 'a', 1.0, 'a') */
   /* search2116_0 -> 81 in the cache */
   /* search2116_1_0 -> 81 in the cache */
   /* search2116_1 -> 89 in the cache */
   /* search2116_2_0 -> 265 in the cache */
   /* search2116_2_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 265, 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 81, 89, 295 },
      -1,
   } },

   /* replace2116_0 -> 81 in the cache */
   /* replace2116_1 -> 268 in the cache */
   /* replace2116_2 -> 81 in the cache */
   /* replace2116 -> 292 in the cache */

   /* ('~fmul@32', 'a', ('fadd', 2.0, ('fneg', 'a'))) => ('flrp', 'a', 1.0, 'a') */
   /* search2117_0 -> 81 in the cache */
   /* search2117_1_0 -> 265 in the cache */
   /* search2117_1_1_0 -> 81 in the cache */
   /* search2117_1_1 -> 89 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 265, 89 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 81, 297 },
      -1,
   } },

   /* replace2117_0 -> 81 in the cache */
   /* replace2117_1 -> 268 in the cache */
   /* replace2117_2 -> 81 in the cache */
   /* replace2117 -> 292 in the cache */

   /* ('fmin', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmin', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 299, 300 },
      0,
   } },
   /* search2118_1_0 -> 299 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 299, 302 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 301, 303 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace2118_1_0 -> 300 in the cache */
   /* replace2118_1_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 300, 302 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 305, 306 },
      -1,
   } },

   /* ('fmax', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmax', 'a', 'b')) */
   /* search2119_0_0 -> 299 in the cache */
   /* search2119_0_1 -> 300 in the cache */
   /* search2119_0 -> 301 in the cache */
   /* search2119_1_0 -> 299 in the cache */
   /* search2119_1_1 -> 302 in the cache */
   /* search2119_1 -> 303 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 301, 303 },
      -1,
   } },

   /* replace2119_0 -> 305 in the cache */
   /* replace2119_1_0 -> 300 in the cache */
   /* replace2119_1_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 300, 302 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 305, 309 },
      -1,
   } },

   /* ('bcsel', ('feq', ('fsqrt', 'a(is_not_negative)'), 0.0), 3.4028234663852886e+38, ('frsq', 'a')) => ('fmin', ('frsq', 'a'), 3.4028234663852886e+38) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 311 },
      -1,
   } },
   /* search2120_0_1 -> 43 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 312, 43 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x47efffffe0000000 /* 3.4028234663852886e+38 */ },
   } },
   /* search2120_2_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 313, 314, 315 },
      -1,
   } },

   /* replace2120_0_0 -> 42 in the cache */
   /* replace2120_0 -> 315 in the cache */
   /* replace2120_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 315, 314 },
      -1,
   } },

   /* ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', ('ffma', 'e', 'f', 'g'))) */
   { .variable = {
      { nir_search_value_variable, -7 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      4, /* e */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      5, /* f */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 322, 323 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 2,
      { 320, 321, 324 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 3,
      { 318, 319, 325 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      6, /* g */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 326, 327 },
      -1,
   } },

   /* replace2121_0 -> 318 in the cache */
   /* replace2121_1 -> 319 in the cache */
   /* replace2121_2_0 -> 320 in the cache */
   /* replace2121_2_1 -> 321 in the cache */
   { .variable = {
      { nir_search_value_variable, -7 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      5, /* f */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      6, /* g */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 329, 330, 331 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 320, 321, 332 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 318, 319, 333 },
      -1,
   } },

   /* ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('fmul(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', 'e')) */
   { .variable = {
      { nir_search_value_variable, -5 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 337, 338 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 335, 336, 339 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 340, 341 },
      -1,
   } },

   /* replace2122_0 -> 335 in the cache */
   /* replace2122_1 -> 336 in the cache */
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 343, 344, 345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 335, 336, 346 },
      -1,
   } },

   /* ('~fadd', ('fneg', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffma', ('fneg', 'a'), 'b', ('ffma', ('fneg', 'c'), 'd', ('ffma', ('fneg', 'e'), 'f', 'g'))) */
   /* search2123_0_0_0 -> 318 in the cache */
   /* search2123_0_0_1 -> 319 in the cache */
   /* search2123_0_0_2_0 -> 320 in the cache */
   /* search2123_0_0_2_1 -> 321 in the cache */
   /* search2123_0_0_2_2_0 -> 322 in the cache */
   /* search2123_0_0_2_2_1 -> 323 in the cache */
   /* search2123_0_0_2_2 -> 324 in the cache */
   /* search2123_0_0_2 -> 325 in the cache */
   /* search2123_0_0 -> 326 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 326 },
      -1,
   } },
   /* search2123_1 -> 327 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 348, 327 },
      -1,
   } },

   /* replace2123_0_0 -> 318 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 318 },
      -1,
   } },
   /* replace2123_1 -> 319 in the cache */
   /* replace2123_2_0_0 -> 320 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 320 },
      -1,
   } },
   /* replace2123_2_1 -> 321 in the cache */
   /* replace2123_2_2_0_0 -> 329 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 329 },
      -1,
   } },
   /* replace2123_2_2_1 -> 330 in the cache */
   /* replace2123_2_2_2 -> 331 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 352, 330, 331 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 351, 321, 353 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 350, 319, 354 },
      -1,
   } },

   /* ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', ('ffmaz', 'e', 'f', 'g'))) */
   /* search2124_0_0 -> 81 in the cache */
   /* search2124_0_1 -> 82 in the cache */
   /* search2124_0_2_0 -> 84 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      5, /* f */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      3, 1,
      { 357, 358 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 2,
      { 84, 356, 359 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 3,
      { 81, 82, 360 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      6, /* g */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 361, 362 },
      -1,
   } },

   /* replace2124_0 -> 81 in the cache */
   /* replace2124_1 -> 82 in the cache */
   /* replace2124_2_0 -> 84 in the cache */
   /* replace2124_2_1 -> 356 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      5, /* f */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      6, /* g */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 364, 365, 366 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 84, 356, 367 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 81, 82, 368 },
      -1,
   } },

   /* ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('fmulz(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', 'e')) */
   /* search2125_0_0 -> 81 in the cache */
   /* search2125_0_1 -> 82 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 370, 371 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 81, 82, 372 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 373, 374 },
      -1,
   } },

   /* replace2125_0 -> 81 in the cache */
   /* replace2125_1 -> 82 in the cache */
   /* replace2125_2_0 -> 84 in the cache */
   /* replace2125_2_1 -> 356 in the cache */
   /* replace2125_2_2 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 84, 356, 364 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 81, 82, 376 },
      -1,
   } },

   /* ('~fadd', ('fneg', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffmaz', ('fneg', 'a'), 'b', ('ffmaz', ('fneg', 'c'), 'd', ('ffmaz', ('fneg', 'e'), 'f', 'g'))) */
   /* search2126_0_0_0 -> 81 in the cache */
   /* search2126_0_0_1 -> 82 in the cache */
   /* search2126_0_0_2_0 -> 84 in the cache */
   /* search2126_0_0_2_1 -> 356 in the cache */
   /* search2126_0_0_2_2_0 -> 357 in the cache */
   /* search2126_0_0_2_2_1 -> 358 in the cache */
   /* search2126_0_0_2_2 -> 359 in the cache */
   /* search2126_0_0_2 -> 360 in the cache */
   /* search2126_0_0 -> 361 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 361 },
      -1,
   } },
   /* search2126_1 -> 362 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 378, 362 },
      -1,
   } },

   /* replace2126_0_0 -> 81 in the cache */
   /* replace2126_0 -> 89 in the cache */
   /* replace2126_1 -> 82 in the cache */
   /* replace2126_2_0_0 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 84 },
      -1,
   } },
   /* replace2126_2_1 -> 356 in the cache */
   /* replace2126_2_2_0_0 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 364 },
      -1,
   } },
   /* replace2126_2_2_1 -> 365 in the cache */
   /* replace2126_2_2_2 -> 366 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 381, 365, 366 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 380, 356, 382 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 89, 82, 383 },
      -1,
   } },

   /* ('ubfe', 'a', 'b', 0) => 0 */
   /* search2127_0 -> 81 in the cache */
   /* search2127_1 -> 82 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 81, 82, 385 },
      -1,
   } },

   /* replace2127 -> 385 in the cache */

   /* ('ibfe', 'a', 'b', 0) => 0 */
   /* search2128_0 -> 81 in the cache */
   /* search2128_1 -> 82 in the cache */
   /* search2128_2 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 81, 82, 385 },
      -1,
   } },

   /* replace2128 -> 385 in the cache */

   /* ('ubfe', 'a', '#b', '#c') => ('iand', ('ushr', 4294967295, ('ineg', 'c')), ('ushr', 'a', 'b')) */
   /* search2129_0 -> 81 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 81, 388, 389 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   /* replace2129_0_1_0 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 84 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 391, 392 },
      -1,
   } },
   /* replace2129_1_0 -> 81 in the cache */
   /* replace2129_1_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 81, 82 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 393, 394 },
      -1,
   } },

   /* ('ibfe', 'a', '#b', '#c') => ('ishr', ('ishl', 'a', ('ineg', ('iadd', 'b', 'c'))), ('ineg', 'c')) */
   /* search2130_0 -> 81 in the cache */
   /* search2130_1 -> 388 in the cache */
   /* search2130_2 -> 389 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 81, 388, 389 },
      -1,
   } },

   /* replace2130_0_0 -> 81 in the cache */
   /* replace2130_0_1_0_0 -> 82 in the cache */
   /* replace2130_0_1_0_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 82, 84 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 397 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 81, 398 },
      -1,
   } },
   /* replace2130_1_0 -> 84 in the cache */
   /* replace2130_1 -> 392 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 399, 392 },
      -1,
   } },

   /* ('ishl', 'a', 0) => a */
   /* search2131_0 -> 42 in the cache */
   /* search2131_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 42, 385 },
      -1,
   } },

   /* replace2131 -> 42 in the cache */

   /* ('ishl', 'a', -32) => a */
   /* search2132_0 -> 42 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x20 /* -32 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 42, 402 },
      -1,
   } },

   /* replace2132 -> 42 in the cache */

   /* ('ishr', 'a', 0) => a */
   /* search2133_0 -> 42 in the cache */
   /* search2133_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 42, 385 },
      -1,
   } },

   /* replace2133 -> 42 in the cache */

   /* ('ishr', 'a', -32) => a */
   /* search2134_0 -> 42 in the cache */
   /* search2134_1 -> 402 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 42, 402 },
      -1,
   } },

   /* replace2134 -> 42 in the cache */

   /* ('ushr', 'a', 0) => a */
   /* search2135_0 -> 42 in the cache */
   /* search2135_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 42, 385 },
      -1,
   } },

   /* replace2135 -> 42 in the cache */

   /* ('extract_i8', ('extract_i8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b') */
   /* search2136_0_0 -> 0 in the cache */
   /* search2136_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 407, 408 },
      -1,
   } },

   /* replace2136_0 -> 0 in the cache */
   /* replace2136_1 -> 1 in the cache */
   /* replace2136 -> 407 in the cache */

   /* ('extract_i8', ('extract_u8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b') */
   /* search2137_0_0 -> 0 in the cache */
   /* search2137_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   /* search2137_1 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 410, 408 },
      -1,
   } },

   /* replace2137_0 -> 0 in the cache */
   /* replace2137_1 -> 1 in the cache */
   /* replace2137 -> 407 in the cache */

   /* ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search2138_0_0 -> 0 in the cache */
   /* search2138_0_1 -> 1 in the cache */
   /* search2138_0 -> 407 in the cache */
   /* search2138_1 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 407, 408 },
      -1,
   } },

   /* replace2138_0 -> 0 in the cache */
   /* replace2138_1 -> 1 in the cache */
   /* replace2138 -> 410 in the cache */

   /* ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search2139_0_0 -> 0 in the cache */
   /* search2139_0_1 -> 1 in the cache */
   /* search2139_0 -> 410 in the cache */
   /* search2139_1 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 410, 408 },
      -1,
   } },

   /* replace2139_0 -> 0 in the cache */
   /* replace2139_1 -> 1 in the cache */
   /* replace2139 -> 410 in the cache */

   /* ('u2u16', ('u2u8', 'a@16')) => ('extract_u8', 'a', 0) */
   /* search2140_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 61 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 414 },
      -1,
   } },

   /* replace2140_0 -> 61 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 61, 416 },
      -1,
   } },

   /* ('u2u16', ('i2i8', 'a@16')) => ('extract_u8', 'a', 0) */
   /* search2141_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 61 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 418 },
      -1,
   } },

   /* replace2141_0 -> 61 in the cache */
   /* replace2141_1 -> 416 in the cache */
   /* replace2141 -> 417 in the cache */

   /* ('i2i16', ('u2u8', 'a@16')) => ('extract_i8', 'a', 0) */
   /* search2142_0_0 -> 61 in the cache */
   /* search2142_0 -> 414 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 414 },
      -1,
   } },

   /* replace2142_0 -> 61 in the cache */
   /* replace2142_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 61, 416 },
      -1,
   } },

   /* ('i2i16', ('i2i8', 'a@16')) => ('extract_i8', 'a', 0) */
   /* search2143_0_0 -> 61 in the cache */
   /* search2143_0 -> 418 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 418 },
      -1,
   } },

   /* replace2143_0 -> 61 in the cache */
   /* replace2143_1 -> 416 in the cache */
   /* replace2143 -> 421 in the cache */

   /* ('u2u32', ('u2u8', 'a@32')) => ('extract_u8', 'a', 0) */
   /* search2144_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 423 },
      -1,
   } },

   /* replace2144_0 -> 81 in the cache */
   /* replace2144_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 81, 385 },
      -1,
   } },

   /* ('u2u32', ('i2i8', 'a@32')) => ('extract_u8', 'a', 0) */
   /* search2145_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 426 },
      -1,
   } },

   /* replace2145_0 -> 81 in the cache */
   /* replace2145_1 -> 385 in the cache */
   /* replace2145 -> 425 in the cache */

   /* ('u2u32', ('u2u16', 'a@32')) => ('extract_u16', 'a', 0) */
   /* search2146_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 428 },
      -1,
   } },

   /* replace2146_0 -> 81 in the cache */
   /* replace2146_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 81, 385 },
      -1,
   } },

   /* ('u2u32', ('i2i16', 'a@32')) => ('extract_u16', 'a', 0) */
   /* search2147_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 431 },
      -1,
   } },

   /* replace2147_0 -> 81 in the cache */
   /* replace2147_1 -> 385 in the cache */
   /* replace2147 -> 430 in the cache */

   /* ('i2i32', ('u2u8', 'a@32')) => ('extract_i8', 'a', 0) */
   /* search2148_0_0 -> 81 in the cache */
   /* search2148_0 -> 423 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 423 },
      -1,
   } },

   /* replace2148_0 -> 81 in the cache */
   /* replace2148_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 81, 385 },
      -1,
   } },

   /* ('i2i32', ('i2i8', 'a@32')) => ('extract_i8', 'a', 0) */
   /* search2149_0_0 -> 81 in the cache */
   /* search2149_0 -> 426 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 426 },
      -1,
   } },

   /* replace2149_0 -> 81 in the cache */
   /* replace2149_1 -> 385 in the cache */
   /* replace2149 -> 434 in the cache */

   /* ('i2i32', ('u2u16', 'a@32')) => ('extract_i16', 'a', 0) */
   /* search2150_0_0 -> 81 in the cache */
   /* search2150_0 -> 428 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 428 },
      -1,
   } },

   /* replace2150_0 -> 81 in the cache */
   /* replace2150_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 81, 385 },
      -1,
   } },

   /* ('i2i32', ('i2i16', 'a@32')) => ('extract_i16', 'a', 0) */
   /* search2151_0_0 -> 81 in the cache */
   /* search2151_0 -> 431 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 431 },
      -1,
   } },

   /* replace2151_0 -> 81 in the cache */
   /* replace2151_1 -> 385 in the cache */
   /* replace2151 -> 437 in the cache */

   /* ('ishl', ('extract_u8', 'a@32', 0), 8) => ('insert_u8', 'a', 1) */
   /* search2152_0_0 -> 81 in the cache */
   /* search2152_0_1 -> 385 in the cache */
   /* search2152_0 -> 425 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x8 /* 8 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 425, 439 },
      -1,
   } },

   /* replace2152_0 -> 81 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 81, 441 },
      -1,
   } },

   /* ('ishl', ('extract_u8', 'a@32', 0), 16) => ('insert_u8', 'a', 2) */
   /* search2153_0_0 -> 81 in the cache */
   /* search2153_0_1 -> 385 in the cache */
   /* search2153_0 -> 425 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x10 /* 16 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 425, 443 },
      -1,
   } },

   /* replace2153_0 -> 81 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 81, 445 },
      -1,
   } },

   /* ('ishl', ('extract_u8', 'a@32', 0), 24) => ('insert_u8', 'a', 3) */
   /* search2154_0_0 -> 81 in the cache */
   /* search2154_0_1 -> 385 in the cache */
   /* search2154_0 -> 425 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x18 /* 24 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 425, 447 },
      -1,
   } },

   /* replace2154_0 -> 81 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 81, 449 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 8), 65280) => ('insert_u8', 'a', 1) */
   /* search2155_0_0 -> 81 in the cache */
   /* search2155_0_1 -> 439 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 81, 439 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00 /* 65280 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 451, 452 },
      -1,
   } },

   /* replace2155_0 -> 81 in the cache */
   /* replace2155_1 -> 441 in the cache */
   /* replace2155 -> 442 in the cache */

   /* ('iand', ('ishl', 'a@32', 16), 16711680) => ('insert_u8', 'a', 2) */
   /* search2156_0_0 -> 81 in the cache */
   /* search2156_0_1 -> 443 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 81, 443 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff0000 /* 16711680 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 454, 455 },
      -1,
   } },

   /* replace2156_0 -> 81 in the cache */
   /* replace2156_1 -> 445 in the cache */
   /* replace2156 -> 446 in the cache */

   /* ('iand', ('ishl', 'a@32', 24), 4278190080) => ('insert_u8', 'a', 3) */
   /* search2157_0_0 -> 81 in the cache */
   /* search2157_0_1 -> 447 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 81, 447 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff000000 /* 4278190080 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 457, 458 },
      -1,
   } },

   /* replace2157_0 -> 81 in the cache */
   /* replace2157_1 -> 449 in the cache */
   /* replace2157 -> 450 in the cache */

   /* ('ishl', 'a@32', 24) => ('insert_u8', 'a', 3) */
   /* search2158_0 -> 81 in the cache */
   /* search2158_1 -> 447 in the cache */
   /* search2158 -> 457 in the cache */

   /* replace2158_0 -> 81 in the cache */
   /* replace2158_1 -> 449 in the cache */
   /* replace2158 -> 450 in the cache */

   /* ('ishl', 'a@32', 16) => ('insert_u16', 'a', 1) */
   /* search2159_0 -> 81 in the cache */
   /* search2159_1 -> 443 in the cache */
   /* search2159 -> 454 in the cache */

   /* replace2159_0 -> 81 in the cache */
   /* replace2159_1 -> 441 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 81, 441 },
      -1,
   } },

   /* ('insert_u8', ('extract_u8', 'a', 0), 'b') => ('insert_u8', 'a', 'b') */
   /* search2160_0_0 -> 0 in the cache */
   /* search2160_0_1 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 408 },
      -1,
   } },
   /* search2160_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 461, 1 },
      -1,
   } },

   /* replace2160_0 -> 0 in the cache */
   /* replace2160_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('insert_u16', ('extract_u16', 'a', 0), 'b') => ('insert_u16', 'a', 'b') */
   /* search2161_0_0 -> 0 in the cache */
   /* search2161_0_1 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 408 },
      -1,
   } },
   /* search2161_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 464, 1 },
      -1,
   } },

   /* replace2161_0 -> 0 in the cache */
   /* replace2161_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2162_0_0 -> 134 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 134, 467 },
      0,
   } },
   /* search2162_1_0 -> 135 in the cache */
   /* search2162_1_1 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 135, 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 468, 469 },
      -1,
   } },

   /* replace2162_0_0 -> 134 in the cache */
   /* replace2162_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 134, 135 },
      -1,
   } },
   /* replace2162_1 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 471, 467 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2163_0_0 -> 134 in the cache */
   /* search2163_0_1 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 134, 467 },
      0,
   } },
   /* search2163_1_0 -> 135 in the cache */
   /* search2163_1_1 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 135, 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 473, 474 },
      -1,
   } },

   /* replace2163_0_0 -> 134 in the cache */
   /* replace2163_0_1 -> 135 in the cache */
   /* replace2163_0 -> 471 in the cache */
   /* replace2163_1 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 471, 467 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2164_0_0 -> 61 in the cache */
   /* search2164_0_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 61, 416 },
      0,
   } },
   /* search2164_1_0 -> 62 in the cache */
   /* search2164_1_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 62, 416 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 477, 478 },
      -1,
   } },

   /* replace2164_0_0 -> 61 in the cache */
   /* replace2164_0_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 61, 62 },
      -1,
   } },
   /* replace2164_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 480, 416 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2165_0_0 -> 61 in the cache */
   /* search2165_0_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 61, 416 },
      0,
   } },
   /* search2165_1_0 -> 62 in the cache */
   /* search2165_1_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 62, 416 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 482, 483 },
      -1,
   } },

   /* replace2165_0_0 -> 61 in the cache */
   /* replace2165_0_1 -> 62 in the cache */
   /* replace2165_0 -> 480 in the cache */
   /* replace2165_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 480, 416 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2166_0_0 -> 81 in the cache */
   /* search2166_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 81, 385 },
      0,
   } },
   /* search2166_1_0 -> 82 in the cache */
   /* search2166_1_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 82, 385 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 486, 487 },
      -1,
   } },

   /* replace2166_0_0 -> 81 in the cache */
   /* replace2166_0_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 81, 82 },
      -1,
   } },
   /* replace2166_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 489, 385 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2167_0_0 -> 81 in the cache */
   /* search2167_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 81, 385 },
      0,
   } },
   /* search2167_1_0 -> 82 in the cache */
   /* search2167_1_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 82, 385 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 491, 492 },
      -1,
   } },

   /* replace2167_0_0 -> 81 in the cache */
   /* replace2167_0_1 -> 82 in the cache */
   /* replace2167_0 -> 489 in the cache */
   /* replace2167_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 489, 385 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2168_0_0 -> 114 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 114, 495 },
      0,
   } },
   /* search2168_1_0 -> 115 in the cache */
   /* search2168_1_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 115, 495 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 496, 497 },
      -1,
   } },

   /* replace2168_0_0 -> 114 in the cache */
   /* replace2168_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 114, 115 },
      -1,
   } },
   /* replace2168_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 499, 495 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2169_0_0 -> 114 in the cache */
   /* search2169_0_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 114, 495 },
      0,
   } },
   /* search2169_1_0 -> 115 in the cache */
   /* search2169_1_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 115, 495 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 501, 502 },
      -1,
   } },

   /* replace2169_0_0 -> 114 in the cache */
   /* replace2169_0_1 -> 115 in the cache */
   /* replace2169_0 -> 499 in the cache */
   /* replace2169_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 499, 495 },
      -1,
   } },

   /* ('~fadd@16', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   /* search2170_0 -> 177 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2170_1_1_0 -> 62 in the cache */
   /* search2170_1_1_1 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 62, 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 505, 506 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 177, 507 },
      -1,
   } },

   /* replace2170_0_0 -> 177 in the cache */
   /* replace2170_0_1_0 -> 505 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 505 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 177, 509 },
      -1,
   } },
   /* replace2170_1_0 -> 62 in the cache */
   /* replace2170_1_1 -> 505 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 62, 505 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 510, 511 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f16', ('inot', 'b@bool'))) => ('b2f16', ('inot', ('ior', 'a', 'b'))) */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2171_1 -> 416 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 514 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 416, 516 },
      -1,
   } },

   /* replace2171_0_0_0 -> 513 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 513, 518 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 519 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 1,
      { 520 },
      -1,
   } },

   /* ('~fadd@32', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   /* search2172_0 -> 268 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2172_1_1_0 -> 82 in the cache */
   /* search2172_1_1_1 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 82, 266 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 522, 523 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 268, 524 },
      -1,
   } },

   /* replace2172_0_0 -> 268 in the cache */
   /* replace2172_0_1_0 -> 522 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 522 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 268, 526 },
      -1,
   } },
   /* replace2172_1_0 -> 82 in the cache */
   /* replace2172_1_1 -> 522 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 82, 522 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 527, 528 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f32', ('inot', 'b@bool'))) => ('b2f32', ('inot', ('ior', 'a', 'b'))) */
   /* search2173_0 -> 513 in the cache */
   /* search2173_1 -> 385 in the cache */
   /* search2173_2_0_0 -> 514 in the cache */
   /* search2173_2_0 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 385, 530 },
      -1,
   } },

   /* replace2173_0_0_0 -> 513 in the cache */
   /* replace2173_0_0_1 -> 518 in the cache */
   /* replace2173_0_0 -> 519 in the cache */
   /* replace2173_0 -> 520 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 1,
      { 520 },
      -1,
   } },

   /* ('~fadd@64', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2174_1_1_0 -> 115 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 115, 535 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 534, 536 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 533, 537 },
      -1,
   } },

   /* replace2174_0_0 -> 533 in the cache */
   /* replace2174_0_1_0 -> 534 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 533, 539 },
      -1,
   } },
   /* replace2174_1_0 -> 115 in the cache */
   /* replace2174_1_1 -> 534 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 115, 534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 540, 541 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f64', ('inot', 'b@bool'))) => ('b2f64', ('inot', ('ior', 'a', 'b'))) */
   /* search2175_0 -> 513 in the cache */
   /* search2175_1 -> 495 in the cache */
   /* search2175_2_0_0 -> 514 in the cache */
   /* search2175_2_0 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 495, 543 },
      -1,
   } },

   /* replace2175_0_0_0 -> 513 in the cache */
   /* replace2175_0_0_1 -> 518 in the cache */
   /* replace2175_0_0 -> 519 in the cache */
   /* replace2175_0 -> 520 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 1,
      { 520 },
      -1,
   } },

   /* ('bcsel', 'a', ('fadd(is_used_once)', 'b', 'c'), ('fadd', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2176_0 -> 513 in the cache */
   /* search2176_1_0 -> 202 in the cache */
   /* search2176_1_1 -> 204 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 202, 204 },
      0,
   } },
   /* search2176_2_0 -> 202 in the cache */
   /* search2176_2_1 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 202, 205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 546, 547 },
      -1,
   } },

   /* replace2176_0 -> 202 in the cache */
   /* replace2176_1_0 -> 513 in the cache */
   /* replace2176_1_1 -> 204 in the cache */
   /* replace2176_1_2 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 204, 205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 202, 549 },
      -1,
   } },

   /* ('bcsel', 'a', ('fadd', 'b', 'c'), ('fadd(is_used_once)', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2177_0 -> 513 in the cache */
   /* search2177_1_0 -> 202 in the cache */
   /* search2177_1_1 -> 204 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 202, 204 },
      -1,
   } },
   /* search2177_2_0 -> 202 in the cache */
   /* search2177_2_1 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 202, 205 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 551, 552 },
      -1,
   } },

   /* replace2177_0 -> 202 in the cache */
   /* replace2177_1_0 -> 513 in the cache */
   /* replace2177_1_1 -> 204 in the cache */
   /* replace2177_1_2 -> 205 in the cache */
   /* replace2177_1 -> 549 in the cache */
   /* replace2177 -> 550 in the cache */

   /* ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2178_0 -> 513 in the cache */
   /* search2178_1_0 -> 336 in the cache */
   /* search2178_1_1 -> 343 in the cache */
   /* search2178_1_2 -> 344 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 336, 343, 344 },
      0,
   } },
   /* search2178_2_0 -> 336 in the cache */
   /* search2178_2_1 -> 343 in the cache */
   /* search2178_2_2 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 336, 343, 345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 554, 555 },
      -1,
   } },

   /* replace2178_0 -> 336 in the cache */
   /* replace2178_1 -> 343 in the cache */
   /* replace2178_2_0 -> 513 in the cache */
   /* replace2178_2_1 -> 344 in the cache */
   /* replace2178_2_2 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 344, 345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 336, 343, 557 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2179_0 -> 513 in the cache */
   /* search2179_1_0 -> 336 in the cache */
   /* search2179_1_1 -> 343 in the cache */
   /* search2179_1_2 -> 344 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 336, 343, 344 },
      -1,
   } },
   /* search2179_2_0 -> 336 in the cache */
   /* search2179_2_1 -> 343 in the cache */
   /* search2179_2_2 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 336, 343, 345 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 559, 560 },
      -1,
   } },

   /* replace2179_0 -> 336 in the cache */
   /* replace2179_1 -> 343 in the cache */
   /* replace2179_2_0 -> 513 in the cache */
   /* replace2179_2_1 -> 344 in the cache */
   /* replace2179_2_2 -> 345 in the cache */
   /* replace2179_2 -> 557 in the cache */
   /* replace2179 -> 558 in the cache */

   /* ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2180_0 -> 513 in the cache */
   /* search2180_1_0 -> 336 in the cache */
   /* search2180_1_1 -> 343 in the cache */
   /* search2180_1_2 -> 344 in the cache */
   /* search2180_1 -> 554 in the cache */
   /* search2180_2_0 -> 336 in the cache */
   /* search2180_2_1 -> 345 in the cache */
   /* search2180_2_2 -> 344 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 336, 345, 344 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 554, 562 },
      -1,
   } },

   /* replace2180_0 -> 336 in the cache */
   /* replace2180_1_0 -> 513 in the cache */
   /* replace2180_1_1 -> 343 in the cache */
   /* replace2180_1_2 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 343, 345 },
      -1,
   } },
   /* replace2180_2 -> 344 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 336, 564, 344 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2181_0 -> 513 in the cache */
   /* search2181_1_0 -> 336 in the cache */
   /* search2181_1_1 -> 343 in the cache */
   /* search2181_1_2 -> 344 in the cache */
   /* search2181_1 -> 559 in the cache */
   /* search2181_2_0 -> 336 in the cache */
   /* search2181_2_1 -> 345 in the cache */
   /* search2181_2_2 -> 344 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 336, 345, 344 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 559, 566 },
      -1,
   } },

   /* replace2181_0 -> 336 in the cache */
   /* replace2181_1_0 -> 513 in the cache */
   /* replace2181_1_1 -> 343 in the cache */
   /* replace2181_1_2 -> 345 in the cache */
   /* replace2181_1 -> 564 in the cache */
   /* replace2181_2 -> 344 in the cache */
   /* replace2181 -> 565 in the cache */

   /* ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2182_0 -> 513 in the cache */
   /* search2182_1_0 -> 82 in the cache */
   /* search2182_1_1 -> 84 in the cache */
   /* search2182_1_2 -> 356 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 82, 84, 356 },
      0,
   } },
   /* search2182_2_0 -> 82 in the cache */
   /* search2182_2_1 -> 84 in the cache */
   /* search2182_2_2 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 82, 84, 364 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 568, 569 },
      -1,
   } },

   /* replace2182_0 -> 82 in the cache */
   /* replace2182_1 -> 84 in the cache */
   /* replace2182_2_0 -> 513 in the cache */
   /* replace2182_2_1 -> 356 in the cache */
   /* replace2182_2_2 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 356, 364 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 82, 84, 571 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2183_0 -> 513 in the cache */
   /* search2183_1_0 -> 82 in the cache */
   /* search2183_1_1 -> 84 in the cache */
   /* search2183_1_2 -> 356 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 82, 84, 356 },
      -1,
   } },
   /* search2183_2_0 -> 82 in the cache */
   /* search2183_2_1 -> 84 in the cache */
   /* search2183_2_2 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 82, 84, 364 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 573, 574 },
      -1,
   } },

   /* replace2183_0 -> 82 in the cache */
   /* replace2183_1 -> 84 in the cache */
   /* replace2183_2_0 -> 513 in the cache */
   /* replace2183_2_1 -> 356 in the cache */
   /* replace2183_2_2 -> 364 in the cache */
   /* replace2183_2 -> 571 in the cache */
   /* replace2183 -> 572 in the cache */

   /* ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2184_0 -> 513 in the cache */
   /* search2184_1_0 -> 82 in the cache */
   /* search2184_1_1 -> 84 in the cache */
   /* search2184_1_2 -> 356 in the cache */
   /* search2184_1 -> 568 in the cache */
   /* search2184_2_0 -> 82 in the cache */
   /* search2184_2_1 -> 364 in the cache */
   /* search2184_2_2 -> 356 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 82, 364, 356 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 568, 576 },
      -1,
   } },

   /* replace2184_0 -> 82 in the cache */
   /* replace2184_1_0 -> 513 in the cache */
   /* replace2184_1_1 -> 84 in the cache */
   /* replace2184_1_2 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 84, 364 },
      -1,
   } },
   /* replace2184_2 -> 356 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 82, 578, 356 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2185_0 -> 513 in the cache */
   /* search2185_1_0 -> 82 in the cache */
   /* search2185_1_1 -> 84 in the cache */
   /* search2185_1_2 -> 356 in the cache */
   /* search2185_1 -> 573 in the cache */
   /* search2185_2_0 -> 82 in the cache */
   /* search2185_2_1 -> 364 in the cache */
   /* search2185_2_2 -> 356 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 82, 364, 356 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 573, 580 },
      -1,
   } },

   /* replace2185_0 -> 82 in the cache */
   /* replace2185_1_0 -> 513 in the cache */
   /* replace2185_1_1 -> 84 in the cache */
   /* replace2185_1_2 -> 364 in the cache */
   /* replace2185_1 -> 578 in the cache */
   /* replace2185_2 -> 356 in the cache */
   /* replace2185 -> 579 in the cache */

   /* ('~f2f32', ('fabs', ('f2fmp', 'a'))) => ('fabs', 'a') */
   /* search2186_0_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 583 },
      -1,
   } },

   /* replace2186_0 -> 81 in the cache */
   /* replace2186 -> 93 in the cache */

   /* ('~f2f32', ('fceil', ('f2fmp', 'a'))) => ('fceil', 'a') */
   /* search2187_0_0_0 -> 81 in the cache */
   /* search2187_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 585 },
      -1,
   } },

   /* replace2187_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fcos', ('f2fmp', 'a'))) => ('fcos', 'a') */
   /* search2188_0_0_0 -> 81 in the cache */
   /* search2188_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 588 },
      -1,
   } },

   /* replace2188_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fddx', ('f2fmp', 'a'))) => ('fddx', 'a') */
   /* search2189_0_0_0 -> 81 in the cache */
   /* search2189_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 591 },
      -1,
   } },

   /* replace2189_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fddx_coarse', ('f2fmp', 'a'))) => ('fddx_coarse', 'a') */
   /* search2190_0_0_0 -> 81 in the cache */
   /* search2190_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 594 },
      -1,
   } },

   /* replace2190_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fddx_fine', ('f2fmp', 'a'))) => ('fddx_fine', 'a') */
   /* search2191_0_0_0 -> 81 in the cache */
   /* search2191_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 597 },
      -1,
   } },

   /* replace2191_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fddy', ('f2fmp', 'a'))) => ('fddy', 'a') */
   /* search2192_0_0_0 -> 81 in the cache */
   /* search2192_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 600 },
      -1,
   } },

   /* replace2192_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fddy_coarse', ('f2fmp', 'a'))) => ('fddy_coarse', 'a') */
   /* search2193_0_0_0 -> 81 in the cache */
   /* search2193_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 603 },
      -1,
   } },

   /* replace2193_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fddy_fine', ('f2fmp', 'a'))) => ('fddy_fine', 'a') */
   /* search2194_0_0_0 -> 81 in the cache */
   /* search2194_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 606 },
      -1,
   } },

   /* replace2194_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fexp2', ('f2fmp', 'a'))) => ('fexp2', 'a') */
   /* search2195_0_0_0 -> 81 in the cache */
   /* search2195_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 609 },
      -1,
   } },

   /* replace2195_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('ffloor', ('f2fmp', 'a'))) => ('ffloor', 'a') */
   /* search2196_0_0_0 -> 81 in the cache */
   /* search2196_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 612 },
      -1,
   } },

   /* replace2196_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('ffract', ('f2fmp', 'a'))) => ('ffract', 'a') */
   /* search2197_0_0_0 -> 81 in the cache */
   /* search2197_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 615 },
      -1,
   } },

   /* replace2197_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('flog2', ('f2fmp', 'a'))) => ('flog2', 'a') */
   /* search2198_0_0_0 -> 81 in the cache */
   /* search2198_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 618 },
      -1,
   } },

   /* replace2198_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fneg', ('f2fmp', 'a'))) => ('fneg', 'a') */
   /* search2199_0_0_0 -> 81 in the cache */
   /* search2199_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 621 },
      -1,
   } },

   /* replace2199_0 -> 81 in the cache */
   /* replace2199 -> 89 in the cache */

   /* ('~f2f32', ('frcp', ('f2fmp', 'a'))) => ('frcp', 'a') */
   /* search2200_0_0_0 -> 81 in the cache */
   /* search2200_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 623 },
      -1,
   } },

   /* replace2200_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fround_even', ('f2fmp', 'a'))) => ('fround_even', 'a') */
   /* search2201_0_0_0 -> 81 in the cache */
   /* search2201_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 626 },
      -1,
   } },

   /* replace2201_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('frsq', ('f2fmp', 'a'))) => ('frsq', 'a') */
   /* search2202_0_0_0 -> 81 in the cache */
   /* search2202_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 629 },
      -1,
   } },

   /* replace2202_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fsat', ('f2fmp', 'a'))) => ('fsat', 'a') */
   /* search2203_0_0_0 -> 81 in the cache */
   /* search2203_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 632 },
      -1,
   } },

   /* replace2203_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fsign', ('f2fmp', 'a'))) => ('fsign', 'a') */
   /* search2204_0_0_0 -> 81 in the cache */
   /* search2204_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 635 },
      -1,
   } },

   /* replace2204_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fsin', ('f2fmp', 'a'))) => ('fsin', 'a') */
   /* search2205_0_0_0 -> 81 in the cache */
   /* search2205_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 638 },
      -1,
   } },

   /* replace2205_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fsqrt', ('f2fmp', 'a'))) => ('fsqrt', 'a') */
   /* search2206_0_0_0 -> 81 in the cache */
   /* search2206_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 641 },
      -1,
   } },

   /* replace2206_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fadd', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fadd', 'a', 'b') */
   /* search2207_0_0_0 -> 81 in the cache */
   /* search2207_0_0 -> 582 in the cache */
   /* search2207_0_1_0 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 82 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 645 },
      -1,
   } },

   /* replace2207_0 -> 81 in the cache */
   /* replace2207_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('fdiv', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fdiv', 'a', 'b') */
   /* search2208_0_0_0 -> 81 in the cache */
   /* search2208_0_0 -> 582 in the cache */
   /* search2208_0_1_0 -> 82 in the cache */
   /* search2208_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 648 },
      -1,
   } },

   /* replace2208_0 -> 81 in the cache */
   /* replace2208_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('fmax', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmax', 'a', 'b') */
   /* search2209_0_0_0 -> 81 in the cache */
   /* search2209_0_0 -> 582 in the cache */
   /* search2209_0_1_0 -> 82 in the cache */
   /* search2209_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 651 },
      -1,
   } },

   /* replace2209_0 -> 81 in the cache */
   /* replace2209_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('fmin', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmin', 'a', 'b') */
   /* search2210_0_0_0 -> 81 in the cache */
   /* search2210_0_0 -> 582 in the cache */
   /* search2210_0_1_0 -> 82 in the cache */
   /* search2210_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 654 },
      -1,
   } },

   /* replace2210_0 -> 81 in the cache */
   /* replace2210_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('fmod', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmod', 'a', 'b') */
   /* search2211_0_0_0 -> 81 in the cache */
   /* search2211_0_0 -> 582 in the cache */
   /* search2211_0_1_0 -> 82 in the cache */
   /* search2211_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 657 },
      -1,
   } },

   /* replace2211_0 -> 81 in the cache */
   /* replace2211_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('fmul', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmul', 'a', 'b') */
   /* search2212_0_0_0 -> 81 in the cache */
   /* search2212_0_0 -> 582 in the cache */
   /* search2212_0_1_0 -> 82 in the cache */
   /* search2212_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 660 },
      -1,
   } },

   /* replace2212_0 -> 81 in the cache */
   /* replace2212_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('fpow', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fpow', 'a', 'b') */
   /* search2213_0_0_0 -> 81 in the cache */
   /* search2213_0_0 -> 582 in the cache */
   /* search2213_0_1_0 -> 82 in the cache */
   /* search2213_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 663 },
      -1,
   } },

   /* replace2213_0 -> 81 in the cache */
   /* replace2213_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('frem', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('frem', 'a', 'b') */
   /* search2214_0_0_0 -> 81 in the cache */
   /* search2214_0_0 -> 582 in the cache */
   /* search2214_0_1_0 -> 82 in the cache */
   /* search2214_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 666 },
      -1,
   } },

   /* replace2214_0 -> 81 in the cache */
   /* replace2214_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('ffma', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('ffma', 'a', 'b', 'c') */
   /* search2215_0_0_0 -> 81 in the cache */
   /* search2215_0_0 -> 582 in the cache */
   /* search2215_0_1_0 -> 82 in the cache */
   /* search2215_0_1 -> 644 in the cache */
   /* search2215_0_2_0 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 84 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 582, 644, 669 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 670 },
      -1,
   } },

   /* replace2215_0 -> 81 in the cache */
   /* replace2215_1 -> 82 in the cache */
   /* replace2215_2 -> 84 in the cache */
   /* replace2215 -> 86 in the cache */

   /* ('~f2f32', ('flrp', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('flrp', 'a', 'b', 'c') */
   /* search2216_0_0_0 -> 81 in the cache */
   /* search2216_0_0 -> 582 in the cache */
   /* search2216_0_1_0 -> 82 in the cache */
   /* search2216_0_1 -> 644 in the cache */
   /* search2216_0_2_0 -> 84 in the cache */
   /* search2216_0_2 -> 669 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 582, 644, 669 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 672 },
      -1,
   } },

   /* replace2216_0 -> 81 in the cache */
   /* replace2216_1 -> 82 in the cache */
   /* replace2216_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 81, 82, 84 },
      -1,
   } },

   /* ('~feq', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('feq', 'a', 'b') */
   /* search2217_0_0 -> 81 in the cache */
   /* search2217_0 -> 582 in the cache */
   /* search2217_1_0 -> 82 in the cache */
   /* search2217_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 582, 644 },
      -1,
   } },

   /* replace2217_0 -> 81 in the cache */
   /* replace2217_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 81, 82 },
      -1,
   } },

   /* ('~fge', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fge', 'a', 'b') */
   /* search2218_0_0 -> 81 in the cache */
   /* search2218_0 -> 582 in the cache */
   /* search2218_1_0 -> 82 in the cache */
   /* search2218_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 582, 644 },
      -1,
   } },

   /* replace2218_0 -> 81 in the cache */
   /* replace2218_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('~flt', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('flt', 'a', 'b') */
   /* search2219_0_0 -> 81 in the cache */
   /* search2219_0 -> 582 in the cache */
   /* search2219_1_0 -> 82 in the cache */
   /* search2219_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 582, 644 },
      -1,
   } },

   /* replace2219_0 -> 81 in the cache */
   /* replace2219_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('~fneu', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fneu', 'a', 'b') */
   /* search2220_0_0 -> 81 in the cache */
   /* search2220_0 -> 582 in the cache */
   /* search2220_1_0 -> 82 in the cache */
   /* search2220_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 582, 644 },
      -1,
   } },

   /* replace2220_0 -> 81 in the cache */
   /* replace2220_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 81, 82 },
      -1,
   } },

   /* ('f2fmp', 'a') => ('f2f16', 'a') */
   /* search2221_0 -> 81 in the cache */
   /* search2221 -> 582 in the cache */

   /* replace2221_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('f2imp', 'a') => ('f2i16', 'a') */
   /* search2222_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 81 },
      -1,
   } },

   /* replace2222_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('f2ump', 'a') => ('f2u16', 'a') */
   /* search2223_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 81 },
      -1,
   } },

   /* replace2223_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('i2imp', 'a') => ('i2i16', 'a') */
   /* search2224_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 81 },
      -1,
   } },

   /* replace2224_0 -> 81 in the cache */
   /* replace2224 -> 431 in the cache */

   /* ('i2fmp', 'a') => ('i2f16', 'a') */
   /* search2225_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 81 },
      -1,
   } },

   /* replace2225_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('i2imp', 'a') => ('u2u16', 'a') */
   /* search2226_0 -> 81 in the cache */
   /* search2226 -> 688 in the cache */

   /* replace2226_0 -> 81 in the cache */
   /* replace2226 -> 428 in the cache */

   /* ('u2fmp', 'a') => ('u2f16', 'a') */
   /* search2227_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 81 },
      -1,
   } },

   /* replace2227_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('fisfinite', 'a') => ('flt', ('fabs', 'a'), inf) */
   /* search2228_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fisfinite,
      -1, 0,
      { 42 },
      -1,
   } },

   /* replace2228_0_0 -> 42 in the cache */
   /* replace2228_0 -> 47 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x7ff0000000000000 /* inf */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 47, 694 },
      -1,
   } },

   /* ('fcsel', ('slt', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'b', 'c') */
   /* search2229_0_0 -> 385 in the cache */
   /* search2229_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 385, 81 },
      -1,
   } },
   /* search2229_1 -> 82 in the cache */
   /* search2229_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 696, 82, 84 },
      -1,
   } },

   /* replace2229_0 -> 81 in the cache */
   /* replace2229_1 -> 82 in the cache */
   /* replace2229_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_gt,
      -1, 0,
      { 81, 82, 84 },
      -1,
   } },

   /* ('fcsel', ('slt', 'a', 0), 'b', 'c') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c') */
   /* search2230_0_0 -> 81 in the cache */
   /* search2230_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 81, 385 },
      -1,
   } },
   /* search2230_1 -> 82 in the cache */
   /* search2230_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 699, 82, 84 },
      -1,
   } },

   /* replace2230_0_0 -> 81 in the cache */
   /* replace2230_0 -> 89 in the cache */
   /* replace2230_1 -> 82 in the cache */
   /* replace2230_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_gt,
      -1, 0,
      { 89, 82, 84 },
      -1,
   } },

   /* ('fcsel', ('sge', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'b', 'c') */
   /* search2231_0_0 -> 81 in the cache */
   /* search2231_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 81, 385 },
      -1,
   } },
   /* search2231_1 -> 82 in the cache */
   /* search2231_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 702, 82, 84 },
      -1,
   } },

   /* replace2231_0 -> 81 in the cache */
   /* replace2231_1 -> 82 in the cache */
   /* replace2231_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_ge,
      -1, 0,
      { 81, 82, 84 },
      -1,
   } },

   /* ('fcsel', ('sge', 0, 'a'), 'b', 'c') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c') */
   /* search2232_0_0 -> 385 in the cache */
   /* search2232_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 385, 81 },
      -1,
   } },
   /* search2232_1 -> 82 in the cache */
   /* search2232_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 705, 82, 84 },
      -1,
   } },

   /* replace2232_0_0 -> 81 in the cache */
   /* replace2232_0 -> 89 in the cache */
   /* replace2232_1 -> 82 in the cache */
   /* replace2232_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_ge,
      -1, 0,
      { 89, 82, 84 },
      -1,
   } },

   /* ('bcsel', ('ilt', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'b', 'c') */
   /* search2233_0_0 -> 385 in the cache */
   /* search2233_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 385, 81 },
      -1,
   } },
   /* search2233_1 -> 82 in the cache */
   /* search2233_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 708, 82, 84 },
      -1,
   } },

   /* replace2233_0 -> 81 in the cache */
   /* replace2233_1 -> 82 in the cache */
   /* replace2233_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_gt,
      -1, 0,
      { 81, 82, 84 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'c', 'b') */
   /* search2234_0_0 -> 81 in the cache */
   /* search2234_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 81, 385 },
      -1,
   } },
   /* search2234_1 -> 82 in the cache */
   /* search2234_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 711, 82, 84 },
      -1,
   } },

   /* replace2234_0 -> 81 in the cache */
   /* replace2234_1 -> 84 in the cache */
   /* replace2234_2 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_ge,
      -1, 0,
      { 81, 84, 82 },
      -1,
   } },

   /* ('bcsel', ('ige', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'b', 'c') */
   /* search2235_0_0 -> 81 in the cache */
   /* search2235_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 81, 385 },
      -1,
   } },
   /* search2235_1 -> 82 in the cache */
   /* search2235_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 714, 82, 84 },
      -1,
   } },

   /* replace2235_0 -> 81 in the cache */
   /* replace2235_1 -> 82 in the cache */
   /* replace2235_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_ge,
      -1, 0,
      { 81, 82, 84 },
      -1,
   } },

   /* ('bcsel', ('ige', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'c', 'b') */
   /* search2236_0_0 -> 385 in the cache */
   /* search2236_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 385, 81 },
      -1,
   } },
   /* search2236_1 -> 82 in the cache */
   /* search2236_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 717, 82, 84 },
      -1,
   } },

   /* replace2236_0 -> 81 in the cache */
   /* replace2236_1 -> 84 in the cache */
   /* replace2236_2 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_gt,
      -1, 0,
      { 81, 84, 82 },
      -1,
   } },

   /* ('bcsel', ('flt', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'b', 'c') */
   /* search2237_0_0 -> 385 in the cache */
   /* search2237_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 385, 81 },
      -1,
   } },
   /* search2237_1 -> 82 in the cache */
   /* search2237_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 720, 82, 84 },
      -1,
   } },

   /* replace2237_0 -> 81 in the cache */
   /* replace2237_1 -> 82 in the cache */
   /* replace2237_2 -> 84 in the cache */
   /* replace2237 -> 698 in the cache */

   /* ('bcsel', ('flt', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c') */
   /* search2238_0_0 -> 81 in the cache */
   /* search2238_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 81, 385 },
      -1,
   } },
   /* search2238_1 -> 82 in the cache */
   /* search2238_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 722, 82, 84 },
      -1,
   } },

   /* replace2238_0_0 -> 81 in the cache */
   /* replace2238_0 -> 89 in the cache */
   /* replace2238_1 -> 82 in the cache */
   /* replace2238_2 -> 84 in the cache */
   /* replace2238 -> 701 in the cache */

   /* ('bcsel', ('fge', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'b', 'c') */
   /* search2239_0_0 -> 81 in the cache */
   /* search2239_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 81, 385 },
      -1,
   } },
   /* search2239_1 -> 82 in the cache */
   /* search2239_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 724, 82, 84 },
      -1,
   } },

   /* replace2239_0 -> 81 in the cache */
   /* replace2239_1 -> 82 in the cache */
   /* replace2239_2 -> 84 in the cache */
   /* replace2239 -> 704 in the cache */

   /* ('bcsel', ('fge', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c') */
   /* search2240_0_0 -> 385 in the cache */
   /* search2240_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 385, 81 },
      -1,
   } },
   /* search2240_1 -> 82 in the cache */
   /* search2240_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 726, 82, 84 },
      -1,
   } },

   /* replace2240_0_0 -> 81 in the cache */
   /* replace2240_0 -> 89 in the cache */
   /* replace2240_1 -> 82 in the cache */
   /* replace2240_2 -> 84 in the cache */
   /* replace2240 -> 707 in the cache */

};

static const nir_search_expression_cond nir_opt_algebraic_late_expression_cond[] = {
   (is_used_once),
   (is_only_used_by_fadd),
   (is_only_used_as_float),
};

static const nir_search_variable_cond nir_opt_algebraic_late_variable_cond[] = {
   (is_finite),
   (is_not_const),
   (is_gt_0_and_lt_1),
   (is_not_fmul),
   (is_not_negative),
   (is_not_const_and_not_fsign),
};

static const struct transform nir_opt_algebraic_late_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 120 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 153, 155, 122 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 157, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 243, 126 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 244, 245, 126 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 246, 247, 126 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 126 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 255, 264, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 267, 269, 17 },
   { 271, 272, 17 },
   { 273, 274, 17 },
   { 275, 276, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 386, 385, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 386, 385, 0 },
   { 390, 395, 129 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 387, 385, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 387, 385, 0 },
   { 396, 400, 129 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 401, 42, 0 },
   { 403, 42, 0 },
   { 457, 450, 130 },
   { 454, 460, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 404, 42, 0 },
   { 405, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 406, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 582, 683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 684, 685, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 686, 687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 688, 431, 0 },
   { 688, 428, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 689, 690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 691, 692, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 693, 695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 723, 701, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 723, 701, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 723, 701, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 723, 701, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 721, 698, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 721, 698, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 721, 698, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 721, 698, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 721, 698, 132 },
   { 723, 701, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 721, 698, 132 },
   { 723, 701, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 721, 698, 132 },
   { 723, 701, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 721, 698, 132 },
   { 723, 701, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 725, 704, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 725, 704, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 725, 704, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 725, 704, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 727, 707, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 727, 707, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 727, 707, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 727, 707, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 725, 704, 132 },
   { 727, 707, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 725, 704, 132 },
   { 727, 707, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 725, 704, 132 },
   { 727, 707, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 725, 704, 132 },
   { 727, 707, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 712, 713, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 712, 713, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 712, 713, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 712, 713, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 709, 710, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 709, 710, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 709, 710, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 709, 710, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 709, 710, 132 },
   { 712, 713, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 709, 710, 132 },
   { 712, 713, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 709, 710, 132 },
   { 712, 713, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 709, 710, 132 },
   { 712, 713, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 715, 716, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 715, 716, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 715, 716, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 715, 716, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 718, 719, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 718, 719, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 718, 719, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 718, 719, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 715, 716, 132 },
   { 718, 719, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 715, 716, 132 },
   { 718, 719, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 715, 716, 132 },
   { 718, 719, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 715, 716, 132 },
   { 718, 719, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 10, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 225, 226, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 188, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 6, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 215, 216, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 679, 680, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 120 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 42, 0 },
   { 59, 149, 120 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 120 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 120 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 120 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 120 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 17, 16, 0 },
   { 29, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 200, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 13, 14, 0 },
   { 26, 14, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 227, 228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 217, 218, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 192, 0 },
   { 199, 200, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 677, 678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 20, 21, 0 },
   { 32, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 232, 233, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 193, 194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 220, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 675, 676, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 22, 23, 0 },
   { 33, 23, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 230, 231, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 195, 196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 222, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 681, 682, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 307, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 252, 254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 308, 310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 278, 269, 17 },
   { 280, 272, 17 },
   { 281, 274, 17 },
   { 282, 276, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 102, 103, 33 },
   { 118, 119, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 180, 182, 125 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 174, 179, 125 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 174, 179, 125 },
   { 180, 182, 125 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 296, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 42, 0 },
   { 453, 442, 130 },
   { 456, 446, 130 },
   { 459, 450, 130 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 48, 0 },
   { 235, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 42, 0 },
   { 470, 472, 0 },
   { 479, 481, 0 },
   { 488, 490, 0 },
   { 498, 500, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 57, 58, 0 },
   { 234, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 42, 0 },
   { 475, 476, 0 },
   { 484, 485, 0 },
   { 493, 494, 0 },
   { 503, 504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 162, 166, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 151, 152, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 168, 170, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 151, 152, 121 },
   { 162, 166, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 162, 166, 124 },
   { 168, 170, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 151, 152, 121 },
   { 168, 170, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 173, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 409, 407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 411, 407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 412, 410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 413, 410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 401, 42, 0 },
   { 403, 42, 0 },
   { 440, 442, 130 },
   { 444, 446, 130 },
   { 448, 450, 130 },
   { 457, 450, 130 },
   { 454, 460, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 462, 463, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 415, 417, 58 },
   { 424, 425, 58 },
   { 429, 430, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 419, 417, 58 },
   { 427, 425, 58 },
   { 432, 430, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 420, 421, 58 },
   { 433, 434, 58 },
   { 436, 437, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 422, 421, 58 },
   { 435, 434, 58 },
   { 438, 437, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 465, 466, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 255, 264, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 700, 701, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 697, 698, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 697, 698, 132 },
   { 700, 701, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 703, 704, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 706, 707, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 703, 704, 132 },
   { 706, 707, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 12, 6, 0 },
   { 225, 226, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 8, 10, 0 },
   { 223, 224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 18, 14, 0 },
   { 30, 14, 0 },
   { 229, 200, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 16, 0 },
   { 28, 16, 0 },
   { 227, 228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 214, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 121, 123, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 347, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 125, 128, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 375, 377, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 121, 123, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 239, 241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 508, 512, 14 },
   { 525, 529, 16 },
   { 538, 542, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 278, 269, 17 },
   { 280, 272, 17 },
   { 281, 274, 17 },
   { 282, 276, 17 },
   { 508, 512, 14 },
   { 525, 529, 16 },
   { 538, 542, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 347, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 125, 128, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 375, 377, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 342, 347, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 125, 128, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 375, 377, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 68, 70, 32 },
   { 85, 86, 33 },
   { 88, 90, 33 },
   { 118, 119, 34 },
   { 121, 123, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 105, 106, 33 },
   { 118, 119, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 342, 347, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 72, 75, 32 },
   { 85, 86, 33 },
   { 92, 95, 33 },
   { 118, 119, 34 },
   { 125, 128, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 108, 109, 33 },
   { 118, 119, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 375, 377, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 102, 103, 33 },
   { 121, 123, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 105, 106, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 342, 347, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 102, 103, 33 },
   { 125, 128, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 108, 109, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 375, 377, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 105, 106, 33 },
   { 121, 123, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 121, 123, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 342, 347, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 72, 75, 32 },
   { 88, 90, 33 },
   { 92, 95, 33 },
   { 121, 123, 34 },
   { 125, 128, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 108, 109, 33 },
   { 121, 123, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 121, 123, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 375, 377, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 342, 347, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 105, 106, 33 },
   { 125, 128, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 108, 109, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 375, 377, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 125, 128, 34 },
   { 342, 347, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { 342, 347, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 347, 128 },
   { 375, 377, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 108, 109, 33 },
   { 125, 128, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 125, 128, 34 },
   { 375, 377, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { 375, 377, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 294, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 288, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 288, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 288, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 294, 292, 17 },
   { 296, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 267, 269, 17 },
   { 271, 272, 17 },
   { 273, 274, 17 },
   { 275, 276, 17 },
   { 287, 288, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 288, 17 },
   { 291, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 288, 17 },
   { 294, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 288, 17 },
   { 296, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 622, 89, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 655, 656, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 673, 674, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 661, 662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 652, 653, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 646, 647, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 671, 86, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 584, 93, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 633, 634, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 627, 628, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 642, 643, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 630, 631, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 586, 587, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 589, 590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 592, 593, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 595, 596, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 598, 599, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 601, 602, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 604, 605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 607, 608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 610, 611, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 613, 614, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 616, 617, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 619, 620, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 624, 625, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 636, 637, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 639, 640, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 649, 650, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 658, 659, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 664, 665, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 667, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 723, 701, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 721, 698, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 721, 698, 132 },
   { 723, 701, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 725, 704, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 727, 707, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 725, 704, 132 },
   { 727, 707, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 712, 713, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 709, 710, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 709, 710, 132 },
   { 712, 713, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 715, 716, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 718, 719, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 715, 716, 132 },
   { 718, 719, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 316, 317, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 298, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 298, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 298, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 38, 41, 0 },
   { 235, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 53, 54, 0 },
   { 234, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 120 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 120 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 334, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 131, 133, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 363, 369, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 334, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 131, 133, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 363, 369, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 328, 334, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 363, 369, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 328, 334, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 78, 80, 32 },
   { 85, 86, 33 },
   { 98, 100, 33 },
   { 118, 119, 34 },
   { 131, 133, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 112, 113, 33 },
   { 118, 119, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 363, 369, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 328, 334, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 102, 103, 33 },
   { 131, 133, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 112, 113, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 363, 369, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 121, 123, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 328, 334, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 78, 80, 32 },
   { 88, 90, 33 },
   { 98, 100, 33 },
   { 121, 123, 34 },
   { 131, 133, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 112, 113, 33 },
   { 121, 123, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 121, 123, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 363, 369, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 328, 334, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 105, 106, 33 },
   { 131, 133, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 112, 113, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 363, 369, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 334, 128 },
   { 342, 347, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 131, 133, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 342, 347, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 342, 347, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 347, 128 },
   { 363, 369, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 125, 128, 34 },
   { 328, 334, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 78, 80, 32 },
   { 92, 95, 33 },
   { 98, 100, 33 },
   { 125, 128, 34 },
   { 131, 133, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 112, 113, 33 },
   { 125, 128, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 125, 128, 34 },
   { 363, 369, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { 328, 334, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 108, 109, 33 },
   { 131, 133, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { 112, 113, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { 363, 369, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 334, 128 },
   { 375, 377, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 131, 133, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 375, 377, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 375, 377, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 363, 369, 128 },
   { 375, 377, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 131, 133, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 328, 334, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 328, 334, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 334, 128 },
   { 363, 369, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 112, 113, 33 },
   { 131, 133, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 131, 133, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 363, 369, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 363, 369, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 120 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 120 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 349, 355, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 379, 384, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 349, 355, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 379, 384, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 349, 355, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 379, 384, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 349, 355, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 379, 384, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 121, 123, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 349, 355, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 121, 123, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 379, 384, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 349, 355, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 379, 384, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 342, 347, 128 },
   { 349, 355, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 342, 347, 128 },
   { 379, 384, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 125, 128, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 349, 355, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 125, 128, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 379, 384, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 349, 355, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 379, 384, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 349, 355, 128 },
   { 375, 377, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 375, 377, 128 },
   { 379, 384, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 328, 334, 128 },
   { 349, 355, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 328, 334, 128 },
   { 379, 384, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 131, 133, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 349, 355, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 131, 133, 34 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 379, 384, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 349, 355, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 33 },
   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 379, 384, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 349, 355, 128 },
   { 363, 369, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 363, 369, 128 },
   { 379, 384, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 118 },
   { 140, 141, 118 },
   { 143, 144, 118 },
   { 146, 147, 119 },
   { 349, 355, 128 },
   { 379, 384, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_late_pass_op_table[nir_num_search_ops] = {
   [nir_op_flt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         121,
         122,
         123,
         3,
         241,
         0,
         124,
         0,
         0,
         0,
         0,
         0,
         0,
         125,
         0,
         126,
         0,
         0,
         126,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         127,
         0,
         0,
         242,
         0,
         126,
         0,
         0,
         126,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         7,
         8,
         9,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         3,
         11,
         4,
         10,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         14,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         12,
         0,
         12,
         16,
         12,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         10,
         0,
         0,
         17,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 22,
      .table = (const uint16_t []) {
      
         5,
         6,
         165,
         166,
         166,
         167,
         5,
         246,
         247,
         165,
         166,
         166,
         248,
         249,
         250,
         251,
         356,
         357,
         358,
         359,
         406,
         407,
         6,
         6,
         168,
         169,
         170,
         171,
         6,
         252,
         253,
         254,
         255,
         256,
         257,
         258,
         259,
         260,
         360,
         361,
         362,
         363,
         408,
         409,
         165,
         168,
         165,
         172,
         172,
         173,
         165,
         246,
         247,
         165,
         172,
         172,
         261,
         262,
         263,
         264,
         364,
         357,
         358,
         365,
         406,
         407,
         166,
         169,
         172,
         166,
         166,
         174,
         166,
         265,
         266,
         172,
         166,
         166,
         267,
         268,
         269,
         270,
         366,
         367,
         368,
         369,
         410,
         411,
         166,
         170,
         172,
         166,
         166,
         174,
         166,
         265,
         266,
         172,
         166,
         166,
         267,
         268,
         269,
         270,
         366,
         367,
         368,
         369,
         410,
         411,
         167,
         171,
         173,
         174,
         174,
         167,
         167,
         271,
         272,
         173,
         174,
         174,
         273,
         274,
         275,
         276,
         370,
         371,
         372,
         373,
         412,
         413,
         5,
         6,
         165,
         166,
         166,
         167,
         175,
         246,
         247,
         165,
         166,
         166,
         248,
         249,
         250,
         251,
         356,
         357,
         358,
         359,
         406,
         407,
         246,
         252,
         246,
         265,
         265,
         271,
         246,
         246,
         277,
         246,
         265,
         265,
         278,
         279,
         280,
         281,
         374,
         375,
         376,
         377,
         414,
         415,
         247,
         253,
         247,
         266,
         266,
         272,
         247,
         277,
         247,
         247,
         266,
         266,
         282,
         283,
         284,
         285,
         378,
         379,
         380,
         381,
         416,
         417,
         165,
         254,
         165,
         172,
         172,
         173,
         165,
         246,
         247,
         165,
         172,
         172,
         261,
         262,
         263,
         264,
         364,
         357,
         358,
         365,
         406,
         407,
         166,
         255,
         172,
         166,
         166,
         174,
         166,
         265,
         266,
         172,
         166,
         166,
         267,
         268,
         269,
         270,
         366,
         367,
         368,
         369,
         410,
         411,
         166,
         256,
         172,
         166,
         166,
         174,
         166,
         265,
         266,
         172,
         166,
         166,
         267,
         268,
         269,
         270,
         366,
         367,
         368,
         369,
         410,
         411,
         248,
         257,
         261,
         267,
         267,
         273,
         248,
         278,
         282,
         261,
         267,
         267,
         248,
         286,
         287,
         288,
         382,
         383,
         384,
         385,
         418,
         419,
         249,
         258,
         262,
         268,
         268,
         274,
         249,
         279,
         283,
         262,
         268,
         268,
         286,
         249,
         289,
         290,
         386,
         387,
         388,
         389,
         420,
         421,
         250,
         259,
         263,
         269,
         269,
         275,
         250,
         280,
         284,
         263,
         269,
         269,
         287,
         289,
         250,
         291,
         390,
         391,
         392,
         393,
         422,
         423,
         251,
         260,
         264,
         270,
         270,
         276,
         251,
         281,
         285,
         264,
         270,
         270,
         288,
         290,
         291,
         251,
         394,
         395,
         396,
         397,
         424,
         425,
         356,
         360,
         364,
         366,
         366,
         370,
         356,
         374,
         378,
         364,
         366,
         366,
         382,
         386,
         390,
         394,
         356,
         398,
         399,
         400,
         426,
         427,
         357,
         361,
         357,
         367,
         367,
         371,
         357,
         375,
         379,
         357,
         367,
         367,
         383,
         387,
         391,
         395,
         398,
         357,
         401,
         402,
         428,
         429,
         358,
         362,
         358,
         368,
         368,
         372,
         358,
         376,
         380,
         358,
         368,
         368,
         384,
         388,
         392,
         396,
         399,
         401,
         358,
         403,
         430,
         431,
         359,
         363,
         365,
         369,
         369,
         373,
         359,
         377,
         381,
         365,
         369,
         369,
         385,
         389,
         393,
         397,
         400,
         402,
         403,
         359,
         432,
         433,
         406,
         408,
         406,
         410,
         410,
         412,
         406,
         414,
         416,
         406,
         410,
         410,
         418,
         420,
         422,
         424,
         426,
         428,
         430,
         432,
         406,
         434,
         407,
         409,
         407,
         411,
         411,
         413,
         407,
         415,
         417,
         407,
         411,
         411,
         419,
         421,
         423,
         425,
         427,
         429,
         431,
         433,
         434,
         407,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         9,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         2,
         2,
         10,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         7,
         128,
         129,
         130,
         131,
         132,
         133,
         353,
         354,
         404,
         405,
      },
   },
   [nir_op_fge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         134,
         135,
         9,
         9,
         243,
         9,
         0,
         136,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         137,
         0,
         138,
         0,
         0,
         138,
         0,
         0,
         139,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         140,
         0,
         0,
         0,
         244,
         0,
         138,
         0,
         0,
         138,
         0,
         0,
         245,
         0,
         0,
         0,
         0,
         0,
         0,
      },
   },
   [nir_op_feq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         11,
         12,
         11,
         11,
         11,
         11,
         11,
         12,
         12,
         141,
         142,
         143,
         144,
         12,
         11,
         141,
         11,
         11,
         11,
         11,
         11,
         11,
         142,
         11,
         145,
         11,
         11,
         11,
         11,
         143,
         11,
         11,
         11,
         11,
         11,
         11,
         144,
         11,
         11,
         11,
         11,
         11,
         11,
         12,
         11,
         11,
         11,
         11,
         146,
      },
   },
   [nir_op_fneu] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         13,
         14,
         13,
         13,
         13,
         13,
         14,
         14,
         147,
         148,
         149,
         14,
         13,
         147,
         13,
         13,
         13,
         13,
         13,
         148,
         13,
         150,
         13,
         13,
         13,
         149,
         13,
         13,
         13,
         13,
         13,
         14,
         13,
         13,
         13,
         151,
      },
   },
   [nir_op_iand] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         182,
         15,
         15,
         15,
         15,
         183,
         15,
         184,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         351,
         15,
         15,
         184,
         15,
         15,
         15,
         15,
         351,
         15,
         182,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         185,
         15,
         15,
         15,
         15,
         351,
         351,
         15,
         15,
         15,
      },
   },
   [nir_op_ior] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         1,
         1,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         352,
         16,
         16,
         16,
         186,
         16,
         352,
         16,
         16,
         186,
         187,
         16,
         16,
         16,
         16,
         16,
         16,
         188,
         16,
         16,
         352,
         352,
         16,
         16,
         16,
      },
   },
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         2,
         5,
         5,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         17,
         18,
         157,
         158,
         17,
         348,
         18,
         18,
         159,
         160,
         18,
         349,
         157,
         159,
         157,
         161,
         157,
         348,
         158,
         160,
         161,
         158,
         158,
         350,
         17,
         18,
         157,
         158,
         162,
         348,
         348,
         349,
         348,
         350,
         348,
         348,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         189,
         190,
         191,
      },
   },
   [nir_op_fmulz] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         19,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         20,
         193,
         194,
         195,
         193,
         193,
         196,
         197,
         194,
         196,
         194,
         198,
         195,
         197,
         198,
         195,
      },
   },
   [nir_op_ineg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         21,
      },
   },
   [nir_op_iabs] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         22,
      },
   },
   [nir_op_isub] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         23,
         23,
         199,
         199,
      },
   },
   [nir_op_vec2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         176,
         177,
         178,
      },
   },
   [nir_op_fsat] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         24,
         212,
      },
   },
   [nir_op_fmin] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         1,
         1,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         152,
         152,
         0,
         0,
         152,
         153,
         0,
         0,
         0,
         0,
         154,
      },
   },
   [nir_op_fdot2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         25,
      },
   },
   [nir_op_fdot3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         26,
      },
   },
   [nir_op_fdot4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         27,
      },
   },
   [nir_op_fdph] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         28,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         155,
         155,
         155,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         156,
      },
   },
   [nir_op_fround_even] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         29,
         213,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         6,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         7,
         4,
         8,
         7,
         3,
         0,
         0,
         9,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         10,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         7,
         0,
         0,
         2,
         2,
         0,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         9,
         9,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         9,
         9,
         0,
         9,
         9,
         9,
         2,
         2,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         31,
         30,
         179,
         180,
         30,
         293,
         294,
         298,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         31,
         30,
         179,
         180,
         30,
         293,
         294,
         298,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         295,
         299,
         295,
         296,
         296,
         295,
         300,
         301,
         301,
         295,
         297,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         31,
         30,
         179,
         180,
         30,
         293,
         294,
         298,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         295,
         295,
         295,
         296,
         302,
         295,
         295,
         296,
         302,
         295,
         297,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         181,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         31,
         30,
         179,
         180,
         30,
         293,
         294,
         298,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         295,
         295,
         295,
         296,
         302,
         295,
         295,
         296,
         302,
         295,
         297,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         299,
         295,
         296,
         296,
         295,
         300,
         301,
         301,
         295,
         297,
         295,
         295,
         295,
         296,
         302,
         295,
         295,
         296,
         302,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         295,
         295,
         296,
         302,
         295,
         295,
         296,
         302,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
      },
   },
   [nir_op_fmax] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         163,
         0,
         0,
         0,
         164,
      },
   },
   [nir_op_bcsel] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         3,
         4,
         5,
         5,
         0,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         10,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         14,
         15,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         6,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         2,
         7,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
      },
      
      .num_filtered_states = 20,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         335,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         74,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         75,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         76,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         336,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         78,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         79,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         80,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         337,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         82,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         83,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         84,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         338,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         86,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         87,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         88,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         339,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         90,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         91,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         92,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         340,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         94,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         95,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         96,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         341,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         98,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         99,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         100,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         342,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         102,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         103,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         104,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         343,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         106,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         107,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         108,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         344,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         111,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         112,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         345,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         114,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         115,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         116,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         346,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         118,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         119,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         120,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         347,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
   },
   [nir_op_fsqrt] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         32,
         214,
      },
   },
   [nir_op_frsq] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         33,
         215,
      },
   },
   [nir_op_ffmaz] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
      },
   },
   [nir_op_ubfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         35,
         0,
         36,
         0,
         35,
         0,
         36,
      },
   },
   [nir_op_ibfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         37,
         0,
         38,
         0,
         37,
         0,
         38,
      },
   },
   [nir_op_ishl] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         39,
         0,
         0,
         39,
         0,
         0,
         204,
         0,
      },
   },
   [nir_op_ishr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         40,
         0,
         40,
      },
   },
   [nir_op_ushr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         41,
         0,
         41,
      },
   },
   [nir_op_extract_i8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         200,
         42,
         42,
         42,
         201,
         42,
         42,
      },
   },
   [nir_op_extract_u8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         43,
         44,
         43,
         43,
         43,
         44,
         43,
         43,
         43,
         202,
         43,
         43,
         43,
         203,
         43,
         43,
      },
   },
   [nir_search_op_u2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         45,
         206,
         207,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         46,
         208,
         209,
      },
   },
   [nir_op_insert_u8] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         205,
         205,
      },
   },
   [nir_op_insert_u16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         210,
         210,
      },
   },
   [nir_op_extract_u16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         47,
         0,
         47,
      },
   },
   [nir_op_ine] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         48,
         48,
         48,
      },
   },
   [nir_op_ieq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         49,
         49,
         49,
      },
   },
   [nir_search_op_b2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         211,
      },
   },
   [nir_op_inot] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         50,
      },
   },
   [nir_search_op_f2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         11,
         12,
         13,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         26,
         27,
         28,
         29,
         30,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 32,
      .table = (const uint16_t []) {
      
         0,
         303,
         304,
         305,
         306,
         307,
         308,
         309,
         310,
         311,
         312,
         313,
         314,
         315,
         316,
         317,
         318,
         319,
         320,
         321,
         322,
         323,
         324,
         325,
         326,
         327,
         328,
         329,
         330,
         331,
         332,
         333,
      },
   },
   [nir_op_f2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         51,
      },
   },
   [nir_op_fceil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         216,
      },
   },
   [nir_op_fcos] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         217,
      },
   },
   [nir_op_fddx] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         218,
      },
   },
   [nir_op_fddx_coarse] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         219,
      },
   },
   [nir_op_fddx_fine] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         220,
      },
   },
   [nir_op_fddy] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         221,
      },
   },
   [nir_op_fddy_coarse] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         222,
      },
   },
   [nir_op_fddy_fine] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         223,
      },
   },
   [nir_op_fexp2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         224,
      },
   },
   [nir_op_ffloor] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         225,
      },
   },
   [nir_op_ffract] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         226,
      },
   },
   [nir_op_flog2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         227,
      },
   },
   [nir_op_frcp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         228,
      },
   },
   [nir_op_fsign] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         229,
      },
   },
   [nir_op_fsin] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         230,
      },
   },
   [nir_op_fdiv] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         231,
      },
   },
   [nir_op_fmod] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         232,
      },
   },
   [nir_op_fpow] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         233,
      },
   },
   [nir_op_frem] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         234,
      },
   },
   [nir_op_f2imp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         52,
      },
   },
   [nir_op_f2ump] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         53,
      },
   },
   [nir_op_i2imp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         54,
      },
   },
   [nir_op_i2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         55,
      },
   },
   [nir_op_u2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         56,
      },
   },
   [nir_op_fisfinite] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         57,
      },
   },
   [nir_op_fcsel] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
      },
   },
   [nir_op_slt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         58,
         59,
         60,
      },
   },
   [nir_op_sge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         61,
         62,
         63,
      },
   },
   [nir_op_ilt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         64,
         65,
         66,
      },
   },
   [nir_op_ige] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         67,
         68,
         69,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_late_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   3,
   5,
   0,
   0,
   0,
   0,
   7,
   9,
   0,
   0,
   11,
   13,
   15,
   17,
   19,
   0,
   21,
   0,
   0,
   0,
   26,
   28,
   31,
   33,
   36,
   41,
   44,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   46,
   48,
   50,
   52,
   55,
   57,
   59,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   61,
   64,
   69,
   74,
   76,
   80,
   86,
   92,
   94,
   98,
   104,
   110,
   113,
   118,
   125,
   132,
   134,
   138,
   144,
   150,
   152,
   156,
   162,
   168,
   171,
   176,
   183,
   190,
   192,
   196,
   202,
   208,
   210,
   214,
   220,
   226,
   229,
   234,
   241,
   248,
   250,
   254,
   260,
   266,
   268,
   272,
   278,
   284,
   287,
   292,
   299,
   306,
   308,
   310,
   312,
   314,
   316,
   318,
   320,
   322,
   325,
   327,
   329,
   331,
   333,
   336,
   338,
   341,
   343,
   345,
   348,
   350,
   353,
   355,
   0,
   357,
   359,
   361,
   364,
   366,
   368,
   370,
   0,
   372,
   0,
   374,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   376,
   0,
   378,
   383,
   387,
   389,
   394,
   398,
   406,
   408,
   416,
   422,
   0,
   427,
   429,
   431,
   0,
   434,
   0,
   436,
   441,
   443,
   446,
   452,
   455,
   457,
   0,
   0,
   0,
   0,
   463,
   465,
   467,
   469,
   472,
   475,
   478,
   480,
   482,
   484,
   486,
   488,
   496,
   498,
   502,
   506,
   510,
   514,
   0,
   0,
   516,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   518,
   520,
   522,
   525,
   527,
   529,
   532,
   535,
   538,
   542,
   546,
   548,
   556,
   562,
   564,
   568,
   570,
   572,
   580,
   586,
   592,
   599,
   610,
   612,
   616,
   618,
   620,
   626,
   634,
   640,
   646,
   657,
   666,
   671,
   678,
   683,
   688,
   697,
   704,
   707,
   712,
   715,
   718,
   727,
   736,
   747,
   756,
   765,
   772,
   781,
   788,
   795,
   800,
   803,
   806,
   811,
   816,
   0,
   819,
   821,
   823,
   825,
   827,
   829,
   832,
   838,
   841,
   844,
   847,
   849,
   851,
   853,
   855,
   857,
   859,
   861,
   863,
   865,
   867,
   869,
   871,
   873,
   875,
   877,
   879,
   881,
   883,
   885,
   887,
   889,
   891,
   893,
   895,
   897,
   899,
   901,
   903,
   905,
   907,
   909,
   913,
   918,
   923,
   929,
   934,
   939,
   945,
   950,
   955,
   961,
   966,
   971,
   977,
   979,
   981,
   983,
   985,
   988,
   991,
   993,
   0,
   995,
   997,
   1005,
   1011,
   1013,
   1015,
   1023,
   1029,
   1031,
   1037,
   1043,
   1048,
   1059,
   1068,
   1073,
   1076,
   1085,
   1092,
   1095,
   1104,
   1115,
   1124,
   1133,
   1140,
   1149,
   1156,
   1163,
   1166,
   1175,
   1182,
   1185,
   1190,
   1201,
   1210,
   1215,
   1218,
   1227,
   1234,
   1237,
   1240,
   1249,
   1256,
   1259,
   1268,
   1275,
   1278,
   1287,
   1296,
   1303,
   1305,
   1307,
   1313,
   1319,
   1325,
   1331,
   1340,
   1349,
   1356,
   1363,
   1372,
   1381,
   1388,
   1395,
   1402,
   1409,
   1418,
   1427,
   1434,
   1441,
   1448,
   1455,
   1462,
   1469,
   1478,
   1487,
   1494,
   1501,
   1508,
   1515,
};

static const nir_algebraic_table nir_opt_algebraic_late_table = {
   .transforms = nir_opt_algebraic_late_transforms,
   .transform_offsets = nir_opt_algebraic_late_transform_offsets,
   .pass_op_table = nir_opt_algebraic_late_pass_op_table,
   .values = nir_opt_algebraic_late_values,
   .expression_cond = nir_opt_algebraic_late_expression_cond,
   .variable_cond = nir_opt_algebraic_late_variable_cond,
};

bool
nir_opt_algebraic_late(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[133];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(728 == ARRAY_SIZE(nir_opt_algebraic_late_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_ftrunc || (options->lower_doubles_options & nir_lower_dtrunc);
   condition_flags[22] = options->lower_ffloor;
   condition_flags[23] = (options->lower_ffloor || (options->lower_doubles_options & nir_lower_dfloor)) && !(options->lower_doubles_options & nir_lower_dfract);
   condition_flags[24] = !options->lower_ffloor;
   condition_flags[25] = !options->lower_ffloor && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[26] = options->lower_ffract;
   condition_flags[27] = options->lower_ffract || (options->lower_doubles_options & nir_lower_dfract);
   condition_flags[28] = options->lower_fceil;
   condition_flags[29] = options->lower_ffma16;
   condition_flags[30] = options->lower_ffma32;
   condition_flags[31] = options->lower_ffma64;
   condition_flags[32] = options->fuse_ffma16;
   condition_flags[33] = options->fuse_ffma32;
   condition_flags[34] = options->fuse_ffma64;
   condition_flags[35] = options->lower_fdph;
   condition_flags[36] = !options->lower_fdph;
   condition_flags[37] = options->lower_fdot;
   condition_flags[38] = !options->lower_fsat;
   condition_flags[39] = !options->lower_iabs;
   condition_flags[40] = options->lower_fsat;
   condition_flags[41] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[42] = !options->lower_fsign;
   condition_flags[43] = options->lower_umax;
   condition_flags[44] = options->lower_umin;
   condition_flags[45] = !options->lower_umax;
   condition_flags[46] = !options->lower_umin;
   condition_flags[47] = options->lower_scmp;
   condition_flags[48] = options->lower_vector_cmp;
   condition_flags[49] = !options->lower_rotate;
   condition_flags[50] = options->lower_rotate;
   condition_flags[51] = options->lower_fpow;
   condition_flags[52] = !options->lower_fpow;
   condition_flags[53] = options->lower_fdiv;
   condition_flags[54] = options->lower_fsqrt;
   condition_flags[55] = !options->lower_fsqrt;
   condition_flags[56] = options->lower_sincos;
   condition_flags[57] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[58] = !options->lower_extract_byte;
   condition_flags[59] = !options->lower_extract_word;
   condition_flags[60] = options->has_pack_32_4x8;
   condition_flags[61] = options->lower_pack_64_2x32_split;
   condition_flags[62] = options->lower_pack_32_2x16_split;
   condition_flags[63] = options->lower_unpack_64_2x32_split;
   condition_flags[64] = options->lower_unpack_32_2x16_split;
   condition_flags[65] = options->has_find_msb_rev;
   condition_flags[66] = !options->lower_find_msb_to_reverse;
   condition_flags[67] = !options->lower_find_lsb;
   condition_flags[68] = options->lower_fmod;
   condition_flags[69] = options->lower_uadd_carry;
   condition_flags[70] = options->lower_usub_borrow;
   condition_flags[71] = options->lower_bitfield_insert;
   condition_flags[72] = options->lower_hadd;
   condition_flags[73] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[74] = options->lower_mul_32x16;
   condition_flags[75] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[76] = options->lower_uadd_sat;
   condition_flags[77] = options->lower_usub_sat;
   condition_flags[78] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[79] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[80] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[81] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[82] = options->lower_bitfield_insert_to_shifts;
   condition_flags[83] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[84] = options->lower_bitfield_extract;
   condition_flags[85] = options->lower_bitfield_extract_to_shifts;
   condition_flags[86] = options->lower_ifind_msb;
   condition_flags[87] = options->lower_find_msb_to_reverse;
   condition_flags[88] = options->lower_uclz;
   condition_flags[89] = options->lower_find_lsb;
   condition_flags[90] = options->lower_extract_byte;
   condition_flags[91] = options->lower_extract_word;
   condition_flags[92] = options->lower_pack_unorm_2x16;
   condition_flags[93] = options->lower_pack_unorm_4x8;
   condition_flags[94] = options->lower_pack_snorm_2x16;
   condition_flags[95] = options->lower_pack_snorm_4x8;
   condition_flags[96] = options->lower_unpack_unorm_2x16;
   condition_flags[97] = options->lower_unpack_unorm_4x8;
   condition_flags[98] = options->lower_unpack_snorm_2x16;
   condition_flags[99] = options->lower_unpack_snorm_4x8;
   condition_flags[100] = options->lower_pack_split;
   condition_flags[101] = options->lower_isign;
   condition_flags[102] = !options->lower_isign;
   condition_flags[103] = options->lower_fsign;
   condition_flags[104] = !options->has_imul24;
   condition_flags[105] = !options->has_umul24;
   condition_flags[106] = !options->has_umad24;
   condition_flags[107] = options->has_imul24;
   condition_flags[108] = options->has_umad24;
   condition_flags[109] = options->has_umul24;
   condition_flags[110] = options->lower_iadd_sat;
   condition_flags[111] = options->support_8bit_alu;
   condition_flags[112] = options->support_16bit_alu;
   condition_flags[113] = options->lower_ldexp;
   condition_flags[114] = !options->lower_bitfield_reverse;
   condition_flags[115] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[116] = options->lower_fisnormal;
   condition_flags[117] = !options->vectorize_vec2_16bit;
   condition_flags[118] = options->has_fsub;
   condition_flags[119] = options->has_fsub && !(options->lower_doubles_options & nir_lower_dsub);
   condition_flags[120] = options->lower_fneg;
   condition_flags[121] = options->has_isub || options->lower_ineg;
   condition_flags[122] = options->lower_ineg;
   condition_flags[123] = options->lower_iabs;
   condition_flags[124] = options->has_iadd3;
   condition_flags[125] = options->vectorize_vec2_16bit;
   condition_flags[126] = options->fdot_replicates;
   condition_flags[127] = options->lower_fround_even;
   condition_flags[128] = (info->stage != MESA_SHADER_VERTEX && info->stage != MESA_SHADER_GEOMETRY) && !options->intel_vec4;
   condition_flags[129] = options->avoid_ternary_with_two_constants;
   condition_flags[130] = !options->lower_insert_byte;
   condition_flags[131] = !options->lower_insert_word;
   condition_flags[132] = options->has_fused_comp_and_csel;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_late_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 19
 * transforms:
 *    ('fmul', ('fneg', 'a'), ('fneg', 'b')) => ('fmul', 'a', 'b')
 *    ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('fdot2_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot2_replicated', 'a', 'b')
 *    ('fdot3_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot3_replicated', 'a', 'b')
 *    ('fdot4_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot4_replicated', 'a', 'b')
 *    ('fneg', ('fneg', 'a')) => a
 *    ('fneg', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fneg', 'a'), 'b')
 *    ('fabs', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fabs', 'a'), ('fabs', 'b'))
 *    ('fneg', ('ffma(is_used_once)', 'a', 'b', 'c')) => ('ffma', ('fneg', 'a'), 'b', ('fneg', 'c'))
 *    ('fneg', ('flrp(is_used_once)', 'a', 'b', 'c')) => ('flrp', ('fneg', 'a'), ('fneg', 'b'), 'c')
 *    ('fneg', ('~fadd(is_used_once)', 'a', 'b')) => ('fadd', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fmin(is_used_once)', 'a', 'b')) => ('fmax', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fmax(is_used_once)', 'a', 'b')) => ('fmin', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fdot2_replicated(is_used_once)', 'a', 'b')) => ('fdot2_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdot3_replicated(is_used_once)', 'a', 'b')) => ('fdot3_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdot4_replicated(is_used_once)', 'a', 'b')) => ('fdot4_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdph_replicated(is_used_once)', 'a', 'b')) => ('fdph_replicated', 'a', ('fneg', 'b'))
 *    ('fneg', ('fsign(is_used_once)', 'a')) => ('fsign', ('fneg', 'a'))
 *    ('fabs', ('fsign(is_used_once)', 'a')) => ('fsign', ('fabs', 'a'))
 */


static const nir_search_value_union nir_opt_algebraic_distribute_src_mods_values[] = {
   /* ('fmul', ('fneg', 'a'), ('fneg', 'b')) => ('fmul', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2241_0 -> 0 in the cache */
   /* replace2241_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 6 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 8 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 7, 9, 10 },
      -1,
   } },

   /* replace2242_0 -> 6 in the cache */
   /* replace2242_1 -> 8 in the cache */
   /* replace2242_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 6, 8, 10 },
      -1,
   } },

   /* ('fdot2_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot2_replicated', 'a', 'b') */
   /* search2243_0_0 -> 0 in the cache */
   /* search2243_0 -> 1 in the cache */
   /* search2243_1_0 -> 2 in the cache */
   /* search2243_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2243_0 -> 0 in the cache */
   /* replace2243_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fdot3_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot3_replicated', 'a', 'b') */
   /* search2244_0_0 -> 0 in the cache */
   /* search2244_0 -> 1 in the cache */
   /* search2244_1_0 -> 2 in the cache */
   /* search2244_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2244_0 -> 0 in the cache */
   /* replace2244_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fdot4_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot4_replicated', 'a', 'b') */
   /* search2245_0_0 -> 0 in the cache */
   /* search2245_0 -> 1 in the cache */
   /* search2245_1_0 -> 2 in the cache */
   /* search2245_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2245_0 -> 0 in the cache */
   /* replace2245_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fneg', ('fneg', 'a')) => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 20 },
      -1,
   } },

   /* replace2246 -> 19 in the cache */

   /* ('fneg', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fneg', 'a'), 'b') */
   /* search2247_0_0 -> 0 in the cache */
   /* search2247_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 22 },
      -1,
   } },

   /* replace2247_0_0 -> 0 in the cache */
   /* replace2247_0 -> 1 in the cache */
   /* replace2247_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fabs', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fabs', 'a'), ('fabs', 'b')) */
   /* search2248_0_0 -> 0 in the cache */
   /* search2248_0_1 -> 2 in the cache */
   /* search2248_0 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 22 },
      -1,
   } },

   /* replace2248_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace2248_1_0 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 26, 27 },
      -1,
   } },

   /* ('fneg', ('ffma(is_used_once)', 'a', 'b', 'c')) => ('ffma', ('fneg', 'a'), 'b', ('fneg', 'c')) */
   /* search2249_0_0 -> 6 in the cache */
   /* search2249_0_1 -> 8 in the cache */
   /* search2249_0_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 6, 8, 10 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 29 },
      -1,
   } },

   /* replace2249_0_0 -> 6 in the cache */
   /* replace2249_0 -> 7 in the cache */
   /* replace2249_1 -> 8 in the cache */
   /* replace2249_2_0 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 10 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 7, 8, 31 },
      -1,
   } },

   /* ('fneg', ('flrp(is_used_once)', 'a', 'b', 'c')) => ('flrp', ('fneg', 'a'), ('fneg', 'b'), 'c') */
   /* search2250_0_0 -> 6 in the cache */
   /* search2250_0_1 -> 8 in the cache */
   /* search2250_0_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 6, 8, 10 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 33 },
      -1,
   } },

   /* replace2250_0_0 -> 6 in the cache */
   /* replace2250_0 -> 7 in the cache */
   /* replace2250_1_0 -> 8 in the cache */
   /* replace2250_1 -> 9 in the cache */
   /* replace2250_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 7, 9, 10 },
      -1,
   } },

   /* ('fneg', ('~fadd(is_used_once)', 'a', 'b')) => ('fadd', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2251_0_0 -> 0 in the cache */
   /* search2251_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 36 },
      -1,
   } },

   /* replace2251_0_0 -> 0 in the cache */
   /* replace2251_0 -> 1 in the cache */
   /* replace2251_1_0 -> 2 in the cache */
   /* replace2251_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fmin(is_used_once)', 'a', 'b')) => ('fmax', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2252_0_0 -> 0 in the cache */
   /* search2252_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 39 },
      -1,
   } },

   /* replace2252_0_0 -> 0 in the cache */
   /* replace2252_0 -> 1 in the cache */
   /* replace2252_1_0 -> 2 in the cache */
   /* replace2252_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fmax(is_used_once)', 'a', 'b')) => ('fmin', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2253_0_0 -> 0 in the cache */
   /* search2253_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 42 },
      -1,
   } },

   /* replace2253_0_0 -> 0 in the cache */
   /* replace2253_0 -> 1 in the cache */
   /* replace2253_1_0 -> 2 in the cache */
   /* replace2253_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fdot2_replicated(is_used_once)', 'a', 'b')) => ('fdot2_replicated', ('fneg', 'a'), 'b') */
   /* search2254_0_0 -> 0 in the cache */
   /* search2254_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 45 },
      -1,
   } },

   /* replace2254_0_0 -> 0 in the cache */
   /* replace2254_0 -> 1 in the cache */
   /* replace2254_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdot3_replicated(is_used_once)', 'a', 'b')) => ('fdot3_replicated', ('fneg', 'a'), 'b') */
   /* search2255_0_0 -> 0 in the cache */
   /* search2255_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 48 },
      -1,
   } },

   /* replace2255_0_0 -> 0 in the cache */
   /* replace2255_0 -> 1 in the cache */
   /* replace2255_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdot4_replicated(is_used_once)', 'a', 'b')) => ('fdot4_replicated', ('fneg', 'a'), 'b') */
   /* search2256_0_0 -> 0 in the cache */
   /* search2256_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 51 },
      -1,
   } },

   /* replace2256_0_0 -> 0 in the cache */
   /* replace2256_0 -> 1 in the cache */
   /* replace2256_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdph_replicated(is_used_once)', 'a', 'b')) => ('fdph_replicated', 'a', ('fneg', 'b')) */
   /* search2257_0_0 -> 0 in the cache */
   /* search2257_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 54 },
      -1,
   } },

   /* replace2257_0 -> 0 in the cache */
   /* replace2257_1_0 -> 2 in the cache */
   /* replace2257_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('fneg', ('fsign(is_used_once)', 'a')) => ('fsign', ('fneg', 'a')) */
   /* search2258_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 19 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 57 },
      -1,
   } },

   /* replace2258_0_0 -> 19 in the cache */
   /* replace2258_0 -> 20 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 20 },
      -1,
   } },

   /* ('fabs', ('fsign(is_used_once)', 'a')) => ('fsign', ('fabs', 'a')) */
   /* search2259_0_0 -> 19 in the cache */
   /* search2259_0 -> 57 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 57 },
      -1,
   } },

   /* replace2259_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 61 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_distribute_src_mods_expression_cond[] = {
   (is_used_once),
};


static const struct transform nir_opt_algebraic_distribute_src_mods_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 23, 24, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 21, 19, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 30, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 47, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 49, 50, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 52, 53, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 40, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 43, 44, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 55, 56, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 58, 59, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 25, 28, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 62, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 5, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 12, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 13, 14, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 17, 18, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_distribute_src_mods_pass_op_table[nir_num_search_ops] = {
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         2,
         2,
         2,
         28,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         2,
         3,
         4,
         5,
         6,
         7,
         8,
         9,
         10,
         11,
         12,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         1,
         3,
         4,
         5,
         6,
      },
      
      .num_filtered_states = 13,
      .table = (const uint16_t []) {
      
         3,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         4,
         4,
         4,
         4,
         4,
         4,
         29,
         29,
      },
   },
   [nir_op_fdot2_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         5,
         5,
         5,
         30,
      },
   },
   [nir_op_fdot3_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         6,
         6,
         6,
         31,
      },
   },
   [nir_op_fdot4_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         7,
         7,
         7,
         32,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         26,
         27,
      },
   },
   [nir_op_flrp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         8,
      },
   },
   [nir_op_fadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         9,
      },
   },
   [nir_op_fmin] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_fmax] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         11,
      },
   },
   [nir_op_fdph_replicated] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         12,
      },
   },
   [nir_op_fsign] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         13,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_distribute_src_mods_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   3,
   5,
   7,
   9,
   11,
   13,
   15,
   17,
   19,
   21,
   23,
   25,
   27,
   29,
   31,
   33,
   35,
   37,
};

static const nir_algebraic_table nir_opt_algebraic_distribute_src_mods_table = {
   .transforms = nir_opt_algebraic_distribute_src_mods_transforms,
   .transform_offsets = nir_opt_algebraic_distribute_src_mods_transform_offsets,
   .pass_op_table = nir_opt_algebraic_distribute_src_mods_pass_op_table,
   .values = nir_opt_algebraic_distribute_src_mods_values,
   .expression_cond = nir_opt_algebraic_distribute_src_mods_expression_cond,
   .variable_cond = NULL,
};

bool
nir_opt_algebraic_distribute_src_mods(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[133];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(63 == ARRAY_SIZE(nir_opt_algebraic_distribute_src_mods_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_ftrunc || (options->lower_doubles_options & nir_lower_dtrunc);
   condition_flags[22] = options->lower_ffloor;
   condition_flags[23] = (options->lower_ffloor || (options->lower_doubles_options & nir_lower_dfloor)) && !(options->lower_doubles_options & nir_lower_dfract);
   condition_flags[24] = !options->lower_ffloor;
   condition_flags[25] = !options->lower_ffloor && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[26] = options->lower_ffract;
   condition_flags[27] = options->lower_ffract || (options->lower_doubles_options & nir_lower_dfract);
   condition_flags[28] = options->lower_fceil;
   condition_flags[29] = options->lower_ffma16;
   condition_flags[30] = options->lower_ffma32;
   condition_flags[31] = options->lower_ffma64;
   condition_flags[32] = options->fuse_ffma16;
   condition_flags[33] = options->fuse_ffma32;
   condition_flags[34] = options->fuse_ffma64;
   condition_flags[35] = options->lower_fdph;
   condition_flags[36] = !options->lower_fdph;
   condition_flags[37] = options->lower_fdot;
   condition_flags[38] = !options->lower_fsat;
   condition_flags[39] = !options->lower_iabs;
   condition_flags[40] = options->lower_fsat;
   condition_flags[41] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[42] = !options->lower_fsign;
   condition_flags[43] = options->lower_umax;
   condition_flags[44] = options->lower_umin;
   condition_flags[45] = !options->lower_umax;
   condition_flags[46] = !options->lower_umin;
   condition_flags[47] = options->lower_scmp;
   condition_flags[48] = options->lower_vector_cmp;
   condition_flags[49] = !options->lower_rotate;
   condition_flags[50] = options->lower_rotate;
   condition_flags[51] = options->lower_fpow;
   condition_flags[52] = !options->lower_fpow;
   condition_flags[53] = options->lower_fdiv;
   condition_flags[54] = options->lower_fsqrt;
   condition_flags[55] = !options->lower_fsqrt;
   condition_flags[56] = options->lower_sincos;
   condition_flags[57] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[58] = !options->lower_extract_byte;
   condition_flags[59] = !options->lower_extract_word;
   condition_flags[60] = options->has_pack_32_4x8;
   condition_flags[61] = options->lower_pack_64_2x32_split;
   condition_flags[62] = options->lower_pack_32_2x16_split;
   condition_flags[63] = options->lower_unpack_64_2x32_split;
   condition_flags[64] = options->lower_unpack_32_2x16_split;
   condition_flags[65] = options->has_find_msb_rev;
   condition_flags[66] = !options->lower_find_msb_to_reverse;
   condition_flags[67] = !options->lower_find_lsb;
   condition_flags[68] = options->lower_fmod;
   condition_flags[69] = options->lower_uadd_carry;
   condition_flags[70] = options->lower_usub_borrow;
   condition_flags[71] = options->lower_bitfield_insert;
   condition_flags[72] = options->lower_hadd;
   condition_flags[73] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[74] = options->lower_mul_32x16;
   condition_flags[75] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[76] = options->lower_uadd_sat;
   condition_flags[77] = options->lower_usub_sat;
   condition_flags[78] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[79] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[80] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[81] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[82] = options->lower_bitfield_insert_to_shifts;
   condition_flags[83] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[84] = options->lower_bitfield_extract;
   condition_flags[85] = options->lower_bitfield_extract_to_shifts;
   condition_flags[86] = options->lower_ifind_msb;
   condition_flags[87] = options->lower_find_msb_to_reverse;
   condition_flags[88] = options->lower_uclz;
   condition_flags[89] = options->lower_find_lsb;
   condition_flags[90] = options->lower_extract_byte;
   condition_flags[91] = options->lower_extract_word;
   condition_flags[92] = options->lower_pack_unorm_2x16;
   condition_flags[93] = options->lower_pack_unorm_4x8;
   condition_flags[94] = options->lower_pack_snorm_2x16;
   condition_flags[95] = options->lower_pack_snorm_4x8;
   condition_flags[96] = options->lower_unpack_unorm_2x16;
   condition_flags[97] = options->lower_unpack_unorm_4x8;
   condition_flags[98] = options->lower_unpack_snorm_2x16;
   condition_flags[99] = options->lower_unpack_snorm_4x8;
   condition_flags[100] = options->lower_pack_split;
   condition_flags[101] = options->lower_isign;
   condition_flags[102] = !options->lower_isign;
   condition_flags[103] = options->lower_fsign;
   condition_flags[104] = !options->has_imul24;
   condition_flags[105] = !options->has_umul24;
   condition_flags[106] = !options->has_umad24;
   condition_flags[107] = options->has_imul24;
   condition_flags[108] = options->has_umad24;
   condition_flags[109] = options->has_umul24;
   condition_flags[110] = options->lower_iadd_sat;
   condition_flags[111] = options->support_8bit_alu;
   condition_flags[112] = options->support_16bit_alu;
   condition_flags[113] = options->lower_ldexp;
   condition_flags[114] = !options->lower_bitfield_reverse;
   condition_flags[115] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[116] = options->lower_fisnormal;
   condition_flags[117] = !options->vectorize_vec2_16bit;
   condition_flags[118] = options->has_fsub;
   condition_flags[119] = options->has_fsub && !(options->lower_doubles_options & nir_lower_dsub);
   condition_flags[120] = options->lower_fneg;
   condition_flags[121] = options->has_isub || options->lower_ineg;
   condition_flags[122] = options->lower_ineg;
   condition_flags[123] = options->lower_iabs;
   condition_flags[124] = options->has_iadd3;
   condition_flags[125] = options->vectorize_vec2_16bit;
   condition_flags[126] = options->fdot_replicates;
   condition_flags[127] = options->lower_fround_even;
   condition_flags[128] = (info->stage != MESA_SHADER_VERTEX && info->stage != MESA_SHADER_GEOMETRY) && !options->intel_vec4;
   condition_flags[129] = options->avoid_ternary_with_two_constants;
   condition_flags[130] = !options->lower_insert_byte;
   condition_flags[131] = !options->lower_insert_word;
   condition_flags[132] = options->has_fused_comp_and_csel;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_distribute_src_mods_table);
      }
   }

   return progress;
}

